=encoding utf8

=head1 NAME

Locale::CLDR::Locales::Pa - Package for language Punjabi

=cut

package Locale::CLDR::Locales::Pa;
# This file auto generated from Data\common\main\pa.xml
#	on Wed 15 Jan 11:22:39 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use utf8;
use feature 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

extends('Locale::CLDR::Locales::Root');
has 'display_name_language' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub {
		 sub {
			 my %languages = (
				'aa' => 'ਅਫ਼ਾਰ',
 				'ab' => 'ਅਬਖਾਜ਼ੀਅਨ',
 				'ace' => 'ਅਚੀਨੀ',
 				'ach' => 'ਅਕੋਲੀ',
 				'ada' => 'ਅਡਾਂਗਮੇ',
 				'ady' => 'ਅਡਿਗੇ',
 				'af' => 'ਅਫ਼ਰੀਕੀ',
 				'agq' => 'ਅਗੇਮ',
 				'ain' => 'ਆਇਨੂ',
 				'ak' => 'ਅਕਾਨ',
 				'ale' => 'ਅਲੇਉਟ',
 				'alt' => 'ਦੱਖਣੀ ਅਲਤਾਈ',
 				'am' => 'ਅਮਹਾਰਿਕ',
 				'an' => 'ਅਰਾਗੋਨੀ',
 				'ang' => 'ਪੁਰਾਣੀ ਅੰਗਰੇਜ਼ੀ',
 				'ann' => 'ਓਬੋਲੋ',
 				'anp' => 'ਅੰਗਿਕਾ',
 				'apc' => 'ਸ਼ਾਮੀ ਅਰਬੀ',
 				'ar' => 'ਅਰਬੀ',
 				'ar_001' => 'ਆਧੁਨਿਕ ਮਿਆਰੀ ਅਰਬੀ',
 				'arn' => 'ਮਾਪੁਚੇ',
 				'arp' => 'ਅਰਾਫਾਓ',
 				'ars' => 'ਨਾਜਦੀ ਅਰਬੀ',
 				'as' => 'ਅਸਾਮੀ',
 				'asa' => 'ਅਸੂ',
 				'ast' => 'ਅਸਤੂਰੀ',
 				'atj' => 'ਅਤਿਕਾਮੇਕਵ',
 				'av' => 'ਅਵਾਰਿਕ',
 				'awa' => 'ਅਵਧੀ',
 				'ay' => 'ਅਈਮਾਰਾ',
 				'az' => 'ਅਜ਼ਰਬਾਈਜਾਨੀ',
 				'az@alt=short' => 'ਅਜ਼ੇਰੀ',
 				'ba' => 'ਬਸ਼ਕੀਰ',
 				'ban' => 'ਬਾਲੀਨੀਜ਼',
 				'bas' => 'ਬਾਸਾ',
 				'be' => 'ਬੇਲਾਰੂਸੀ',
 				'bem' => 'ਬੇਂਬਾ',
 				'bez' => 'ਬੇਨਾ',
 				'bg' => 'ਬੁਲਗਾਰੀਆਈ',
 				'bgc' => 'ਹਰਿਆਣਵੀ',
 				'bgn' => 'ਪੱਛਮੀ ਬਲੂਚੀ',
 				'bho' => 'ਭੋਜਪੁਰੀ',
 				'bi' => 'ਬਿਸਲਾਮਾ',
 				'bin' => 'ਬਿਨੀ',
 				'bla' => 'ਸਿਕਸਿਕਾ',
 				'blo' => 'ਅਨੀ',
 				'bm' => 'ਬੰਬਾਰਾ',
 				'bn' => 'ਬੰਗਾਲੀ',
 				'bo' => 'ਤਿੱਬਤੀ',
 				'br' => 'ਬਰੇਟਨ',
 				'brx' => 'ਬੋਡੋ',
 				'bs' => 'ਬੋਸਨੀਆਈ',
 				'bug' => 'ਬਗਨੀਜ਼',
 				'byn' => 'ਬਲਿਨ',
 				'ca' => 'ਕੈਟਾਲਾਨ',
 				'cay' => 'ਕਾਯੁਗਾ',
 				'ccp' => 'ਚਕਮਾ',
 				'ce' => 'ਚੇਚਨ',
 				'ceb' => 'ਸੀਬੂਆਨੋ',
 				'cgg' => 'ਚੀਗਾ',
 				'ch' => 'ਚਮੋਰੋ',
 				'chk' => 'ਚੂਕੀਸ',
 				'chm' => 'ਮਾਰੀ',
 				'cho' => 'ਚੌਕਟੋ',
 				'chp' => 'ਚਿਪਵਿਆਨ',
 				'chr' => 'ਚੇਰੋਕੀ',
 				'chy' => 'ਛਾਇਆਨ',
 				'ckb' => 'ਕੇਂਦਰੀ ਕੁਰਦਿਸ਼',
 				'ckb@alt=menu' => 'ਕੁਰਦਿਸ਼, ਕੇਂਦਰੀ',
 				'ckb@alt=variant' => 'ਕੁਰਦਿਸ਼, ਸੋਰਾਨੀ',
 				'clc' => 'ਚਿਲਕੋਟਿਨ',
 				'co' => 'ਕੋਰਸੀਕਨ',
 				'crg' => 'ਮਿਚਿਫੋ',
 				'crj' => 'ਦੱਖਣੀ ਪੂਰਬੀ ਕ੍ਰੀ',
 				'crk' => 'ਪਲੇਨਸ ਕ੍ਰੀ',
 				'crl' => 'ਉੱਤਰੀ ਪੂਰਬੀ ਕ੍ਰੀ',
 				'crm' => 'ਮੂਜ਼ ਕ੍ਰੀ',
 				'crr' => 'ਕੈਰੋਲੀਨਾ ਐਲਗੋਂਕਵਿਅਨ',
 				'crs' => 'ਸੇਸੇਲਵਾ ਕ੍ਰਿਓਲ ਫ੍ਰੈਂਚ',
 				'cs' => 'ਚੈੱਕ',
 				'csw' => 'ਸਵੈਂਪੀ ਕ੍ਰੀ',
 				'cu' => 'ਚਰਚ ਸਲਾਵੀ',
 				'cv' => 'ਚੁਵਾਸ਼',
 				'cy' => 'ਵੈਲਸ਼',
 				'da' => 'ਡੈਨਿਸ਼',
 				'dak' => 'ਡਕੋਟਾ',
 				'dar' => 'ਦਾਰਗਵਾ',
 				'dav' => 'ਟੇਟਾ',
 				'de' => 'ਜਰਮਨ',
 				'de_AT' => 'ਜਰਮਨ (ਆਸਟਰੀਆਈ)',
 				'de_CH' => 'ਹਾਈ ਜਰਮਨ (ਸਵਿਟਜ਼ਰਲੈਂਡ)',
 				'dgr' => 'ਡੋਗਰਿੱਬ',
 				'dje' => 'ਜ਼ਾਰਮਾ',
 				'doi' => 'ਡੋਗਰੀ',
 				'dsb' => 'ਲੋਅਰ ਸੋਰਬੀਅਨ',
 				'dua' => 'ਡੂਆਲਾ',
 				'dv' => 'ਦਿਵੇਹੀ',
 				'dyo' => 'ਜੋਲਾ-ਫੋਇਨੀ',
 				'dz' => 'ਜ਼ੋਂਗਖਾ',
 				'dzg' => 'ਡਜ਼ਾਗਾ',
 				'ebu' => 'ਇੰਬੂ',
 				'ee' => 'ਈਵਈ',
 				'efi' => 'ਐਫਿਕ',
 				'egy' => 'ਪੁਰਾਤਨ ਮਿਸਰੀ',
 				'eka' => 'ਏਕਾਜੁਕ',
 				'el' => 'ਯੂਨਾਨੀ',
 				'en' => 'ਅੰਗਰੇਜ਼ੀ',
 				'en_GB' => 'ਅੰਗਰੇਜ਼ੀ (ਬਰਤਾਨਵੀ)',
 				'en_GB@alt=short' => 'ਅੰਗਰੇਜ਼ੀ (ਯੂ.ਕੇ.)',
 				'en_US' => 'ਅੰਗਰੇਜ਼ੀ (ਅਮਰੀਕੀ)',
 				'en_US@alt=short' => 'ਅੰਗਰੇਜ਼ੀ (ਯੂ.ਐੱਸ.)',
 				'eo' => 'ਇਸਪੇਰਾਂਟੋ',
 				'es' => 'ਸਪੇਨੀ',
 				'es_419' => 'ਸਪੇਨੀ (ਲਾਤੀਨੀ ਅਮਰੀਕੀ)',
 				'es_ES' => 'ਸਪੇਨੀ (ਯੂਰਪੀ)',
 				'et' => 'ਇਸਟੋਨੀਆਈ',
 				'eu' => 'ਬਾਸਕ',
 				'ewo' => 'ਇਵੋਂਡੋ',
 				'fa' => 'ਫ਼ਾਰਸੀ',
 				'fa_AF' => 'ਦਾਰੀ',
 				'ff' => 'ਫੁਲਾਹ',
 				'fi' => 'ਫਿਨਿਸ਼',
 				'fil' => 'ਫਿਲੀਪਿਨੋ',
 				'fj' => 'ਫ਼ਿਜ਼ੀ',
 				'fo' => 'ਫ਼ੇਰੋਸੇ',
 				'fon' => 'ਫੌਨ',
 				'fr' => 'ਫਰਾਂਸੀਸੀ',
 				'fr_CA' => 'ਫਰਾਂਸੀਸੀ (ਕੈਨੇਡੀਅਨ)',
 				'frc' => 'ਕੇਜੁਨ ਫ਼੍ਰੈਂਚ',
 				'frr' => 'ਉੱਤਰੀ ਫ੍ਰੀਜ਼ੀਅਨ',
 				'fur' => 'ਫਰੀਉਲੀਅਨ',
 				'fy' => 'ਪੱਛਮੀ ਫ੍ਰਿਸੀਅਨ',
 				'ga' => 'ਆਇਰਸ਼',
 				'gaa' => 'ਗਾ',
 				'gag' => 'ਗਾਗੌਜ਼',
 				'gan' => 'ਚੀਨੀ ਗਾਨ',
 				'gd' => 'ਸਕਾਟਿਸ਼ ਗੇਲਿਕ',
 				'gez' => 'ਜੀਜ਼',
 				'gil' => 'ਗਿਲਬਰਤੀਜ਼',
 				'gl' => 'ਗੈਲਿਸ਼ਿਅਨ',
 				'gn' => 'ਗੁਆਰਾਨੀ',
 				'gor' => 'ਗੋਰੋਂਤਾਲੋ',
 				'grc' => 'ਪੁਰਾਤਨ ਯੂਨਾਨੀ',
 				'gsw' => 'ਜਰਮਨ (ਸਵਿਸ)',
 				'gu' => 'ਗੁਜਰਾਤੀ',
 				'guz' => 'ਗੁਸੀ',
 				'gv' => 'ਮੈਂਕਸ',
 				'gwi' => 'ਗਵਿਚ’ਇਨ',
 				'ha' => 'ਹੌਸਾ',
 				'hai' => 'ਹਾਇਡਾ',
 				'hak' => 'ਚੀਨੀ ਹਾਕਾ',
 				'haw' => 'ਹਵਾਈ',
 				'hax' => 'ਦੱਖਣੀ ਹਾਇਡਾ',
 				'he' => 'ਹਿਬਰੂ',
 				'hi' => 'ਹਿੰਦੀ',
 				'hi_Latn@alt=variant' => 'ਹਿੰਗਲਿਸ਼',
 				'hif' => 'ਫਿਜੀ ਹਿੰਦੀ',
 				'hil' => 'ਹਿਲੀਗੇਨਨ',
 				'hmn' => 'ਹਮੋਂਗ',
 				'hr' => 'ਕ੍ਰੋਏਸ਼ਿਆਈ',
 				'hsb' => 'ਅੱਪਰ ਸੋਰਬੀਅਨ',
 				'hsn' => 'ਚੀਨੀ ਜ਼ਿਆਂਗ',
 				'ht' => 'ਹੈਤੀਆਈ',
 				'hu' => 'ਹੰਗਰੀਆਈ',
 				'hup' => 'ਹੂਪਾ',
 				'hur' => 'ਹਾਲਕੋਮੇਲਮ',
 				'hy' => 'ਅਰਮੀਨੀਆਈ',
 				'hz' => 'ਹਰੇਰੋ',
 				'ia' => 'ਇੰਟਰਲਿੰਗੁਆ',
 				'iba' => 'ਇਬਾਨ',
 				'ibb' => 'ਇਬੀਬੀਓ',
 				'id' => 'ਇੰਡੋਨੇਸ਼ੀਆਈ',
 				'ie' => 'ਇੰਟਰਲਿੰਗੁਈ',
 				'ig' => 'ਇਗਬੋ',
 				'ii' => 'ਸਿਚੁਆਨ ਯੀ',
 				'ikt' => 'ਪੱਛਮੀ ਕੈਨੇਡੀਅਨ ਇਨੂਕਟੀਟੂਟ',
 				'ilo' => 'ਇਲੋਕੋ',
 				'inh' => 'ਇੰਗੁਸ਼',
 				'io' => 'ਇਡੂ',
 				'is' => 'ਆਈਸਲੈਂਡਿਕ',
 				'it' => 'ਇਤਾਲਵੀ',
 				'iu' => 'ਇੰਕਟੀਟੂਤ',
 				'ja' => 'ਜਪਾਨੀ',
 				'jbo' => 'ਲੋਜਬਾਨ',
 				'jgo' => 'ਨਗੋਂਬਾ',
 				'jmc' => 'ਮਚਾਮੇ',
 				'jv' => 'ਜਾਵਾਨੀਜ਼',
 				'ka' => 'ਜਾਰਜੀਆਈ',
 				'kab' => 'ਕਬਾਇਲ',
 				'kac' => 'ਕਾਚਿਨ',
 				'kaj' => 'ਜਜੂ',
 				'kam' => 'ਕੰਬਾ',
 				'kbd' => 'ਕਬਾਰਦੀ',
 				'kcg' => 'ਟਾਇਪ',
 				'kde' => 'ਮਕੋਂਡ',
 				'kea' => 'ਕਾਬੁਵੇਰਦਿਆਨੂ',
 				'kfo' => 'ਕੋਰੋ',
 				'kgp' => 'ਕੈਨਗਾਂਗੋ',
 				'kha' => 'ਖਾਸੀ',
 				'khq' => 'ਕੋਯਰਾ ਚੀਨੀ',
 				'ki' => 'ਕਿਕੂਯੂ',
 				'kj' => 'ਕੁਆਨਯਾਮਾ',
 				'kk' => 'ਕਜ਼ਾਖ਼',
 				'kkj' => 'ਕਾਕੋ',
 				'kl' => 'ਕਲਾਅੱਲੀਸੁਟ',
 				'kln' => 'ਕਲੇਜਿਨ',
 				'km' => 'ਖਮੇਰ',
 				'kmb' => 'ਕਿਮਬੁੰਦੂ',
 				'kn' => 'ਕੰਨੜ',
 				'ko' => 'ਕੋਰੀਆਈ',
 				'koi' => 'ਕੋਮੀ-ਪੇਰਮਿਆਕ',
 				'kok' => 'ਕੋਂਕਣੀ',
 				'kpe' => 'ਕਪੇਲ',
 				'kr' => 'ਕਨੂਰੀ',
 				'krc' => 'ਕਰਾਚੇ ਬਲਕਾਰ',
 				'krl' => 'ਕਰੀਲੀਅਨ',
 				'kru' => 'ਕੁਰੁਖ',
 				'ks' => 'ਕਸ਼ਮੀਰੀ',
 				'ksb' => 'ਸ਼ੰਬਾਲਾ',
 				'ksf' => 'ਬਫ਼ੀਆ',
 				'ksh' => 'ਕਲੋਨੀਅਨ',
 				'ku' => 'ਕੁਰਦਿਸ਼',
 				'kum' => 'ਕੁਮੀਕ',
 				'kv' => 'ਕੋਮੀ',
 				'kw' => 'ਕੋਰਨਿਸ਼',
 				'kwk' => 'ਕਵਾਕ’ਵਾਲਾ',
 				'kxv' => 'ਕੁਵੀ',
 				'ky' => 'ਕਿਰਗੀਜ਼',
 				'la' => 'ਲਾਤੀਨੀ',
 				'lad' => 'ਲੈਡੀਨੋ',
 				'lag' => 'ਲੰਗਾਈ',
 				'lb' => 'ਲਕਜ਼ਮਬਰਗਿਸ਼',
 				'lez' => 'ਲੈਜ਼ਗੀ',
 				'lg' => 'ਗਾਂਡਾ',
 				'li' => 'ਲਿਮਬੁਰਗੀ',
 				'lij' => 'ਲਿਗੂਰੀ',
 				'lil' => 'ਲਿਲੂਏਟ',
 				'lkt' => 'ਲਕੋਟਾ',
 				'lmo' => 'ਲੰਬਾਰਡ',
 				'ln' => 'ਲਿੰਗਾਲਾ',
 				'lo' => 'ਲਾਓ',
 				'lou' => 'ਲੇਉ',
 				'loz' => 'ਲੋਜ਼ੀ',
 				'lrc' => 'ਉੱਤਰੀ ਲੁਰੀ',
 				'lsm' => 'ਸਾਮੀਆ',
 				'lt' => 'ਲਿਥੁਆਨੀਅਨ',
 				'lu' => 'ਲੂਬਾ-ਕਾਟਾਂਗਾ',
 				'lua' => 'ਲਿਊਬਾ-ਲਿਊਲਿਆ',
 				'lun' => 'ਲੁੰਡਾ',
 				'luo' => 'ਲੂਓ',
 				'lus' => 'ਮਿਜ਼ੋ',
 				'luy' => 'ਲੂਈਆ',
 				'lv' => 'ਲਾਤੀਵੀ',
 				'mad' => 'ਮਾਡੂਰੀਸ',
 				'mag' => 'ਮਗਾਹੀ',
 				'mai' => 'ਮੈਥਲੀ',
 				'mak' => 'ਮਕਾਸਰ',
 				'mas' => 'ਮਸਾਈ',
 				'mdf' => 'ਮੋਕਸ਼ਾ',
 				'men' => 'ਮੇਂਡੇ',
 				'mer' => 'ਮੇਰੂ',
 				'mfe' => 'ਮੋਰੀਸਿਅਨ',
 				'mg' => 'ਮਾਲਾਗੈਸੀ',
 				'mgh' => 'ਮਖੋਵਾ-ਮਿੱਟੋ',
 				'mgo' => 'ਮੇਟਾ',
 				'mh' => 'ਮਾਰਸ਼ਲੀਜ਼',
 				'mi' => 'ਮਾਉਰੀ',
 				'mic' => 'ਮਾਇਮੈਕ',
 				'min' => 'ਮਿਨਾਂਗਕਾਬਾਓ',
 				'mk' => 'ਮੈਕਡੋਨੀਆਈ',
 				'ml' => 'ਮਲਿਆਲਮ',
 				'mn' => 'ਮੰਗੋਲੀ',
 				'mni' => 'ਮਨੀਪੁਰੀ',
 				'moe' => 'ਇਨੂੰ-ਏਮੁਨ',
 				'moh' => 'ਮੋਹਆਕ',
 				'mos' => 'ਮੋਸੀ',
 				'mr' => 'ਮਰਾਠੀ',
 				'ms' => 'ਮਲਯ',
 				'mt' => 'ਮਾਲਟੀਜ਼',
 				'mua' => 'ਮੁੰਡੇਂਗ',
 				'mul' => 'ਬਹੁਤੀਆਂ ਬੋਲੀਆਂ',
 				'mus' => 'ਕ੍ਰੀਕ',
 				'mwl' => 'ਮਿਰਾਂਡੀ',
 				'my' => 'ਬਰਮੀ',
 				'myv' => 'ਇਰਜ਼ੀਆ',
 				'mzn' => 'ਮੇਜ਼ੈਂਡਰਾਨੀ',
 				'na' => 'ਨਾਉਰੂ',
 				'nan' => 'ਚੀਨੀ ਮਿਨ ਨਾਨ',
 				'nap' => 'ਨਿਆਪੋਲੀਟਨ',
 				'naq' => 'ਨਾਮਾ',
 				'nb' => 'ਨਾਰਵੇਜਿਆਈ ਬੋਕਮਲ',
 				'nd' => 'ਉੱਤਰੀ ਨਡੇਬੇਲੇ',
 				'nds' => 'ਲੋ ਜਰਮਨ',
 				'nds_NL' => 'ਲੋ ਸੈਕਸਨ',
 				'ne' => 'ਨੇਪਾਲੀ',
 				'new' => 'ਨੇਵਾਰੀ',
 				'ng' => 'ਐਂਡੋਂਗਾ',
 				'nia' => 'ਨਿਆਸ',
 				'niu' => 'ਨਿਊਏਈ',
 				'nl' => 'ਡੱਚ',
 				'nl_BE' => 'ਫਲੈਮਿਸ਼',
 				'nmg' => 'ਕਵਾਸਿਓ',
 				'nn' => 'ਨਾਰਵੇਜਿਆਈ ਨਿਓਨੌਰਸਕ',
 				'nnh' => 'ਨਿਓਮਬੂਨ',
 				'no' => 'ਨਾਰਵੇਜਿਆਈ',
 				'nog' => 'ਨੋਗਾਈ',
 				'nqo' => 'ਐਂਕੋ',
 				'nr' => 'ਸਾਊਥ ਨਡੇਬੇਲੇ',
 				'nso' => 'ਉੱਤਰੀ ਸੋਥੋ',
 				'nus' => 'ਨੁਏਰ',
 				'nv' => 'ਨਵਾਜੋ',
 				'ny' => 'ਨਯਾਂਜਾ',
 				'nyn' => 'ਨਿਆਂਕੋਲੇ',
 				'oc' => 'ਓਕਸੀਟਾਨ',
 				'ojb' => 'ਉੱਤਰ-ਪੱਛਮੀ ਔਜਿਬਵਾ',
 				'ojc' => 'ਸੈਂਟਰਲ ਔਜਿਬਵਾ',
 				'ojs' => 'ਓਜੀ-ਕ੍ਰੀ',
 				'ojw' => 'ਪੱਛਮੀ ਓਜਿਬਵਾ',
 				'oka' => 'ਓਕਾਨਾਗਨ',
 				'om' => 'ਓਰੋਮੋ',
 				'or' => 'ਉੜੀਆ',
 				'os' => 'ਓਸੈਟਿਕ',
 				'pa' => 'ਪੰਜਾਬੀ',
 				'pag' => 'ਪੰਗਾਸੀਨਾਨ',
 				'pam' => 'ਪੈਂਪਾਂਗਾ',
 				'pap' => 'ਪਾਪਿਆਮੈਂਟੋ',
 				'pau' => 'ਪਲਾਊਵੀ',
 				'pcm' => 'ਨਾਇਜੀਰੀਆਈ ਪਿਡਗਿਨ',
 				'pi' => 'ਪਾਲੀ',
 				'pis' => 'ਪਿਜਿਨ',
 				'pl' => 'ਪੋਲੈਂਡੀ',
 				'pqm' => 'ਮਾਲੀਸੇਟ-ਪਾਸਾਮਾਕਵੋਡੀ',
 				'prg' => 'ਪਰੂਸ਼ੀਆ',
 				'ps' => 'ਪਸ਼ਤੋ',
 				'pt' => 'ਪੁਰਤਗਾਲੀ',
 				'pt_BR' => 'ਪੁਰਤਗਾਲੀ (ਬ੍ਰਾਜ਼ੀਲੀ)',
 				'pt_PT' => 'ਪੁਰਤਗਾਲੀ (ਯੂਰਪੀ)',
 				'qu' => 'ਕਕੇਸ਼ੁਆ',
 				'quc' => 'ਕੇਸ਼',
 				'raj' => 'ਰਾਜਸਥਾਨੀ',
 				'rap' => 'ਰਾਪਾਨੁਈ',
 				'rar' => 'ਰਾਰੋਤੋਂਗਨ',
 				'rhg' => 'ਰੋਹਿੰਗਿਆ',
 				'rm' => 'ਰੋਮਾਂਸ਼',
 				'rn' => 'ਰੁੰਡੀ',
 				'ro' => 'ਰੋਮਾਨੀਆਈ',
 				'ro_MD' => 'ਮੋਲਡਾਵੀਆਈ',
 				'rof' => 'ਰੋਮਬੋ',
 				'ru' => 'ਰੂਸੀ',
 				'rup' => 'ਅਰੋਮੀਨੀਆਈ',
 				'rw' => 'ਕਿਨਿਆਰਵਾਂਡਾ',
 				'rwk' => 'ਰਵਾ',
 				'sa' => 'ਸੰਸਕ੍ਰਿਤ',
 				'sad' => 'ਸਾਂਡੋ',
 				'sah' => 'ਸਾਖਾ',
 				'saq' => 'ਸਮਬੁਰੂ',
 				'sat' => 'ਸੰਥਾਲੀ',
 				'sba' => 'ਨਗਾਂਬੇ',
 				'sbp' => 'ਸੇਂਗੋ',
 				'sc' => 'ਸਾਰਡੀਨੀਆਈ',
 				'scn' => 'ਸਿਸੀਲੀਅਨ',
 				'sco' => 'ਸਕਾਟਸ',
 				'sd' => 'ਸਿੰਧੀ',
 				'sdh' => 'ਦੱਖਣੀ ਕੁਰਦਿਸ਼',
 				'se' => 'ਉੱਤਰੀ ਸਾਮੀ',
 				'seh' => 'ਸੇਨਾ',
 				'ses' => 'ਕੋਇਰਾਬੋਰੋ ਸੇਂਨੀ',
 				'sg' => 'ਸਾਂਗੋ',
 				'shi' => 'ਟਚੇਲਹਿਟ',
 				'shn' => 'ਸ਼ਾਨ',
 				'si' => 'ਸਿੰਹਾਲਾ',
 				'sk' => 'ਸਲੋਵਾਕ',
 				'sl' => 'ਸਲੋਵੇਨੀਆਈ',
 				'slh' => 'ਦੱਖਣੀ ਲੁਸ਼ੂਟਸੀਡ',
 				'sm' => 'ਸਾਮੋਨ',
 				'sma' => 'ਦੱਖਣੀ ਸਾਮੀ',
 				'smj' => 'ਲਿਊਲ ਸਾਮੀ',
 				'smn' => 'ਇਨਾਰੀ ਸਾਮੀ',
 				'sms' => 'ਸਕੌਲਟ ਸਾਮੀ',
 				'sn' => 'ਸ਼ੋਨਾ',
 				'snk' => 'ਸੋਨਿੰਕੇ',
 				'so' => 'ਸੋਮਾਲੀ',
 				'sq' => 'ਅਲਬਾਨੀਆਈ',
 				'sr' => 'ਸਰਬੀਆਈ',
 				'srn' => 'ਸ੍ਰਾਨਾਨ ਟੋਂਗੋ',
 				'ss' => 'ਸਵਾਤੀ',
 				'ssy' => 'ਸਾਹੋ',
 				'st' => 'ਦੱਖਣੀ ਸੋਥੋ',
 				'str' => 'ਸਟਰੇਟਸ ਸੈਲਿਸ਼',
 				'su' => 'ਸੂੰਡਾਨੀ',
 				'suk' => 'ਸੁਕੁਮਾ',
 				'sv' => 'ਸਵੀਡਿਸ਼',
 				'sw' => 'ਸਵਾਹਿਲੀ',
 				'sw_CD' => 'ਕਾਂਗੋ ਸਵਾਇਲੀ',
 				'swb' => 'ਕੋਮੋਰੀਅਨ',
 				'syr' => 'ਸੀਰੀਆਈ',
 				'szl' => 'ਸਿਲੇਸੀਅਨ',
 				'ta' => 'ਤਮਿਲ',
 				'tce' => 'ਦੱਖਣੀ ਟਚੋਨ',
 				'te' => 'ਤੇਲਗੂ',
 				'tem' => 'ਟਿਮਨੇ',
 				'teo' => 'ਟੇਸੋ',
 				'tet' => 'ਟੇਟਮ',
 				'tg' => 'ਤਾਜਿਕ',
 				'tgx' => 'ਟੈਗਿਸ਼',
 				'th' => 'ਥਾਈ',
 				'tht' => 'ਤਹਿਲਟਨ',
 				'ti' => 'ਤਿਗ੍ਰੀਨਿਆ',
 				'tig' => 'ਟਿਗਰਾ',
 				'tk' => 'ਤੁਰਕਮੇਨ',
 				'tlh' => 'ਕਲਿੰਗਨ',
 				'tli' => 'ਟਲਿੰਗਿਟ',
 				'tn' => 'ਤਸਵਾਨਾ',
 				'to' => 'ਟੌਂਗਨ',
 				'tok' => 'ਤੋਕੀ ਪੋਨਾ',
 				'tpi' => 'ਟੋਕ ਪਿਸਿਨ',
 				'tr' => 'ਤੁਰਕੀ',
 				'trv' => 'ਟਾਰੋਕੋ',
 				'ts' => 'ਸੋਂਗਾ',
 				'tt' => 'ਤਤਾਰ',
 				'ttm' => 'ਉੱਤਰੀ ਟਚੋਨ',
 				'tum' => 'ਤੁੰਬੁਕਾ',
 				'tvl' => 'ਟਿਊਵਾਲੂ',
 				'tw' => 'ਤ੍ਵਿ',
 				'twq' => 'ਤਾਸਾਵਿਕ',
 				'ty' => 'ਤਾਹੀਟੀ',
 				'tyv' => 'ਤੁਵੀਨੀਅਨ',
 				'tzm' => 'ਮੱਧ ਐਟਲਸ ਤਮਾਜ਼ਿਤ',
 				'udm' => 'ਉਦਮੁਰਤ',
 				'ug' => 'ਉਇਗੁਰ',
 				'uk' => 'ਯੂਕਰੇਨੀਆਈ',
 				'umb' => 'ਉਮਬੁੰਡੂ',
 				'und' => 'ਅਣਪਛਾਤੀ ਬੋਲੀ',
 				'ur' => 'ਉਰਦੂ',
 				'uz' => 'ਉਜ਼ਬੇਕ',
 				'vai' => 'ਵਾਈ',
 				've' => 'ਵੇਂਡਾ',
 				'vec' => 'ਵੇਨੇਸ਼ੀਅਨ',
 				'vi' => 'ਵੀਅਤਨਾਮੀ',
 				'vmw' => 'ਮਖੂਵਾ',
 				'vo' => 'ਵੋਲਾਪੂਕ',
 				'vun' => 'ਵੂੰਜੋ',
 				'wa' => 'ਵਲੂਨ',
 				'wae' => 'ਵਾਲਸਰ',
 				'wal' => 'ਵੋਲਾਏਟਾ',
 				'war' => 'ਵੈਰੇ',
 				'wbp' => 'ਵਾਲਪੁਰੀ',
 				'wo' => 'ਵੋਲੋਫ',
 				'wuu' => 'ਚੀਨੀ ਵੂ',
 				'xal' => 'ਕਾਲਮਿਕ',
 				'xh' => 'ਖੋਸਾ',
 				'xnr' => 'ਕਾਂਗੜੀ',
 				'xog' => 'ਸੋਗਾ',
 				'yav' => 'ਯਾਂਗਬੇਨ',
 				'ybb' => 'ਯੇਂਬਾ',
 				'yi' => 'ਯਿਦਿਸ਼',
 				'yo' => 'ਯੋਰੂਬਾ',
 				'yrl' => 'ਨਹੀਂਗਾਤੂ',
 				'yue' => 'ਕੈਂਟੋਨੀਜ਼',
 				'yue@alt=menu' => 'ਚੀਨੀ, ਕੈਂਟੋਨੀਜ਼',
 				'za' => 'ਜ਼ੁਆਂਗ',
 				'zgh' => 'ਮਿਆਰੀ ਮੋਰੋਕੇਨ ਟਾਮਾਜ਼ਿਕ',
 				'zh' => 'ਚੀਨੀ',
 				'zh@alt=menu' => 'ਚੀਨੀ, ਮੈਂਡਰਿਨ',
 				'zh_Hans@alt=long' => 'ਚੀਨੀ ਮੈਂਡਰਿਨ (ਸਰਲ)',
 				'zh_Hant@alt=long' => 'ਚੀਨੀ ਮੈਂਡਰਿਨ (ਰਵਾਇਤੀ)',
 				'zu' => 'ਜ਼ੁਲੂ',
 				'zun' => 'ਜ਼ੂਨੀ',
 				'zxx' => 'ਬੋਲੀ ਸੰਬੰਧੀ ਕੋਈ ਸਮੱਗਰੀ ਨਹੀਂ',
 				'zza' => 'ਜ਼ਾਜ਼ਾ',

			);
			if (@_) {
				return $languages{$_[0]};
			}
			return \%languages;
		}
	},
);

has 'display_name_script' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub {
		sub {
			my %scripts = (
			'Adlm' => 'ਅਦਲਾਮ',
 			'Arab' => 'ਅਰਬੀ',
 			'Aran' => 'ਨਸਤਾਲੀਕ',
 			'Armn' => 'ਅਰਮੀਨੀਆਈ',
 			'Bali' => 'ਬਾਲਿਨੀ',
 			'Beng' => 'ਬੰਗਾਲੀ',
 			'Bopo' => 'ਬੋਪੋਮੋਫੋ',
 			'Brah' => 'ਬਰਾਹਮੀ',
 			'Brai' => 'ਬਰੇਲ',
 			'Cakm' => 'ਚਕਮਾ',
 			'Cans' => 'ਯੂਨੀਫਾਈਡ ਕੈਨੇਡੀਅਨ ਐਬੋਰਿਜਿਨਲ ਸਿਲੇਬਿਕਸ',
 			'Cher' => 'ਚੈਰੋਕੀ',
 			'Cyrl' => 'ਸਿਰਿਲਿਕ',
 			'Deva' => 'ਦੇਵਨਾਗਰੀ',
 			'Dogr' => 'ਡੋਗਰਾ',
 			'Ethi' => 'ਇਥੀਓਪਿਕ',
 			'Geor' => 'ਜਾਰਜੀਆਈ',
 			'Grek' => 'ਯੂਨਾਨੀ',
 			'Gujr' => 'ਗੁਜਰਾਤੀ',
 			'Guru' => 'ਗੁਰਮੁਖੀ',
 			'Hanb' => 'ਹਾਂਬ',
 			'Hang' => 'ਹੰਗੁਲ',
 			'Hani' => 'ਹਾਨ',
 			'Hans' => 'ਸਰਲ',
 			'Hans@alt=stand-alone' => 'ਸਰਲ ਹਾਨ',
 			'Hant' => 'ਰਵਾਇਤੀ',
 			'Hant@alt=stand-alone' => 'ਰਵਾਇਤੀ ਹਾਨ',
 			'Hebr' => 'ਹਿਬਰੂ',
 			'Hira' => 'ਹਿਰਾਗਾਨਾ',
 			'Hrkt' => 'ਜਾਪਾਨੀ ਸਿਲੇਬਰੀਜ਼',
 			'Jamo' => 'ਜਾਮੋ',
 			'Jpan' => 'ਜਪਾਨੀ',
 			'Kana' => 'ਕਾਟਾਕਾਨਾ',
 			'Khmr' => 'ਖਮੇਰ',
 			'Knda' => 'ਕੰਨੜ',
 			'Kore' => 'ਕੋਰੀਆਈ',
 			'Laoo' => 'ਲਾਓ',
 			'Latn' => 'ਲਾਤੀਨੀ',
 			'Mlym' => 'ਮਲਿਆਲਮ',
 			'Mong' => 'ਮੰਗੋਲੀਅਨ',
 			'Mtei' => 'ਮਿਤੇਈ ਮਾਏਕ',
 			'Mymr' => 'ਮਿਆਂਮਾਰ',
 			'Nkoo' => 'ਐਨ’ਕੋ',
 			'Olck' => 'ਓਲ ਚੀਕੀ',
 			'Orya' => 'ਉੜੀਆ',
 			'Rohg' => 'ਹਨੀਫੀ',
 			'Sinh' => 'ਸਿੰਹਾਲਾ',
 			'Sund' => 'ਸੂੰਡਾਨੀ',
 			'Syrc' => 'ਸੀਰੀਆਈ',
 			'Taml' => 'ਤਮਿਲ',
 			'Telu' => 'ਤੇਲਗੂ',
 			'Tfng' => 'ਟਿਫੀਨਾਘ',
 			'Thaa' => 'ਥਾਨਾ',
 			'Thai' => 'ਥਾਈ',
 			'Tibt' => 'ਤਿੱਬਤੀ',
 			'Vaii' => 'ਵਾਈ',
 			'Yiii' => 'ਯੀ',
 			'Zinh' => 'ਵਿਰਸੇ ਵਿਚ ਹੋਇਆ',
 			'Zmth' => 'ਗਣਿਤ ਚਿੰਨ੍ਹ-ਲਿਪੀ',
 			'Zsye' => 'ਇਮੋਜੀ',
 			'Zsym' => 'ਚਿੰਨ੍ਹ',
 			'Zxxx' => 'ਅਲਿਖਤ',
 			'Zyyy' => 'ਸਧਾਰਨ',
 			'Zzzz' => 'ਅਣਪਛਾਤੀ ਲਿਪੀ',

			);
			if ( @_ ) {
				return $scripts{$_[0]};
			}
			return \%scripts;
		}
	}
);

has 'display_name_region' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'001' => 'ਸੰਸਾਰ',
 			'002' => 'ਅਫ਼ਰੀਕਾ',
 			'003' => 'ਉੱਤਰ ਅਮਰੀਕਾ',
 			'005' => 'ਦੱਖਣ ਅਮਰੀਕਾ',
 			'009' => 'ਓਸ਼ੇਨੀਆ',
 			'011' => 'ਪੱਛਮੀ ਅਫ਼ਰੀਕਾ',
 			'013' => 'ਕੇਂਦਰੀ ਅਮਰੀਕਾ',
 			'014' => 'ਪੂਰਬੀ ਅਫ਼ਰੀਕਾ',
 			'015' => 'ਉੱਤਰੀ ਅਫ਼ਰੀਕਾ',
 			'017' => 'ਮੱਧ ਅਫ਼ਰੀਕਾ',
 			'018' => 'ਦੱਖਣੀ ਅਫ਼ਰੀਕਾ',
 			'019' => 'ਅਮਰੀਕਾ',
 			'021' => 'ਉੱਤਰੀ ਅਮਰੀਕਾ',
 			'029' => 'ਕੈਰੇਬੀਆਈ',
 			'030' => 'ਪੂਰਬੀ ਏਸ਼ੀਆ',
 			'034' => 'ਦੱਖਣੀ ਏਸ਼ੀਆ',
 			'035' => 'ਦੱਖਣ-ਪੂਰਬੀ ਏਸ਼ੀਆ',
 			'039' => 'ਦੱਖਣੀ ਯੂਰਪ',
 			'053' => 'ਆਸਟਰੇਲੇਸ਼ੀਆ',
 			'054' => 'ਮੇਲਾਨੇਸ਼ੀਆ',
 			'057' => 'ਮਾਇਕ੍ਰੋਨੇਸ਼ੀਆਈ ਇਲਾਕਾ',
 			'061' => 'ਪੋਲੀਨੇਸ਼ੀਆ',
 			'142' => 'ਏਸ਼ੀਆ',
 			'143' => 'ਕੇਂਦਰੀ ਏਸ਼ੀਆ',
 			'145' => 'ਪੱਛਮੀ ਏਸ਼ੀਆ',
 			'150' => 'ਯੂਰਪ',
 			'151' => 'ਪੂਰਬੀ ਯੂਰਪ',
 			'154' => 'ਉੱਤਰੀ ਯੂਰਪ',
 			'155' => 'ਪੱਛਮੀ ਯੂਰਪ',
 			'202' => 'ਉਪ-ਸਹਾਰਾ ਅਫ਼ਰੀਕਾ',
 			'419' => 'ਲਾਤੀਨੀ ਅਮਰੀਕਾ',
 			'AC' => 'ਅਸੈਂਸ਼ਨ ਟਾਪੂ',
 			'AD' => 'ਅੰਡੋਰਾ',
 			'AE' => 'ਸੰਯੁਕਤ ਅਰਬ ਅਮੀਰਾਤ',
 			'AF' => 'ਅਫ਼ਗਾਨਿਸਤਾਨ',
 			'AG' => 'ਐਂਟੀਗੁਆ ਅਤੇ ਬਾਰਬੁਡਾ',
 			'AI' => 'ਅੰਗੁਇਲਾ',
 			'AL' => 'ਅਲਬਾਨੀਆ',
 			'AM' => 'ਅਰਮੀਨੀਆ',
 			'AO' => 'ਅੰਗੋਲਾ',
 			'AQ' => 'ਅੰਟਾਰਕਟਿਕਾ',
 			'AR' => 'ਅਰਜਨਟੀਨਾ',
 			'AS' => 'ਅਮੈਰੀਕਨ ਸਮੋਆ',
 			'AT' => 'ਆਸਟਰੀਆ',
 			'AU' => 'ਆਸਟ੍ਰੇਲੀਆ',
 			'AW' => 'ਅਰੂਬਾ',
 			'AX' => 'ਅਲੈਂਡ ਟਾਪੂ',
 			'AZ' => 'ਅਜ਼ਰਬਾਈਜਾਨ',
 			'BA' => 'ਬੋਸਨੀਆ ਅਤੇ ਹਰਜ਼ੇਗੋਵੀਨਾ',
 			'BB' => 'ਬਾਰਬਾਡੋਸ',
 			'BD' => 'ਬੰਗਲਾਦੇਸ਼',
 			'BE' => 'ਬੈਲਜੀਅਮ',
 			'BF' => 'ਬੁਰਕੀਨਾ ਫ਼ਾਸੋ',
 			'BG' => 'ਬੁਲਗਾਰੀਆ',
 			'BH' => 'ਬਹਿਰੀਨ',
 			'BI' => 'ਬੁਰੁੰਡੀ',
 			'BJ' => 'ਬੇਨਿਨ',
 			'BL' => 'ਸੇਂਟ ਬਾਰਥੇਲੇਮੀ',
 			'BM' => 'ਬਰਮੂਡਾ',
 			'BN' => 'ਬਰੂਨੇਈ',
 			'BO' => 'ਬੋਲੀਵੀਆ',
 			'BQ' => 'ਕੈਰੇਬੀਆਈ ਨੀਦਰਲੈਂਡ',
 			'BR' => 'ਬ੍ਰਾਜ਼ੀਲ',
 			'BS' => 'ਬਹਾਮਾਸ',
 			'BT' => 'ਭੂਟਾਨ',
 			'BV' => 'ਬੌਵੇਟ ਟਾਪੂ',
 			'BW' => 'ਬੋਤਸਵਾਨਾ',
 			'BY' => 'ਬੇਲਾਰੂਸ',
 			'BZ' => 'ਬੇਲੀਜ਼',
 			'CA' => 'ਕੈਨੇਡਾ',
 			'CC' => 'ਕੋਕੋਸ (ਕੀਲਿੰਗ) ਟਾਪੂ',
 			'CD' => 'ਕਾਂਗੋ - ਕਿੰਸ਼ਾਸਾ',
 			'CD@alt=variant' => 'ਕਾਂਗੋ (ਡੀਆਰਸੀ)',
 			'CF' => 'ਕੇਂਦਰੀ ਅਫ਼ਰੀਕੀ ਗਣਰਾਜ',
 			'CG' => 'ਕਾਂਗੋ - ਬ੍ਰਾਜ਼ਾਵਿਲੇ',
 			'CG@alt=variant' => 'ਕਾਂਗੋ ਗਣਰਾਜ',
 			'CH' => 'ਸਵਿਟਜ਼ਰਲੈਂਡ',
 			'CI' => 'ਕੋਟ ਡੀਵੋਆਰ',
 			'CI@alt=variant' => 'ਆਇਵਰੀ ਕੋਸਟ',
 			'CK' => 'ਕੁੱਕ ਟਾਪੂ',
 			'CL' => 'ਚਿਲੀ',
 			'CM' => 'ਕੈਮਰੂਨ',
 			'CN' => 'ਚੀਨ',
 			'CO' => 'ਕੋਲੰਬੀਆ',
 			'CP' => 'ਕਲਿੱਪਰਟਨ ਟਾਪੂ',
 			'CR' => 'ਕੋਸਟਾ ਰੀਕਾ',
 			'CU' => 'ਕਿਊਬਾ',
 			'CV' => 'ਕੇਪ ਵਰਡੇ',
 			'CW' => 'ਕੁਰਾਕਾਓ',
 			'CX' => 'ਕ੍ਰਿਸਮਿਸ ਟਾਪੂ',
 			'CY' => 'ਸਾਇਪ੍ਰਸ',
 			'CZ' => 'ਚੈਕੀਆ',
 			'CZ@alt=variant' => 'ਚੈੱਕ ਗਣਰਾਜ',
 			'DE' => 'ਜਰਮਨੀ',
 			'DG' => 'ਡੀਇਗੋ ਗਾਰਸੀਆ',
 			'DJ' => 'ਜਿਬੂਤੀ',
 			'DK' => 'ਡੈਨਮਾਰਕ',
 			'DM' => 'ਡੋਮੀਨਿਕਾ',
 			'DO' => 'ਡੋਮੀਨਿਕਾਈ ਗਣਰਾਜ',
 			'DZ' => 'ਅਲਜੀਰੀਆ',
 			'EA' => 'ਸਿਓਟਾ ਅਤੇ ਮੇਲਿੱਲਾ',
 			'EC' => 'ਇਕਵੇਡੋਰ',
 			'EE' => 'ਇਸਟੋਨੀਆ',
 			'EG' => 'ਮਿਸਰ',
 			'EH' => 'ਪੱਛਮੀ ਸਹਾਰਾ',
 			'ER' => 'ਇਰੀਟ੍ਰਿਆ',
 			'ES' => 'ਸਪੇਨ',
 			'ET' => 'ਇਥੋਪੀਆ',
 			'EU' => 'ਯੂਰਪੀ ਸੰਘ',
 			'EZ' => 'ਯੂਰੋਜ਼ੋਨ',
 			'FI' => 'ਫਿਨਲੈਂਡ',
 			'FJ' => 'ਫ਼ਿਜੀ',
 			'FK' => 'ਫ਼ਾਕਲੈਂਡ ਟਾਪੂ',
 			'FK@alt=variant' => 'ਫ਼ਾਕਲੈਂਡ ਟਾਪੂ (ਆਈਲਾਸ ਮਾਲਵਿਨਾਸ)',
 			'FM' => 'ਮਾਇਕ੍ਰੋਨੇਸ਼ੀਆ',
 			'FO' => 'ਫੈਰੋ ਟਾਪੂ',
 			'FR' => 'ਫ਼ਰਾਂਸ',
 			'GA' => 'ਗਬੋਨ',
 			'GB' => 'ਯੂਨਾਈਟਡ ਕਿੰਗਡਮ',
 			'GB@alt=short' => 'ਯੂ.ਕੇ.',
 			'GD' => 'ਗ੍ਰੇਨਾਡਾ',
 			'GE' => 'ਜਾਰਜੀਆ',
 			'GF' => 'ਫਰੈਂਚ ਗੁਇਆਨਾ',
 			'GG' => 'ਗਰਨਜੀ',
 			'GH' => 'ਘਾਨਾ',
 			'GI' => 'ਜਿਬਰਾਲਟਰ',
 			'GL' => 'ਗ੍ਰੀਨਲੈਂਡ',
 			'GM' => 'ਗੈਂਬੀਆ',
 			'GN' => 'ਗਿਨੀ',
 			'GP' => 'ਗੁਆਡੇਲੋਪ',
 			'GQ' => 'ਭੂ-ਖੰਡੀ ਗਿਨੀ',
 			'GR' => 'ਗ੍ਰੀਸ',
 			'GS' => 'ਦੱਖਣੀ ਜਾਰਜੀਆ ਅਤੇ ਦੱਖਣੀ ਸੈਂਡਵਿਚ ਟਾਪੂ',
 			'GT' => 'ਗੁਆਟੇਮਾਲਾ',
 			'GU' => 'ਗੁਆਮ',
 			'GW' => 'ਗਿਨੀ-ਬਿਸਾਉ',
 			'GY' => 'ਗੁਯਾਨਾ',
 			'HK' => 'ਹਾਂਗ ਕਾਂਗ ਐਸਏਆਰ ਚੀਨ',
 			'HK@alt=short' => 'ਹਾਂਗ ਕਾਂਗ',
 			'HM' => 'ਹਰਡ ਤੇ ਮੈਕਡੋਨਾਲਡ ਟਾਪੂ',
 			'HN' => 'ਹੋਂਡੁਰਸ',
 			'HR' => 'ਕਰੋਏਸ਼ੀਆ',
 			'HT' => 'ਹੈਤੀ',
 			'HU' => 'ਹੰਗਰੀ',
 			'IC' => 'ਕੇਨਾਰੀ ਟਾਪੂ',
 			'ID' => 'ਇੰਡੋਨੇਸ਼ੀਆ',
 			'IE' => 'ਆਇਰਲੈਂਡ',
 			'IL' => 'ਇਜ਼ਰਾਈਲ',
 			'IM' => 'ਆਇਲ ਆਫ ਮੈਨ',
 			'IN' => 'ਭਾਰਤ',
 			'IO' => 'ਬਰਤਾਨਵੀ ਹਿੰਦ ਮਹਾਂਸਾਗਰ ਖਿੱਤਾ',
 			'IO@alt=chagos' => 'ਚਗੋਸ ਟਾਪੂ',
 			'IQ' => 'ਇਰਾਕ',
 			'IR' => 'ਈਰਾਨ',
 			'IS' => 'ਆਈਸਲੈਂਡ',
 			'IT' => 'ਇਟਲੀ',
 			'JE' => 'ਜਰਸੀ',
 			'JM' => 'ਜਮਾਇਕਾ',
 			'JO' => 'ਜਾਰਡਨ',
 			'JP' => 'ਜਪਾਨ',
 			'KE' => 'ਕੀਨੀਆ',
 			'KG' => 'ਕਿਰਗਿਜ਼ਸਤਾਨ',
 			'KH' => 'ਕੰਬੋਡੀਆ',
 			'KI' => 'ਕਿਰਬਾਤੀ',
 			'KM' => 'ਕੋਮੋਰੋਸ',
 			'KN' => 'ਸੇਂਟ ਕਿਟਸ ਐਂਡ ਨੇਵਿਸ',
 			'KP' => 'ਉੱਤਰ ਕੋਰੀਆ',
 			'KR' => 'ਦੱਖਣ ਕੋਰੀਆ',
 			'KW' => 'ਕੁਵੈਤ',
 			'KY' => 'ਕੇਮੈਨ ਟਾਪੂ',
 			'KZ' => 'ਕਜ਼ਾਖਸਤਾਨ',
 			'LA' => 'ਲਾਓਸ',
 			'LB' => 'ਲੈਬਨਾਨ',
 			'LC' => 'ਸੇਂਟ ਲੂਸੀਆ',
 			'LI' => 'ਲਿਚੇਂਸਟਾਇਨ',
 			'LK' => 'ਸ੍ਰੀ ਲੰਕਾ',
 			'LR' => 'ਲਾਈਬੀਰੀਆ',
 			'LS' => 'ਲੇਸੋਥੋ',
 			'LT' => 'ਲਿਥੁਆਨੀਆ',
 			'LU' => 'ਲਕਜ਼ਮਬਰਗ',
 			'LV' => 'ਲਾਤਵੀਆ',
 			'LY' => 'ਲੀਬੀਆ',
 			'MA' => 'ਮੋਰੱਕੋ',
 			'MC' => 'ਮੋਨਾਕੋ',
 			'MD' => 'ਮੋਲਡੋਵਾ',
 			'ME' => 'ਮੋਂਟੇਨੇਗਰੋ',
 			'MF' => 'ਸੇਂਟ ਮਾਰਟਿਨ',
 			'MG' => 'ਮੈਡਾਗਾਸਕਰ',
 			'MH' => 'ਮਾਰਸ਼ਲ ਟਾਪੂ',
 			'MK' => 'ਉੱਤਰੀ ਮੈਕਡੋਨੀਆ',
 			'ML' => 'ਮਾਲੀ',
 			'MM' => 'ਮਿਆਂਮਾਰ (ਬਰਮਾ)',
 			'MN' => 'ਮੰਗੋਲੀਆ',
 			'MO' => 'ਮਕਾਉ ਐਸਏਆਰ ਚੀਨ',
 			'MO@alt=short' => 'ਮਕਾਉ',
 			'MP' => 'ਉੱਤਰੀ ਮਾਰੀਆਨਾ ਟਾਪੂ',
 			'MQ' => 'ਮਾਰਟੀਨਿਕ',
 			'MR' => 'ਮੋਰਿਟਾਨੀਆ',
 			'MS' => 'ਮੋਂਟਸੇਰਾਤ',
 			'MT' => 'ਮਾਲਟਾ',
 			'MU' => 'ਮੌਰੀਸ਼ਸ',
 			'MV' => 'ਮਾਲਦੀਵ',
 			'MW' => 'ਮਲਾਵੀ',
 			'MX' => 'ਮੈਕਸੀਕੋ',
 			'MY' => 'ਮਲੇਸ਼ੀਆ',
 			'MZ' => 'ਮੋਜ਼ਾਮਬੀਕ',
 			'NA' => 'ਨਾਮੀਬੀਆ',
 			'NC' => 'ਨਿਊ ਕੈਲੇਡੋਨੀਆ',
 			'NE' => 'ਨਾਈਜਰ',
 			'NF' => 'ਨੋਰਫੌਕ ਟਾਪੂ',
 			'NG' => 'ਨਾਈਜੀਰੀਆ',
 			'NI' => 'ਨਿਕਾਰਾਗੁਆ',
 			'NL' => 'ਨੀਦਰਲੈਂਡ',
 			'NO' => 'ਨਾਰਵੇ',
 			'NP' => 'ਨੇਪਾਲ',
 			'NR' => 'ਨਾਉਰੂ',
 			'NU' => 'ਨਿਯੂ',
 			'NZ' => 'ਨਿਊਜ਼ੀਲੈਂਡ',
 			'NZ@alt=variant' => 'ਐਓਟੇਰੋਆ ਨਿਊਜ਼ੀਲੈਂਡ',
 			'OM' => 'ਓਮਾਨ',
 			'PA' => 'ਪਨਾਮਾ',
 			'PE' => 'ਪੇਰੂ',
 			'PF' => 'ਫਰੈਂਚ ਪੋਲੀਨੇਸ਼ੀਆ',
 			'PG' => 'ਪਾਪੂਆ ਨਿਊ ਗਿਨੀ',
 			'PH' => 'ਫਿਲੀਪੀਨਜ',
 			'PK' => 'ਪਾਕਿਸਤਾਨ',
 			'PL' => 'ਪੋਲੈਂਡ',
 			'PM' => 'ਸੇਂਟ ਪੀਅਰੇ ਐਂਡ ਮਿਕੇਲਨ',
 			'PN' => 'ਪਿਟਕੇਰਨ ਟਾਪੂ',
 			'PR' => 'ਪਿਊਰਟੋ ਰਿਕੋ',
 			'PS' => 'ਫਿਲੀਸਤੀਨੀ ਇਲਾਕਾ',
 			'PS@alt=short' => 'ਫਿਲੀਸਤੀਨ',
 			'PT' => 'ਪੁਰਤਗਾਲ',
 			'PW' => 'ਪਲਾਉ',
 			'PY' => 'ਪੈਰਾਗਵੇ',
 			'QA' => 'ਕਤਰ',
 			'QO' => 'ਆਊਟਲਾਇੰਗ ਓਸ਼ੀਨੀਆ',
 			'RE' => 'ਰਿਯੂਨੀਅਨ',
 			'RO' => 'ਰੋਮਾਨੀਆ',
 			'RS' => 'ਸਰਬੀਆ',
 			'RU' => 'ਰੂਸ',
 			'RW' => 'ਰਵਾਂਡਾ',
 			'SA' => 'ਸਾਊਦੀ ਅਰਬ',
 			'SB' => 'ਸੋਲੋਮਨ ਟਾਪੂ',
 			'SC' => 'ਸੇਸ਼ਲਸ',
 			'SD' => 'ਸੂਡਾਨ',
 			'SE' => 'ਸਵੀਡਨ',
 			'SG' => 'ਸਿੰਗਾਪੁਰ',
 			'SH' => 'ਸੇਂਟ ਹੇਲੇਨਾ',
 			'SI' => 'ਸਲੋਵੇਨੀਆ',
 			'SJ' => 'ਸਵਾਲਬਰਡ ਅਤੇ ਜਾਨ ਮਾਯੇਨ',
 			'SK' => 'ਸਲੋਵਾਕੀਆ',
 			'SL' => 'ਸਿਏਰਾ ਲਿਓਨ',
 			'SM' => 'ਸੈਨ ਮਰੀਨੋ',
 			'SN' => 'ਸੇਨੇਗਲ',
 			'SO' => 'ਸੋਮਾਲੀਆ',
 			'SR' => 'ਸੂਰੀਨਾਮ',
 			'SS' => 'ਦੱਖਣ ਸੁਡਾਨ',
 			'ST' => 'ਸਾਓ ਟੋਮ ਅਤੇ ਪ੍ਰਿੰਸੀਪੇ',
 			'SV' => 'ਅਲ ਸਲਵਾਡੋਰ',
 			'SX' => 'ਸਿੰਟ ਮਾਰਟੀਨ',
 			'SY' => 'ਸੀਰੀਆ',
 			'SZ' => 'ਇਸਵਾਤੀਨੀ',
 			'SZ@alt=variant' => 'ਸਵਾਜ਼ੀਲੈਂਡ',
 			'TA' => 'ਟ੍ਰਿਸਟਾਨ ਦਾ ਕੁੰਹਾ',
 			'TC' => 'ਟੁਰਕਸ ਅਤੇ ਕੈਕੋਸ ਟਾਪੂ',
 			'TD' => 'ਚਾਡ',
 			'TF' => 'ਫਰੈਂਚ ਦੱਖਣੀ ਪ੍ਰਦੇਸ਼',
 			'TG' => 'ਟੋਗੋ',
 			'TH' => 'ਥਾਈਲੈਂਡ',
 			'TJ' => 'ਤਾਜਿਕਿਸਤਾਨ',
 			'TK' => 'ਟੋਕੇਲਾਉ',
 			'TL' => 'ਤਿਮੋਰ-ਲੇਸਤੇ',
 			'TL@alt=variant' => 'ਪੂਰਬ ਤਿਮੋਰ',
 			'TM' => 'ਤੁਰਕਮੇਨਿਸਤਾਨ',
 			'TN' => 'ਟਿਊਨੀਸ਼ੀਆ',
 			'TO' => 'ਟੌਂਗਾ',
 			'TR' => 'ਤੁਰਕੀ',
 			'TT' => 'ਟ੍ਰਿਨੀਡਾਡ ਅਤੇ ਟੋਬਾਗੋ',
 			'TV' => 'ਟੁਵਾਲੂ',
 			'TW' => 'ਤਾਇਵਾਨ',
 			'TZ' => 'ਤਨਜ਼ਾਨੀਆ',
 			'UA' => 'ਯੂਕਰੇਨ',
 			'UG' => 'ਯੂਗਾਂਡਾ',
 			'UM' => 'ਯੂ.ਐੱਸ. ਦੂਰ-ਦੁਰਾਡੇ ਟਾਪੂ',
 			'UN' => 'ਸੰਯੁਕਤ ਰਾਸ਼ਟਰ',
 			'UN@alt=short' => 'ਯੂ.ਐੱਨ.',
 			'US' => 'ਸੰਯੁਕਤ ਰਾਜ',
 			'US@alt=short' => 'ਯੂ.ਐੱਸ.',
 			'UY' => 'ਉਰੂਗਵੇ',
 			'UZ' => 'ਉਜ਼ਬੇਕਿਸਤਾਨ',
 			'VA' => 'ਵੈਟੀਕਨ ਸਿਟੀ',
 			'VC' => 'ਸੇਂਟ ਵਿਨਸੈਂਟ ਐਂਡ ਗ੍ਰੇਨਾਡੀਨਸ',
 			'VE' => 'ਵੇਨੇਜ਼ੂਏਲਾ',
 			'VG' => 'ਬ੍ਰਿਟਿਸ਼ ਵਰਜਿਨ ਟਾਪੂ',
 			'VI' => 'ਯੂ ਐੱਸ ਵਰਜਿਨ ਟਾਪੂ',
 			'VN' => 'ਵੀਅਤਨਾਮ',
 			'VU' => 'ਵਾਨੂਆਟੂ',
 			'WF' => 'ਵਾਲਿਸ ਅਤੇ ਫੂਟੂਨਾ',
 			'WS' => 'ਸਾਮੋਆ',
 			'XA' => 'ਗਲਤ-ਉਚਾਰਨ',
 			'XB' => 'ਲਿਖਤ ਦੀ ਗਲਤ ਦਿਸ਼ਾ',
 			'XK' => 'ਕੋਸੋਵੋ',
 			'YE' => 'ਯਮਨ',
 			'YT' => 'ਮਾਯੋਟੀ',
 			'ZA' => 'ਦੱਖਣੀ ਅਫਰੀਕਾ',
 			'ZM' => 'ਜ਼ਾਮਬੀਆ',
 			'ZW' => 'ਜ਼ਿੰਬਾਬਵੇ',
 			'ZZ' => 'ਅਣਪਛਾਤਾ ਇਲਾਕਾ',

		}
	},
);

has 'display_name_key' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'calendar' => 'ਕੈਲੰਡਰ',
 			'cf' => 'ਮੁਦਰਾ ਬਣਤਰ',
 			'collation' => 'ਲੜੀਬੱਧ ਕ੍ਰਮ',
 			'currency' => 'ਮੁਦਰਾ',
 			'hc' => 'ਘੰਟੇ ਦਾ ਚੱਕਰ (12 ਬਨਾਮ 24)',
 			'lb' => 'ਰੇਖਾ ਵਿੱਥ ਸ਼ੈਲੀ',
 			'ms' => 'ਮਾਪ ਪ੍ਰਣਾਲੀ',
 			'numbers' => 'ਸੰਖਿਆਵਾਂ',

		}
	},
);

has 'display_name_type' => (
	is			=> 'ro',
	isa			=> HashRef[HashRef[Str]],
	init_arg	=> undef,
	default		=> sub {
		{
			'calendar' => {
 				'buddhist' => q{ਬੋਧੀ ਕੈਲੰਡਰ},
 				'chinese' => q{ਚੀਨੀ ਕੈਲੰਡਰ},
 				'coptic' => q{ਕੋਪਟਿਕ ਕੈਲੰਡਰ},
 				'dangi' => q{ਡਾਂਗੀ ਕੈਲੰਡਰ},
 				'ethiopic' => q{ਇਥੀਓਪਿਕ ਕੈਲੰਡਰ},
 				'ethiopic-amete-alem' => q{ਇਥੀਓਪਿਕ-ਅਮੀਟ-ਆਲਮ},
 				'gregorian' => q{ਗਰੇਗੋਰੀਅਨ ਕੈਲੰਡਰ},
 				'hebrew' => q{ਹਿਬਰੂ ਕੈਲੰਡਰ},
 				'indian' => q{ਭਾਰਤੀ ਕੌਮੀ ਕੈਲੰਡਰ},
 				'islamic' => q{ਇਸਲਾਮੀ ਕੈਲੰਡਰ},
 				'islamic-civil' => q{ਇਸਲਾਮੀ ਕੈਲੰਡਰ (ਸਾਰਨੀਬੱਧ, ਸਮਾਜਿਕ ਯੁੱਗ)},
 				'islamic-rgsa' => q{ਇਸਲਾਮੀ ਕੈਲੰਡਰ (ਸਾਊਦੀ ਅਰਬ, ਚੰਨ ਦਿਖਣਾ)},
 				'islamic-tbla' => q{ਇਸਲਾਮੀ ਕੈਲੰਡਰ (ਟੇਬਲਰ, ਖਗੋਲੀ ਯੁੱਗ)},
 				'islamic-umalqura' => q{ਇਸਲਾਮੀ ਕੈਲੰਡਰ (ਅਮ ਅਲ-ਕੁਰਾ)},
 				'iso8601' => q{(ISO-8601) ਕੈਲੰਡਰ},
 				'japanese' => q{ਜਪਾਨੀ ਕੈਲੰਡਰ},
 				'persian' => q{ਫ਼ਾਰਸੀ ਕੈਲੰਡਰ},
 				'roc' => q{ਮਿੰਗੂਓ ਕੈਲੰਡਰ},
 			},
 			'cf' => {
 				'account' => q{ਲੇਖਾ ਮੁਦਰਾ ਬਣਤਰ},
 				'standard' => q{ਮਿਆਰੀ ਮੁਦਰਾ ਬਣਤਰ},
 			},
 			'collation' => {
 				'compat' => q{ਪਿਛਲਾ ਤਰਤੀਬ ਵਾਰ ਕ੍ਰਮ, ਅਨੁਰੂਪਤਾ ਲਈ},
 				'dictionary' => q{ਸ਼ਬਦ-ਕੋਸ਼ ਲੜੀਬੱਧ ਕ੍ਰਮ},
 				'ducet' => q{ਮੂਲ ਯੂਨੀਕੋਡ ਲੜੀਬੱਧ ਕ੍ਰਮ},
 				'search' => q{ਆਮ-ਮੰਤਵ ਖੋਜ},
 				'standard' => q{ਸਧਾਰਨ ਲੜੀਬੱਧ ਕ੍ਰਮ},
 				'traditional' => q{ਰਵਾਇਤੀ ਲੜੀਬੱਧ ਕ੍ਰਮ},
 			},
 			'hc' => {
 				'h11' => q{12 ਘੰਟੇ ਦੀ ਪ੍ਰਣਾਲੀ (0–11)},
 				'h12' => q{12 ਘੰਟੇ ਦੀ ਪ੍ਰਣਾਲੀ (1–12)},
 				'h23' => q{24 ਘੰਟੇ ਦੀ ਪ੍ਰਣਾਲੀ (0–23)},
 				'h24' => q{24 ਘੰਟੇ ਦੀ ਪ੍ਰਣਾਲੀ (1–24)},
 			},
 			'lb' => {
 				'loose' => q{ਖੁੱਲ੍ਹੀ ਰੇਖਾ ਵਿੱਥ ਸ਼ੈਲੀ},
 				'normal' => q{ਸਧਾਰਨ ਰੇਖਾ ਵਿੱਥ ਸ਼ੈਲੀ},
 				'strict' => q{ਪੱਕੀ ਰੇਖਾ ਵਿੱਥ ਸ਼ੈਲੀ},
 			},
 			'ms' => {
 				'metric' => q{ਮੀਟਰਿਕ ਪ੍ਰਣਾਲੀ},
 				'uksystem' => q{ਇੰਪੀਰੀਅਲ ਮਾਪ ਪ੍ਰਣਾਲੀ},
 				'ussystem' => q{ਅਮਰੀਕੀ ਮਾਪ ਪ੍ਰਣਾਲੀ},
 			},
 			'numbers' => {
 				'arab' => q{ਅਰਬੀ-ਭਾਰਤੀ ਅੰਕ},
 				'arabext' => q{ਵਿਸਤਾਰਿਤ ਅਰਬੀ-ਭਾਰਤੀ ਅੰਕ},
 				'armn' => q{ਆਰਮੀਨੀਅਨ ਸੰਖਿਆਵਾਂ},
 				'armnlow' => q{ਆਰਮੀਨੀਅਨ ਲੋਅਰਕੇਸ ਸੰਖਿਆਵਾਂ},
 				'beng' => q{ਬੰਗਾਲੀ ਅੰਕ},
 				'brah' => q{ਬਰਾਹਮੀ ਅੰਕ},
 				'cakm' => q{ਚਕਮਾ ਅੰਕ},
 				'deva' => q{ਦੇਵਨਾਗਰੀ ਅੰਕ},
 				'ethi' => q{ਐਥਿਓਪਿਕ ਸੰਖਿਆਵਾਂ},
 				'fullwide' => q{ਪੂਰਨ ਵਿਸਤਾਰ ਅੰਕ},
 				'geor' => q{ਜਾਰਜੀਅਨ ਸੰਖਿਆਵਾਂ},
 				'grek' => q{ਯੂਨਾਨੀ ਸੰਖਿਆਵਾਂ},
 				'greklow' => q{ਯੂਨਾਨੀ ਲੋਅਰਕੇਸ ਸੰਖਿਆਵਾਂ},
 				'gujr' => q{ਗੁਜਰਾਤੀ ਅੰਕ},
 				'guru' => q{ਗੁਰਮੁਖੀ ਅੰਕ},
 				'hanidec' => q{ਚੀਨੀ ਦਸ਼ਮਲਵ ਸੰਖਿਆਵਾਂ},
 				'hans' => q{ਸਰਲ ਚੀਨੀ ਸੰਖਿਆਵਾਂ},
 				'hansfin' => q{ਸਰਲ ਚੀਨੀ ਵਿੱਤੀ ਸੰਖਿਆਵਾਂ},
 				'hant' => q{ਰਵਾਇਤੀ ਚੀਨੀ ਸੰਖਿਆਵਾਂ},
 				'hantfin' => q{ਰਵਾਇਤੀ ਚੀਨੀ ਵਿੱਤੀ ਸੰਖਿਆਵਾਂ},
 				'hebr' => q{ਹਿਬਰੂ ਸੰਖਿਆਵਾਂ},
 				'java' => q{ਜਾਵਾਨੀਜ਼ ਅੰਕ},
 				'jpan' => q{ਜਪਾਨੀ ਸੰਖਿਆਵਾਂ},
 				'jpanfin' => q{ਜਪਾਨੀ ਵਿੱਤੀ ਸੰਖਿਆਵਾਂ},
 				'khmr' => q{ਖਮੇਰ ਅੰਕ},
 				'knda' => q{ਕੰਨੜ ਅੰਕ},
 				'laoo' => q{ਲਾਓ ਅੰਕ},
 				'latn' => q{ਪੱਛਮੀ ਅੰਕ},
 				'mlym' => q{ਮਲਿਆਲਮ ਅੰਕ},
 				'mong' => q{ਮੰਗੋਲ ਅੰਕ},
 				'mtei' => q{ਮਿਤੇਈ ਮਾਏਕ ਅੰਕ},
 				'mymr' => q{ਮਿਆਂਮਾਰ ਅੰਕ},
 				'olck' => q{ਓਲ ਚੀਕੀ ਅੰਕ},
 				'orya' => q{ਉੜੀਆ ਅੰਕ},
 				'roman' => q{ਰੋਮਨ ਸੰਖਿਆਵਾਂ},
 				'romanlow' => q{ਰੋਮਨ ਲੋਅਰਕੇਸ ਸੰਖਿਆਵਾਂ},
 				'taml' => q{ਰਵਾਇਤੀ ਤਮਿਲ ਸੰਖਿਆਵਾਂ},
 				'tamldec' => q{ਤਮਿਲ ਅੰਕ},
 				'telu' => q{ਤੇਲਗੂ ਅੰਕ},
 				'thai' => q{ਥਾਈ ਅੰਕ},
 				'tibt' => q{ਤਿੱਬਤੀ ਅੰਕ},
 				'vaii' => q{ਵਾਈ ਅੰਕ},
 			},

		}
	},
);

has 'display_name_measurement_system' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'metric' => q{ਮੀਟਰਿਕ},
 			'UK' => q{ਯੂ. ਕੇ.},
 			'US' => q{ਯੂ. ਐੱਸ.},

		}
	},
);

has 'display_name_code_patterns' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'language' => 'ਬੋਲੀ: {0}',
 			'script' => 'ਲਿਪੀ: {0}',
 			'region' => 'ਇਲਾਕਾ: {0}',

		}
	},
);

has 'characters' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> $^V ge v5.18.0
	? eval <<'EOT'
	sub {
		no warnings 'experimental::regex_sets';
		return {
			auxiliary => qr{[‌‍ਃ ਂ {ਲ਼}]},
			index => ['ੳ', 'ਅ', 'ੲ', 'ਸ', 'ਹ', 'ਕ', 'ਖ', 'ਗ', 'ਘ', 'ਙ', 'ਚ', 'ਛ', 'ਜ', 'ਝ', 'ਞ', 'ਟ', 'ਠ', 'ਡ', 'ਢ', 'ਣ', 'ਤ', 'ਥ', 'ਦ', 'ਧ', 'ਨ', 'ਪ', 'ਫ', 'ਬ', 'ਭ', 'ਮ', 'ਯ', 'ਰ', 'ਲ', 'ਵ', 'ੜ'],
			main => qr{[ੱ ੰ ਼ ੦ ੧ ੨ ੩ ੪ ੫ ੬ ੭ ੮ ੯ ੴ ੳ ਉ ਊ ਓ ਅ ਆ ਐ ਔ ੲ ਇ ਈ ਏ ਸ{ਸ਼} ਹ ਕ ਖ{ਖ਼} ਗ{ਗ਼} ਘ ਙ ਚ ਛ ਜ{ਜ਼} ਝ ਞ ਟ ਠ ਡ ਢ ਣ ਤ ਥ ਦ ਧ ਨ ਪ ਫ{ਫ਼} ਬ ਭ ਮ ਯ ਰ ਲ ਵ ੜ ੍ ਾ ਿ ੀ ੁ ੂ ੇ ੈ ੋ ੌ]},
			numbers => qr{[\- ‑ , . % ‰ + 0੦ 1੧ 2੨ 3੩ 4੪ 5੫ 6੬ 7੭ 8੮ 9੯]},
			punctuation => qr{[\- ‐‑ – — , ; \: ! ? . '‘’ "“” ( ) \[ \] / \& ′ ″]},
		};
	},
EOT
: sub {
		return { index => ['ੳ', 'ਅ', 'ੲ', 'ਸ', 'ਹ', 'ਕ', 'ਖ', 'ਗ', 'ਘ', 'ਙ', 'ਚ', 'ਛ', 'ਜ', 'ਝ', 'ਞ', 'ਟ', 'ਠ', 'ਡ', 'ਢ', 'ਣ', 'ਤ', 'ਥ', 'ਦ', 'ਧ', 'ਨ', 'ਪ', 'ਫ', 'ਬ', 'ਭ', 'ਮ', 'ਯ', 'ਰ', 'ਲ', 'ਵ', 'ੜ'], };
},
);


has 'units' => (
	is			=> 'ro',
	isa			=> HashRef[HashRef[HashRef[Str]]],
	init_arg	=> undef,
	default		=> sub { {
				'long' => {
					# Long Unit Identifier
					'' => {
						'name' => q(ਮੁੱਖ ਦਿਸ਼ਾ),
					},
					# Core Unit Identifier
					'' => {
						'name' => q(ਮੁੱਖ ਦਿਸ਼ਾ),
					},
					# Long Unit Identifier
					'1024p1' => {
						'1' => q(ਕੀਬੀ{0}),
					},
					# Core Unit Identifier
					'1024p1' => {
						'1' => q(ਕੀਬੀ{0}),
					},
					# Long Unit Identifier
					'1024p2' => {
						'1' => q(ਮੇਬੀ{0}),
					},
					# Core Unit Identifier
					'1024p2' => {
						'1' => q(ਮੇਬੀ{0}),
					},
					# Long Unit Identifier
					'1024p3' => {
						'1' => q(ਗੀਬੀ{0}),
					},
					# Core Unit Identifier
					'1024p3' => {
						'1' => q(ਗੀਬੀ{0}),
					},
					# Long Unit Identifier
					'1024p4' => {
						'1' => q(ਟੇਬੀ{0}),
					},
					# Core Unit Identifier
					'1024p4' => {
						'1' => q(ਟੇਬੀ{0}),
					},
					# Long Unit Identifier
					'1024p5' => {
						'1' => q(ਪੇਬੀ{0}),
					},
					# Core Unit Identifier
					'1024p5' => {
						'1' => q(ਪੇਬੀ{0}),
					},
					# Long Unit Identifier
					'1024p6' => {
						'1' => q(ਐਕਸਬੀ{0}),
					},
					# Core Unit Identifier
					'1024p6' => {
						'1' => q(ਐਕਸਬੀ{0}),
					},
					# Long Unit Identifier
					'1024p7' => {
						'1' => q(ਜ਼ੇਬੀ{0}),
					},
					# Core Unit Identifier
					'1024p7' => {
						'1' => q(ਜ਼ੇਬੀ{0}),
					},
					# Long Unit Identifier
					'1024p8' => {
						'1' => q(ਯੋਬ{0}),
					},
					# Core Unit Identifier
					'1024p8' => {
						'1' => q(ਯੋਬ{0}),
					},
					# Long Unit Identifier
					'10p-1' => {
						'1' => q(ਡੈਸੀ{0}),
					},
					# Core Unit Identifier
					'1' => {
						'1' => q(ਡੈਸੀ{0}),
					},
					# Long Unit Identifier
					'10p-12' => {
						'1' => q(ਪਿਕੋ{0}),
					},
					# Core Unit Identifier
					'12' => {
						'1' => q(ਪਿਕੋ{0}),
					},
					# Long Unit Identifier
					'10p-15' => {
						'1' => q(ਫੈਮਟੋ{0}),
					},
					# Core Unit Identifier
					'15' => {
						'1' => q(ਫੈਮਟੋ{0}),
					},
					# Long Unit Identifier
					'10p-18' => {
						'1' => q(ਐੱਟੋ{0}),
					},
					# Core Unit Identifier
					'18' => {
						'1' => q(ਐੱਟੋ{0}),
					},
					# Long Unit Identifier
					'10p-2' => {
						'1' => q(ਸੈਂਟੀ{0}),
					},
					# Core Unit Identifier
					'2' => {
						'1' => q(ਸੈਂਟੀ{0}),
					},
					# Long Unit Identifier
					'10p-21' => {
						'1' => q(ਜ਼ੈਪਟੋ{0}),
					},
					# Core Unit Identifier
					'21' => {
						'1' => q(ਜ਼ੈਪਟੋ{0}),
					},
					# Long Unit Identifier
					'10p-24' => {
						'1' => q(ਯੋਕਟੋ{0}),
					},
					# Core Unit Identifier
					'24' => {
						'1' => q(ਯੋਕਟੋ{0}),
					},
					# Long Unit Identifier
					'10p-27' => {
						'1' => q(ਰੋਂਟੋ{0}),
					},
					# Core Unit Identifier
					'27' => {
						'1' => q(ਰੋਂਟੋ{0}),
					},
					# Long Unit Identifier
					'10p-3' => {
						'1' => q(ਮਿਲੀ{0}),
					},
					# Core Unit Identifier
					'3' => {
						'1' => q(ਮਿਲੀ{0}),
					},
					# Long Unit Identifier
					'10p-30' => {
						'1' => q(ਕੁਏਕਟੋ{0}),
					},
					# Core Unit Identifier
					'30' => {
						'1' => q(ਕੁਏਕਟੋ{0}),
					},
					# Long Unit Identifier
					'10p-6' => {
						'1' => q(ਮਾਈਕਰੋ{0}),
					},
					# Core Unit Identifier
					'6' => {
						'1' => q(ਮਾਈਕਰੋ{0}),
					},
					# Long Unit Identifier
					'10p-9' => {
						'1' => q(ਨੈਨੋ{0}),
					},
					# Core Unit Identifier
					'9' => {
						'1' => q(ਨੈਨੋ{0}),
					},
					# Long Unit Identifier
					'10p1' => {
						'1' => q(ਡੇਕਾ{0}),
					},
					# Core Unit Identifier
					'10p1' => {
						'1' => q(ਡੇਕਾ{0}),
					},
					# Long Unit Identifier
					'10p12' => {
						'1' => q(ਟੈਰਾ{0}),
					},
					# Core Unit Identifier
					'10p12' => {
						'1' => q(ਟੈਰਾ{0}),
					},
					# Long Unit Identifier
					'10p2' => {
						'1' => q(ਹੈਕਟੋ{0}),
					},
					# Core Unit Identifier
					'10p2' => {
						'1' => q(ਹੈਕਟੋ{0}),
					},
					# Long Unit Identifier
					'10p27' => {
						'1' => q(ਰੌਨਾ{0}),
					},
					# Core Unit Identifier
					'10p27' => {
						'1' => q(ਰੌਨਾ{0}),
					},
					# Long Unit Identifier
					'10p3' => {
						'1' => q(ਕਿਲੋ{0}),
					},
					# Core Unit Identifier
					'10p3' => {
						'1' => q(ਕਿਲੋ{0}),
					},
					# Long Unit Identifier
					'10p30' => {
						'1' => q(ਕਵੇਟਾ{0}),
					},
					# Core Unit Identifier
					'10p30' => {
						'1' => q(ਕਵੇਟਾ{0}),
					},
					# Long Unit Identifier
					'10p6' => {
						'1' => q(ਮੈਗਾ{0}),
					},
					# Core Unit Identifier
					'10p6' => {
						'1' => q(ਮੈਗਾ{0}),
					},
					# Long Unit Identifier
					'acceleration-g-force' => {
						'1' => q(masculine),
						'one' => q({0} ਗੁਰੂਤਾਕਰਸ਼ਣ ਬਲ),
						'other' => q({0} ਗੁਰੂਤਾਕਰਸ਼ਣ ਬਲ),
					},
					# Core Unit Identifier
					'g-force' => {
						'1' => q(masculine),
						'one' => q({0} ਗੁਰੂਤਾਕਰਸ਼ਣ ਬਲ),
						'other' => q({0} ਗੁਰੂਤਾਕਰਸ਼ਣ ਬਲ),
					},
					# Long Unit Identifier
					'acceleration-meter-per-square-second' => {
						'1' => q(masculine),
						'name' => q(ਮੀਟਰ ਪ੍ਰਤੀ ਵਰਗ ਸਕਿੰਟ),
						'one' => q({0} ਮੀਟਰ ਪ੍ਰਤੀ ਵਰਗ ਸਕਿੰਟ),
						'other' => q({0} ਮੀਟਰ ਪ੍ਰਤੀ ਵਰਗ ਸਕਿੰਟ),
					},
					# Core Unit Identifier
					'meter-per-square-second' => {
						'1' => q(masculine),
						'name' => q(ਮੀਟਰ ਪ੍ਰਤੀ ਵਰਗ ਸਕਿੰਟ),
						'one' => q({0} ਮੀਟਰ ਪ੍ਰਤੀ ਵਰਗ ਸਕਿੰਟ),
						'other' => q({0} ਮੀਟਰ ਪ੍ਰਤੀ ਵਰਗ ਸਕਿੰਟ),
					},
					# Long Unit Identifier
					'angle-arc-minute' => {
						'1' => q(masculine),
					},
					# Core Unit Identifier
					'arc-minute' => {
						'1' => q(masculine),
					},
					# Long Unit Identifier
					'angle-arc-second' => {
						'1' => q(masculine),
					},
					# Core Unit Identifier
					'arc-second' => {
						'1' => q(masculine),
					},
					# Long Unit Identifier
					'angle-degree' => {
						'1' => q(feminine),
						'one' => q({0} ਡਿਗਰੀ),
						'other' => q({0} ਡਿਗਰੀ),
					},
					# Core Unit Identifier
					'degree' => {
						'1' => q(feminine),
						'one' => q({0} ਡਿਗਰੀ),
						'other' => q({0} ਡਿਗਰੀ),
					},
					# Long Unit Identifier
					'angle-radian' => {
						'1' => q(masculine),
						'one' => q({0} ਰੇਡੀਅਨ),
						'other' => q({0} ਰੇਡੀਅਨ),
					},
					# Core Unit Identifier
					'radian' => {
						'1' => q(masculine),
						'one' => q({0} ਰੇਡੀਅਨ),
						'other' => q({0} ਰੇਡੀਅਨ),
					},
					# Long Unit Identifier
					'angle-revolution' => {
						'1' => q(feminine),
					},
					# Core Unit Identifier
					'revolution' => {
						'1' => q(feminine),
					},
					# Long Unit Identifier
					'area-hectare' => {
						'1' => q(masculine),
						'one' => q({0} ਹੈਕਟੇਅਰ),
						'other' => q({0} ਹੈਕਟੇਅਰ),
					},
					# Core Unit Identifier
					'hectare' => {
						'1' => q(masculine),
						'one' => q({0} ਹੈਕਟੇਅਰ),
						'other' => q({0} ਹੈਕਟੇਅਰ),
					},
					# Long Unit Identifier
					'area-square-centimeter' => {
						'1' => q(masculine),
						'name' => q(ਵਰਗ ਸੈਂਟੀਮੀਟਰ),
						'one' => q({0} ਵਰਗ ਸੈਂਟੀਮੀਟਰ),
						'other' => q({0} ਵਰਗ ਸੈਂਟੀਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਵਰਗ ਸੈਂਟੀਮੀਟਰ),
					},
					# Core Unit Identifier
					'square-centimeter' => {
						'1' => q(masculine),
						'name' => q(ਵਰਗ ਸੈਂਟੀਮੀਟਰ),
						'one' => q({0} ਵਰਗ ਸੈਂਟੀਮੀਟਰ),
						'other' => q({0} ਵਰਗ ਸੈਂਟੀਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਵਰਗ ਸੈਂਟੀਮੀਟਰ),
					},
					# Long Unit Identifier
					'area-square-foot' => {
						'name' => q(ਵਰਗ ਫੁੱਟ),
						'one' => q({0} ਵਰਗ ਫੁੱਟ),
						'other' => q({0} ਵਰਗ ਫੁੱਟ),
					},
					# Core Unit Identifier
					'square-foot' => {
						'name' => q(ਵਰਗ ਫੁੱਟ),
						'one' => q({0} ਵਰਗ ਫੁੱਟ),
						'other' => q({0} ਵਰਗ ਫੁੱਟ),
					},
					# Long Unit Identifier
					'area-square-inch' => {
						'name' => q(ਵਰਗ ਇੰਚ),
						'one' => q({0} ਵਰਗ ਇੰਚ),
						'other' => q({0} ਵਰਗ ਇੰਚ),
						'per' => q({0} ਪ੍ਰਤੀ ਵਰਗ ਇੰਚ),
					},
					# Core Unit Identifier
					'square-inch' => {
						'name' => q(ਵਰਗ ਇੰਚ),
						'one' => q({0} ਵਰਗ ਇੰਚ),
						'other' => q({0} ਵਰਗ ਇੰਚ),
						'per' => q({0} ਪ੍ਰਤੀ ਵਰਗ ਇੰਚ),
					},
					# Long Unit Identifier
					'area-square-kilometer' => {
						'1' => q(masculine),
						'name' => q(ਵਰਗ ਕਿਲੋਮੀਟਰ),
						'one' => q({0} ਵਰਗ ਕਿਲੋਮੀਟਰ),
						'other' => q({0} ਵਰਗ ਕਿਲੋਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਵਰਗ ਕਿਲੋਮੀਟਰ),
					},
					# Core Unit Identifier
					'square-kilometer' => {
						'1' => q(masculine),
						'name' => q(ਵਰਗ ਕਿਲੋਮੀਟਰ),
						'one' => q({0} ਵਰਗ ਕਿਲੋਮੀਟਰ),
						'other' => q({0} ਵਰਗ ਕਿਲੋਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਵਰਗ ਕਿਲੋਮੀਟਰ),
					},
					# Long Unit Identifier
					'area-square-meter' => {
						'1' => q(masculine),
						'name' => q(ਵਰਗ ਮੀਟਰ),
						'one' => q({0} ਵਰਗ ਮੀਟਰ),
						'other' => q({0} ਵਰਗ ਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਵਰਗ ਮੀਟਰ),
					},
					# Core Unit Identifier
					'square-meter' => {
						'1' => q(masculine),
						'name' => q(ਵਰਗ ਮੀਟਰ),
						'one' => q({0} ਵਰਗ ਮੀਟਰ),
						'other' => q({0} ਵਰਗ ਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਵਰਗ ਮੀਟਰ),
					},
					# Long Unit Identifier
					'area-square-mile' => {
						'one' => q({0} ਵਰਗ ਮੀਲ),
						'other' => q({0} ਵਰਗ ਮੀਲ),
						'per' => q({0} ਪ੍ਰਤੀ ਵਰਗ ਮੀਲ),
					},
					# Core Unit Identifier
					'square-mile' => {
						'one' => q({0} ਵਰਗ ਮੀਲ),
						'other' => q({0} ਵਰਗ ਮੀਲ),
						'per' => q({0} ਪ੍ਰਤੀ ਵਰਗ ਮੀਲ),
					},
					# Long Unit Identifier
					'area-square-yard' => {
						'name' => q(ਵਰਗ ਗਜ਼),
						'one' => q({0} ਵਰਗ ਗਜ਼),
						'other' => q({0} ਵਰਗ ਗਜ਼),
					},
					# Core Unit Identifier
					'square-yard' => {
						'name' => q(ਵਰਗ ਗਜ਼),
						'one' => q({0} ਵਰਗ ਗਜ਼),
						'other' => q({0} ਵਰਗ ਗਜ਼),
					},
					# Long Unit Identifier
					'concentr-item' => {
						'1' => q(feminine),
						'name' => q(ਆਈਟਮਾਂ),
					},
					# Core Unit Identifier
					'item' => {
						'1' => q(feminine),
						'name' => q(ਆਈਟਮਾਂ),
					},
					# Long Unit Identifier
					'concentr-karat' => {
						'1' => q(masculine),
					},
					# Core Unit Identifier
					'karat' => {
						'1' => q(masculine),
					},
					# Long Unit Identifier
					'concentr-milligram-ofglucose-per-deciliter' => {
						'1' => q(masculine),
						'name' => q(ਮਿਲੀਗ੍ਰਾਮ ਪ੍ਰਤੀ ਡੈਸੀਲਿਟਰ),
						'one' => q({0} ਮਿਲੀਗ੍ਰਾਮ ਪ੍ਰਤੀ ਡੈਸੀਲਿਟਰ),
						'other' => q({0} ਮਿਲੀਗ੍ਰਾਮ ਪ੍ਰਤੀ ਡੈਸੀਲਿਟਰ),
					},
					# Core Unit Identifier
					'milligram-ofglucose-per-deciliter' => {
						'1' => q(masculine),
						'name' => q(ਮਿਲੀਗ੍ਰਾਮ ਪ੍ਰਤੀ ਡੈਸੀਲਿਟਰ),
						'one' => q({0} ਮਿਲੀਗ੍ਰਾਮ ਪ੍ਰਤੀ ਡੈਸੀਲਿਟਰ),
						'other' => q({0} ਮਿਲੀਗ੍ਰਾਮ ਪ੍ਰਤੀ ਡੈਸੀਲਿਟਰ),
					},
					# Long Unit Identifier
					'concentr-millimole-per-liter' => {
						'1' => q(masculine),
						'name' => q(ਮਿਲੀਮੋਲ ਪ੍ਰਤੀ ਲਿਟਰ),
						'one' => q({0} ਮਿਲੀਮੋਲ ਪ੍ਰਤੀ ਲਿਟਰ),
						'other' => q({0} ਮਿਲੀਮੋਲ ਪ੍ਰਤੀ ਲਿਟਰ),
					},
					# Core Unit Identifier
					'millimole-per-liter' => {
						'1' => q(masculine),
						'name' => q(ਮਿਲੀਮੋਲ ਪ੍ਰਤੀ ਲਿਟਰ),
						'one' => q({0} ਮਿਲੀਮੋਲ ਪ੍ਰਤੀ ਲਿਟਰ),
						'other' => q({0} ਮਿਲੀਮੋਲ ਪ੍ਰਤੀ ਲਿਟਰ),
					},
					# Long Unit Identifier
					'concentr-mole' => {
						'1' => q(masculine),
					},
					# Core Unit Identifier
					'mole' => {
						'1' => q(masculine),
					},
					# Long Unit Identifier
					'concentr-percent' => {
						'1' => q(masculine),
						'one' => q({0} ਪ੍ਰਤੀਸ਼ਤ),
						'other' => q({0} ਪ੍ਰਤੀਸ਼ਤ),
					},
					# Core Unit Identifier
					'percent' => {
						'1' => q(masculine),
						'one' => q({0} ਪ੍ਰਤੀਸ਼ਤ),
						'other' => q({0} ਪ੍ਰਤੀਸ਼ਤ),
					},
					# Long Unit Identifier
					'concentr-permille' => {
						'1' => q(masculine),
						'one' => q({0} ਪਰਮਾਈਲ),
						'other' => q({0} ਪਰਮਾਈਲ),
					},
					# Core Unit Identifier
					'permille' => {
						'1' => q(masculine),
						'one' => q({0} ਪਰਮਾਈਲ),
						'other' => q({0} ਪਰਮਾਈਲ),
					},
					# Long Unit Identifier
					'concentr-permillion' => {
						'1' => q(masculine),
						'name' => q(ਹਿੱਸੇ ਪ੍ਰਤੀ ਮਿਲੀਅਨ),
						'one' => q({0} ਹਿੱਸਾ ਪ੍ਰਤੀ ਮਿਲੀਅਨ),
						'other' => q({0} ਹਿੱਸੇ ਪ੍ਰਤੀ ਮਿਲੀਅਨ),
					},
					# Core Unit Identifier
					'permillion' => {
						'1' => q(masculine),
						'name' => q(ਹਿੱਸੇ ਪ੍ਰਤੀ ਮਿਲੀਅਨ),
						'one' => q({0} ਹਿੱਸਾ ਪ੍ਰਤੀ ਮਿਲੀਅਨ),
						'other' => q({0} ਹਿੱਸੇ ਪ੍ਰਤੀ ਮਿਲੀਅਨ),
					},
					# Long Unit Identifier
					'concentr-permyriad' => {
						'1' => q(masculine),
						'one' => q({0} ਪ੍ਰਤੀ ਦਸ ਹਜ਼ਾਰ),
						'other' => q({0} ਪ੍ਰਤੀ ਦਸ ਹਜ਼ਾਰ),
					},
					# Core Unit Identifier
					'permyriad' => {
						'1' => q(masculine),
						'one' => q({0} ਪ੍ਰਤੀ ਦਸ ਹਜ਼ਾਰ),
						'other' => q({0} ਪ੍ਰਤੀ ਦਸ ਹਜ਼ਾਰ),
					},
					# Long Unit Identifier
					'concentr-portion-per-1e9' => {
						'1' => q(masculine),
						'name' => q(ਹਿੱਸਾ ਪ੍ਰਤੀ ਅਰਬ),
						'one' => q({0} ਹਿੱਸਾ ਪ੍ਰਤੀ ਅਰਬ),
						'other' => q({0} ਹਿੱਸਾ ਪ੍ਰਤੀ ਅਰਬ),
					},
					# Core Unit Identifier
					'portion-per-1e9' => {
						'1' => q(masculine),
						'name' => q(ਹਿੱਸਾ ਪ੍ਰਤੀ ਅਰਬ),
						'one' => q({0} ਹਿੱਸਾ ਪ੍ਰਤੀ ਅਰਬ),
						'other' => q({0} ਹਿੱਸਾ ਪ੍ਰਤੀ ਅਰਬ),
					},
					# Long Unit Identifier
					'consumption-liter-per-100-kilometer' => {
						'1' => q(masculine),
						'name' => q(ਲਿਟਰ ਪ੍ਰਤੀ 100 ਕਿਲੋਮੀਟਰ),
						'one' => q({0} ਲਿਟਰ ਪ੍ਰਤੀ 100 ਕਿਲੋਮੀਟਰ),
						'other' => q({0} ਲਿਟਰ ਪ੍ਰਤੀ 100 ਕਿਲੋਮੀਟਰ),
					},
					# Core Unit Identifier
					'liter-per-100-kilometer' => {
						'1' => q(masculine),
						'name' => q(ਲਿਟਰ ਪ੍ਰਤੀ 100 ਕਿਲੋਮੀਟਰ),
						'one' => q({0} ਲਿਟਰ ਪ੍ਰਤੀ 100 ਕਿਲੋਮੀਟਰ),
						'other' => q({0} ਲਿਟਰ ਪ੍ਰਤੀ 100 ਕਿਲੋਮੀਟਰ),
					},
					# Long Unit Identifier
					'consumption-liter-per-kilometer' => {
						'1' => q(masculine),
						'name' => q(ਲਿਟਰ ਪ੍ਰਤੀ ਕਿਲੋਮੀਟਰ),
						'one' => q({0} ਲਿਟਰ ਪ੍ਰਤੀ ਕਿਲੋਮੀਟਰ),
						'other' => q({0} ਲਿਟਰ ਪ੍ਰਤੀ ਕਿਲੋਮੀਟਰ),
					},
					# Core Unit Identifier
					'liter-per-kilometer' => {
						'1' => q(masculine),
						'name' => q(ਲਿਟਰ ਪ੍ਰਤੀ ਕਿਲੋਮੀਟਰ),
						'one' => q({0} ਲਿਟਰ ਪ੍ਰਤੀ ਕਿਲੋਮੀਟਰ),
						'other' => q({0} ਲਿਟਰ ਪ੍ਰਤੀ ਕਿਲੋਮੀਟਰ),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon' => {
						'name' => q(ਮੀਲ ਪ੍ਰਤੀ ਗੈਲਨ),
						'one' => q({0} ਮੀਲ ਪ੍ਰਤੀ ਗੈਲਨ),
						'other' => q({0} ਮੀਲ ਪ੍ਰਤੀ ਗੈਲਨ),
					},
					# Core Unit Identifier
					'mile-per-gallon' => {
						'name' => q(ਮੀਲ ਪ੍ਰਤੀ ਗੈਲਨ),
						'one' => q({0} ਮੀਲ ਪ੍ਰਤੀ ਗੈਲਨ),
						'other' => q({0} ਮੀਲ ਪ੍ਰਤੀ ਗੈਲਨ),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon-imperial' => {
						'name' => q(ਮੀਲ ਪ੍ਰਤੀ ਇੰਪ. ਗੈਲਨ),
						'one' => q({0} ਮੀਲ ਪ੍ਰਤੀ ਇੰਪ. ਗੈਲਨ),
						'other' => q({0} ਮੀਲ ਪ੍ਰਤੀ ਇੰਪ. ਗੈਲਨ),
					},
					# Core Unit Identifier
					'mile-per-gallon-imperial' => {
						'name' => q(ਮੀਲ ਪ੍ਰਤੀ ਇੰਪ. ਗੈਲਨ),
						'one' => q({0} ਮੀਲ ਪ੍ਰਤੀ ਇੰਪ. ਗੈਲਨ),
						'other' => q({0} ਮੀਲ ਪ੍ਰਤੀ ਇੰਪ. ਗੈਲਨ),
					},
					# Long Unit Identifier
					'coordinate' => {
						'east' => q({0} ਪੂਰਬ),
						'north' => q({0} ਉੱਤਰ),
						'south' => q({0} ਦੱਖਣ),
						'west' => q({0} ਪੱਛਮ),
					},
					# Core Unit Identifier
					'coordinate' => {
						'east' => q({0} ਪੂਰਬ),
						'north' => q({0} ਉੱਤਰ),
						'south' => q({0} ਦੱਖਣ),
						'west' => q({0} ਪੱਛਮ),
					},
					# Long Unit Identifier
					'digital-bit' => {
						'1' => q(feminine),
					},
					# Core Unit Identifier
					'bit' => {
						'1' => q(feminine),
					},
					# Long Unit Identifier
					'digital-byte' => {
						'1' => q(feminine),
					},
					# Core Unit Identifier
					'byte' => {
						'1' => q(feminine),
					},
					# Long Unit Identifier
					'digital-gigabit' => {
						'1' => q(feminine),
						'name' => q(ਗੀਗਾਬਿਟ),
						'one' => q({0} ਗੀਗਾਬਿਟ),
						'other' => q({0} ਗੀਗਾਬਿਟ),
					},
					# Core Unit Identifier
					'gigabit' => {
						'1' => q(feminine),
						'name' => q(ਗੀਗਾਬਿਟ),
						'one' => q({0} ਗੀਗਾਬਿਟ),
						'other' => q({0} ਗੀਗਾਬਿਟ),
					},
					# Long Unit Identifier
					'digital-gigabyte' => {
						'1' => q(feminine),
						'one' => q({0} ਗੀਗਾਬਾਇਟ),
						'other' => q({0} ਗੀਗਾਬਾਇਟ),
					},
					# Core Unit Identifier
					'gigabyte' => {
						'1' => q(feminine),
						'one' => q({0} ਗੀਗਾਬਾਇਟ),
						'other' => q({0} ਗੀਗਾਬਾਇਟ),
					},
					# Long Unit Identifier
					'digital-kilobit' => {
						'1' => q(feminine),
						'one' => q({0} ਕਿਲੋਬਿਟ),
						'other' => q({0} ਕਿਲੋਬਿਟ),
					},
					# Core Unit Identifier
					'kilobit' => {
						'1' => q(feminine),
						'one' => q({0} ਕਿਲੋਬਿਟ),
						'other' => q({0} ਕਿਲੋਬਿਟ),
					},
					# Long Unit Identifier
					'digital-kilobyte' => {
						'1' => q(feminine),
						'one' => q({0} ਕਿਲੋਬਾਇਟ),
						'other' => q({0} ਕਿਲੋਬਾਇਟ),
					},
					# Core Unit Identifier
					'kilobyte' => {
						'1' => q(feminine),
						'one' => q({0} ਕਿਲੋਬਾਇਟ),
						'other' => q({0} ਕਿਲੋਬਾਇਟ),
					},
					# Long Unit Identifier
					'digital-megabit' => {
						'1' => q(feminine),
						'one' => q({0} ਮੈਗਾਬਿਟ),
						'other' => q({0} ਮੈਗਾਬਿਟ),
					},
					# Core Unit Identifier
					'megabit' => {
						'1' => q(feminine),
						'one' => q({0} ਮੈਗਾਬਿਟ),
						'other' => q({0} ਮੈਗਾਬਿਟ),
					},
					# Long Unit Identifier
					'digital-megabyte' => {
						'1' => q(feminine),
						'one' => q({0} ਮੈਗਾਬਾਇਟ),
						'other' => q({0} ਮੈਗਾਬਾਇਟ),
					},
					# Core Unit Identifier
					'megabyte' => {
						'1' => q(feminine),
						'one' => q({0} ਮੈਗਾਬਾਇਟ),
						'other' => q({0} ਮੈਗਾਬਾਇਟ),
					},
					# Long Unit Identifier
					'digital-petabyte' => {
						'1' => q(feminine),
						'one' => q({0} ਪੈਟਾਬਾਇਟ),
						'other' => q({0} ਪੈਟਾਬਾਇਟ),
					},
					# Core Unit Identifier
					'petabyte' => {
						'1' => q(feminine),
						'one' => q({0} ਪੈਟਾਬਾਇਟ),
						'other' => q({0} ਪੈਟਾਬਾਇਟ),
					},
					# Long Unit Identifier
					'digital-terabit' => {
						'1' => q(feminine),
						'one' => q({0} ਟੇਰਾਬਿਟ),
						'other' => q({0} ਟੇਰਾਬਿਟ),
					},
					# Core Unit Identifier
					'terabit' => {
						'1' => q(feminine),
						'one' => q({0} ਟੇਰਾਬਿਟ),
						'other' => q({0} ਟੇਰਾਬਿਟ),
					},
					# Long Unit Identifier
					'digital-terabyte' => {
						'1' => q(feminine),
						'one' => q({0} ਟੈਰਾਬਾਇਟ),
						'other' => q({0} ਟੈਰਾਬਾਇਟ),
					},
					# Core Unit Identifier
					'terabyte' => {
						'1' => q(feminine),
						'one' => q({0} ਟੈਰਾਬਾਇਟ),
						'other' => q({0} ਟੈਰਾਬਾਇਟ),
					},
					# Long Unit Identifier
					'duration-century' => {
						'1' => q(feminine),
						'name' => q(ਸਦੀਆਂ),
						'one' => q({0} ਸਦੀ),
						'other' => q({0} ਸਦੀਆਂ),
					},
					# Core Unit Identifier
					'century' => {
						'1' => q(feminine),
						'name' => q(ਸਦੀਆਂ),
						'one' => q({0} ਸਦੀ),
						'other' => q({0} ਸਦੀਆਂ),
					},
					# Long Unit Identifier
					'duration-day' => {
						'1' => q(masculine),
						'per' => q({0} ਪ੍ਰਤੀ ਦਿਨ),
					},
					# Core Unit Identifier
					'day' => {
						'1' => q(masculine),
						'per' => q({0} ਪ੍ਰਤੀ ਦਿਨ),
					},
					# Long Unit Identifier
					'duration-decade' => {
						'1' => q(masculine),
						'name' => q(ਦਹਾਕੇ),
						'one' => q({0} ਦਹਾਕਾ),
						'other' => q({0} ਦਹਾਕੇ),
					},
					# Core Unit Identifier
					'decade' => {
						'1' => q(masculine),
						'name' => q(ਦਹਾਕੇ),
						'one' => q({0} ਦਹਾਕਾ),
						'other' => q({0} ਦਹਾਕੇ),
					},
					# Long Unit Identifier
					'duration-hour' => {
						'1' => q(masculine),
						'one' => q({0} ਘੰਟਾ),
						'other' => q({0} ਘੰਟੇ),
						'per' => q({0} ਪ੍ਰਤੀ ਘੰਟਾ),
					},
					# Core Unit Identifier
					'hour' => {
						'1' => q(masculine),
						'one' => q({0} ਘੰਟਾ),
						'other' => q({0} ਘੰਟੇ),
						'per' => q({0} ਪ੍ਰਤੀ ਘੰਟਾ),
					},
					# Long Unit Identifier
					'duration-microsecond' => {
						'1' => q(masculine),
						'one' => q({0} ਮਾਈਕਰੋਸਕਿੰਟ),
						'other' => q({0} ਮਾਈਕਰੋਸਕਿੰਟ),
					},
					# Core Unit Identifier
					'microsecond' => {
						'1' => q(masculine),
						'one' => q({0} ਮਾਈਕਰੋਸਕਿੰਟ),
						'other' => q({0} ਮਾਈਕਰੋਸਕਿੰਟ),
					},
					# Long Unit Identifier
					'duration-millisecond' => {
						'1' => q(masculine),
					},
					# Core Unit Identifier
					'millisecond' => {
						'1' => q(masculine),
					},
					# Long Unit Identifier
					'duration-minute' => {
						'1' => q(masculine),
						'one' => q({0} ਮਿੰਟ),
						'other' => q({0} ਮਿੰਟ),
						'per' => q({0} ਪ੍ਰਤੀ ਮਿੰਟ),
					},
					# Core Unit Identifier
					'minute' => {
						'1' => q(masculine),
						'one' => q({0} ਮਿੰਟ),
						'other' => q({0} ਮਿੰਟ),
						'per' => q({0} ਪ੍ਰਤੀ ਮਿੰਟ),
					},
					# Long Unit Identifier
					'duration-month' => {
						'1' => q(masculine),
						'one' => q({0} ਮਹੀਨਾ),
						'other' => q({0} ਮਹੀਨੇ),
						'per' => q({0} ਪ੍ਰਤੀ ਮਹੀਨਾ),
					},
					# Core Unit Identifier
					'month' => {
						'1' => q(masculine),
						'one' => q({0} ਮਹੀਨਾ),
						'other' => q({0} ਮਹੀਨੇ),
						'per' => q({0} ਪ੍ਰਤੀ ਮਹੀਨਾ),
					},
					# Long Unit Identifier
					'duration-nanosecond' => {
						'1' => q(masculine),
						'one' => q({0} ਨੈਨੋਸਕਿੰਟ),
						'other' => q({0} ਨੈਨੋਸਕਿੰਟ),
					},
					# Core Unit Identifier
					'nanosecond' => {
						'1' => q(masculine),
						'one' => q({0} ਨੈਨੋਸਕਿੰਟ),
						'other' => q({0} ਨੈਨੋਸਕਿੰਟ),
					},
					# Long Unit Identifier
					'duration-night' => {
						'1' => q(feminine),
						'name' => q(ਰਾਤਾਂ),
						'one' => q({0} ਰਾਤ),
						'other' => q({0} ਰਾਤਾਂ),
						'per' => q({0} ਪ੍ਰਤੀ ਰਾਤ),
					},
					# Core Unit Identifier
					'night' => {
						'1' => q(feminine),
						'name' => q(ਰਾਤਾਂ),
						'one' => q({0} ਰਾਤ),
						'other' => q({0} ਰਾਤਾਂ),
						'per' => q({0} ਪ੍ਰਤੀ ਰਾਤ),
					},
					# Long Unit Identifier
					'duration-quarter' => {
						'1' => q(feminine),
						'name' => q(ਤਿਮਾਹੀਆਂ),
					},
					# Core Unit Identifier
					'quarter' => {
						'1' => q(feminine),
						'name' => q(ਤਿਮਾਹੀਆਂ),
					},
					# Long Unit Identifier
					'duration-second' => {
						'1' => q(masculine),
						'one' => q({0} ਸਕਿੰਟ),
						'other' => q({0} ਸਕਿੰਟ),
						'per' => q({0} ਪ੍ਰਤੀ ਸਕਿੰਟ),
					},
					# Core Unit Identifier
					'second' => {
						'1' => q(masculine),
						'one' => q({0} ਸਕਿੰਟ),
						'other' => q({0} ਸਕਿੰਟ),
						'per' => q({0} ਪ੍ਰਤੀ ਸਕਿੰਟ),
					},
					# Long Unit Identifier
					'duration-week' => {
						'1' => q(masculine),
						'one' => q({0} ਹਫ਼ਤਾ),
						'other' => q({0} ਹਫ਼ਤੇ),
						'per' => q({0} ਪ੍ਰਤੀ ਹਫ਼ਤਾ),
					},
					# Core Unit Identifier
					'week' => {
						'1' => q(masculine),
						'one' => q({0} ਹਫ਼ਤਾ),
						'other' => q({0} ਹਫ਼ਤੇ),
						'per' => q({0} ਪ੍ਰਤੀ ਹਫ਼ਤਾ),
					},
					# Long Unit Identifier
					'duration-year' => {
						'1' => q(masculine),
						'one' => q({0} ਸਾਲ),
						'other' => q({0} ਸਾਲ),
						'per' => q({0} ਪ੍ਰਤੀ ਸਾਲ),
					},
					# Core Unit Identifier
					'year' => {
						'1' => q(masculine),
						'one' => q({0} ਸਾਲ),
						'other' => q({0} ਸਾਲ),
						'per' => q({0} ਪ੍ਰਤੀ ਸਾਲ),
					},
					# Long Unit Identifier
					'electric-ampere' => {
						'1' => q(masculine),
						'one' => q({0} ਐਮਪੀਅਰ),
						'other' => q({0} ਐਮਪੀਅਰ),
					},
					# Core Unit Identifier
					'ampere' => {
						'1' => q(masculine),
						'one' => q({0} ਐਮਪੀਅਰ),
						'other' => q({0} ਐਮਪੀਅਰ),
					},
					# Long Unit Identifier
					'electric-milliampere' => {
						'1' => q(masculine),
						'one' => q({0} ਮਿਲੀਐਮਪੀਅਰ),
						'other' => q({0} ਮਿਲੀਐਮਪੀਅਰ),
					},
					# Core Unit Identifier
					'milliampere' => {
						'1' => q(masculine),
						'one' => q({0} ਮਿਲੀਐਮਪੀਅਰ),
						'other' => q({0} ਮਿਲੀਐਮਪੀਅਰ),
					},
					# Long Unit Identifier
					'electric-ohm' => {
						'1' => q(masculine),
						'one' => q({0} ਓਹਮ),
						'other' => q({0} ਓਹਮ),
					},
					# Core Unit Identifier
					'ohm' => {
						'1' => q(masculine),
						'one' => q({0} ਓਹਮ),
						'other' => q({0} ਓਹਮ),
					},
					# Long Unit Identifier
					'electric-volt' => {
						'1' => q(masculine),
						'one' => q({0} ਵੋਲਟ),
						'other' => q({0} ਵੋਲਟ),
					},
					# Core Unit Identifier
					'volt' => {
						'1' => q(masculine),
						'one' => q({0} ਵੋਲਟ),
						'other' => q({0} ਵੋਲਟ),
					},
					# Long Unit Identifier
					'energy-british-thermal-unit' => {
						'name' => q(ਬਰਤਾਨਵੀ ਤਾਪ ਇਕਾਈ),
						'one' => q({0} ਬਰਤਾਨਵੀ ਤਾਪ ਇਕਾਈ),
						'other' => q({0} ਬਰਤਾਨਵੀ ਤਾਪ ਇਕਾਈ),
					},
					# Core Unit Identifier
					'british-thermal-unit' => {
						'name' => q(ਬਰਤਾਨਵੀ ਤਾਪ ਇਕਾਈ),
						'one' => q({0} ਬਰਤਾਨਵੀ ਤਾਪ ਇਕਾਈ),
						'other' => q({0} ਬਰਤਾਨਵੀ ਤਾਪ ਇਕਾਈ),
					},
					# Long Unit Identifier
					'energy-calorie' => {
						'1' => q(feminine),
						'name' => q(ਕੈਲੋਰੀਆਂ),
					},
					# Core Unit Identifier
					'calorie' => {
						'1' => q(feminine),
						'name' => q(ਕੈਲੋਰੀਆਂ),
					},
					# Long Unit Identifier
					'energy-electronvolt' => {
						'one' => q({0} ਇਲੈਕਟ੍ਰਾਨਵੋਲਟ),
						'other' => q({0} ਇਲੈਕਟ੍ਰਾਨਵੋਲਟ),
					},
					# Core Unit Identifier
					'electronvolt' => {
						'one' => q({0} ਇਲੈਕਟ੍ਰਾਨਵੋਲਟ),
						'other' => q({0} ਇਲੈਕਟ੍ਰਾਨਵੋਲਟ),
					},
					# Long Unit Identifier
					'energy-foodcalorie' => {
						'name' => q(ਕੈਲੋਰੀਆਂ),
					},
					# Core Unit Identifier
					'foodcalorie' => {
						'name' => q(ਕੈਲੋਰੀਆਂ),
					},
					# Long Unit Identifier
					'energy-joule' => {
						'1' => q(masculine),
						'one' => q({0} ਜੂਲ),
						'other' => q({0} ਜੂਲ),
					},
					# Core Unit Identifier
					'joule' => {
						'1' => q(masculine),
						'one' => q({0} ਜੂਲ),
						'other' => q({0} ਜੂਲ),
					},
					# Long Unit Identifier
					'energy-kilocalorie' => {
						'1' => q(feminine),
						'name' => q(ਕਿਲੋਕੈਲੋਰੀਆਂ),
						'one' => q({0} ਕਿਲੋਕੈਲੋਰੀ),
						'other' => q({0} ਕਿਲੋਕੈਲੋਰੀਆਂ),
					},
					# Core Unit Identifier
					'kilocalorie' => {
						'1' => q(feminine),
						'name' => q(ਕਿਲੋਕੈਲੋਰੀਆਂ),
						'one' => q({0} ਕਿਲੋਕੈਲੋਰੀ),
						'other' => q({0} ਕਿਲੋਕੈਲੋਰੀਆਂ),
					},
					# Long Unit Identifier
					'energy-kilojoule' => {
						'1' => q(masculine),
						'one' => q({0} ਕਿਲੋਜੂਲ),
						'other' => q({0} ਕਿਲੋਜੂਲ),
					},
					# Core Unit Identifier
					'kilojoule' => {
						'1' => q(masculine),
						'one' => q({0} ਕਿਲੋਜੂਲ),
						'other' => q({0} ਕਿਲੋਜੂਲ),
					},
					# Long Unit Identifier
					'energy-kilowatt-hour' => {
						'1' => q(masculine),
						'name' => q(ਕਿਲੋਵਾਟ-ਘੰਟੇ),
						'one' => q({0} ਕਿਲੋਵਾਟ ਘੰਟਾ),
						'other' => q({0} ਕਿਲੋਵਾਟ ਘੰਟੇ),
					},
					# Core Unit Identifier
					'kilowatt-hour' => {
						'1' => q(masculine),
						'name' => q(ਕਿਲੋਵਾਟ-ਘੰਟੇ),
						'one' => q({0} ਕਿਲੋਵਾਟ ਘੰਟਾ),
						'other' => q({0} ਕਿਲੋਵਾਟ ਘੰਟੇ),
					},
					# Long Unit Identifier
					'energy-therm-us' => {
						'name' => q(US therms),
					},
					# Core Unit Identifier
					'therm-us' => {
						'name' => q(US therms),
					},
					# Long Unit Identifier
					'force-kilowatt-hour-per-100-kilometer' => {
						'1' => q(masculine),
						'name' => q(ਕਿੱਲੋਵਾਟ-ਘੰਟਾ ਪ੍ਰਤੀ 100 ਕਿੱਲੋਮੀਟਰ),
						'one' => q({0} ਕਿੱਲੋਵਾਟ-ਘੰਟਾ ਪ੍ਰਤੀ 100 ਕਿੱਲੋਮੀਟਰ),
						'other' => q({0} ਕਿੱਲੋਵਾਟ-ਘੰਟਾ ਪ੍ਰਤੀ 100 ਕਿੱਲੋਮੀਟਰ),
					},
					# Core Unit Identifier
					'kilowatt-hour-per-100-kilometer' => {
						'1' => q(masculine),
						'name' => q(ਕਿੱਲੋਵਾਟ-ਘੰਟਾ ਪ੍ਰਤੀ 100 ਕਿੱਲੋਮੀਟਰ),
						'one' => q({0} ਕਿੱਲੋਵਾਟ-ਘੰਟਾ ਪ੍ਰਤੀ 100 ਕਿੱਲੋਮੀਟਰ),
						'other' => q({0} ਕਿੱਲੋਵਾਟ-ਘੰਟਾ ਪ੍ਰਤੀ 100 ਕਿੱਲੋਮੀਟਰ),
					},
					# Long Unit Identifier
					'force-newton' => {
						'1' => q(masculine),
						'one' => q({0} ਨਿਊਟਨ),
						'other' => q({0} ਨਿਊਟਨ),
					},
					# Core Unit Identifier
					'newton' => {
						'1' => q(masculine),
						'one' => q({0} ਨਿਊਟਨ),
						'other' => q({0} ਨਿਊਟਨ),
					},
					# Long Unit Identifier
					'force-pound-force' => {
						'name' => q(ਪੌਂਡ ਬਲ),
						'one' => q({0} ਪੌਂਡ ਬਲ),
						'other' => q({0} ਪੌਂਡ ਬਲ),
					},
					# Core Unit Identifier
					'pound-force' => {
						'name' => q(ਪੌਂਡ ਬਲ),
						'one' => q({0} ਪੌਂਡ ਬਲ),
						'other' => q({0} ਪੌਂਡ ਬਲ),
					},
					# Long Unit Identifier
					'frequency-gigahertz' => {
						'1' => q(masculine),
						'name' => q(ਗੀਗਾਹਰਟਜ਼),
						'one' => q({0} ਗੀਗਾਹਰਟਜ਼),
						'other' => q({0} ਗੀਗਾਹਰਟਜ਼),
					},
					# Core Unit Identifier
					'gigahertz' => {
						'1' => q(masculine),
						'name' => q(ਗੀਗਾਹਰਟਜ਼),
						'one' => q({0} ਗੀਗਾਹਰਟਜ਼),
						'other' => q({0} ਗੀਗਾਹਰਟਜ਼),
					},
					# Long Unit Identifier
					'frequency-hertz' => {
						'1' => q(masculine),
						'name' => q(ਹਰਟਜ਼),
						'one' => q({0} ਹਰਟਜ਼),
						'other' => q({0} ਹਰਟਜ਼),
					},
					# Core Unit Identifier
					'hertz' => {
						'1' => q(masculine),
						'name' => q(ਹਰਟਜ਼),
						'one' => q({0} ਹਰਟਜ਼),
						'other' => q({0} ਹਰਟਜ਼),
					},
					# Long Unit Identifier
					'frequency-kilohertz' => {
						'1' => q(masculine),
						'name' => q(ਕਿਲੋਹਰਟਜ਼),
						'one' => q({0} ਕਿਲੋਹਰਟਜ਼),
						'other' => q({0} ਕਿਲੋਹਰਟਜ਼),
					},
					# Core Unit Identifier
					'kilohertz' => {
						'1' => q(masculine),
						'name' => q(ਕਿਲੋਹਰਟਜ਼),
						'one' => q({0} ਕਿਲੋਹਰਟਜ਼),
						'other' => q({0} ਕਿਲੋਹਰਟਜ਼),
					},
					# Long Unit Identifier
					'frequency-megahertz' => {
						'1' => q(masculine),
						'name' => q(ਮੈਗਾਹਰਟਜ਼),
						'one' => q({0} ਮੈਗਾਹਰਟਜ਼),
						'other' => q({0} ਮੈਗਾਹਰਟਜ਼),
					},
					# Core Unit Identifier
					'megahertz' => {
						'1' => q(masculine),
						'name' => q(ਮੈਗਾਹਰਟਜ਼),
						'one' => q({0} ਮੈਗਾਹਰਟਜ਼),
						'other' => q({0} ਮੈਗਾਹਰਟਜ਼),
					},
					# Long Unit Identifier
					'graphics-dot-per-centimeter' => {
						'name' => q(ਡਾਟਸ ਪ੍ਰਤੀ ਸੈਂਟੀਮੀਟਰ),
						'one' => q({0} ਡਾਟ ਪ੍ਰਤੀ ਸੈਂਟੀਮੀਟਰ),
						'other' => q({0} ਡਾਟਸ ਪ੍ਰਤੀ ਸੈਂਟੀਮੀਟਰ),
					},
					# Core Unit Identifier
					'dot-per-centimeter' => {
						'name' => q(ਡਾਟਸ ਪ੍ਰਤੀ ਸੈਂਟੀਮੀਟਰ),
						'one' => q({0} ਡਾਟ ਪ੍ਰਤੀ ਸੈਂਟੀਮੀਟਰ),
						'other' => q({0} ਡਾਟਸ ਪ੍ਰਤੀ ਸੈਂਟੀਮੀਟਰ),
					},
					# Long Unit Identifier
					'graphics-dot-per-inch' => {
						'name' => q(ਡਾਟਸ ਪ੍ਰਤੀ ਇੰਚ),
						'one' => q({0} ਡਾਟ ਪ੍ਰਤੀ ਇੰਚ),
						'other' => q({0} ਡਾਟਸ ਪ੍ਰਤੀ ਇੰਚ),
					},
					# Core Unit Identifier
					'dot-per-inch' => {
						'name' => q(ਡਾਟਸ ਪ੍ਰਤੀ ਇੰਚ),
						'one' => q({0} ਡਾਟ ਪ੍ਰਤੀ ਇੰਚ),
						'other' => q({0} ਡਾਟਸ ਪ੍ਰਤੀ ਇੰਚ),
					},
					# Long Unit Identifier
					'graphics-em' => {
						'1' => q(masculine),
						'name' => q(ਟਾਈਪੋਗ੍ਰਾਫ਼ਿਕ ਐਮ),
						'one' => q({0} ਟਾਈਪੋਗ੍ਰਾਫ਼ਿਕ ਐਮ),
						'other' => q({0} ਟਾਈਪੋਗ੍ਰਾਫ਼ਿਕ ਐਮ),
					},
					# Core Unit Identifier
					'em' => {
						'1' => q(masculine),
						'name' => q(ਟਾਈਪੋਗ੍ਰਾਫ਼ਿਕ ਐਮ),
						'one' => q({0} ਟਾਈਪੋਗ੍ਰਾਫ਼ਿਕ ਐਮ),
						'other' => q({0} ਟਾਈਪੋਗ੍ਰਾਫ਼ਿਕ ਐਮ),
					},
					# Long Unit Identifier
					'graphics-megapixel' => {
						'1' => q(masculine),
						'name' => q(ਮੈਗਾਪਿਕਸਲ),
						'one' => q({0} ਮੈਗਾਪਿਕਸਲ),
						'other' => q({0} ਮੈਗਾਪਿਕਸਲ),
					},
					# Core Unit Identifier
					'megapixel' => {
						'1' => q(masculine),
						'name' => q(ਮੈਗਾਪਿਕਸਲ),
						'one' => q({0} ਮੈਗਾਪਿਕਸਲ),
						'other' => q({0} ਮੈਗਾਪਿਕਸਲ),
					},
					# Long Unit Identifier
					'graphics-pixel' => {
						'1' => q(masculine),
						'name' => q(ਪਿਕਸਲ),
						'one' => q({0} ਪਿਕਸਲ),
						'other' => q({0} ਪਿਕਸਲ),
					},
					# Core Unit Identifier
					'pixel' => {
						'1' => q(masculine),
						'name' => q(ਪਿਕਸਲ),
						'one' => q({0} ਪਿਕਸਲ),
						'other' => q({0} ਪਿਕਸਲ),
					},
					# Long Unit Identifier
					'graphics-pixel-per-centimeter' => {
						'1' => q(masculine),
						'name' => q(ਪਿਕਸਲ ਪ੍ਰਤੀ ਸੈਂਟੀਮੀਟਰ),
						'one' => q({0} ਪਿਕਸਲ ਪ੍ਰਤੀ ਸੈਂਟੀਮੀਟਰ),
						'other' => q({0} ਪਿਕਸਲ ਪ੍ਰਤੀ ਸੈਂਟੀਮੀਟਰ),
					},
					# Core Unit Identifier
					'pixel-per-centimeter' => {
						'1' => q(masculine),
						'name' => q(ਪਿਕਸਲ ਪ੍ਰਤੀ ਸੈਂਟੀਮੀਟਰ),
						'one' => q({0} ਪਿਕਸਲ ਪ੍ਰਤੀ ਸੈਂਟੀਮੀਟਰ),
						'other' => q({0} ਪਿਕਸਲ ਪ੍ਰਤੀ ਸੈਂਟੀਮੀਟਰ),
					},
					# Long Unit Identifier
					'graphics-pixel-per-inch' => {
						'name' => q(ਪਿਕਸਲ ਪ੍ਰਤੀ ਇੰਚ),
						'one' => q({0} ਪਿਕਸਲ ਪ੍ਰਤੀ ਇੰਚ),
						'other' => q({0} ਪਿਕਸਲ ਪ੍ਰਤੀ ਇੰਚ),
					},
					# Core Unit Identifier
					'pixel-per-inch' => {
						'name' => q(ਪਿਕਸਲ ਪ੍ਰਤੀ ਇੰਚ),
						'one' => q({0} ਪਿਕਸਲ ਪ੍ਰਤੀ ਇੰਚ),
						'other' => q({0} ਪਿਕਸਲ ਪ੍ਰਤੀ ਇੰਚ),
					},
					# Long Unit Identifier
					'length-astronomical-unit' => {
						'name' => q(ਖਗੋਲੀ ਇਕਾਈਆਂ),
						'one' => q({0} ਖਗੋਲੀ ਇਕਾਈ),
						'other' => q({0} ਖਗੋਲੀ ਇਕਾਈਆਂ),
					},
					# Core Unit Identifier
					'astronomical-unit' => {
						'name' => q(ਖਗੋਲੀ ਇਕਾਈਆਂ),
						'one' => q({0} ਖਗੋਲੀ ਇਕਾਈ),
						'other' => q({0} ਖਗੋਲੀ ਇਕਾਈਆਂ),
					},
					# Long Unit Identifier
					'length-centimeter' => {
						'1' => q(masculine),
						'name' => q(ਸੈਂਟੀਮੀਟਰ),
						'one' => q({0} ਸੈਂਟੀਮੀਟਰ),
						'other' => q({0} ਸੈਂਟੀਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਸੈਂਟੀਮੀਟਰ),
					},
					# Core Unit Identifier
					'centimeter' => {
						'1' => q(masculine),
						'name' => q(ਸੈਂਟੀਮੀਟਰ),
						'one' => q({0} ਸੈਂਟੀਮੀਟਰ),
						'other' => q({0} ਸੈਂਟੀਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਸੈਂਟੀਮੀਟਰ),
					},
					# Long Unit Identifier
					'length-decimeter' => {
						'1' => q(masculine),
						'name' => q(ਡੈਸੀਮੀਟਰ),
						'one' => q({0} ਡੈਸੀਮੀਟਰ),
						'other' => q({0} ਡੈਸੀਮੀਟਰ),
					},
					# Core Unit Identifier
					'decimeter' => {
						'1' => q(masculine),
						'name' => q(ਡੈਸੀਮੀਟਰ),
						'one' => q({0} ਡੈਸੀਮੀਟਰ),
						'other' => q({0} ਡੈਸੀਮੀਟਰ),
					},
					# Long Unit Identifier
					'length-earth-radius' => {
						'name' => q(ਧਰਤੀ ਦਾ ਘੇਰਾ),
						'one' => q({0} ਧਰਤੀ ਦਾ ਘੇਰਾ),
						'other' => q({0} ਧਰਤੀ ਦਾ ਘੇਰਾ),
					},
					# Core Unit Identifier
					'earth-radius' => {
						'name' => q(ਧਰਤੀ ਦਾ ਘੇਰਾ),
						'one' => q({0} ਧਰਤੀ ਦਾ ਘੇਰਾ),
						'other' => q({0} ਧਰਤੀ ਦਾ ਘੇਰਾ),
					},
					# Long Unit Identifier
					'length-foot' => {
						'per' => q({0} ਪ੍ਰਤੀ ਫੁੱਟ),
					},
					# Core Unit Identifier
					'foot' => {
						'per' => q({0} ਪ੍ਰਤੀ ਫੁੱਟ),
					},
					# Long Unit Identifier
					'length-inch' => {
						'per' => q({0} ਪ੍ਰਤੀ ਇੰਚ),
					},
					# Core Unit Identifier
					'inch' => {
						'per' => q({0} ਪ੍ਰਤੀ ਇੰਚ),
					},
					# Long Unit Identifier
					'length-kilometer' => {
						'1' => q(masculine),
						'name' => q(ਕਿਲੋਮੀਟਰ),
						'one' => q({0} ਕਿਲੋਮੀਟਰ),
						'other' => q({0} ਕਿਲੋਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਕਿਲੋਮੀਟਰ),
					},
					# Core Unit Identifier
					'kilometer' => {
						'1' => q(masculine),
						'name' => q(ਕਿਲੋਮੀਟਰ),
						'one' => q({0} ਕਿਲੋਮੀਟਰ),
						'other' => q({0} ਕਿਲੋਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਕਿਲੋਮੀਟਰ),
					},
					# Long Unit Identifier
					'length-light-year' => {
						'one' => q({0} ਪ੍ਰਕਾਸ਼ ਸਾਲ),
						'other' => q({0} ਪ੍ਰਕਾਸ਼ ਸਾਲ),
					},
					# Core Unit Identifier
					'light-year' => {
						'one' => q({0} ਪ੍ਰਕਾਸ਼ ਸਾਲ),
						'other' => q({0} ਪ੍ਰਕਾਸ਼ ਸਾਲ),
					},
					# Long Unit Identifier
					'length-meter' => {
						'1' => q(masculine),
						'one' => q({0} ਮੀਟਰ),
						'other' => q({0} ਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਮੀਟਰ),
					},
					# Core Unit Identifier
					'meter' => {
						'1' => q(masculine),
						'one' => q({0} ਮੀਟਰ),
						'other' => q({0} ਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਮੀਟਰ),
					},
					# Long Unit Identifier
					'length-micrometer' => {
						'1' => q(masculine),
						'one' => q({0} ਮਾਈਕਰੋਮੀਟਰ),
						'other' => q({0} ਮਾਈਕਰੋਮੀਟਰ),
					},
					# Core Unit Identifier
					'micrometer' => {
						'1' => q(masculine),
						'one' => q({0} ਮਾਈਕਰੋਮੀਟਰ),
						'other' => q({0} ਮਾਈਕਰੋਮੀਟਰ),
					},
					# Long Unit Identifier
					'length-mile-scandinavian' => {
						'1' => q(masculine),
						'name' => q(ਮੀਲ-ਸਕੈਂਡਿਨੇਵਿਆਈ),
						'one' => q({0} ਮੀਲ-ਸਕੈਂਡਿਨੇਵਿਆਈ),
						'other' => q({0} ਮੀਲ-ਸਕੈਂਡਿਨੇਵਿਆਈ),
					},
					# Core Unit Identifier
					'mile-scandinavian' => {
						'1' => q(masculine),
						'name' => q(ਮੀਲ-ਸਕੈਂਡਿਨੇਵਿਆਈ),
						'one' => q({0} ਮੀਲ-ਸਕੈਂਡਿਨੇਵਿਆਈ),
						'other' => q({0} ਮੀਲ-ਸਕੈਂਡਿਨੇਵਿਆਈ),
					},
					# Long Unit Identifier
					'length-millimeter' => {
						'1' => q(masculine),
						'name' => q(ਮਿਲੀਮੀਟਰ),
						'one' => q({0} ਮਿਲੀਮੀਟਰ),
						'other' => q({0} ਮਿਲੀਮੀਟਰ),
					},
					# Core Unit Identifier
					'millimeter' => {
						'1' => q(masculine),
						'name' => q(ਮਿਲੀਮੀਟਰ),
						'one' => q({0} ਮਿਲੀਮੀਟਰ),
						'other' => q({0} ਮਿਲੀਮੀਟਰ),
					},
					# Long Unit Identifier
					'length-nanometer' => {
						'1' => q(masculine),
						'name' => q(ਨੈਨੋਮੀਟਰ),
						'one' => q({0} ਨੈਨੋਮੀਟਰ),
						'other' => q({0} ਨੈਨੋਮੀਟਰ),
					},
					# Core Unit Identifier
					'nanometer' => {
						'1' => q(masculine),
						'name' => q(ਨੈਨੋਮੀਟਰ),
						'one' => q({0} ਨੈਨੋਮੀਟਰ),
						'other' => q({0} ਨੈਨੋਮੀਟਰ),
					},
					# Long Unit Identifier
					'length-nautical-mile' => {
						'name' => q(ਨੋਟੀਕਲ ਮੀਲ),
						'one' => q({0} ਨੋਟੀਕਲ ਮੀਲ),
						'other' => q({0} ਨੋਟੀਕਲ ਮੀਲ),
					},
					# Core Unit Identifier
					'nautical-mile' => {
						'name' => q(ਨੋਟੀਕਲ ਮੀਲ),
						'one' => q({0} ਨੋਟੀਕਲ ਮੀਲ),
						'other' => q({0} ਨੋਟੀਕਲ ਮੀਲ),
					},
					# Long Unit Identifier
					'length-picometer' => {
						'1' => q(masculine),
						'name' => q(ਪਿਕੋਮੀਟਰ),
					},
					# Core Unit Identifier
					'picometer' => {
						'1' => q(masculine),
						'name' => q(ਪਿਕੋਮੀਟਰ),
					},
					# Long Unit Identifier
					'length-point' => {
						'1' => q(masculine),
						'one' => q({0} ਪੁਆਇੰਟ),
						'other' => q({0} ਪੁਆਇੰਟ),
					},
					# Core Unit Identifier
					'point' => {
						'1' => q(masculine),
						'one' => q({0} ਪੁਆਇੰਟ),
						'other' => q({0} ਪੁਆਇੰਟ),
					},
					# Long Unit Identifier
					'length-solar-radius' => {
						'one' => q({0} ਸੋਲਰ ਰੇਡੀਅਸ),
						'other' => q({0} ਸੋਲਰ ਰੇਡੀਅਸ),
					},
					# Core Unit Identifier
					'solar-radius' => {
						'one' => q({0} ਸੋਲਰ ਰੇਡੀਅਸ),
						'other' => q({0} ਸੋਲਰ ਰੇਡੀਅਸ),
					},
					# Long Unit Identifier
					'light-candela' => {
						'1' => q(masculine),
						'name' => q(ਕੈਂਡੇਲਾ),
						'one' => q({0} ਕੈਂਡੇਲਾ),
						'other' => q({0} ਕੈਂਡੇਲਾ),
					},
					# Core Unit Identifier
					'candela' => {
						'1' => q(masculine),
						'name' => q(ਕੈਂਡੇਲਾ),
						'one' => q({0} ਕੈਂਡੇਲਾ),
						'other' => q({0} ਕੈਂਡੇਲਾ),
					},
					# Long Unit Identifier
					'light-lumen' => {
						'1' => q(masculine),
					},
					# Core Unit Identifier
					'lumen' => {
						'1' => q(masculine),
					},
					# Long Unit Identifier
					'light-lux' => {
						'1' => q(masculine),
					},
					# Core Unit Identifier
					'lux' => {
						'1' => q(masculine),
					},
					# Long Unit Identifier
					'light-solar-luminosity' => {
						'one' => q({0} ਸੋਲਰ ਲੂਮਨਾਸਿਟੀ),
						'other' => q({0} ਸੋਲਰ ਲੂਮਨਾਸਿਟੀ),
					},
					# Core Unit Identifier
					'solar-luminosity' => {
						'one' => q({0} ਸੋਲਰ ਲੂਮਨਾਸਿਟੀ),
						'other' => q({0} ਸੋਲਰ ਲੂਮਨਾਸਿਟੀ),
					},
					# Long Unit Identifier
					'mass-carat' => {
						'1' => q(masculine),
					},
					# Core Unit Identifier
					'carat' => {
						'1' => q(masculine),
					},
					# Long Unit Identifier
					'mass-dalton' => {
						'one' => q({0} ਡਾਲਟਨ),
						'other' => q({0} ਡਾਲਟਨ),
					},
					# Core Unit Identifier
					'dalton' => {
						'one' => q({0} ਡਾਲਟਨ),
						'other' => q({0} ਡਾਲਟਨ),
					},
					# Long Unit Identifier
					'mass-earth-mass' => {
						'one' => q({0} ਅਰਥ ਮਾਸ),
						'other' => q({0} ਅਰਥ ਮਾਸ),
					},
					# Core Unit Identifier
					'earth-mass' => {
						'one' => q({0} ਅਰਥ ਮਾਸ),
						'other' => q({0} ਅਰਥ ਮਾਸ),
					},
					# Long Unit Identifier
					'mass-gram' => {
						'1' => q(masculine),
						'one' => q({0} ਗ੍ਰਾਮ),
						'other' => q({0} ਗ੍ਰਾਮ),
						'per' => q({0} ਪ੍ਰਤੀ ਗ੍ਰਾਮ),
					},
					# Core Unit Identifier
					'gram' => {
						'1' => q(masculine),
						'one' => q({0} ਗ੍ਰਾਮ),
						'other' => q({0} ਗ੍ਰਾਮ),
						'per' => q({0} ਪ੍ਰਤੀ ਗ੍ਰਾਮ),
					},
					# Long Unit Identifier
					'mass-kilogram' => {
						'1' => q(masculine),
						'name' => q(ਕਿਲੋਗ੍ਰਾਮ),
						'one' => q({0} ਕਿਲੋਗ੍ਰਾਮ),
						'other' => q({0} ਕਿਲੋਗ੍ਰਾਮ),
						'per' => q({0} ਪ੍ਰਤੀ ਕਿਲੋਗ੍ਰਾਮ),
					},
					# Core Unit Identifier
					'kilogram' => {
						'1' => q(masculine),
						'name' => q(ਕਿਲੋਗ੍ਰਾਮ),
						'one' => q({0} ਕਿਲੋਗ੍ਰਾਮ),
						'other' => q({0} ਕਿਲੋਗ੍ਰਾਮ),
						'per' => q({0} ਪ੍ਰਤੀ ਕਿਲੋਗ੍ਰਾਮ),
					},
					# Long Unit Identifier
					'mass-microgram' => {
						'1' => q(masculine),
						'name' => q(ਮਾਈਕਰੋਗ੍ਰਾਮ),
						'one' => q({0} ਮਾਈਕਰੋਗ੍ਰਾਮ),
						'other' => q({0} ਮਾਈਕਰੋਗ੍ਰਾਮ),
					},
					# Core Unit Identifier
					'microgram' => {
						'1' => q(masculine),
						'name' => q(ਮਾਈਕਰੋਗ੍ਰਾਮ),
						'one' => q({0} ਮਾਈਕਰੋਗ੍ਰਾਮ),
						'other' => q({0} ਮਾਈਕਰੋਗ੍ਰਾਮ),
					},
					# Long Unit Identifier
					'mass-milligram' => {
						'1' => q(masculine),
						'name' => q(ਮਿਲੀਗ੍ਰਾਮ),
						'one' => q({0} ਮਿਲੀਗ੍ਰਾਮ),
						'other' => q({0} ਮਿਲੀਗ੍ਰਾਮ),
					},
					# Core Unit Identifier
					'milligram' => {
						'1' => q(masculine),
						'name' => q(ਮਿਲੀਗ੍ਰਾਮ),
						'one' => q({0} ਮਿਲੀਗ੍ਰਾਮ),
						'other' => q({0} ਮਿਲੀਗ੍ਰਾਮ),
					},
					# Long Unit Identifier
					'mass-ounce' => {
						'per' => q({0} ਪ੍ਰਤੀ ਔਂਸ),
					},
					# Core Unit Identifier
					'ounce' => {
						'per' => q({0} ਪ੍ਰਤੀ ਔਂਸ),
					},
					# Long Unit Identifier
					'mass-ounce-troy' => {
						'name' => q(ਟਰੌਏ ਔਂਸ),
						'one' => q({0} ਟਰੌਏ ਔਂਸ),
						'other' => q({0} ਟਰੌਏ ਔਂਸ),
					},
					# Core Unit Identifier
					'ounce-troy' => {
						'name' => q(ਟਰੌਏ ਔਂਸ),
						'one' => q({0} ਟਰੌਏ ਔਂਸ),
						'other' => q({0} ਟਰੌਏ ਔਂਸ),
					},
					# Long Unit Identifier
					'mass-pound' => {
						'per' => q({0} ਪ੍ਰਤੀ ਪੌਂਡ),
					},
					# Core Unit Identifier
					'pound' => {
						'per' => q({0} ਪ੍ਰਤੀ ਪੌਂਡ),
					},
					# Long Unit Identifier
					'mass-solar-mass' => {
						'one' => q({0} ਸੋਲਰ ਮਾਸ),
						'other' => q({0} ਸੋਲਰ ਮਾਸ),
					},
					# Core Unit Identifier
					'solar-mass' => {
						'one' => q({0} ਸੋਲਰ ਮਾਸ),
						'other' => q({0} ਸੋਲਰ ਮਾਸ),
					},
					# Long Unit Identifier
					'mass-tonne' => {
						'1' => q(masculine),
						'name' => q(ਮੀਟਰਿਕ ਟਨ),
						'one' => q({0} ਮੀਟਰਿਕ ਟਨ),
						'other' => q({0} ਮੀਟਰਿਕ ਟਨ),
					},
					# Core Unit Identifier
					'tonne' => {
						'1' => q(masculine),
						'name' => q(ਮੀਟਰਿਕ ਟਨ),
						'one' => q({0} ਮੀਟਰਿਕ ਟਨ),
						'other' => q({0} ਮੀਟਰਿਕ ਟਨ),
					},
					# Long Unit Identifier
					'per' => {
						'1' => q({0} ਪ੍ਰਤੀ {1}),
					},
					# Core Unit Identifier
					'per' => {
						'1' => q({0} ਪ੍ਰਤੀ {1}),
					},
					# Long Unit Identifier
					'power-gigawatt' => {
						'1' => q(masculine),
						'name' => q(ਗੀਗਾਵਾਟ),
						'one' => q({0} ਗੀਗਾਵਾਟ),
						'other' => q({0} ਗੀਗਾਵਾਟ),
					},
					# Core Unit Identifier
					'gigawatt' => {
						'1' => q(masculine),
						'name' => q(ਗੀਗਾਵਾਟ),
						'one' => q({0} ਗੀਗਾਵਾਟ),
						'other' => q({0} ਗੀਗਾਵਾਟ),
					},
					# Long Unit Identifier
					'power-horsepower' => {
						'name' => q(ਹੌਰਸਪਾਵਰ),
					},
					# Core Unit Identifier
					'horsepower' => {
						'name' => q(ਹੌਰਸਪਾਵਰ),
					},
					# Long Unit Identifier
					'power-kilowatt' => {
						'1' => q(masculine),
						'name' => q(ਕਿਲੋਵਾਟ),
						'one' => q({0} ਕਿਲੋਵਾਟ),
						'other' => q({0} ਕਿਲੋਵਾਟ),
					},
					# Core Unit Identifier
					'kilowatt' => {
						'1' => q(masculine),
						'name' => q(ਕਿਲੋਵਾਟ),
						'one' => q({0} ਕਿਲੋਵਾਟ),
						'other' => q({0} ਕਿਲੋਵਾਟ),
					},
					# Long Unit Identifier
					'power-megawatt' => {
						'1' => q(masculine),
						'name' => q(ਮੈਗਾਵਾਟ),
						'one' => q({0} ਮੈਗਾਵਾਟ),
						'other' => q({0} ਮੈਗਾਵਾਟ),
					},
					# Core Unit Identifier
					'megawatt' => {
						'1' => q(masculine),
						'name' => q(ਮੈਗਾਵਾਟ),
						'one' => q({0} ਮੈਗਾਵਾਟ),
						'other' => q({0} ਮੈਗਾਵਾਟ),
					},
					# Long Unit Identifier
					'power-milliwatt' => {
						'1' => q(masculine),
						'name' => q(ਮਿਲੀਵਾਟ),
						'one' => q({0} ਮਿਲੀਵਾਟ),
						'other' => q({0} ਮਿਲੀਵਾਟ),
					},
					# Core Unit Identifier
					'milliwatt' => {
						'1' => q(masculine),
						'name' => q(ਮਿਲੀਵਾਟ),
						'one' => q({0} ਮਿਲੀਵਾਟ),
						'other' => q({0} ਮਿਲੀਵਾਟ),
					},
					# Long Unit Identifier
					'power-watt' => {
						'1' => q(feminine),
					},
					# Core Unit Identifier
					'watt' => {
						'1' => q(feminine),
					},
					# Long Unit Identifier
					'power2' => {
						'1' => q(ਵਰਗ{0}),
						'one' => q(ਵਰਗ{0}),
						'other' => q(ਵਰਗ{0}),
					},
					# Core Unit Identifier
					'power2' => {
						'1' => q(ਵਰਗ{0}),
						'one' => q(ਵਰਗ{0}),
						'other' => q(ਵਰਗ{0}),
					},
					# Long Unit Identifier
					'power3' => {
						'1' => q(ਘਣ{0}),
						'one' => q(ਘਣ{0}),
						'other' => q(ਘਣ{0}),
					},
					# Core Unit Identifier
					'power3' => {
						'1' => q(ਘਣ{0}),
						'one' => q(ਘਣ{0}),
						'other' => q(ਘਣ{0}),
					},
					# Long Unit Identifier
					'pressure-atmosphere' => {
						'1' => q(masculine),
						'name' => q(ਵਾਯੂਮੰਡਲ),
						'one' => q({0} ਵਾਯੂਮੰਡਲ),
						'other' => q({0} ਵਾਯੂਮੰਡਲ),
					},
					# Core Unit Identifier
					'atmosphere' => {
						'1' => q(masculine),
						'name' => q(ਵਾਯੂਮੰਡਲ),
						'one' => q({0} ਵਾਯੂਮੰਡਲ),
						'other' => q({0} ਵਾਯੂਮੰਡਲ),
					},
					# Long Unit Identifier
					'pressure-bar' => {
						'1' => q(masculine),
					},
					# Core Unit Identifier
					'bar' => {
						'1' => q(masculine),
					},
					# Long Unit Identifier
					'pressure-hectopascal' => {
						'1' => q(masculine),
						'name' => q(ਹੈਕਟੋਪਾਸਕਲ),
						'one' => q({0} ਹੈਕਟੋਪਾਸਕਲ),
						'other' => q({0} ਹੈਕਟੋਪਾਸਕਲ),
					},
					# Core Unit Identifier
					'hectopascal' => {
						'1' => q(masculine),
						'name' => q(ਹੈਕਟੋਪਾਸਕਲ),
						'one' => q({0} ਹੈਕਟੋਪਾਸਕਲ),
						'other' => q({0} ਹੈਕਟੋਪਾਸਕਲ),
					},
					# Long Unit Identifier
					'pressure-kilopascal' => {
						'1' => q(masculine),
						'name' => q(ਕਿੱਲੋਪਾਸਕਲ),
						'one' => q({0} ਕਿੱਲੋਪਾਸਕਲ),
						'other' => q({0} ਕਿੱਲੋਪਾਸਕਲ),
					},
					# Core Unit Identifier
					'kilopascal' => {
						'1' => q(masculine),
						'name' => q(ਕਿੱਲੋਪਾਸਕਲ),
						'one' => q({0} ਕਿੱਲੋਪਾਸਕਲ),
						'other' => q({0} ਕਿੱਲੋਪਾਸਕਲ),
					},
					# Long Unit Identifier
					'pressure-megapascal' => {
						'1' => q(masculine),
						'name' => q(ਮੈਗਾਪਾਸਕਲ),
						'one' => q({0} ਮੈਗਾਪਾਸਕਲ),
						'other' => q({0} ਮੈਗਾਪਾਸਕਲ),
					},
					# Core Unit Identifier
					'megapascal' => {
						'1' => q(masculine),
						'name' => q(ਮੈਗਾਪਾਸਕਲ),
						'one' => q({0} ਮੈਗਾਪਾਸਕਲ),
						'other' => q({0} ਮੈਗਾਪਾਸਕਲ),
					},
					# Long Unit Identifier
					'pressure-millibar' => {
						'1' => q(masculine),
					},
					# Core Unit Identifier
					'millibar' => {
						'1' => q(masculine),
					},
					# Long Unit Identifier
					'pressure-millimeter-ofhg' => {
						'1' => q(masculine),
						'name' => q(ਮਿਲੀਮੀਟਰ ਪਾਰਾ),
						'one' => q({0} ਮਿਲੀਮੀਟਰ ਪਾਰਾ),
						'other' => q({0} ਮਿਲੀਮੀਟਰ ਪਾਰਾ),
					},
					# Core Unit Identifier
					'millimeter-ofhg' => {
						'1' => q(masculine),
						'name' => q(ਮਿਲੀਮੀਟਰ ਪਾਰਾ),
						'one' => q({0} ਮਿਲੀਮੀਟਰ ਪਾਰਾ),
						'other' => q({0} ਮਿਲੀਮੀਟਰ ਪਾਰਾ),
					},
					# Long Unit Identifier
					'pressure-pascal' => {
						'1' => q(masculine),
						'name' => q(ਪੈਸਕਲ),
						'one' => q({0} ਪੈਸਕਲ),
						'other' => q({0} ਪੈਸਕਲ),
					},
					# Core Unit Identifier
					'pascal' => {
						'1' => q(masculine),
						'name' => q(ਪੈਸਕਲ),
						'one' => q({0} ਪੈਸਕਲ),
						'other' => q({0} ਪੈਸਕਲ),
					},
					# Long Unit Identifier
					'pressure-pound-force-per-square-inch' => {
						'name' => q(ਪੌਂਡ ਪ੍ਰਤੀ ਵਰਗ ਇੰਚ),
						'one' => q({0} ਪੌਂਡ ਪ੍ਰਤੀ ਵਰਗ ਇੰਚ),
						'other' => q({0} ਪੌਂਡ ਪ੍ਰਤੀ ਵਰਗ ਇੰਚ),
					},
					# Core Unit Identifier
					'pound-force-per-square-inch' => {
						'name' => q(ਪੌਂਡ ਪ੍ਰਤੀ ਵਰਗ ਇੰਚ),
						'one' => q({0} ਪੌਂਡ ਪ੍ਰਤੀ ਵਰਗ ਇੰਚ),
						'other' => q({0} ਪੌਂਡ ਪ੍ਰਤੀ ਵਰਗ ਇੰਚ),
					},
					# Long Unit Identifier
					'speed-beaufort' => {
						'name' => q(ਬਿਊਫੋਰਟ),
						'one' => q(ਬਿਊਫੋਰਟ {0}),
						'other' => q(ਬਿਊਫੋਰਟ {0}),
					},
					# Core Unit Identifier
					'beaufort' => {
						'name' => q(ਬਿਊਫੋਰਟ),
						'one' => q(ਬਿਊਫੋਰਟ {0}),
						'other' => q(ਬਿਊਫੋਰਟ {0}),
					},
					# Long Unit Identifier
					'speed-kilometer-per-hour' => {
						'1' => q(masculine),
						'name' => q(ਕਿਲੋਮੀਟਰ ਪ੍ਰਤੀ ਘੰਟਾ),
						'one' => q({0} ਕਿਲੋਮੀਟਰ ਪ੍ਰਤੀ ਘੰਟਾ),
						'other' => q({0} ਕਿਲੋਮੀਟਰ ਪ੍ਰਤੀ ਘੰਟਾ),
					},
					# Core Unit Identifier
					'kilometer-per-hour' => {
						'1' => q(masculine),
						'name' => q(ਕਿਲੋਮੀਟਰ ਪ੍ਰਤੀ ਘੰਟਾ),
						'one' => q({0} ਕਿਲੋਮੀਟਰ ਪ੍ਰਤੀ ਘੰਟਾ),
						'other' => q({0} ਕਿਲੋਮੀਟਰ ਪ੍ਰਤੀ ਘੰਟਾ),
					},
					# Long Unit Identifier
					'speed-knot' => {
						'name' => q(ਨੌਟ),
						'one' => q({0} ਨੌਟ),
						'other' => q({0} ਨੌਟ),
					},
					# Core Unit Identifier
					'knot' => {
						'name' => q(ਨੌਟ),
						'one' => q({0} ਨੌਟ),
						'other' => q({0} ਨੌਟ),
					},
					# Long Unit Identifier
					'speed-light-speed' => {
						'1' => q(masculine),
						'name' => q(ਪ੍ਰਕਾਸ਼),
						'one' => q({0} ਪ੍ਰਕਾਸ਼),
						'other' => q({0} ਪ੍ਰਕਾਸ਼),
					},
					# Core Unit Identifier
					'light-speed' => {
						'1' => q(masculine),
						'name' => q(ਪ੍ਰਕਾਸ਼),
						'one' => q({0} ਪ੍ਰਕਾਸ਼),
						'other' => q({0} ਪ੍ਰਕਾਸ਼),
					},
					# Long Unit Identifier
					'speed-meter-per-second' => {
						'1' => q(masculine),
						'name' => q(ਮੀਟਰ ਪ੍ਰਤੀ ਸਕਿੰਟ),
						'one' => q({0} ਮੀਟਰ ਪ੍ਰਤੀ ਸਕਿੰਟ),
						'other' => q({0} ਮੀਟਰ ਪ੍ਰਤੀ ਸਕਿੰਟ),
					},
					# Core Unit Identifier
					'meter-per-second' => {
						'1' => q(masculine),
						'name' => q(ਮੀਟਰ ਪ੍ਰਤੀ ਸਕਿੰਟ),
						'one' => q({0} ਮੀਟਰ ਪ੍ਰਤੀ ਸਕਿੰਟ),
						'other' => q({0} ਮੀਟਰ ਪ੍ਰਤੀ ਸਕਿੰਟ),
					},
					# Long Unit Identifier
					'speed-mile-per-hour' => {
						'name' => q(ਮੀਲ ਪ੍ਰਤੀ ਘੰਟਾ),
						'one' => q({0} ਮੀਲ ਪ੍ਰਤੀ ਘੰਟਾ),
						'other' => q({0} ਮੀਲ ਪ੍ਰਤੀ ਘੰਟਾ),
					},
					# Core Unit Identifier
					'mile-per-hour' => {
						'name' => q(ਮੀਲ ਪ੍ਰਤੀ ਘੰਟਾ),
						'one' => q({0} ਮੀਲ ਪ੍ਰਤੀ ਘੰਟਾ),
						'other' => q({0} ਮੀਲ ਪ੍ਰਤੀ ਘੰਟਾ),
					},
					# Long Unit Identifier
					'temperature-celsius' => {
						'1' => q(masculine),
						'name' => q(ਡਿਗਰੀ ਸੈਲਸੀਅਸ),
						'one' => q({0} ਡਿਗਰੀ ਸੈਲਸੀਅਸ),
						'other' => q({0} ਡਿਗਰੀ ਸੈਲਸੀਅਸ),
					},
					# Core Unit Identifier
					'celsius' => {
						'1' => q(masculine),
						'name' => q(ਡਿਗਰੀ ਸੈਲਸੀਅਸ),
						'one' => q({0} ਡਿਗਰੀ ਸੈਲਸੀਅਸ),
						'other' => q({0} ਡਿਗਰੀ ਸੈਲਸੀਅਸ),
					},
					# Long Unit Identifier
					'temperature-fahrenheit' => {
						'name' => q(ਡਿਗਰੀ ਫਾਰੇਨਹਾਈਟ),
						'one' => q({0} ਡਿਗਰੀ ਫਾਰੇਨਹਾਈਟ),
						'other' => q({0} ਡਿਗਰੀ ਫਾਰੇਨਹਾਈਟ),
					},
					# Core Unit Identifier
					'fahrenheit' => {
						'name' => q(ਡਿਗਰੀ ਫਾਰੇਨਹਾਈਟ),
						'one' => q({0} ਡਿਗਰੀ ਫਾਰੇਨਹਾਈਟ),
						'other' => q({0} ਡਿਗਰੀ ਫਾਰੇਨਹਾਈਟ),
					},
					# Long Unit Identifier
					'temperature-generic' => {
						'1' => q(feminine),
						'one' => q({0} ਡਿਗਰੀ),
						'other' => q({0} ਡਿਗਰੀ),
					},
					# Core Unit Identifier
					'generic' => {
						'1' => q(feminine),
						'one' => q({0} ਡਿਗਰੀ),
						'other' => q({0} ਡਿਗਰੀ),
					},
					# Long Unit Identifier
					'temperature-kelvin' => {
						'1' => q(masculine),
						'name' => q(ਕੈਲਵਿਨ),
						'one' => q({0} ਕੈਲਵਿਨ),
						'other' => q({0} ਕੈਲਵਿਨ),
					},
					# Core Unit Identifier
					'kelvin' => {
						'1' => q(masculine),
						'name' => q(ਕੈਲਵਿਨ),
						'one' => q({0} ਕੈਲਵਿਨ),
						'other' => q({0} ਕੈਲਵਿਨ),
					},
					# Long Unit Identifier
					'torque-newton-meter' => {
						'1' => q(masculine),
						'name' => q(ਨਿਊਟਨ-ਮੀਟਰ),
						'one' => q({0} ਨਿਊਟਨ-ਮੀਟਰ),
						'other' => q({0} ਨਿਊਟਨ-ਮੀਟਰ),
					},
					# Core Unit Identifier
					'newton-meter' => {
						'1' => q(masculine),
						'name' => q(ਨਿਊਟਨ-ਮੀਟਰ),
						'one' => q({0} ਨਿਊਟਨ-ਮੀਟਰ),
						'other' => q({0} ਨਿਊਟਨ-ਮੀਟਰ),
					},
					# Long Unit Identifier
					'torque-pound-force-foot' => {
						'name' => q(ਪੌਂਡ-ਫੁੱਟ),
						'one' => q({0} ਪੌਂਡ-ਬਲ-ਫੁੱਟ),
						'other' => q({0} ਪੌਂਡ-ਫੁੱਟ),
					},
					# Core Unit Identifier
					'pound-force-foot' => {
						'name' => q(ਪੌਂਡ-ਫੁੱਟ),
						'one' => q({0} ਪੌਂਡ-ਬਲ-ਫੁੱਟ),
						'other' => q({0} ਪੌਂਡ-ਫੁੱਟ),
					},
					# Long Unit Identifier
					'volume-centiliter' => {
						'1' => q(masculine),
						'name' => q(ਸੈਂਟੀਲਿਟਰ),
						'one' => q({0} ਸੈਂਟੀਲਿਟਰ),
						'other' => q({0} ਸੈਂਟੀਲਿਟਰ),
					},
					# Core Unit Identifier
					'centiliter' => {
						'1' => q(masculine),
						'name' => q(ਸੈਂਟੀਲਿਟਰ),
						'one' => q({0} ਸੈਂਟੀਲਿਟਰ),
						'other' => q({0} ਸੈਂਟੀਲਿਟਰ),
					},
					# Long Unit Identifier
					'volume-cubic-centimeter' => {
						'1' => q(masculine),
						'name' => q(ਘਣ ਸੈਂਟੀਮੀਟਰ),
						'one' => q({0} ਘਣ ਸੈਂਟੀਮੀਟਰ),
						'other' => q({0} ਘਣ ਸੈਂਟੀਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਘਣ ਸੈਂਟੀਮੀਟਰ),
					},
					# Core Unit Identifier
					'cubic-centimeter' => {
						'1' => q(masculine),
						'name' => q(ਘਣ ਸੈਂਟੀਮੀਟਰ),
						'one' => q({0} ਘਣ ਸੈਂਟੀਮੀਟਰ),
						'other' => q({0} ਘਣ ਸੈਂਟੀਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਘਣ ਸੈਂਟੀਮੀਟਰ),
					},
					# Long Unit Identifier
					'volume-cubic-foot' => {
						'name' => q(ਘਣ ਫੁੱਟ),
						'one' => q({0} ਘਣ ਫੁੱਟ),
						'other' => q({0} ਘਣ ਫੁੱਟ),
					},
					# Core Unit Identifier
					'cubic-foot' => {
						'name' => q(ਘਣ ਫੁੱਟ),
						'one' => q({0} ਘਣ ਫੁੱਟ),
						'other' => q({0} ਘਣ ਫੁੱਟ),
					},
					# Long Unit Identifier
					'volume-cubic-inch' => {
						'name' => q(ਘਣ ਇੰਚ),
						'one' => q({0} ਘਣ ਇੰਚ),
						'other' => q({0} ਘਣ ਇੰਚ),
					},
					# Core Unit Identifier
					'cubic-inch' => {
						'name' => q(ਘਣ ਇੰਚ),
						'one' => q({0} ਘਣ ਇੰਚ),
						'other' => q({0} ਘਣ ਇੰਚ),
					},
					# Long Unit Identifier
					'volume-cubic-kilometer' => {
						'1' => q(masculine),
						'name' => q(ਘਣ ਕਿਲੋਮੀਟਰ),
						'one' => q({0} ਘਣ ਕਿਲੋਮੀਟਰ),
						'other' => q({0} ਘਣ ਕਿਲੋਮੀਟਰ),
					},
					# Core Unit Identifier
					'cubic-kilometer' => {
						'1' => q(masculine),
						'name' => q(ਘਣ ਕਿਲੋਮੀਟਰ),
						'one' => q({0} ਘਣ ਕਿਲੋਮੀਟਰ),
						'other' => q({0} ਘਣ ਕਿਲੋਮੀਟਰ),
					},
					# Long Unit Identifier
					'volume-cubic-meter' => {
						'1' => q(masculine),
						'name' => q(ਘਣ ਮੀਟਰ),
						'one' => q({0} ਘਣ ਮੀਟਰ),
						'other' => q({0} ਘਣ ਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਘਣ ਮੀਟਰ),
					},
					# Core Unit Identifier
					'cubic-meter' => {
						'1' => q(masculine),
						'name' => q(ਘਣ ਮੀਟਰ),
						'one' => q({0} ਘਣ ਮੀਟਰ),
						'other' => q({0} ਘਣ ਮੀਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਘਣ ਮੀਟਰ),
					},
					# Long Unit Identifier
					'volume-cubic-mile' => {
						'name' => q(ਘਣ ਮੀਲ),
						'one' => q({0} ਘਣ ਮੀਲ),
						'other' => q({0} ਘਣ ਮੀਲ),
					},
					# Core Unit Identifier
					'cubic-mile' => {
						'name' => q(ਘਣ ਮੀਲ),
						'one' => q({0} ਘਣ ਮੀਲ),
						'other' => q({0} ਘਣ ਮੀਲ),
					},
					# Long Unit Identifier
					'volume-cubic-yard' => {
						'name' => q(ਘਣ ਗਜ਼),
						'one' => q({0} ਘਣ ਗਜ਼),
						'other' => q({0} ਘਣ ਗਜ਼),
					},
					# Core Unit Identifier
					'cubic-yard' => {
						'name' => q(ਘਣ ਗਜ਼),
						'one' => q({0} ਘਣ ਗਜ਼),
						'other' => q({0} ਘਣ ਗਜ਼),
					},
					# Long Unit Identifier
					'volume-cup-metric' => {
						'1' => q(masculine),
						'name' => q(ਮੀਟਰਿਕ ਕੱਪ),
						'one' => q({0} ਮੀਟਰਿਕ ਕੱਪ),
						'other' => q({0} ਮੀਟਰਿਕ ਕੱਪ),
					},
					# Core Unit Identifier
					'cup-metric' => {
						'1' => q(masculine),
						'name' => q(ਮੀਟਰਿਕ ਕੱਪ),
						'one' => q({0} ਮੀਟਰਿਕ ਕੱਪ),
						'other' => q({0} ਮੀਟਰਿਕ ਕੱਪ),
					},
					# Long Unit Identifier
					'volume-deciliter' => {
						'1' => q(masculine),
						'name' => q(ਡੈਸੀਲਿਟਰ),
						'one' => q({0} ਡੈਸੀਲਿਟਰ),
						'other' => q({0} ਡੈਸੀਲਿਟਰ),
					},
					# Core Unit Identifier
					'deciliter' => {
						'1' => q(masculine),
						'name' => q(ਡੈਸੀਲਿਟਰ),
						'one' => q({0} ਡੈਸੀਲਿਟਰ),
						'other' => q({0} ਡੈਸੀਲਿਟਰ),
					},
					# Long Unit Identifier
					'volume-dessert-spoon-imperial' => {
						'one' => q({0} ਇੰਪੀਰੀਅਲ ਡੈਜ਼ਰਟ ਸਪੂਨ),
						'other' => q({0} ਇੰਪੀਰੀਅਲ ਡੈਜ਼ਰਟ ਸਪੂਨ),
					},
					# Core Unit Identifier
					'dessert-spoon-imperial' => {
						'one' => q({0} ਇੰਪੀਰੀਅਲ ਡੈਜ਼ਰਟ ਸਪੂਨ),
						'other' => q({0} ਇੰਪੀਰੀਅਲ ਡੈਜ਼ਰਟ ਸਪੂਨ),
					},
					# Long Unit Identifier
					'volume-dram' => {
						'name' => q(ਚੁਸਕੀ),
						'one' => q({0} ਚੁਸਕੀ),
						'other' => q({0} ਚੁਸਕੀ),
					},
					# Core Unit Identifier
					'dram' => {
						'name' => q(ਚੁਸਕੀ),
						'one' => q({0} ਚੁਸਕੀ),
						'other' => q({0} ਚੁਸਕੀ),
					},
					# Long Unit Identifier
					'volume-fluid-ounce' => {
						'name' => q(ਤਰਲ ਔਂਸ),
						'one' => q({0} ਤਰਲ ਔਂਸ),
						'other' => q({0} ਤਰਲ ਔਂਸ),
					},
					# Core Unit Identifier
					'fluid-ounce' => {
						'name' => q(ਤਰਲ ਔਂਸ),
						'one' => q({0} ਤਰਲ ਔਂਸ),
						'other' => q({0} ਤਰਲ ਔਂਸ),
					},
					# Long Unit Identifier
					'volume-fluid-ounce-imperial' => {
						'name' => q(ਇੰਪੀਰੀਅਲ ਫਲੁਡ ਔਂਸ),
						'one' => q({0} ਇੰਪੀਰੀਅਲ ਫਲੁਡ ਔਂਸ),
						'other' => q({0} ਇੰਪੀਰੀਅਲ ਫਲੁਡ ਔਂਸ),
					},
					# Core Unit Identifier
					'fluid-ounce-imperial' => {
						'name' => q(ਇੰਪੀਰੀਅਲ ਫਲੁਡ ਔਂਸ),
						'one' => q({0} ਇੰਪੀਰੀਅਲ ਫਲੁਡ ਔਂਸ),
						'other' => q({0} ਇੰਪੀਰੀਅਲ ਫਲੁਡ ਔਂਸ),
					},
					# Long Unit Identifier
					'volume-gallon' => {
						'per' => q({0} ਪ੍ਰਤੀ ਗੈਲਨ),
					},
					# Core Unit Identifier
					'gallon' => {
						'per' => q({0} ਪ੍ਰਤੀ ਗੈਲਨ),
					},
					# Long Unit Identifier
					'volume-gallon-imperial' => {
						'one' => q({0} ਇੰਪ. ਗੈਲਨ),
						'other' => q({0} ਇੰਪ. ਗੈਲਨ),
						'per' => q({0} ਪ੍ਰਤੀ ਇੰਪ. ਗੈਲਨ),
					},
					# Core Unit Identifier
					'gallon-imperial' => {
						'one' => q({0} ਇੰਪ. ਗੈਲਨ),
						'other' => q({0} ਇੰਪ. ਗੈਲਨ),
						'per' => q({0} ਪ੍ਰਤੀ ਇੰਪ. ਗੈਲਨ),
					},
					# Long Unit Identifier
					'volume-hectoliter' => {
						'1' => q(masculine),
						'name' => q(ਹੈਕਟੋਲਿਟਰ),
						'one' => q({0} ਹੈਕਟੋਲਿਟਰ),
						'other' => q({0} ਹੈਕਟੋਲਿਟਰ),
					},
					# Core Unit Identifier
					'hectoliter' => {
						'1' => q(masculine),
						'name' => q(ਹੈਕਟੋਲਿਟਰ),
						'one' => q({0} ਹੈਕਟੋਲਿਟਰ),
						'other' => q({0} ਹੈਕਟੋਲਿਟਰ),
					},
					# Long Unit Identifier
					'volume-liter' => {
						'1' => q(masculine),
						'one' => q({0} ਲਿਟਰ),
						'other' => q({0} ਲਿਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਲਿਟਰ),
					},
					# Core Unit Identifier
					'liter' => {
						'1' => q(masculine),
						'one' => q({0} ਲਿਟਰ),
						'other' => q({0} ਲਿਟਰ),
						'per' => q({0} ਪ੍ਰਤੀ ਲਿਟਰ),
					},
					# Long Unit Identifier
					'volume-megaliter' => {
						'1' => q(masculine),
						'name' => q(ਮੈਗਾਲਿਟਰ),
						'one' => q({0} ਮੈਗਾਲਿਟਰ),
						'other' => q({0} ਮੈਗਾਲਿਟਰ),
					},
					# Core Unit Identifier
					'megaliter' => {
						'1' => q(masculine),
						'name' => q(ਮੈਗਾਲਿਟਰ),
						'one' => q({0} ਮੈਗਾਲਿਟਰ),
						'other' => q({0} ਮੈਗਾਲਿਟਰ),
					},
					# Long Unit Identifier
					'volume-milliliter' => {
						'1' => q(masculine),
						'name' => q(ਮਿਲੀਲਿਟਰ),
						'one' => q({0} ਮਿਲੀਲਿਟਰ),
						'other' => q({0} ਮਿਲੀਲਿਟਰ),
					},
					# Core Unit Identifier
					'milliliter' => {
						'1' => q(masculine),
						'name' => q(ਮਿਲੀਲਿਟਰ),
						'one' => q({0} ਮਿਲੀਲਿਟਰ),
						'other' => q({0} ਮਿਲੀਲਿਟਰ),
					},
					# Long Unit Identifier
					'volume-pint-metric' => {
						'1' => q(masculine),
						'name' => q(ਮੀਟਰਿਕ ਪਿੰਟ),
						'one' => q({0} ਮੀਟਰਿਕ ਪਿੰਟ),
						'other' => q({0} ਮੀਟਰਿਕ ਪਿੰਟ),
					},
					# Core Unit Identifier
					'pint-metric' => {
						'1' => q(masculine),
						'name' => q(ਮੀਟਰਿਕ ਪਿੰਟ),
						'one' => q({0} ਮੀਟਰਿਕ ਪਿੰਟ),
						'other' => q({0} ਮੀਟਰਿਕ ਪਿੰਟ),
					},
					# Long Unit Identifier
					'volume-quart-imperial' => {
						'one' => q({0} ਇੰਪੀਰੀਅਲ ਚੁਥਾਈ ਗੈਲਨ),
						'other' => q({0} ਇੰਪੀਰੀਅਲ ਚੁਥਾਈ ਗੈਲਨ),
					},
					# Core Unit Identifier
					'quart-imperial' => {
						'one' => q({0} ਇੰਪੀਰੀਅਲ ਚੁਥਾਈ ਗੈਲਨ),
						'other' => q({0} ਇੰਪੀਰੀਅਲ ਚੁਥਾਈ ਗੈਲਨ),
					},
				},
				'narrow' => {
					# Long Unit Identifier
					'acceleration-g-force' => {
						'one' => q({0}G),
						'other' => q({0}Gs),
					},
					# Core Unit Identifier
					'g-force' => {
						'one' => q({0}G),
						'other' => q({0}Gs),
					},
					# Long Unit Identifier
					'acceleration-meter-per-square-second' => {
						'one' => q({0}ਮੀ/ਸ²),
						'other' => q({0}ਮੀ/ਸ²),
					},
					# Core Unit Identifier
					'meter-per-square-second' => {
						'one' => q({0}ਮੀ/ਸ²),
						'other' => q({0}ਮੀ/ਸ²),
					},
					# Long Unit Identifier
					'angle-arc-minute' => {
						'one' => q({0}′),
						'other' => q({0}′),
					},
					# Core Unit Identifier
					'arc-minute' => {
						'one' => q({0}′),
						'other' => q({0}′),
					},
					# Long Unit Identifier
					'angle-arc-second' => {
						'one' => q({0}″),
						'other' => q({0}″),
					},
					# Core Unit Identifier
					'arc-second' => {
						'one' => q({0}″),
						'other' => q({0}″),
					},
					# Long Unit Identifier
					'angle-degree' => {
						'name' => q(ਡਿ.),
						'one' => q({0}°),
						'other' => q({0}°),
					},
					# Core Unit Identifier
					'degree' => {
						'name' => q(ਡਿ.),
						'one' => q({0}°),
						'other' => q({0}°),
					},
					# Long Unit Identifier
					'area-acre' => {
						'one' => q({0}ਏਕੜ),
						'other' => q({0}ਏਕੜ),
					},
					# Core Unit Identifier
					'acre' => {
						'one' => q({0}ਏਕੜ),
						'other' => q({0}ਏਕੜ),
					},
					# Long Unit Identifier
					'area-square-centimeter' => {
						'one' => q({0}ਸੈਮੀ²),
						'other' => q({0}ਸੈਮੀ²),
					},
					# Core Unit Identifier
					'square-centimeter' => {
						'one' => q({0}ਸੈਮੀ²),
						'other' => q({0}ਸੈਮੀ²),
					},
					# Long Unit Identifier
					'area-square-foot' => {
						'one' => q({0}ਫੁੱਟ²),
						'other' => q({0}ਫੁੱਟ²),
					},
					# Core Unit Identifier
					'square-foot' => {
						'one' => q({0}ਫੁੱਟ²),
						'other' => q({0}ਫੁੱਟ²),
					},
					# Long Unit Identifier
					'area-square-inch' => {
						'one' => q({0}ਇੰਚ²),
						'other' => q({0}ਇੰਚ²),
					},
					# Core Unit Identifier
					'square-inch' => {
						'one' => q({0}ਇੰਚ²),
						'other' => q({0}ਇੰਚ²),
					},
					# Long Unit Identifier
					'area-square-mile' => {
						'one' => q({0}ਮੀਲ²),
						'other' => q({0}ਮੀਲ²),
					},
					# Core Unit Identifier
					'square-mile' => {
						'one' => q({0}ਮੀਲ²),
						'other' => q({0}ਮੀਲ²),
					},
					# Long Unit Identifier
					'concentr-item' => {
						'one' => q({0}ਆਈਟਮ),
						'other' => q({0}ਆਈਟਮ),
					},
					# Core Unit Identifier
					'item' => {
						'one' => q({0}ਆਈਟਮ),
						'other' => q({0}ਆਈਟਮ),
					},
					# Long Unit Identifier
					'concentr-milligram-ofglucose-per-deciliter' => {
						'one' => q({0}mg/dL),
						'other' => q({0}mg/dL),
					},
					# Core Unit Identifier
					'milligram-ofglucose-per-deciliter' => {
						'one' => q({0}mg/dL),
						'other' => q({0}mg/dL),
					},
					# Long Unit Identifier
					'concentr-permyriad' => {
						'name' => q(‱),
					},
					# Core Unit Identifier
					'permyriad' => {
						'name' => q(‱),
					},
					# Long Unit Identifier
					'consumption-liter-per-kilometer' => {
						'one' => q({0}ਲਿ./ਕਿ.ਮੀ.),
						'other' => q({0}ਲਿ./ਕਿ.ਮੀ.),
					},
					# Core Unit Identifier
					'liter-per-kilometer' => {
						'one' => q({0}ਲਿ./ਕਿ.ਮੀ.),
						'other' => q({0}ਲਿ./ਕਿ.ਮੀ.),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon-imperial' => {
						'one' => q({0}m/gUK),
						'other' => q({0}m/gUK),
					},
					# Core Unit Identifier
					'mile-per-gallon-imperial' => {
						'one' => q({0}m/gUK),
						'other' => q({0}m/gUK),
					},
					# Long Unit Identifier
					'digital-bit' => {
						'one' => q({0}ਬਿਟ),
						'other' => q({0}ਬਿਟ),
					},
					# Core Unit Identifier
					'bit' => {
						'one' => q({0}ਬਿਟ),
						'other' => q({0}ਬਿਟ),
					},
					# Long Unit Identifier
					'digital-byte' => {
						'one' => q({0}ਬਾਇਟ),
						'other' => q({0}ਬਾਇਟ),
					},
					# Core Unit Identifier
					'byte' => {
						'one' => q({0}ਬਾਇਟ),
						'other' => q({0}ਬਾਇਟ),
					},
					# Long Unit Identifier
					'digital-gigabit' => {
						'name' => q(Gb),
					},
					# Core Unit Identifier
					'gigabit' => {
						'name' => q(Gb),
					},
					# Long Unit Identifier
					'duration-day' => {
						'per' => q({0}/ਦਿ),
					},
					# Core Unit Identifier
					'day' => {
						'per' => q({0}/ਦਿ),
					},
					# Long Unit Identifier
					'duration-decade' => {
						'one' => q({0} ਦਹਾਕਾ),
						'other' => q({0} ਦਹਾਕੇ),
					},
					# Core Unit Identifier
					'decade' => {
						'one' => q({0} ਦਹਾਕਾ),
						'other' => q({0} ਦਹਾਕੇ),
					},
					# Long Unit Identifier
					'duration-hour' => {
						'name' => q(ਘੰਟਾ),
						'per' => q({0}/ਘੰ),
					},
					# Core Unit Identifier
					'hour' => {
						'name' => q(ਘੰਟਾ),
						'per' => q({0}/ਘੰ),
					},
					# Long Unit Identifier
					'duration-millisecond' => {
						'one' => q({0} ਮਿ.ਸ.),
						'other' => q({0} ਮਿ.ਸ.),
					},
					# Core Unit Identifier
					'millisecond' => {
						'one' => q({0} ਮਿ.ਸ.),
						'other' => q({0} ਮਿ.ਸ.),
					},
					# Long Unit Identifier
					'duration-month' => {
						'name' => q(ਮਹੀਨਾ),
						'per' => q({0}/ਮ),
					},
					# Core Unit Identifier
					'month' => {
						'name' => q(ਮਹੀਨਾ),
						'per' => q({0}/ਮ),
					},
					# Long Unit Identifier
					'duration-night' => {
						'name' => q(ਰਾਤਾਂ),
						'one' => q({0} ਰਾਤ),
						'other' => q({0} ਰਾਤਾਂ),
						'per' => q({0}/ਰਾਤ),
					},
					# Core Unit Identifier
					'night' => {
						'name' => q(ਰਾਤਾਂ),
						'one' => q({0} ਰਾਤ),
						'other' => q({0} ਰਾਤਾਂ),
						'per' => q({0}/ਰਾਤ),
					},
					# Long Unit Identifier
					'duration-second' => {
						'per' => q({0}/ਸਕਿੰ),
					},
					# Core Unit Identifier
					'second' => {
						'per' => q({0}/ਸਕਿੰ),
					},
					# Long Unit Identifier
					'duration-week' => {
						'name' => q(ਹਫ਼ਤਾ),
						'per' => q({0}/ਹ),
					},
					# Core Unit Identifier
					'week' => {
						'name' => q(ਹਫ਼ਤਾ),
						'per' => q({0}/ਹ),
					},
					# Long Unit Identifier
					'electric-ampere' => {
						'one' => q({0}A),
						'other' => q({0}A),
					},
					# Core Unit Identifier
					'ampere' => {
						'one' => q({0}A),
						'other' => q({0}A),
					},
					# Long Unit Identifier
					'electric-milliampere' => {
						'one' => q({0}mA),
						'other' => q({0}mA),
					},
					# Core Unit Identifier
					'milliampere' => {
						'one' => q({0}mA),
						'other' => q({0}mA),
					},
					# Long Unit Identifier
					'electric-ohm' => {
						'one' => q({0}Ω),
						'other' => q({0}Ω),
					},
					# Core Unit Identifier
					'ohm' => {
						'one' => q({0}Ω),
						'other' => q({0}Ω),
					},
					# Long Unit Identifier
					'electric-volt' => {
						'one' => q({0}V),
						'other' => q({0}V),
					},
					# Core Unit Identifier
					'volt' => {
						'one' => q({0}V),
						'other' => q({0}V),
					},
					# Long Unit Identifier
					'energy-kilocalorie' => {
						'one' => q({0}ਕਿ.ਕੈਲੋਰੀਆਂ),
						'other' => q({0}ਕਿ.ਕੈਲੋਰੀਆਂ),
					},
					# Core Unit Identifier
					'kilocalorie' => {
						'one' => q({0}ਕਿ.ਕੈਲੋਰੀਆਂ),
						'other' => q({0}ਕਿ.ਕੈਲੋਰੀਆਂ),
					},
					# Long Unit Identifier
					'energy-therm-us' => {
						'name' => q(ਯੂ.ਐਸ. ਥੈਰਮ),
					},
					# Core Unit Identifier
					'therm-us' => {
						'name' => q(ਯੂ.ਐਸ. ਥੈਰਮ),
					},
					# Long Unit Identifier
					'force-kilowatt-hour-per-100-kilometer' => {
						'one' => q({0}ਕਿ.ਵ.ਘੰ./100ਕਿ.ਮੀ.),
						'other' => q({0}ਕਿ.ਵ.ਘੰ./100ਕਿ.ਮੀ.),
					},
					# Core Unit Identifier
					'kilowatt-hour-per-100-kilometer' => {
						'one' => q({0}ਕਿ.ਵ.ਘੰ./100ਕਿ.ਮੀ.),
						'other' => q({0}ਕਿ.ਵ.ਘੰ./100ਕਿ.ਮੀ.),
					},
					# Long Unit Identifier
					'frequency-gigahertz' => {
						'one' => q({0}GHz),
						'other' => q({0}GHz),
					},
					# Core Unit Identifier
					'gigahertz' => {
						'one' => q({0}GHz),
						'other' => q({0}GHz),
					},
					# Long Unit Identifier
					'frequency-hertz' => {
						'one' => q({0}Hz),
						'other' => q({0}Hz),
					},
					# Core Unit Identifier
					'hertz' => {
						'one' => q({0}Hz),
						'other' => q({0}Hz),
					},
					# Long Unit Identifier
					'frequency-kilohertz' => {
						'one' => q({0}kHz),
						'other' => q({0}kHz),
					},
					# Core Unit Identifier
					'kilohertz' => {
						'one' => q({0}kHz),
						'other' => q({0}kHz),
					},
					# Long Unit Identifier
					'frequency-megahertz' => {
						'one' => q({0}MHz),
						'other' => q({0}MHz),
					},
					# Core Unit Identifier
					'megahertz' => {
						'one' => q({0}MHz),
						'other' => q({0}MHz),
					},
					# Long Unit Identifier
					'graphics-dot' => {
						'name' => q(ਡਾਟ),
						'one' => q({0}ਡਾਟ),
						'other' => q({0}ਡਾਟ),
					},
					# Core Unit Identifier
					'dot' => {
						'name' => q(ਡਾਟ),
						'one' => q({0}ਡਾਟ),
						'other' => q({0}ਡਾਟ),
					},
					# Long Unit Identifier
					'graphics-dot-per-centimeter' => {
						'one' => q({0}dpcm),
						'other' => q({0} dpcm),
					},
					# Core Unit Identifier
					'dot-per-centimeter' => {
						'one' => q({0}dpcm),
						'other' => q({0} dpcm),
					},
					# Long Unit Identifier
					'graphics-dot-per-inch' => {
						'one' => q({0}dpi),
						'other' => q({0}dpi),
					},
					# Core Unit Identifier
					'dot-per-inch' => {
						'one' => q({0}dpi),
						'other' => q({0}dpi),
					},
					# Long Unit Identifier
					'graphics-em' => {
						'one' => q({0}em),
						'other' => q({0}em),
					},
					# Core Unit Identifier
					'em' => {
						'one' => q({0}em),
						'other' => q({0}em),
					},
					# Long Unit Identifier
					'graphics-megapixel' => {
						'one' => q({0}MP),
						'other' => q({0}MP),
					},
					# Core Unit Identifier
					'megapixel' => {
						'one' => q({0}MP),
						'other' => q({0}MP),
					},
					# Long Unit Identifier
					'graphics-pixel' => {
						'one' => q({0}px),
						'other' => q({0}px),
					},
					# Core Unit Identifier
					'pixel' => {
						'one' => q({0}px),
						'other' => q({0}px),
					},
					# Long Unit Identifier
					'graphics-pixel-per-centimeter' => {
						'one' => q({0}ppcm),
						'other' => q({0}ppcm),
					},
					# Core Unit Identifier
					'pixel-per-centimeter' => {
						'one' => q({0}ppcm),
						'other' => q({0}ppcm),
					},
					# Long Unit Identifier
					'length-centimeter' => {
						'one' => q({0}ਸੈਂ.ਮੀ.),
						'other' => q({0}ਸੈਂ.ਮੀ.),
					},
					# Core Unit Identifier
					'centimeter' => {
						'one' => q({0}ਸੈਂ.ਮੀ.),
						'other' => q({0}ਸੈਂ.ਮੀ.),
					},
					# Long Unit Identifier
					'length-foot' => {
						'one' => q({0}'),
						'other' => q({0}'),
					},
					# Core Unit Identifier
					'foot' => {
						'one' => q({0}'),
						'other' => q({0}'),
					},
					# Long Unit Identifier
					'length-inch' => {
						'one' => q({0}"),
						'other' => q({0}"),
					},
					# Core Unit Identifier
					'inch' => {
						'one' => q({0}"),
						'other' => q({0}"),
					},
					# Long Unit Identifier
					'length-picometer' => {
						'one' => q({0} ਪਿ.ਮੀ.),
						'other' => q({0} ਪਿ.ਮੀ.),
					},
					# Core Unit Identifier
					'picometer' => {
						'one' => q({0} ਪਿ.ਮੀ.),
						'other' => q({0} ਪਿ.ਮੀ.),
					},
					# Long Unit Identifier
					'length-solar-radius' => {
						'name' => q(R☉),
					},
					# Core Unit Identifier
					'solar-radius' => {
						'name' => q(R☉),
					},
					# Long Unit Identifier
					'mass-kilogram' => {
						'name' => q(ਕਿ ਗ੍ਰਾ),
					},
					# Core Unit Identifier
					'kilogram' => {
						'name' => q(ਕਿ ਗ੍ਰਾ),
					},
					# Long Unit Identifier
					'mass-pound' => {
						'one' => q({0}#),
						'other' => q({0}#),
					},
					# Core Unit Identifier
					'pound' => {
						'one' => q({0}#),
						'other' => q({0}#),
					},
					# Long Unit Identifier
					'mass-stone' => {
						'one' => q({0}ਸਟੋਨ),
						'other' => q({0}ਸਟੋਨ),
					},
					# Core Unit Identifier
					'stone' => {
						'one' => q({0}ਸਟੋਨ),
						'other' => q({0}ਸਟੋਨ),
					},
					# Long Unit Identifier
					'mass-ton' => {
						'one' => q({0}ਟਨ),
						'other' => q({0}ਟਨ),
					},
					# Core Unit Identifier
					'ton' => {
						'one' => q({0}ਟਨ),
						'other' => q({0}ਟਨ),
					},
					# Long Unit Identifier
					'power-horsepower' => {
						'one' => q({0}hp),
						'other' => q({0} hp),
					},
					# Core Unit Identifier
					'horsepower' => {
						'one' => q({0}hp),
						'other' => q({0} hp),
					},
					# Long Unit Identifier
					'pressure-inch-ofhg' => {
						'one' => q({0}" ਪਾਰਾ),
						'other' => q({0}" ਪਾਰਾ),
					},
					# Core Unit Identifier
					'inch-ofhg' => {
						'one' => q({0}" ਪਾਰਾ),
						'other' => q({0}" ਪਾਰਾ),
					},
					# Long Unit Identifier
					'pressure-millibar' => {
						'name' => q(ਮਿ.ਬਾਰ),
						'one' => q({0} ਮਿ.ਬਾ.),
						'other' => q({0} ਮਿ.ਬਾ.),
					},
					# Core Unit Identifier
					'millibar' => {
						'name' => q(ਮਿ.ਬਾਰ),
						'one' => q({0} ਮਿ.ਬਾ.),
						'other' => q({0} ਮਿ.ਬਾ.),
					},
					# Long Unit Identifier
					'speed-kilometer-per-hour' => {
						'one' => q({0} ਕਿ.ਮੀ./ਘੰ.),
						'other' => q({0} ਕਿ.ਮੀ./ਘੰ.),
					},
					# Core Unit Identifier
					'kilometer-per-hour' => {
						'one' => q({0} ਕਿ.ਮੀ./ਘੰ.),
						'other' => q({0} ਕਿ.ਮੀ./ਘੰ.),
					},
					# Long Unit Identifier
					'speed-light-speed' => {
						'name' => q(ਪ੍ਰਕਾਸ਼),
						'one' => q({0} ਪ੍ਰਕਾਸ਼),
						'other' => q({0} ਪ੍ਰਕਾਸ਼),
					},
					# Core Unit Identifier
					'light-speed' => {
						'name' => q(ਪ੍ਰਕਾਸ਼),
						'one' => q({0} ਪ੍ਰਕਾਸ਼),
						'other' => q({0} ਪ੍ਰਕਾਸ਼),
					},
					# Long Unit Identifier
					'speed-meter-per-second' => {
						'one' => q({0}ਮੀ/ਸ),
						'other' => q({0}ਮੀ/ਸ),
					},
					# Core Unit Identifier
					'meter-per-second' => {
						'one' => q({0}ਮੀ/ਸ),
						'other' => q({0}ਮੀ/ਸ),
					},
					# Long Unit Identifier
					'speed-mile-per-hour' => {
						'one' => q({0} ਮੀਲ/ਘੰ.),
						'other' => q({0} ਮੀਲ/ਘੰ.),
					},
					# Core Unit Identifier
					'mile-per-hour' => {
						'one' => q({0} ਮੀਲ/ਘੰ.),
						'other' => q({0} ਮੀਲ/ਘੰ.),
					},
					# Long Unit Identifier
					'temperature-celsius' => {
						'name' => q(°C),
					},
					# Core Unit Identifier
					'celsius' => {
						'name' => q(°C),
					},
					# Long Unit Identifier
					'temperature-fahrenheit' => {
						'name' => q(°F),
						'one' => q({0}°),
						'other' => q({0}°),
					},
					# Core Unit Identifier
					'fahrenheit' => {
						'name' => q(°F),
						'one' => q({0}°),
						'other' => q({0}°),
					},
					# Long Unit Identifier
					'temperature-kelvin' => {
						'one' => q({0}°K),
						'other' => q({0}°K),
					},
					# Core Unit Identifier
					'kelvin' => {
						'one' => q({0}°K),
						'other' => q({0}°K),
					},
					# Long Unit Identifier
					'torque-newton-meter' => {
						'name' => q(N⋅m),
						'one' => q({0}N⋅m),
						'other' => q({0}N⋅m),
					},
					# Core Unit Identifier
					'newton-meter' => {
						'name' => q(N⋅m),
						'one' => q({0}N⋅m),
						'other' => q({0}N⋅m),
					},
					# Long Unit Identifier
					'volume-acre-foot' => {
						'one' => q({0} ਏ.ਫੁ.),
						'other' => q({0} ਏ.ਫੁ.),
					},
					# Core Unit Identifier
					'acre-foot' => {
						'one' => q({0} ਏ.ਫੁ.),
						'other' => q({0} ਏ.ਫੁ.),
					},
					# Long Unit Identifier
					'volume-bushel' => {
						'one' => q({0}ਬੁਸ਼ਲ),
						'other' => q({0}ਬੁਸ਼ਲ),
					},
					# Core Unit Identifier
					'bushel' => {
						'one' => q({0}ਬੁਸ਼ਲ),
						'other' => q({0}ਬੁਸ਼ਲ),
					},
					# Long Unit Identifier
					'volume-cubic-centimeter' => {
						'one' => q({0}ਸੈਮੀ³),
						'other' => q({0}ਸੈਮੀ³),
					},
					# Core Unit Identifier
					'cubic-centimeter' => {
						'one' => q({0}ਸੈਮੀ³),
						'other' => q({0}ਸੈਮੀ³),
					},
					# Long Unit Identifier
					'volume-cubic-foot' => {
						'one' => q({0}ਫੁੱਟ³),
						'other' => q({0}ਫੁੱਟ³),
					},
					# Core Unit Identifier
					'cubic-foot' => {
						'one' => q({0}ਫੁੱਟ³),
						'other' => q({0}ਫੁੱਟ³),
					},
					# Long Unit Identifier
					'volume-cubic-inch' => {
						'one' => q({0}ਇੰਚ³),
						'other' => q({0}ਇੰਚ³),
					},
					# Core Unit Identifier
					'cubic-inch' => {
						'one' => q({0}ਇੰਚ³),
						'other' => q({0}ਇੰਚ³),
					},
					# Long Unit Identifier
					'volume-cubic-kilometer' => {
						'one' => q({0}ਕਿਮੀ³),
						'other' => q({0}ਕਿਮੀ³),
					},
					# Core Unit Identifier
					'cubic-kilometer' => {
						'one' => q({0}ਕਿਮੀ³),
						'other' => q({0}ਕਿਮੀ³),
					},
					# Long Unit Identifier
					'volume-cubic-meter' => {
						'one' => q({0}ਮੀ³),
						'other' => q({0}ਮੀ³),
					},
					# Core Unit Identifier
					'cubic-meter' => {
						'one' => q({0}ਮੀ³),
						'other' => q({0}ਮੀ³),
					},
					# Long Unit Identifier
					'volume-cubic-mile' => {
						'one' => q({0}ਮੀਲ³),
						'other' => q({0}ਮੀਲ³),
					},
					# Core Unit Identifier
					'cubic-mile' => {
						'one' => q({0}ਮੀਲ³),
						'other' => q({0}ਮੀਲ³),
					},
					# Long Unit Identifier
					'volume-cubic-yard' => {
						'one' => q({0}ਗਜ਼³),
						'other' => q({0}ਗਜ਼³),
					},
					# Core Unit Identifier
					'cubic-yard' => {
						'one' => q({0}ਗਜ਼³),
						'other' => q({0}ਗਜ਼³),
					},
					# Long Unit Identifier
					'volume-cup' => {
						'one' => q({0}ਕੱਪ),
						'other' => q({0}ਕੱਪ),
					},
					# Core Unit Identifier
					'cup' => {
						'one' => q({0}ਕੱਪ),
						'other' => q({0}ਕੱਪ),
					},
					# Long Unit Identifier
					'volume-fluid-ounce-imperial' => {
						'one' => q({0} ਫ.ਔ.ਇ.),
						'other' => q({0} ਫ.ਔ.ਇ.),
					},
					# Core Unit Identifier
					'fluid-ounce-imperial' => {
						'one' => q({0} ਫ.ਔ.ਇ.),
						'other' => q({0} ਫ.ਔ.ਇ.),
					},
					# Long Unit Identifier
					'volume-gallon' => {
						'one' => q({0}ਗੈਲਨ),
						'other' => q({0}ਗੈਲਨ),
					},
					# Core Unit Identifier
					'gallon' => {
						'one' => q({0}ਗੈਲਨ),
						'other' => q({0}ਗੈਲਨ),
					},
					# Long Unit Identifier
					'volume-pint' => {
						'one' => q({0}ਪਿੰਟ),
						'other' => q({0}ਪਿੰਟ),
					},
					# Core Unit Identifier
					'pint' => {
						'one' => q({0}ਪਿੰਟ),
						'other' => q({0}ਪਿੰਟ),
					},
					# Long Unit Identifier
					'volume-quart' => {
						'one' => q({0}ਕੁਆਟ),
						'other' => q({0}ਕੁਆਟ),
					},
					# Core Unit Identifier
					'quart' => {
						'one' => q({0}ਕੁਆਟ),
						'other' => q({0}ਕੁਆਟ),
					},
					# Long Unit Identifier
					'volume-quart-imperial' => {
						'one' => q({0} ਇ.ਚੁ.ਗੈ.),
						'other' => q({0} ਇ.ਚੁ.ਗੈ.),
					},
					# Core Unit Identifier
					'quart-imperial' => {
						'one' => q({0} ਇ.ਚੁ.ਗੈ.),
						'other' => q({0} ਇ.ਚੁ.ਗੈ.),
					},
					# Long Unit Identifier
					'volume-tablespoon' => {
						'one' => q({0} ਟੇ. ਸ.),
						'other' => q({0} ਟੇ. ਸ.),
					},
					# Core Unit Identifier
					'tablespoon' => {
						'one' => q({0} ਟੇ. ਸ.),
						'other' => q({0} ਟੇ. ਸ.),
					},
				},
				'short' => {
					# Long Unit Identifier
					'' => {
						'name' => q(ਦਿਸ਼ਾ),
					},
					# Core Unit Identifier
					'' => {
						'name' => q(ਦਿਸ਼ਾ),
					},
					# Long Unit Identifier
					'1024p1' => {
						'1' => q(ਕੀ{0}),
					},
					# Core Unit Identifier
					'1024p1' => {
						'1' => q(ਕੀ{0}),
					},
					# Long Unit Identifier
					'1024p2' => {
						'1' => q(ਮੇ{0}),
					},
					# Core Unit Identifier
					'1024p2' => {
						'1' => q(ਮੇ{0}),
					},
					# Long Unit Identifier
					'1024p3' => {
						'1' => q(ਗੀ{0}),
					},
					# Core Unit Identifier
					'1024p3' => {
						'1' => q(ਗੀ{0}),
					},
					# Long Unit Identifier
					'1024p4' => {
						'1' => q(ਟੀ{0}),
					},
					# Core Unit Identifier
					'1024p4' => {
						'1' => q(ਟੀ{0}),
					},
					# Long Unit Identifier
					'1024p5' => {
						'1' => q(ਪੀ{0}),
					},
					# Core Unit Identifier
					'1024p5' => {
						'1' => q(ਪੀ{0}),
					},
					# Long Unit Identifier
					'1024p6' => {
						'1' => q(ਈ{0}),
					},
					# Core Unit Identifier
					'1024p6' => {
						'1' => q(ਈ{0}),
					},
					# Long Unit Identifier
					'1024p7' => {
						'1' => q(ਜ਼ੀ{0}),
					},
					# Core Unit Identifier
					'1024p7' => {
						'1' => q(ਜ਼ੀ{0}),
					},
					# Long Unit Identifier
					'1024p8' => {
						'1' => q(ਯੀ{0}),
					},
					# Core Unit Identifier
					'1024p8' => {
						'1' => q(ਯੀ{0}),
					},
					# Long Unit Identifier
					'10p-1' => {
						'1' => q(ਡੈ.{0}),
					},
					# Core Unit Identifier
					'1' => {
						'1' => q(ਡੈ.{0}),
					},
					# Long Unit Identifier
					'10p-12' => {
						'1' => q(ਪਿ.{0}),
					},
					# Core Unit Identifier
					'12' => {
						'1' => q(ਪਿ.{0}),
					},
					# Long Unit Identifier
					'10p-15' => {
						'1' => q(ਫੈ.{0}),
					},
					# Core Unit Identifier
					'15' => {
						'1' => q(ਫੈ.{0}),
					},
					# Long Unit Identifier
					'10p-18' => {
						'1' => q(ਐੱ.{0}),
					},
					# Core Unit Identifier
					'18' => {
						'1' => q(ਐੱ.{0}),
					},
					# Long Unit Identifier
					'10p-2' => {
						'1' => q(ਸੈਂ.{0}),
					},
					# Core Unit Identifier
					'2' => {
						'1' => q(ਸੈਂ.{0}),
					},
					# Long Unit Identifier
					'10p-21' => {
						'1' => q(ਜ਼ੈ.{0}),
					},
					# Core Unit Identifier
					'21' => {
						'1' => q(ਜ਼ੈ.{0}),
					},
					# Long Unit Identifier
					'10p-24' => {
						'1' => q(ਯੋ.{0}),
					},
					# Core Unit Identifier
					'24' => {
						'1' => q(ਯੋ.{0}),
					},
					# Long Unit Identifier
					'10p-27' => {
						'1' => q(ਰੋਂ{0}),
					},
					# Core Unit Identifier
					'27' => {
						'1' => q(ਰੋਂ{0}),
					},
					# Long Unit Identifier
					'10p-3' => {
						'1' => q(ਮਿ.{0}),
					},
					# Core Unit Identifier
					'3' => {
						'1' => q(ਮਿ.{0}),
					},
					# Long Unit Identifier
					'10p-30' => {
						'1' => q(ਕੁ{0}),
					},
					# Core Unit Identifier
					'30' => {
						'1' => q(ਕੁ{0}),
					},
					# Long Unit Identifier
					'10p-6' => {
						'1' => q(ਮਾ.{0}),
					},
					# Core Unit Identifier
					'6' => {
						'1' => q(ਮਾ.{0}),
					},
					# Long Unit Identifier
					'10p-9' => {
						'1' => q(ਨੈ.{0}),
					},
					# Core Unit Identifier
					'9' => {
						'1' => q(ਨੈ.{0}),
					},
					# Long Unit Identifier
					'10p1' => {
						'1' => q(ਡੇ.{0}),
					},
					# Core Unit Identifier
					'10p1' => {
						'1' => q(ਡੇ.{0}),
					},
					# Long Unit Identifier
					'10p12' => {
						'1' => q(ਟੈ.{0}),
					},
					# Core Unit Identifier
					'10p12' => {
						'1' => q(ਟੈ.{0}),
					},
					# Long Unit Identifier
					'10p15' => {
						'1' => q(ਪੈਟਾ{0}),
					},
					# Core Unit Identifier
					'10p15' => {
						'1' => q(ਪੈਟਾ{0}),
					},
					# Long Unit Identifier
					'10p18' => {
						'1' => q(ਐਕਸਾ{0}),
					},
					# Core Unit Identifier
					'10p18' => {
						'1' => q(ਐਕਸਾ{0}),
					},
					# Long Unit Identifier
					'10p2' => {
						'1' => q(ਹੈ.{0}),
					},
					# Core Unit Identifier
					'10p2' => {
						'1' => q(ਹੈ.{0}),
					},
					# Long Unit Identifier
					'10p21' => {
						'1' => q(ਜ਼ੀਟਾ{0}),
					},
					# Core Unit Identifier
					'10p21' => {
						'1' => q(ਜ਼ੀਟਾ{0}),
					},
					# Long Unit Identifier
					'10p24' => {
						'1' => q(ਯੋਟਾ{0}),
					},
					# Core Unit Identifier
					'10p24' => {
						'1' => q(ਯੋਟਾ{0}),
					},
					# Long Unit Identifier
					'10p27' => {
						'1' => q(ਰੌ{0}),
					},
					# Core Unit Identifier
					'10p27' => {
						'1' => q(ਰੌ{0}),
					},
					# Long Unit Identifier
					'10p3' => {
						'1' => q(ਕਿ.{0}),
					},
					# Core Unit Identifier
					'10p3' => {
						'1' => q(ਕਿ.{0}),
					},
					# Long Unit Identifier
					'10p30' => {
						'1' => q(ਕਵ{0}),
					},
					# Core Unit Identifier
					'10p30' => {
						'1' => q(ਕਵ{0}),
					},
					# Long Unit Identifier
					'10p6' => {
						'1' => q(ਮੈ.{0}),
					},
					# Core Unit Identifier
					'10p6' => {
						'1' => q(ਮੈ.{0}),
					},
					# Long Unit Identifier
					'10p9' => {
						'1' => q(ਗੀਗਾ{0}),
					},
					# Core Unit Identifier
					'10p9' => {
						'1' => q(ਗੀਗਾ{0}),
					},
					# Long Unit Identifier
					'acceleration-g-force' => {
						'name' => q(ਗੁਰੂਤਾਕਰਸ਼ਣ ਬਲ),
					},
					# Core Unit Identifier
					'g-force' => {
						'name' => q(ਗੁਰੂਤਾਕਰਸ਼ਣ ਬਲ),
					},
					# Long Unit Identifier
					'acceleration-meter-per-square-second' => {
						'name' => q(ਮੀਟਰ/ਸਕਿੰਟ²),
						'one' => q({0} ਮੀ/ਸ²),
						'other' => q({0} ਮੀ/ਸ²),
					},
					# Core Unit Identifier
					'meter-per-square-second' => {
						'name' => q(ਮੀਟਰ/ਸਕਿੰਟ²),
						'one' => q({0} ਮੀ/ਸ²),
						'other' => q({0} ਮੀ/ਸ²),
					},
					# Long Unit Identifier
					'angle-arc-minute' => {
						'name' => q(ਚਾਪ-ਮਿੰਟ),
						'one' => q({0} ਚਾਪ-ਮਿੰਟ),
						'other' => q({0} ਚਾਪ-ਮਿੰਟ),
					},
					# Core Unit Identifier
					'arc-minute' => {
						'name' => q(ਚਾਪ-ਮਿੰਟ),
						'one' => q({0} ਚਾਪ-ਮਿੰਟ),
						'other' => q({0} ਚਾਪ-ਮਿੰਟ),
					},
					# Long Unit Identifier
					'angle-arc-second' => {
						'name' => q(ਚਾਪ-ਸਕਿੰਟ),
						'one' => q({0} ਚਾਪ-ਸਕਿੰਟ),
						'other' => q({0} ਚਾਪ-ਸਕਿੰਟ),
					},
					# Core Unit Identifier
					'arc-second' => {
						'name' => q(ਚਾਪ-ਸਕਿੰਟ),
						'one' => q({0} ਚਾਪ-ਸਕਿੰਟ),
						'other' => q({0} ਚਾਪ-ਸਕਿੰਟ),
					},
					# Long Unit Identifier
					'angle-degree' => {
						'name' => q(ਡਿਗਰੀ),
						'one' => q({0} ਡਿ.),
						'other' => q({0} ਡਿ.),
					},
					# Core Unit Identifier
					'degree' => {
						'name' => q(ਡਿਗਰੀ),
						'one' => q({0} ਡਿ.),
						'other' => q({0} ਡਿ.),
					},
					# Long Unit Identifier
					'angle-radian' => {
						'name' => q(ਰੇਡੀਅਨ),
						'one' => q({0} ਰੇਡੀ.),
						'other' => q({0} ਰੇਡੀ.),
					},
					# Core Unit Identifier
					'radian' => {
						'name' => q(ਰੇਡੀਅਨ),
						'one' => q({0} ਰੇਡੀ.),
						'other' => q({0} ਰੇਡੀ.),
					},
					# Long Unit Identifier
					'angle-revolution' => {
						'name' => q(ਪਰਿਕਰਮਾ),
						'one' => q({0} ਪਰਿਕਰਮਾ),
						'other' => q({0} ਪਰਿਕਰਮਾ),
					},
					# Core Unit Identifier
					'revolution' => {
						'name' => q(ਪਰਿਕਰਮਾ),
						'one' => q({0} ਪਰਿਕਰਮਾ),
						'other' => q({0} ਪਰਿਕਰਮਾ),
					},
					# Long Unit Identifier
					'area-acre' => {
						'name' => q(ਏਕੜ),
						'one' => q({0} ਏਕੜ),
						'other' => q({0} ਏਕੜ),
					},
					# Core Unit Identifier
					'acre' => {
						'name' => q(ਏਕੜ),
						'one' => q({0} ਏਕੜ),
						'other' => q({0} ਏਕੜ),
					},
					# Long Unit Identifier
					'area-dunam' => {
						'name' => q(ਦੁਨਮ),
						'one' => q({0} ਦੁਨਮ),
						'other' => q({0} ਦੁਨਮ),
					},
					# Core Unit Identifier
					'dunam' => {
						'name' => q(ਦੁਨਮ),
						'one' => q({0} ਦੁਨਮ),
						'other' => q({0} ਦੁਨਮ),
					},
					# Long Unit Identifier
					'area-hectare' => {
						'name' => q(ਹੈਕਟੇਅਰ),
						'one' => q({0} ਹੈਕਟ.),
						'other' => q({0} ਹੈਕਟ.),
					},
					# Core Unit Identifier
					'hectare' => {
						'name' => q(ਹੈਕਟੇਅਰ),
						'one' => q({0} ਹੈਕਟ.),
						'other' => q({0} ਹੈਕਟ.),
					},
					# Long Unit Identifier
					'area-square-centimeter' => {
						'name' => q(ਸੈਮੀ²),
						'one' => q({0} ਸੈਮੀ²),
						'other' => q({0} ਸੈਮੀ²),
						'per' => q({0}/ਸੈਮੀ²),
					},
					# Core Unit Identifier
					'square-centimeter' => {
						'name' => q(ਸੈਮੀ²),
						'one' => q({0} ਸੈਮੀ²),
						'other' => q({0} ਸੈਮੀ²),
						'per' => q({0}/ਸੈਮੀ²),
					},
					# Long Unit Identifier
					'area-square-foot' => {
						'name' => q(ਵ. ਫੁੱਟ),
						'one' => q({0} ਵ. ਫੁੱਟ),
						'other' => q({0} ਵ. ਫੁੱਟ),
					},
					# Core Unit Identifier
					'square-foot' => {
						'name' => q(ਵ. ਫੁੱਟ),
						'one' => q({0} ਵ. ਫੁੱਟ),
						'other' => q({0} ਵ. ਫੁੱਟ),
					},
					# Long Unit Identifier
					'area-square-inch' => {
						'name' => q(ਇੰਚ²),
						'one' => q({0} ਇੰਚ²),
						'other' => q({0} ਇੰਚ²),
						'per' => q({0}/ਇੰਚ²),
					},
					# Core Unit Identifier
					'square-inch' => {
						'name' => q(ਇੰਚ²),
						'one' => q({0} ਇੰਚ²),
						'other' => q({0} ਇੰਚ²),
						'per' => q({0}/ਇੰਚ²),
					},
					# Long Unit Identifier
					'area-square-kilometer' => {
						'name' => q(ਕਿਮੀ²),
						'one' => q({0} ਕਿਮੀ²),
						'other' => q({0} ਕਿਮੀ²),
						'per' => q({0}/ਕਿਮੀ²),
					},
					# Core Unit Identifier
					'square-kilometer' => {
						'name' => q(ਕਿਮੀ²),
						'one' => q({0} ਕਿਮੀ²),
						'other' => q({0} ਕਿਮੀ²),
						'per' => q({0}/ਕਿਮੀ²),
					},
					# Long Unit Identifier
					'area-square-meter' => {
						'name' => q(ਮੀਟਰ²),
						'one' => q({0} ਮੀ²),
						'other' => q({0} ਮੀ²),
						'per' => q({0} ਪ੍ਰਤੀ ਮੀ²),
					},
					# Core Unit Identifier
					'square-meter' => {
						'name' => q(ਮੀਟਰ²),
						'one' => q({0} ਮੀ²),
						'other' => q({0} ਮੀ²),
						'per' => q({0} ਪ੍ਰਤੀ ਮੀ²),
					},
					# Long Unit Identifier
					'area-square-mile' => {
						'name' => q(ਵਰਗ ਮੀਲ),
						'one' => q({0} ਵ. ਮੀਲ),
						'other' => q({0} ਵ. ਮੀਲ),
						'per' => q({0}/ਮੀਲ²),
					},
					# Core Unit Identifier
					'square-mile' => {
						'name' => q(ਵਰਗ ਮੀਲ),
						'one' => q({0} ਵ. ਮੀਲ),
						'other' => q({0} ਵ. ਮੀਲ),
						'per' => q({0}/ਮੀਲ²),
					},
					# Long Unit Identifier
					'area-square-yard' => {
						'name' => q(ਗਜ਼²),
						'one' => q({0} ਗਜ਼²),
						'other' => q({0} ਗਜ਼²),
					},
					# Core Unit Identifier
					'square-yard' => {
						'name' => q(ਗਜ਼²),
						'one' => q({0} ਗਜ਼²),
						'other' => q({0} ਗਜ਼²),
					},
					# Long Unit Identifier
					'concentr-item' => {
						'name' => q(ਆਈਟਮ),
						'one' => q({0} ਆਈਟਮ),
						'other' => q({0} ਆਈਟਮਾਂ),
					},
					# Core Unit Identifier
					'item' => {
						'name' => q(ਆਈਟਮ),
						'one' => q({0} ਆਈਟਮ),
						'other' => q({0} ਆਈਟਮਾਂ),
					},
					# Long Unit Identifier
					'concentr-karat' => {
						'name' => q(ਕੇਰਟ),
						'one' => q({0} ਕੇਰਟ),
						'other' => q({0} ਕੇਰਟ),
					},
					# Core Unit Identifier
					'karat' => {
						'name' => q(ਕੇਰਟ),
						'one' => q({0} ਕੇਰਟ),
						'other' => q({0} ਕੇਰਟ),
					},
					# Long Unit Identifier
					'concentr-milligram-ofglucose-per-deciliter' => {
						'name' => q(ਮਿ.ਗ੍ਰਾ./ਡੈ.ਲਿ.),
						'one' => q({0}ਮਿਗ੍ਰਾ/ਡੈ.ਲਿ),
						'other' => q({0}ਮਿਗ੍ਰਾ/ਡੈ.ਲਿ),
					},
					# Core Unit Identifier
					'milligram-ofglucose-per-deciliter' => {
						'name' => q(ਮਿ.ਗ੍ਰਾ./ਡੈ.ਲਿ.),
						'one' => q({0}ਮਿਗ੍ਰਾ/ਡੈ.ਲਿ),
						'other' => q({0}ਮਿਗ੍ਰਾ/ਡੈ.ਲਿ),
					},
					# Long Unit Identifier
					'concentr-millimole-per-liter' => {
						'name' => q(ਮਿਲੀਮੋਲ/ਲਿਟਰ),
						'one' => q({0} ਮਿ.ਮੋ./ਲਿ.),
						'other' => q({0} ਮਿ.ਮੋ./ਲਿ.),
					},
					# Core Unit Identifier
					'millimole-per-liter' => {
						'name' => q(ਮਿਲੀਮੋਲ/ਲਿਟਰ),
						'one' => q({0} ਮਿ.ਮੋ./ਲਿ.),
						'other' => q({0} ਮਿ.ਮੋ./ਲਿ.),
					},
					# Long Unit Identifier
					'concentr-mole' => {
						'name' => q(ਮੋਲ),
						'one' => q({0} ਮੋਲ),
						'other' => q({0} ਮੋਲ),
					},
					# Core Unit Identifier
					'mole' => {
						'name' => q(ਮੋਲ),
						'one' => q({0} ਮੋਲ),
						'other' => q({0} ਮੋਲ),
					},
					# Long Unit Identifier
					'concentr-percent' => {
						'name' => q(ਪ੍ਰਤੀਸ਼ਤ),
					},
					# Core Unit Identifier
					'percent' => {
						'name' => q(ਪ੍ਰਤੀਸ਼ਤ),
					},
					# Long Unit Identifier
					'concentr-permille' => {
						'name' => q(ਪਰਮਾਈਲ),
					},
					# Core Unit Identifier
					'permille' => {
						'name' => q(ਪਰਮਾਈਲ),
					},
					# Long Unit Identifier
					'concentr-permillion' => {
						'name' => q(ਹਿੱਸੇ/ਮਿਲੀਅਨ),
					},
					# Core Unit Identifier
					'permillion' => {
						'name' => q(ਹਿੱਸੇ/ਮਿਲੀਅਨ),
					},
					# Long Unit Identifier
					'concentr-permyriad' => {
						'name' => q(ਪ੍ਰਤੀ ਦਸ ਹਜ਼ਾਰ),
					},
					# Core Unit Identifier
					'permyriad' => {
						'name' => q(ਪ੍ਰਤੀ ਦਸ ਹਜ਼ਾਰ),
					},
					# Long Unit Identifier
					'concentr-portion-per-1e9' => {
						'name' => q(ਹਿੱਸਾ/ਅਰਬ),
					},
					# Core Unit Identifier
					'portion-per-1e9' => {
						'name' => q(ਹਿੱਸਾ/ਅਰਬ),
					},
					# Long Unit Identifier
					'consumption-liter-per-100-kilometer' => {
						'name' => q(ਲਿ./100ਕਿ.ਮੀ.),
						'one' => q({0}ਲਿ/100 ਕਿਮੀ),
						'other' => q({0}ਲਿ/100 ਕਿਮੀ),
					},
					# Core Unit Identifier
					'liter-per-100-kilometer' => {
						'name' => q(ਲਿ./100ਕਿ.ਮੀ.),
						'one' => q({0}ਲਿ/100 ਕਿਮੀ),
						'other' => q({0}ਲਿ/100 ਕਿਮੀ),
					},
					# Long Unit Identifier
					'consumption-liter-per-kilometer' => {
						'name' => q(ਲਿਟਰ/ਕਿ.ਮੀ.),
						'one' => q({0} ਲਿ./ਕਿ.ਮੀ.),
						'other' => q({0} ਲਿ./ਕਿ.ਮੀ.),
					},
					# Core Unit Identifier
					'liter-per-kilometer' => {
						'name' => q(ਲਿਟਰ/ਕਿ.ਮੀ.),
						'one' => q({0} ਲਿ./ਕਿ.ਮੀ.),
						'other' => q({0} ਲਿ./ਕਿ.ਮੀ.),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon' => {
						'name' => q(ਮੀਲ/ਗੈਲਨ),
						'one' => q({0} ਮੀ.ਪ੍ਰ.ਗੈ.),
						'other' => q({0} ਮੀ.ਪ੍ਰ.ਗੈ.),
					},
					# Core Unit Identifier
					'mile-per-gallon' => {
						'name' => q(ਮੀਲ/ਗੈਲਨ),
						'one' => q({0} ਮੀ.ਪ੍ਰ.ਗੈ.),
						'other' => q({0} ਮੀ.ਪ੍ਰ.ਗੈ.),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon-imperial' => {
						'name' => q(ਮੀਲ/ਗੈਲਨ ਇੰਪ.),
						'one' => q({0} mpg ਇੰਪ.),
						'other' => q({0} mpg ਇੰਪ.),
					},
					# Core Unit Identifier
					'mile-per-gallon-imperial' => {
						'name' => q(ਮੀਲ/ਗੈਲਨ ਇੰਪ.),
						'one' => q({0} mpg ਇੰਪ.),
						'other' => q({0} mpg ਇੰਪ.),
					},
					# Long Unit Identifier
					'coordinate' => {
						'east' => q({0}ਪੂ),
						'north' => q({0}ਉ),
						'south' => q({0}ਦੱ),
						'west' => q({0}ਪੱ),
					},
					# Core Unit Identifier
					'coordinate' => {
						'east' => q({0}ਪੂ),
						'north' => q({0}ਉ),
						'south' => q({0}ਦੱ),
						'west' => q({0}ਪੱ),
					},
					# Long Unit Identifier
					'digital-bit' => {
						'name' => q(ਬਿਟ),
						'one' => q({0} ਬਿਟ),
						'other' => q({0} ਬਿਟ),
					},
					# Core Unit Identifier
					'bit' => {
						'name' => q(ਬਿਟ),
						'one' => q({0} ਬਿਟ),
						'other' => q({0} ਬਿਟ),
					},
					# Long Unit Identifier
					'digital-byte' => {
						'name' => q(ਬਾਇਟ),
						'one' => q({0} ਬਾਇਟ),
						'other' => q({0} ਬਾਇਟ),
					},
					# Core Unit Identifier
					'byte' => {
						'name' => q(ਬਾਇਟ),
						'one' => q({0} ਬਾਇਟ),
						'other' => q({0} ਬਾਇਟ),
					},
					# Long Unit Identifier
					'digital-gigabit' => {
						'name' => q(Gbit),
					},
					# Core Unit Identifier
					'gigabit' => {
						'name' => q(Gbit),
					},
					# Long Unit Identifier
					'digital-gigabyte' => {
						'name' => q(ਗੀਗਾਬਾਇਟ),
					},
					# Core Unit Identifier
					'gigabyte' => {
						'name' => q(ਗੀਗਾਬਾਇਟ),
					},
					# Long Unit Identifier
					'digital-kilobit' => {
						'name' => q(ਕਿਲੋਬਿਟ),
					},
					# Core Unit Identifier
					'kilobit' => {
						'name' => q(ਕਿਲੋਬਿਟ),
					},
					# Long Unit Identifier
					'digital-kilobyte' => {
						'name' => q(ਕਿਲੋਬਾਇਟ),
					},
					# Core Unit Identifier
					'kilobyte' => {
						'name' => q(ਕਿਲੋਬਾਇਟ),
					},
					# Long Unit Identifier
					'digital-megabit' => {
						'name' => q(ਮੈਗਾਬਿਟ),
					},
					# Core Unit Identifier
					'megabit' => {
						'name' => q(ਮੈਗਾਬਿਟ),
					},
					# Long Unit Identifier
					'digital-megabyte' => {
						'name' => q(ਮੈਗਾਬਾਇਟ),
					},
					# Core Unit Identifier
					'megabyte' => {
						'name' => q(ਮੈਗਾਬਾਇਟ),
					},
					# Long Unit Identifier
					'digital-petabyte' => {
						'name' => q(ਪੈਟਾਬਾਇਟ),
					},
					# Core Unit Identifier
					'petabyte' => {
						'name' => q(ਪੈਟਾਬਾਇਟ),
					},
					# Long Unit Identifier
					'digital-terabit' => {
						'name' => q(ਟੇਰਾਬਿਟ),
					},
					# Core Unit Identifier
					'terabit' => {
						'name' => q(ਟੇਰਾਬਿਟ),
					},
					# Long Unit Identifier
					'digital-terabyte' => {
						'name' => q(ਟੈਰਾਬਾਇਟ),
					},
					# Core Unit Identifier
					'terabyte' => {
						'name' => q(ਟੈਰਾਬਾਇਟ),
					},
					# Long Unit Identifier
					'duration-century' => {
						'name' => q(ਸਦੀ),
						'one' => q({0} ਸਦੀ),
						'other' => q({0} ਸਦੀ),
					},
					# Core Unit Identifier
					'century' => {
						'name' => q(ਸਦੀ),
						'one' => q({0} ਸਦੀ),
						'other' => q({0} ਸਦੀ),
					},
					# Long Unit Identifier
					'duration-day' => {
						'name' => q(ਦਿਨ),
						'one' => q({0} ਦਿਨ),
						'other' => q({0} ਦਿਨ),
						'per' => q({0}/ਦਿਨ),
					},
					# Core Unit Identifier
					'day' => {
						'name' => q(ਦਿਨ),
						'one' => q({0} ਦਿਨ),
						'other' => q({0} ਦਿਨ),
						'per' => q({0}/ਦਿਨ),
					},
					# Long Unit Identifier
					'duration-decade' => {
						'name' => q(ਦਹਾ),
						'one' => q({0} ਦਹਾ),
						'other' => q({0} ਦਹਾ),
					},
					# Core Unit Identifier
					'decade' => {
						'name' => q(ਦਹਾ),
						'one' => q({0} ਦਹਾ),
						'other' => q({0} ਦਹਾ),
					},
					# Long Unit Identifier
					'duration-hour' => {
						'name' => q(ਘੰਟੇ),
						'one' => q({0} ਘੰਟਾ),
						'other' => q({0} ਘੰਟੇ),
						'per' => q({0} ਪ੍ਰ.ਘੰ.),
					},
					# Core Unit Identifier
					'hour' => {
						'name' => q(ਘੰਟੇ),
						'one' => q({0} ਘੰਟਾ),
						'other' => q({0} ਘੰਟੇ),
						'per' => q({0} ਪ੍ਰ.ਘੰ.),
					},
					# Long Unit Identifier
					'duration-microsecond' => {
						'name' => q(ਮਾਈਕਰੋਸਕਿੰਟ),
					},
					# Core Unit Identifier
					'microsecond' => {
						'name' => q(ਮਾਈਕਰੋਸਕਿੰਟ),
					},
					# Long Unit Identifier
					'duration-millisecond' => {
						'name' => q(ਮਿਲੀਸਕਿੰਟ),
						'one' => q({0} ਮਿਲੀਸਕਿੰਟ),
						'other' => q({0} ਮਿਲੀਸਕਿੰਟ),
					},
					# Core Unit Identifier
					'millisecond' => {
						'name' => q(ਮਿਲੀਸਕਿੰਟ),
						'one' => q({0} ਮਿਲੀਸਕਿੰਟ),
						'other' => q({0} ਮਿਲੀਸਕਿੰਟ),
					},
					# Long Unit Identifier
					'duration-minute' => {
						'name' => q(ਮਿੰਟ),
						'one' => q({0} ਮਿੰਟ),
						'other' => q({0} ਮਿੰਟ),
						'per' => q({0}/ਮਿੰਟ),
					},
					# Core Unit Identifier
					'minute' => {
						'name' => q(ਮਿੰਟ),
						'one' => q({0} ਮਿੰਟ),
						'other' => q({0} ਮਿੰਟ),
						'per' => q({0}/ਮਿੰਟ),
					},
					# Long Unit Identifier
					'duration-month' => {
						'name' => q(ਮਹੀਨੇ),
						'one' => q({0} ਮਹੀਨਾ),
						'other' => q({0} ਮਹੀਨੇ),
						'per' => q({0}/ਮਹੀਨਾ),
					},
					# Core Unit Identifier
					'month' => {
						'name' => q(ਮਹੀਨੇ),
						'one' => q({0} ਮਹੀਨਾ),
						'other' => q({0} ਮਹੀਨੇ),
						'per' => q({0}/ਮਹੀਨਾ),
					},
					# Long Unit Identifier
					'duration-nanosecond' => {
						'name' => q(ਨੈਨੋਸਕਿੰਟ),
					},
					# Core Unit Identifier
					'nanosecond' => {
						'name' => q(ਨੈਨੋਸਕਿੰਟ),
					},
					# Long Unit Identifier
					'duration-night' => {
						'name' => q(ਰਾਤਾਂ),
						'one' => q({0} ਰਾਤ),
						'other' => q({0} ਰਾਤਾਂ),
						'per' => q({0}/ਰਾਤ),
					},
					# Core Unit Identifier
					'night' => {
						'name' => q(ਰਾਤਾਂ),
						'one' => q({0} ਰਾਤ),
						'other' => q({0} ਰਾਤਾਂ),
						'per' => q({0}/ਰਾਤ),
					},
					# Long Unit Identifier
					'duration-quarter' => {
						'name' => q(ਤਿਮਾਹੀ),
						'one' => q({0} ਤਿਮਾਹੀ),
						'other' => q({0} ਤਿਮਾਹੀਆਂ),
						'per' => q({0}/ਤਿਮਾਹੀ),
					},
					# Core Unit Identifier
					'quarter' => {
						'name' => q(ਤਿਮਾਹੀ),
						'one' => q({0} ਤਿਮਾਹੀ),
						'other' => q({0} ਤਿਮਾਹੀਆਂ),
						'per' => q({0}/ਤਿਮਾਹੀ),
					},
					# Long Unit Identifier
					'duration-second' => {
						'name' => q(ਸਕਿੰਟ),
						'one' => q({0} ਸਕਿੰਟ),
						'other' => q({0} ਸਕਿੰਟ),
						'per' => q({0} ਪ੍ਰ.ਸ.),
					},
					# Core Unit Identifier
					'second' => {
						'name' => q(ਸਕਿੰਟ),
						'one' => q({0} ਸਕਿੰਟ),
						'other' => q({0} ਸਕਿੰਟ),
						'per' => q({0} ਪ੍ਰ.ਸ.),
					},
					# Long Unit Identifier
					'duration-week' => {
						'name' => q(ਹਫ਼ਤੇ),
						'one' => q({0} ਹਫ਼ਤਾ),
						'other' => q({0} ਹਫ਼ਤੇ),
						'per' => q({0}/ਹਫ਼ਤਾ),
					},
					# Core Unit Identifier
					'week' => {
						'name' => q(ਹਫ਼ਤੇ),
						'one' => q({0} ਹਫ਼ਤਾ),
						'other' => q({0} ਹਫ਼ਤੇ),
						'per' => q({0}/ਹਫ਼ਤਾ),
					},
					# Long Unit Identifier
					'duration-year' => {
						'name' => q(ਸਾਲ),
						'one' => q({0} ਸਾਲ),
						'other' => q({0} ਸਾਲ),
						'per' => q({0}/ਸਾਲ),
					},
					# Core Unit Identifier
					'year' => {
						'name' => q(ਸਾਲ),
						'one' => q({0} ਸਾਲ),
						'other' => q({0} ਸਾਲ),
						'per' => q({0}/ਸਾਲ),
					},
					# Long Unit Identifier
					'electric-ampere' => {
						'name' => q(ਐਮਪੀਅਰ),
					},
					# Core Unit Identifier
					'ampere' => {
						'name' => q(ਐਮਪੀਅਰ),
					},
					# Long Unit Identifier
					'electric-milliampere' => {
						'name' => q(ਮਿਲੀਐਮਪੀਅਰ),
					},
					# Core Unit Identifier
					'milliampere' => {
						'name' => q(ਮਿਲੀਐਮਪੀਅਰ),
					},
					# Long Unit Identifier
					'electric-ohm' => {
						'name' => q(ਓਹਮ),
					},
					# Core Unit Identifier
					'ohm' => {
						'name' => q(ਓਹਮ),
					},
					# Long Unit Identifier
					'electric-volt' => {
						'name' => q(ਵੋਲਟ),
					},
					# Core Unit Identifier
					'volt' => {
						'name' => q(ਵੋਲਟ),
					},
					# Long Unit Identifier
					'energy-british-thermal-unit' => {
						'name' => q(BTU),
					},
					# Core Unit Identifier
					'british-thermal-unit' => {
						'name' => q(BTU),
					},
					# Long Unit Identifier
					'energy-calorie' => {
						'name' => q(ਕੈਲੋਰੀ),
						'one' => q({0} ਕੈਲੋਰੀ),
						'other' => q({0} ਕੈਲੋਰੀਆਂ),
					},
					# Core Unit Identifier
					'calorie' => {
						'name' => q(ਕੈਲੋਰੀ),
						'one' => q({0} ਕੈਲੋਰੀ),
						'other' => q({0} ਕੈਲੋਰੀਆਂ),
					},
					# Long Unit Identifier
					'energy-electronvolt' => {
						'name' => q(ਇਲੈਕਟ੍ਰਾਨਵੋਲਟ),
					},
					# Core Unit Identifier
					'electronvolt' => {
						'name' => q(ਇਲੈਕਟ੍ਰਾਨਵੋਲਟ),
					},
					# Long Unit Identifier
					'energy-foodcalorie' => {
						'name' => q(ਕੈਲੋਰੀ),
						'one' => q({0} ਕੈਲੋਰੀ),
						'other' => q({0} ਕੈਲੋਰੀਆਂ),
					},
					# Core Unit Identifier
					'foodcalorie' => {
						'name' => q(ਕੈਲੋਰੀ),
						'one' => q({0} ਕੈਲੋਰੀ),
						'other' => q({0} ਕੈਲੋਰੀਆਂ),
					},
					# Long Unit Identifier
					'energy-joule' => {
						'name' => q(ਜੂਲ),
					},
					# Core Unit Identifier
					'joule' => {
						'name' => q(ਜੂਲ),
					},
					# Long Unit Identifier
					'energy-kilocalorie' => {
						'name' => q(ਕਿ.ਕੈਲੋਰੀ),
						'one' => q({0} ਕਿ.ਕੈਲੋਰੀ),
						'other' => q({0} ਕਿ.ਕੈਲੋਰੀਆਂ),
					},
					# Core Unit Identifier
					'kilocalorie' => {
						'name' => q(ਕਿ.ਕੈਲੋਰੀ),
						'one' => q({0} ਕਿ.ਕੈਲੋਰੀ),
						'other' => q({0} ਕਿ.ਕੈਲੋਰੀਆਂ),
					},
					# Long Unit Identifier
					'energy-kilojoule' => {
						'name' => q(ਕਿਲੋਜੂਲ),
						'one' => q({0} ਕਿ.ਜੂਲ),
						'other' => q({0} ਕਿ.ਜੂਲ),
					},
					# Core Unit Identifier
					'kilojoule' => {
						'name' => q(ਕਿਲੋਜੂਲ),
						'one' => q({0} ਕਿ.ਜੂਲ),
						'other' => q({0} ਕਿ.ਜੂਲ),
					},
					# Long Unit Identifier
					'energy-kilowatt-hour' => {
						'name' => q(ਕਿ.ਵਾ.ਘੰ.),
						'one' => q({0} ਕਿ.ਵਾ.ਘੰ.),
						'other' => q({0} ਕਿ.ਵਾ.ਘੰ.),
					},
					# Core Unit Identifier
					'kilowatt-hour' => {
						'name' => q(ਕਿ.ਵਾ.ਘੰ.),
						'one' => q({0} ਕਿ.ਵਾ.ਘੰ.),
						'other' => q({0} ਕਿ.ਵਾ.ਘੰ.),
					},
					# Long Unit Identifier
					'energy-therm-us' => {
						'one' => q({0} ਯੂ.ਐਸ. ਥੈਰਮ),
						'other' => q({0} ਯੂ.ਐਸ. ਥੈਰਮ),
					},
					# Core Unit Identifier
					'therm-us' => {
						'one' => q({0} ਯੂ.ਐਸ. ਥੈਰਮ),
						'other' => q({0} ਯੂ.ਐਸ. ਥੈਰਮ),
					},
					# Long Unit Identifier
					'force-kilowatt-hour-per-100-kilometer' => {
						'name' => q(ਕਿ.ਵ.ਘੰ./100ਕਿ.ਮੀ.),
						'one' => q({0} ਕਿ.ਵ.ਘੰ./100ਕਿ.ਮੀ.),
						'other' => q({0} ਕਿ.ਵ.ਘੰ./100ਕਿ.ਮੀ.),
					},
					# Core Unit Identifier
					'kilowatt-hour-per-100-kilometer' => {
						'name' => q(ਕਿ.ਵ.ਘੰ./100ਕਿ.ਮੀ.),
						'one' => q({0} ਕਿ.ਵ.ਘੰ./100ਕਿ.ਮੀ.),
						'other' => q({0} ਕਿ.ਵ.ਘੰ./100ਕਿ.ਮੀ.),
					},
					# Long Unit Identifier
					'force-newton' => {
						'name' => q(ਨਿਊਟਨ),
						'one' => q({0} ਨਿ),
						'other' => q({0} ਨਿ),
					},
					# Core Unit Identifier
					'newton' => {
						'name' => q(ਨਿਊਟਨ),
						'one' => q({0} ਨਿ),
						'other' => q({0} ਨਿ),
					},
					# Long Unit Identifier
					'force-pound-force' => {
						'name' => q(ਪੌਂਡ-ਬਲ),
					},
					# Core Unit Identifier
					'pound-force' => {
						'name' => q(ਪੌਂਡ-ਬਲ),
					},
					# Long Unit Identifier
					'graphics-dot' => {
						'name' => q(ਡਾਟਸ),
						'one' => q({0} ਡਾਟ),
						'other' => q({0} ਡਾਟਸ),
					},
					# Core Unit Identifier
					'dot' => {
						'name' => q(ਡਾਟਸ),
						'one' => q({0} ਡਾਟ),
						'other' => q({0} ਡਾਟਸ),
					},
					# Long Unit Identifier
					'graphics-dot-per-centimeter' => {
						'name' => q(dpcm),
						'one' => q({0} dpcm),
						'other' => q({0} dpcm),
					},
					# Core Unit Identifier
					'dot-per-centimeter' => {
						'name' => q(dpcm),
						'one' => q({0} dpcm),
						'other' => q({0} dpcm),
					},
					# Long Unit Identifier
					'graphics-dot-per-inch' => {
						'name' => q(dpi),
						'one' => q({0} dpi),
						'other' => q({0} dpi),
					},
					# Core Unit Identifier
					'dot-per-inch' => {
						'name' => q(dpi),
						'one' => q({0} dpi),
						'other' => q({0} dpi),
					},
					# Long Unit Identifier
					'length-centimeter' => {
						'name' => q(ਸੈਂ.ਮੀ.),
						'one' => q({0} ਸੈਂ.ਮੀ.),
						'other' => q({0} ਸੈਂ.ਮੀ.),
						'per' => q({0}/ਸੈਂ.ਮੀ.),
					},
					# Core Unit Identifier
					'centimeter' => {
						'name' => q(ਸੈਂ.ਮੀ.),
						'one' => q({0} ਸੈਂ.ਮੀ.),
						'other' => q({0} ਸੈਂ.ਮੀ.),
						'per' => q({0}/ਸੈਂ.ਮੀ.),
					},
					# Long Unit Identifier
					'length-decimeter' => {
						'name' => q(ਡੈ.ਮੀ.),
						'one' => q({0} ਡੈ.ਮੀ.),
						'other' => q({0} ਡੈ.ਮੀ.),
					},
					# Core Unit Identifier
					'decimeter' => {
						'name' => q(ਡੈ.ਮੀ.),
						'one' => q({0} ਡੈ.ਮੀ.),
						'other' => q({0} ਡੈ.ਮੀ.),
					},
					# Long Unit Identifier
					'length-fathom' => {
						'name' => q(ਫ਼ੈਦਮ),
						'one' => q({0} ਫ਼ੈਦਮ),
						'other' => q({0} ਫ਼ੈਦਮ),
					},
					# Core Unit Identifier
					'fathom' => {
						'name' => q(ਫ਼ੈਦਮ),
						'one' => q({0} ਫ਼ੈਦਮ),
						'other' => q({0} ਫ਼ੈਦਮ),
					},
					# Long Unit Identifier
					'length-foot' => {
						'name' => q(ਫੁੱਟ),
						'one' => q({0} ਫੁੱਟ),
						'other' => q({0} ਫੁੱਟ),
						'per' => q({0}/ਫੁੱਟ),
					},
					# Core Unit Identifier
					'foot' => {
						'name' => q(ਫੁੱਟ),
						'one' => q({0} ਫੁੱਟ),
						'other' => q({0} ਫੁੱਟ),
						'per' => q({0}/ਫੁੱਟ),
					},
					# Long Unit Identifier
					'length-furlong' => {
						'name' => q(ਫਰਲਾਂਗ),
						'one' => q({0} ਫਰਲਾਂਗ),
						'other' => q({0} ਫਰਲਾਂਗ),
					},
					# Core Unit Identifier
					'furlong' => {
						'name' => q(ਫਰਲਾਂਗ),
						'one' => q({0} ਫਰਲਾਂਗ),
						'other' => q({0} ਫਰਲਾਂਗ),
					},
					# Long Unit Identifier
					'length-inch' => {
						'name' => q(ਇੰਚ),
						'one' => q({0} ਇੰਚ),
						'other' => q({0} ਇੰਚ),
						'per' => q({0}/ਇੰਚ),
					},
					# Core Unit Identifier
					'inch' => {
						'name' => q(ਇੰਚ),
						'one' => q({0} ਇੰਚ),
						'other' => q({0} ਇੰਚ),
						'per' => q({0}/ਇੰਚ),
					},
					# Long Unit Identifier
					'length-kilometer' => {
						'name' => q(ਕਿ.ਮੀ.),
						'one' => q({0} ਕਿ.ਮੀ.),
						'other' => q({0} ਕਿ.ਮੀ.),
						'per' => q({0}/ਕਿ.ਮੀ.),
					},
					# Core Unit Identifier
					'kilometer' => {
						'name' => q(ਕਿ.ਮੀ.),
						'one' => q({0} ਕਿ.ਮੀ.),
						'other' => q({0} ਕਿ.ਮੀ.),
						'per' => q({0}/ਕਿ.ਮੀ.),
					},
					# Long Unit Identifier
					'length-light-year' => {
						'name' => q(ਪ੍ਰਕਾਸ਼ ਸਾਲ),
						'one' => q({0} ਪ੍ਰ.ਸ.),
						'other' => q({0} ਪ੍ਰ.ਸ.),
					},
					# Core Unit Identifier
					'light-year' => {
						'name' => q(ਪ੍ਰਕਾਸ਼ ਸਾਲ),
						'one' => q({0} ਪ੍ਰ.ਸ.),
						'other' => q({0} ਪ੍ਰ.ਸ.),
					},
					# Long Unit Identifier
					'length-meter' => {
						'name' => q(ਮੀਟਰ),
						'one' => q({0} ਮੀ.),
						'other' => q({0} ਮੀ.),
						'per' => q({0}/ਮੀ.),
					},
					# Core Unit Identifier
					'meter' => {
						'name' => q(ਮੀਟਰ),
						'one' => q({0} ਮੀ.),
						'other' => q({0} ਮੀ.),
						'per' => q({0}/ਮੀ.),
					},
					# Long Unit Identifier
					'length-micrometer' => {
						'name' => q(ਮਾਈਕਰੋਮੀਟਰ),
					},
					# Core Unit Identifier
					'micrometer' => {
						'name' => q(ਮਾਈਕਰੋਮੀਟਰ),
					},
					# Long Unit Identifier
					'length-mile' => {
						'name' => q(ਮੀਲ),
						'one' => q({0} ਮੀਲ),
						'other' => q({0} ਮੀਲ),
					},
					# Core Unit Identifier
					'mile' => {
						'name' => q(ਮੀਲ),
						'one' => q({0} ਮੀਲ),
						'other' => q({0} ਮੀਲ),
					},
					# Long Unit Identifier
					'length-mile-scandinavian' => {
						'name' => q(ਸਕੈਂਡ. ਮੀਲ),
						'one' => q({0} ਸਕੈਂਡ. ਮੀਲ),
						'other' => q({0} ਸਕੈਂਡ. ਮੀਲ),
					},
					# Core Unit Identifier
					'mile-scandinavian' => {
						'name' => q(ਸਕੈਂਡ. ਮੀਲ),
						'one' => q({0} ਸਕੈਂਡ. ਮੀਲ),
						'other' => q({0} ਸਕੈਂਡ. ਮੀਲ),
					},
					# Long Unit Identifier
					'length-millimeter' => {
						'name' => q(ਮਿ.ਮੀ.),
						'one' => q({0} ਮਿ.ਮੀ.),
						'other' => q({0} ਮਿ.ਮੀ.),
					},
					# Core Unit Identifier
					'millimeter' => {
						'name' => q(ਮਿ.ਮੀ.),
						'one' => q({0} ਮਿ.ਮੀ.),
						'other' => q({0} ਮਿ.ਮੀ.),
					},
					# Long Unit Identifier
					'length-nanometer' => {
						'name' => q(ਨੈ.ਮੀ.),
						'one' => q({0} ਨੈ.ਮੀ.),
						'other' => q({0} ਨੈ.ਮੀ.),
					},
					# Core Unit Identifier
					'nanometer' => {
						'name' => q(ਨੈ.ਮੀ.),
						'one' => q({0} ਨੈ.ਮੀ.),
						'other' => q({0} ਨੈ.ਮੀ.),
					},
					# Long Unit Identifier
					'length-nautical-mile' => {
						'name' => q(ਨੋ.ਮੀਲ),
						'one' => q({0} ਨੋ.ਮੀਲ),
						'other' => q({0} ਨੋ.ਮੀਲ),
					},
					# Core Unit Identifier
					'nautical-mile' => {
						'name' => q(ਨੋ.ਮੀਲ),
						'one' => q({0} ਨੋ.ਮੀਲ),
						'other' => q({0} ਨੋ.ਮੀਲ),
					},
					# Long Unit Identifier
					'length-parsec' => {
						'name' => q(ਪਾਸੈੱਕ),
						'one' => q({0} ਪਾਸੈੱਕ),
						'other' => q({0} ਪਾਸੈੱਕ),
					},
					# Core Unit Identifier
					'parsec' => {
						'name' => q(ਪਾਸੈੱਕ),
						'one' => q({0} ਪਾਸੈੱਕ),
						'other' => q({0} ਪਾਸੈੱਕ),
					},
					# Long Unit Identifier
					'length-picometer' => {
						'name' => q(ਪਿ.ਮੀ.),
						'one' => q({0} ਪਿਕੋਮੀਟਰ),
						'other' => q({0} ਪਿਕੋਮੀਟਰ),
					},
					# Core Unit Identifier
					'picometer' => {
						'name' => q(ਪਿ.ਮੀ.),
						'one' => q({0} ਪਿਕੋਮੀਟਰ),
						'other' => q({0} ਪਿਕੋਮੀਟਰ),
					},
					# Long Unit Identifier
					'length-point' => {
						'name' => q(ਪੁਆਇੰਟ),
					},
					# Core Unit Identifier
					'point' => {
						'name' => q(ਪੁਆਇੰਟ),
					},
					# Long Unit Identifier
					'length-solar-radius' => {
						'name' => q(ਸੋਲਰ ਰੇਡੀਅਸ),
					},
					# Core Unit Identifier
					'solar-radius' => {
						'name' => q(ਸੋਲਰ ਰੇਡੀਅਸ),
					},
					# Long Unit Identifier
					'length-yard' => {
						'name' => q(ਗਜ਼),
						'one' => q({0} ਗਜ਼),
						'other' => q({0} ਗਜ਼),
					},
					# Core Unit Identifier
					'yard' => {
						'name' => q(ਗਜ਼),
						'one' => q({0} ਗਜ਼),
						'other' => q({0} ਗਜ਼),
					},
					# Long Unit Identifier
					'light-lumen' => {
						'name' => q(ਲੁਮੇਨ),
						'one' => q({0} ਲੁਮੇਨ),
						'other' => q({0} ਲੁਮੇਨ),
					},
					# Core Unit Identifier
					'lumen' => {
						'name' => q(ਲੁਮੇਨ),
						'one' => q({0} ਲੁਮੇਨ),
						'other' => q({0} ਲੁਮੇਨ),
					},
					# Long Unit Identifier
					'light-lux' => {
						'name' => q(ਲਕਸ),
						'one' => q({0} ਲਕਸ),
						'other' => q({0} ਲਕਸ),
					},
					# Core Unit Identifier
					'lux' => {
						'name' => q(ਲਕਸ),
						'one' => q({0} ਲਕਸ),
						'other' => q({0} ਲਕਸ),
					},
					# Long Unit Identifier
					'light-solar-luminosity' => {
						'name' => q(ਸੋਲਰ ਲੂਮਨਾਸਿਟੀ),
					},
					# Core Unit Identifier
					'solar-luminosity' => {
						'name' => q(ਸੋਲਰ ਲੂਮਨਾਸਿਟੀ),
					},
					# Long Unit Identifier
					'mass-carat' => {
						'name' => q(ਕੈਰਟ),
						'one' => q({0} ਕੈਰਟ),
						'other' => q({0} ਕੈਰਟ),
					},
					# Core Unit Identifier
					'carat' => {
						'name' => q(ਕੈਰਟ),
						'one' => q({0} ਕੈਰਟ),
						'other' => q({0} ਕੈਰਟ),
					},
					# Long Unit Identifier
					'mass-dalton' => {
						'name' => q(ਡਾਲਟਨ),
						'one' => q({0} ਡਾ),
						'other' => q({0} ਡਾ),
					},
					# Core Unit Identifier
					'dalton' => {
						'name' => q(ਡਾਲਟਨ),
						'one' => q({0} ਡਾ),
						'other' => q({0} ਡਾ),
					},
					# Long Unit Identifier
					'mass-earth-mass' => {
						'name' => q(ਅਰਥ ਮਾਸ),
					},
					# Core Unit Identifier
					'earth-mass' => {
						'name' => q(ਅਰਥ ਮਾਸ),
					},
					# Long Unit Identifier
					'mass-grain' => {
						'name' => q(ਗ੍ਰੇਨ),
						'one' => q({0} ਗ੍ਰੇਨ),
						'other' => q({0} ਗ੍ਰੇਨ),
					},
					# Core Unit Identifier
					'grain' => {
						'name' => q(ਗ੍ਰੇਨ),
						'one' => q({0} ਗ੍ਰੇਨ),
						'other' => q({0} ਗ੍ਰੇਨ),
					},
					# Long Unit Identifier
					'mass-gram' => {
						'name' => q(ਗ੍ਰਾਮ),
						'one' => q({0} ਗ੍ਰਾ.),
						'other' => q({0} ਗ੍ਰਾ.),
						'per' => q({0}/ਗ੍ਰਾ.),
					},
					# Core Unit Identifier
					'gram' => {
						'name' => q(ਗ੍ਰਾਮ),
						'one' => q({0} ਗ੍ਰਾ.),
						'other' => q({0} ਗ੍ਰਾ.),
						'per' => q({0}/ਗ੍ਰਾ.),
					},
					# Long Unit Identifier
					'mass-kilogram' => {
						'name' => q(ਕਿ.ਗ੍ਰਾ.),
						'one' => q({0} ਕਿ.ਗ੍ਰਾ.),
						'other' => q({0} ਕਿ.ਗ੍ਰਾ.),
						'per' => q({0}/ਕਿ.ਗ੍ਰਾ.),
					},
					# Core Unit Identifier
					'kilogram' => {
						'name' => q(ਕਿ.ਗ੍ਰਾ.),
						'one' => q({0} ਕਿ.ਗ੍ਰਾ.),
						'other' => q({0} ਕਿ.ਗ੍ਰਾ.),
						'per' => q({0}/ਕਿ.ਗ੍ਰਾ.),
					},
					# Long Unit Identifier
					'mass-milligram' => {
						'name' => q(ਮਿ.ਗ੍ਰਾ.),
						'one' => q({0} ਮਿ.ਗ੍ਰਾ.),
						'other' => q({0} ਮਿ.ਗ੍ਰਾ.),
					},
					# Core Unit Identifier
					'milligram' => {
						'name' => q(ਮਿ.ਗ੍ਰਾ.),
						'one' => q({0} ਮਿ.ਗ੍ਰਾ.),
						'other' => q({0} ਮਿ.ਗ੍ਰਾ.),
					},
					# Long Unit Identifier
					'mass-ounce' => {
						'name' => q(ਔਂਸ),
						'one' => q({0} ਔਂਸ),
						'other' => q({0} ਔਂਸ),
						'per' => q({0}/ਔਂਸ),
					},
					# Core Unit Identifier
					'ounce' => {
						'name' => q(ਔਂਸ),
						'one' => q({0} ਔਂਸ),
						'other' => q({0} ਔਂਸ),
						'per' => q({0}/ਔਂਸ),
					},
					# Long Unit Identifier
					'mass-ounce-troy' => {
						'name' => q(ਔਂਸ ਟਰੌਏ),
						'one' => q({0} ਔਂਸ ਟ.),
						'other' => q({0} ਔਂਸ ਟ.),
					},
					# Core Unit Identifier
					'ounce-troy' => {
						'name' => q(ਔਂਸ ਟਰੌਏ),
						'one' => q({0} ਔਂਸ ਟ.),
						'other' => q({0} ਔਂਸ ਟ.),
					},
					# Long Unit Identifier
					'mass-pound' => {
						'name' => q(ਪੌਂਡ),
						'one' => q({0} ਪੌਂਡ),
						'other' => q({0} ਪੌਂਡ),
						'per' => q({0}/ਪੌਂਡ),
					},
					# Core Unit Identifier
					'pound' => {
						'name' => q(ਪੌਂਡ),
						'one' => q({0} ਪੌਂਡ),
						'other' => q({0} ਪੌਂਡ),
						'per' => q({0}/ਪੌਂਡ),
					},
					# Long Unit Identifier
					'mass-solar-mass' => {
						'name' => q(ਸੋਲਰ ਮਾਸ),
					},
					# Core Unit Identifier
					'solar-mass' => {
						'name' => q(ਸੋਲਰ ਮਾਸ),
					},
					# Long Unit Identifier
					'mass-stone' => {
						'name' => q(ਸਟੋਨ),
						'one' => q({0} ਸਟੋਨ),
						'other' => q({0} ਸਟੋਨ),
					},
					# Core Unit Identifier
					'stone' => {
						'name' => q(ਸਟੋਨ),
						'one' => q({0} ਸਟੋਨ),
						'other' => q({0} ਸਟੋਨ),
					},
					# Long Unit Identifier
					'mass-ton' => {
						'name' => q(ਅਮਰੀਕੀ ਟਨ),
						'one' => q({0} ਅਮਰੀਕੀ ਟਨ),
						'other' => q({0} ਅਮਰੀਕੀ ਟਨ),
					},
					# Core Unit Identifier
					'ton' => {
						'name' => q(ਅਮਰੀਕੀ ਟਨ),
						'one' => q({0} ਅਮਰੀਕੀ ਟਨ),
						'other' => q({0} ਅਮਰੀਕੀ ਟਨ),
					},
					# Long Unit Identifier
					'power-gigawatt' => {
						'name' => q(ਗੀ.ਵਾਟ),
						'one' => q({0} ਗੀ.ਵਾਟ),
						'other' => q({0} ਗੀ.ਵਾਟ),
					},
					# Core Unit Identifier
					'gigawatt' => {
						'name' => q(ਗੀ.ਵਾਟ),
						'one' => q({0} ਗੀ.ਵਾਟ),
						'other' => q({0} ਗੀ.ਵਾਟ),
					},
					# Long Unit Identifier
					'power-horsepower' => {
						'one' => q({0} ਹੌਰਸਪਾਵਰ),
						'other' => q({0} ਹੌਰਸਪਾਵਰ),
					},
					# Core Unit Identifier
					'horsepower' => {
						'one' => q({0} ਹੌਰਸਪਾਵਰ),
						'other' => q({0} ਹੌਰਸਪਾਵਰ),
					},
					# Long Unit Identifier
					'power-kilowatt' => {
						'name' => q(ਕਿ.ਵਾਟ),
						'one' => q({0} ਕਿ. ਵਾਟ),
						'other' => q({0} ਕਿ. ਵਾਟ),
					},
					# Core Unit Identifier
					'kilowatt' => {
						'name' => q(ਕਿ.ਵਾਟ),
						'one' => q({0} ਕਿ. ਵਾਟ),
						'other' => q({0} ਕਿ. ਵਾਟ),
					},
					# Long Unit Identifier
					'power-megawatt' => {
						'name' => q(ਮੈ.ਵਾਟ),
						'one' => q({0} ਮੈ.ਵਾਟ),
						'other' => q({0} ਮੈ.ਵਾਟ),
					},
					# Core Unit Identifier
					'megawatt' => {
						'name' => q(ਮੈ.ਵਾਟ),
						'one' => q({0} ਮੈ.ਵਾਟ),
						'other' => q({0} ਮੈ.ਵਾਟ),
					},
					# Long Unit Identifier
					'power-milliwatt' => {
						'name' => q(ਮਿ.ਵਾਟ),
						'one' => q({0} ਮਿ.ਵਾਟ),
						'other' => q({0} ਮਿ.ਵਾਟ),
					},
					# Core Unit Identifier
					'milliwatt' => {
						'name' => q(ਮਿ.ਵਾਟ),
						'one' => q({0} ਮਿ.ਵਾਟ),
						'other' => q({0} ਮਿ.ਵਾਟ),
					},
					# Long Unit Identifier
					'power-watt' => {
						'name' => q(ਵਾਟ),
						'one' => q({0} ਵਾਟ),
						'other' => q({0} ਵਾਟ),
					},
					# Core Unit Identifier
					'watt' => {
						'name' => q(ਵਾਟ),
						'one' => q({0} ਵਾਟ),
						'other' => q({0} ਵਾਟ),
					},
					# Long Unit Identifier
					'pressure-atmosphere' => {
						'name' => q(ਵਾ. ਮੰ.),
						'one' => q({0} ਵਾ. ਮੰ.),
						'other' => q({0} ਵਾ. ਮੰ.),
					},
					# Core Unit Identifier
					'atmosphere' => {
						'name' => q(ਵਾ. ਮੰ.),
						'one' => q({0} ਵਾ. ਮੰ.),
						'other' => q({0} ਵਾ. ਮੰ.),
					},
					# Long Unit Identifier
					'pressure-bar' => {
						'name' => q(ਬਾਰ),
						'one' => q({0} ਬਾਰ),
						'other' => q({0} ਬਾਰ),
					},
					# Core Unit Identifier
					'bar' => {
						'name' => q(ਬਾਰ),
						'one' => q({0} ਬਾਰ),
						'other' => q({0} ਬਾਰ),
					},
					# Long Unit Identifier
					'pressure-hectopascal' => {
						'name' => q(ਹੈ.ਪਾ.),
						'one' => q({0} ਹੈ.ਪਾ.),
						'other' => q({0} ਹੈ.ਪਾ.),
					},
					# Core Unit Identifier
					'hectopascal' => {
						'name' => q(ਹੈ.ਪਾ.),
						'one' => q({0} ਹੈ.ਪਾ.),
						'other' => q({0} ਹੈ.ਪਾ.),
					},
					# Long Unit Identifier
					'pressure-inch-ofhg' => {
						'name' => q(ਇੰਚ ਪਾਰਾ),
						'one' => q({0} ਇੰਚ ਪਾਰਾ),
						'other' => q({0} ਇੰਚ ਪਾਰਾ),
					},
					# Core Unit Identifier
					'inch-ofhg' => {
						'name' => q(ਇੰਚ ਪਾਰਾ),
						'one' => q({0} ਇੰਚ ਪਾਰਾ),
						'other' => q({0} ਇੰਚ ਪਾਰਾ),
					},
					# Long Unit Identifier
					'pressure-kilopascal' => {
						'name' => q(ਕਿ.ਪਾ),
						'one' => q({0} ਕਿ.ਪਾ),
						'other' => q({0} ਕਿ.ਪਾ),
					},
					# Core Unit Identifier
					'kilopascal' => {
						'name' => q(ਕਿ.ਪਾ),
						'one' => q({0} ਕਿ.ਪਾ),
						'other' => q({0} ਕਿ.ਪਾ),
					},
					# Long Unit Identifier
					'pressure-megapascal' => {
						'name' => q(ਮੈ.ਪਾ),
						'one' => q({0} ਮੈ.ਪਾ),
						'other' => q({0} ਮੈ.ਪਾ),
					},
					# Core Unit Identifier
					'megapascal' => {
						'name' => q(ਮੈ.ਪਾ),
						'one' => q({0} ਮੈ.ਪਾ),
						'other' => q({0} ਮੈ.ਪਾ),
					},
					# Long Unit Identifier
					'pressure-millibar' => {
						'name' => q(ਮਿਲੀਬਾਰ),
						'one' => q({0} ਮਿਲੀਬਾਰ),
						'other' => q({0} ਮਿਲੀਬਾਰ),
					},
					# Core Unit Identifier
					'millibar' => {
						'name' => q(ਮਿਲੀਬਾਰ),
						'one' => q({0} ਮਿਲੀਬਾਰ),
						'other' => q({0} ਮਿਲੀਬਾਰ),
					},
					# Long Unit Identifier
					'pressure-millimeter-ofhg' => {
						'name' => q(ਮਿ.ਮੀ. ਪਾਰਾ),
						'one' => q({0} ਮਿ.ਮੀ. ਪਾਰਾ),
						'other' => q({0} ਮਿ.ਮੀ. ਪਾਰਾ),
					},
					# Core Unit Identifier
					'millimeter-ofhg' => {
						'name' => q(ਮਿ.ਮੀ. ਪਾਰਾ),
						'one' => q({0} ਮਿ.ਮੀ. ਪਾਰਾ),
						'other' => q({0} ਮਿ.ਮੀ. ਪਾਰਾ),
					},
					# Long Unit Identifier
					'pressure-pound-force-per-square-inch' => {
						'name' => q(ਪੌਂ.ਵ.ਇੰਚ),
						'one' => q({0} ਪੌਂ.ਵ.ਇੰਚ),
						'other' => q({0} ਪੌਂ.ਵ.ਇੰਚ),
					},
					# Core Unit Identifier
					'pound-force-per-square-inch' => {
						'name' => q(ਪੌਂ.ਵ.ਇੰਚ),
						'one' => q({0} ਪੌਂ.ਵ.ਇੰਚ),
						'other' => q({0} ਪੌਂ.ਵ.ਇੰਚ),
					},
					# Long Unit Identifier
					'speed-kilometer-per-hour' => {
						'name' => q(ਕਿ.ਮੀ./ਘੰਟਾ),
						'one' => q({0} ਕਿ.ਮੀ./ਘੰ.),
						'other' => q({0} ਕਿ.ਮੀ./ਘੰ.),
					},
					# Core Unit Identifier
					'kilometer-per-hour' => {
						'name' => q(ਕਿ.ਮੀ./ਘੰਟਾ),
						'one' => q({0} ਕਿ.ਮੀ./ਘੰ.),
						'other' => q({0} ਕਿ.ਮੀ./ਘੰ.),
					},
					# Long Unit Identifier
					'speed-light-speed' => {
						'name' => q(ਪ੍ਰਕਾਸ਼),
						'one' => q({0} ਪ੍ਰਕਾਸ਼),
						'other' => q({0} ਪ੍ਰਕਾਸ਼),
					},
					# Core Unit Identifier
					'light-speed' => {
						'name' => q(ਪ੍ਰਕਾਸ਼),
						'one' => q({0} ਪ੍ਰਕਾਸ਼),
						'other' => q({0} ਪ੍ਰਕਾਸ਼),
					},
					# Long Unit Identifier
					'speed-meter-per-second' => {
						'name' => q(ਮੀਟਰ/ਸਕਿੰਟ),
						'one' => q({0} ਮੀ./ਸ.),
						'other' => q({0} ਮੀ./ਸ.),
					},
					# Core Unit Identifier
					'meter-per-second' => {
						'name' => q(ਮੀਟਰ/ਸਕਿੰਟ),
						'one' => q({0} ਮੀ./ਸ.),
						'other' => q({0} ਮੀ./ਸ.),
					},
					# Long Unit Identifier
					'speed-mile-per-hour' => {
						'name' => q(ਮੀਲ/ਘੰਟਾ),
						'one' => q({0} ਮੀਲ/ਘੰ.),
						'other' => q({0} ਮੀਲ/ਘੰ.),
					},
					# Core Unit Identifier
					'mile-per-hour' => {
						'name' => q(ਮੀਲ/ਘੰਟਾ),
						'one' => q({0} ਮੀਲ/ਘੰ.),
						'other' => q({0} ਮੀਲ/ਘੰ.),
					},
					# Long Unit Identifier
					'temperature-celsius' => {
						'name' => q(ਡਿ. ਸੈਲਸੀਅਸ),
					},
					# Core Unit Identifier
					'celsius' => {
						'name' => q(ਡਿ. ਸੈਲਸੀਅਸ),
					},
					# Long Unit Identifier
					'temperature-fahrenheit' => {
						'name' => q(ਡਿ. ਫਾ.),
					},
					# Core Unit Identifier
					'fahrenheit' => {
						'name' => q(ਡਿ. ਫਾ.),
					},
					# Long Unit Identifier
					'torque-newton-meter' => {
						'name' => q(ਨਿ⋅ਮੀ),
						'one' => q({0} ਨਿ⋅ਮੀ),
						'other' => q({0} ਨਿ⋅ਮੀ),
					},
					# Core Unit Identifier
					'newton-meter' => {
						'name' => q(ਨਿ⋅ਮੀ),
						'one' => q({0} ਨਿ⋅ਮੀ),
						'other' => q({0} ਨਿ⋅ਮੀ),
					},
					# Long Unit Identifier
					'volume-acre-foot' => {
						'name' => q(ਏਕੜ ਫੁੱਟ),
						'one' => q({0} ਏਕੜ ਫੁੱਟ),
						'other' => q({0} ਏਕੜ ਫੁੱਟ),
					},
					# Core Unit Identifier
					'acre-foot' => {
						'name' => q(ਏਕੜ ਫੁੱਟ),
						'one' => q({0} ਏਕੜ ਫੁੱਟ),
						'other' => q({0} ਏਕੜ ਫੁੱਟ),
					},
					# Long Unit Identifier
					'volume-barrel' => {
						'name' => q(ਬੈਰਲ),
						'one' => q({0} ਬੈਰਲ),
						'other' => q({0} ਬੈਰਲ),
					},
					# Core Unit Identifier
					'barrel' => {
						'name' => q(ਬੈਰਲ),
						'one' => q({0} ਬੈਰਲ),
						'other' => q({0} ਬੈਰਲ),
					},
					# Long Unit Identifier
					'volume-bushel' => {
						'name' => q(ਬੁਸ਼ਲ),
						'one' => q({0} ਬੁਸ਼ਲ),
						'other' => q({0} ਬੁਸ਼ਲ),
					},
					# Core Unit Identifier
					'bushel' => {
						'name' => q(ਬੁਸ਼ਲ),
						'one' => q({0} ਬੁਸ਼ਲ),
						'other' => q({0} ਬੁਸ਼ਲ),
					},
					# Long Unit Identifier
					'volume-centiliter' => {
						'name' => q(ਸੈਂ.ਲਿ.),
						'one' => q({0} ਸੈਂ.ਲਿ.),
						'other' => q({0} ਸੈਂ.ਲਿ.),
					},
					# Core Unit Identifier
					'centiliter' => {
						'name' => q(ਸੈਂ.ਲਿ.),
						'one' => q({0} ਸੈਂ.ਲਿ.),
						'other' => q({0} ਸੈਂ.ਲਿ.),
					},
					# Long Unit Identifier
					'volume-cubic-centimeter' => {
						'name' => q(ਸੈਮੀ³),
						'one' => q({0} ਸੈਮੀ³),
						'other' => q({0} ਸੈਮੀ³),
						'per' => q({0}/ਸੈਮੀ³),
					},
					# Core Unit Identifier
					'cubic-centimeter' => {
						'name' => q(ਸੈਮੀ³),
						'one' => q({0} ਸੈਮੀ³),
						'other' => q({0} ਸੈਮੀ³),
						'per' => q({0}/ਸੈਮੀ³),
					},
					# Long Unit Identifier
					'volume-cubic-foot' => {
						'name' => q(ਫੁੱਟ³),
						'one' => q({0} ਫੁੱਟ³),
						'other' => q({0} ਫੁੱਟ³),
					},
					# Core Unit Identifier
					'cubic-foot' => {
						'name' => q(ਫੁੱਟ³),
						'one' => q({0} ਫੁੱਟ³),
						'other' => q({0} ਫੁੱਟ³),
					},
					# Long Unit Identifier
					'volume-cubic-inch' => {
						'name' => q(ਇੰਚ³),
						'one' => q({0} ਇੰਚ³),
						'other' => q({0} ਇੰਚ³),
					},
					# Core Unit Identifier
					'cubic-inch' => {
						'name' => q(ਇੰਚ³),
						'one' => q({0} ਇੰਚ³),
						'other' => q({0} ਇੰਚ³),
					},
					# Long Unit Identifier
					'volume-cubic-kilometer' => {
						'name' => q(ਕਿਮੀ³),
						'one' => q({0} ਕਿਮੀ³),
						'other' => q({0} ਕਿਮੀ³),
					},
					# Core Unit Identifier
					'cubic-kilometer' => {
						'name' => q(ਕਿਮੀ³),
						'one' => q({0} ਕਿਮੀ³),
						'other' => q({0} ਕਿਮੀ³),
					},
					# Long Unit Identifier
					'volume-cubic-meter' => {
						'name' => q(ਮੀ³),
						'one' => q({0} ਮੀ³),
						'other' => q({0} ਮੀ³),
						'per' => q({0}/ਮੀ³),
					},
					# Core Unit Identifier
					'cubic-meter' => {
						'name' => q(ਮੀ³),
						'one' => q({0} ਮੀ³),
						'other' => q({0} ਮੀ³),
						'per' => q({0}/ਮੀ³),
					},
					# Long Unit Identifier
					'volume-cubic-mile' => {
						'name' => q(ਮੀਲ³),
						'one' => q({0} ਮੀਲ³),
						'other' => q({0} ਮੀਲ³),
					},
					# Core Unit Identifier
					'cubic-mile' => {
						'name' => q(ਮੀਲ³),
						'one' => q({0} ਮੀਲ³),
						'other' => q({0} ਮੀਲ³),
					},
					# Long Unit Identifier
					'volume-cubic-yard' => {
						'name' => q(ਗਜ਼³),
						'one' => q({0} ਗਜ਼³),
						'other' => q({0} ਗਜ਼³),
					},
					# Core Unit Identifier
					'cubic-yard' => {
						'name' => q(ਗਜ਼³),
						'one' => q({0} ਗਜ਼³),
						'other' => q({0} ਗਜ਼³),
					},
					# Long Unit Identifier
					'volume-cup' => {
						'name' => q(ਕੱਪ),
						'one' => q({0} ਕੱਪ),
						'other' => q({0} ਕੱਪ),
					},
					# Core Unit Identifier
					'cup' => {
						'name' => q(ਕੱਪ),
						'one' => q({0} ਕੱਪ),
						'other' => q({0} ਕੱਪ),
					},
					# Long Unit Identifier
					'volume-cup-metric' => {
						'name' => q(ਮੀ ਕੱਪ),
						'one' => q({0} ਮੀ ਕੱਪ),
						'other' => q({0} ਮੀ ਕੱਪ),
					},
					# Core Unit Identifier
					'cup-metric' => {
						'name' => q(ਮੀ ਕੱਪ),
						'one' => q({0} ਮੀ ਕੱਪ),
						'other' => q({0} ਮੀ ਕੱਪ),
					},
					# Long Unit Identifier
					'volume-deciliter' => {
						'name' => q(ਡੈ.ਲਿ.),
						'one' => q({0} ਡੈ.ਲਿ.),
						'other' => q({0} ਡੈ.ਲਿ.),
					},
					# Core Unit Identifier
					'deciliter' => {
						'name' => q(ਡੈ.ਲਿ.),
						'one' => q({0} ਡੈ.ਲਿ.),
						'other' => q({0} ਡੈ.ਲਿ.),
					},
					# Long Unit Identifier
					'volume-dessert-spoon' => {
						'name' => q(ਡੈਜ਼ਰਟ ਸਪੂਨ),
						'one' => q({0} ਡੈਜ਼ਰਟ ਸਪੂਨ),
						'other' => q({0} ਡੈਜ਼ਰਟ ਸਪੂਨ),
					},
					# Core Unit Identifier
					'dessert-spoon' => {
						'name' => q(ਡੈਜ਼ਰਟ ਸਪੂਨ),
						'one' => q({0} ਡੈਜ਼ਰਟ ਸਪੂਨ),
						'other' => q({0} ਡੈਜ਼ਰਟ ਸਪੂਨ),
					},
					# Long Unit Identifier
					'volume-dessert-spoon-imperial' => {
						'name' => q(ਇੰਪੀਰੀਅਲ ਡੈਜ਼ਰਟ ਸਪੂਨ),
						'one' => q({0} ਇੰਪ. ਡੈ. ਸ.),
						'other' => q({0} ਇੰਪ. ਡੈ. ਸ.),
					},
					# Core Unit Identifier
					'dessert-spoon-imperial' => {
						'name' => q(ਇੰਪੀਰੀਅਲ ਡੈਜ਼ਰਟ ਸਪੂਨ),
						'one' => q({0} ਇੰਪ. ਡੈ. ਸ.),
						'other' => q({0} ਇੰਪ. ਡੈ. ਸ.),
					},
					# Long Unit Identifier
					'volume-dram' => {
						'name' => q(ਚੁਸਕੀ ਭਰ),
						'one' => q({0} ਚੁਸਕੀ ਭਰ),
						'other' => q({0} ਚੁਸਕੀ ਭਰ),
					},
					# Core Unit Identifier
					'dram' => {
						'name' => q(ਚੁਸਕੀ ਭਰ),
						'one' => q({0} ਚੁਸਕੀ ਭਰ),
						'other' => q({0} ਚੁਸਕੀ ਭਰ),
					},
					# Long Unit Identifier
					'volume-drop' => {
						'name' => q(ਬੂੰਦ),
						'one' => q({0} ਬੂੰਦ),
						'other' => q({0} ਬੂੰਦ),
					},
					# Core Unit Identifier
					'drop' => {
						'name' => q(ਬੂੰਦ),
						'one' => q({0} ਬੂੰਦ),
						'other' => q({0} ਬੂੰਦ),
					},
					# Long Unit Identifier
					'volume-fluid-ounce' => {
						'name' => q(ਤ. ਔਂਸ),
						'one' => q({0} ਤ. ਔਂਸ),
						'other' => q({0} ਤ. ਔਂਸ),
					},
					# Core Unit Identifier
					'fluid-ounce' => {
						'name' => q(ਤ. ਔਂਸ),
						'one' => q({0} ਤ. ਔਂਸ),
						'other' => q({0} ਤ. ਔਂਸ),
					},
					# Long Unit Identifier
					'volume-fluid-ounce-imperial' => {
						'name' => q(ਇੰਪ. ਫਲੂ. ਔ.),
						'one' => q({0} ਫਲੂ. ਔ. ਇੰਪ.),
						'other' => q({0} ਫਲੂ. ਔ. ਇੰਪ.),
					},
					# Core Unit Identifier
					'fluid-ounce-imperial' => {
						'name' => q(ਇੰਪ. ਫਲੂ. ਔ.),
						'one' => q({0} ਫਲੂ. ਔ. ਇੰਪ.),
						'other' => q({0} ਫਲੂ. ਔ. ਇੰਪ.),
					},
					# Long Unit Identifier
					'volume-gallon' => {
						'name' => q(ਗੈਲਨ),
						'one' => q({0} ਗੈਲਨ),
						'other' => q({0} ਗੈਲਨ),
						'per' => q({0}/ਗੈਲਨ),
					},
					# Core Unit Identifier
					'gallon' => {
						'name' => q(ਗੈਲਨ),
						'one' => q({0} ਗੈਲਨ),
						'other' => q({0} ਗੈਲਨ),
						'per' => q({0}/ਗੈਲਨ),
					},
					# Long Unit Identifier
					'volume-gallon-imperial' => {
						'name' => q(ਇੰਪ. ਗੈਲਨ),
						'one' => q({0} ਗੈਲਨ ਇੰਪ.),
						'other' => q({0} ਗੈਲਨ ਇੰਪ.),
						'per' => q({0}/ਗੈਲਨ ਇੰਪ.),
					},
					# Core Unit Identifier
					'gallon-imperial' => {
						'name' => q(ਇੰਪ. ਗੈਲਨ),
						'one' => q({0} ਗੈਲਨ ਇੰਪ.),
						'other' => q({0} ਗੈਲਨ ਇੰਪ.),
						'per' => q({0}/ਗੈਲਨ ਇੰਪ.),
					},
					# Long Unit Identifier
					'volume-hectoliter' => {
						'name' => q(ਹੈ.ਲਿ.),
						'one' => q({0} ਹੈ.ਲਿ.),
						'other' => q({0} ਹੈ.ਲਿ.),
					},
					# Core Unit Identifier
					'hectoliter' => {
						'name' => q(ਹੈ.ਲਿ.),
						'one' => q({0} ਹੈ.ਲਿ.),
						'other' => q({0} ਹੈ.ਲਿ.),
					},
					# Long Unit Identifier
					'volume-jigger' => {
						'name' => q(ਚੱਕਾ),
						'one' => q({0} ਚੱਕਾ),
						'other' => q({0} ਚੱਕਾ),
					},
					# Core Unit Identifier
					'jigger' => {
						'name' => q(ਚੱਕਾ),
						'one' => q({0} ਚੱਕਾ),
						'other' => q({0} ਚੱਕਾ),
					},
					# Long Unit Identifier
					'volume-liter' => {
						'name' => q(ਲਿਟਰ),
						'one' => q({0} ਲਿ.),
						'other' => q({0} ਲਿ.),
						'per' => q({0}/ਲਿ.),
					},
					# Core Unit Identifier
					'liter' => {
						'name' => q(ਲਿਟਰ),
						'one' => q({0} ਲਿ.),
						'other' => q({0} ਲਿ.),
						'per' => q({0}/ਲਿ.),
					},
					# Long Unit Identifier
					'volume-megaliter' => {
						'name' => q(ਮੈ.ਲਿ.),
						'one' => q({0} ਮੈ.ਲਿ.),
						'other' => q({0} ਮੈ.ਲਿ.),
					},
					# Core Unit Identifier
					'megaliter' => {
						'name' => q(ਮੈ.ਲਿ.),
						'one' => q({0} ਮੈ.ਲਿ.),
						'other' => q({0} ਮੈ.ਲਿ.),
					},
					# Long Unit Identifier
					'volume-milliliter' => {
						'name' => q(ਮਿ.ਲਿ.),
						'one' => q({0} ਮਿ.ਲਿ.),
						'other' => q({0} ਮਿ.ਲਿ.),
					},
					# Core Unit Identifier
					'milliliter' => {
						'name' => q(ਮਿ.ਲਿ.),
						'one' => q({0} ਮਿ.ਲਿ.),
						'other' => q({0} ਮਿ.ਲਿ.),
					},
					# Long Unit Identifier
					'volume-pinch' => {
						'name' => q(ਚੁਟਕੀ),
						'one' => q({0} ਚੁਟਕੀ),
						'other' => q({0} ਚੁਟਕੀ),
					},
					# Core Unit Identifier
					'pinch' => {
						'name' => q(ਚੁਟਕੀ),
						'one' => q({0} ਚੁਟਕੀ),
						'other' => q({0} ਚੁਟਕੀ),
					},
					# Long Unit Identifier
					'volume-pint' => {
						'name' => q(ਪਿੰਟ),
						'one' => q({0} ਪਿੰਟ),
						'other' => q({0} ਪਿੰਟ),
					},
					# Core Unit Identifier
					'pint' => {
						'name' => q(ਪਿੰਟ),
						'one' => q({0} ਪਿੰਟ),
						'other' => q({0} ਪਿੰਟ),
					},
					# Long Unit Identifier
					'volume-pint-metric' => {
						'name' => q(ਮੀ ਪਿੰਟ),
						'one' => q({0} ਮੀ ਪਿੰਟ),
						'other' => q({0} ਮੀ ਪਿੰਟ),
					},
					# Core Unit Identifier
					'pint-metric' => {
						'name' => q(ਮੀ ਪਿੰਟ),
						'one' => q({0} ਮੀ ਪਿੰਟ),
						'other' => q({0} ਮੀ ਪਿੰਟ),
					},
					# Long Unit Identifier
					'volume-quart' => {
						'name' => q(ਕੁਆਟ),
						'one' => q({0} ਕੁਆਟ),
						'other' => q({0} ਕੁਆਟ),
					},
					# Core Unit Identifier
					'quart' => {
						'name' => q(ਕੁਆਟ),
						'one' => q({0} ਕੁਆਟ),
						'other' => q({0} ਕੁਆਟ),
					},
					# Long Unit Identifier
					'volume-quart-imperial' => {
						'name' => q(ਇੰਪੀਰੀਅਲ ਚੁਥਾਈ ਗੈਲਨ),
						'one' => q({0} ਇੰਪ. ਚੁ. ਗੈ.),
						'other' => q({0} ਇੰਪ. ਚੁ. ਗੈ.),
					},
					# Core Unit Identifier
					'quart-imperial' => {
						'name' => q(ਇੰਪੀਰੀਅਲ ਚੁਥਾਈ ਗੈਲਨ),
						'one' => q({0} ਇੰਪ. ਚੁ. ਗੈ.),
						'other' => q({0} ਇੰਪ. ਚੁ. ਗੈ.),
					},
					# Long Unit Identifier
					'volume-tablespoon' => {
						'name' => q(ਟੇਬਲ ਸਪੂਨ),
						'one' => q({0} ਟੇਬਲ ਸਪੂਨ),
						'other' => q({0} ਟੇਬਲ ਸਪੂਨ),
					},
					# Core Unit Identifier
					'tablespoon' => {
						'name' => q(ਟੇਬਲ ਸਪੂਨ),
						'one' => q({0} ਟੇਬਲ ਸਪੂਨ),
						'other' => q({0} ਟੇਬਲ ਸਪੂਨ),
					},
					# Long Unit Identifier
					'volume-teaspoon' => {
						'name' => q(ਟੀ ਸਪੂਨ),
						'one' => q({0} ਟੀ ਸਪੂਨ),
						'other' => q({0} ਟੀ ਸਪੂਨ),
					},
					# Core Unit Identifier
					'teaspoon' => {
						'name' => q(ਟੀ ਸਪੂਨ),
						'one' => q({0} ਟੀ ਸਪੂਨ),
						'other' => q({0} ਟੀ ਸਪੂਨ),
					},
				},
			} }
);

has 'yesstr' => (
	is			=> 'ro',
	isa			=> RegexpRef,
	init_arg	=> undef,
	default		=> sub { qr'^(?i:ਹਾਂ|ਹ|yes|y)$' }
);

has 'nostr' => (
	is			=> 'ro',
	isa			=> RegexpRef,
	init_arg	=> undef,
	default		=> sub { qr'^(?i:ਨਹੀਂ|ਨ|no|n)$' }
);

has 'listPatterns' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
				end => q({0} ਅਤੇ {1}),
				2 => q({0} ਅਤੇ {1}),
		} }
);

has native_numbering_system => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> 'guru',
);

has 'number_symbols' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'arab' => {
			'decimal' => q(.),
			'exponential' => q(E),
			'group' => q(,),
			'minusSign' => q(-),
			'perMille' => q(‰),
			'percentSign' => q(%),
			'plusSign' => q(+),
		},
		'arabext' => {
			'group' => q(,),
			'minusSign' => q(-),
			'plusSign' => q(+),
		},
	} }
);

has 'number_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		decimalFormat => {
			'default' => {
				'1000' => {
					'one' => '0 ਹਜ਼ਾਰ',
					'other' => '0 ਹਜ਼ਾਰ',
				},
				'10000' => {
					'one' => '00 ਹਜ਼ਾਰ',
					'other' => '00 ਹਜ਼ਾਰ',
				},
				'100000' => {
					'one' => '0 ਲੱਖ',
					'other' => '0 ਲੱਖ',
				},
				'1000000' => {
					'one' => '00 ਲੱਖ',
					'other' => '00 ਲੱਖ',
				},
				'10000000' => {
					'one' => '0 ਕਰੋੜ',
					'other' => '0 ਕਰੋੜ',
				},
				'100000000' => {
					'one' => '00 ਕਰੋੜ',
					'other' => '00 ਕਰੋੜ',
				},
				'1000000000' => {
					'one' => '0 ਅਰਬ',
					'other' => '0 ਅਰਬ',
				},
				'10000000000' => {
					'one' => '00 ਅਰਬ',
					'other' => '00 ਅਰਬ',
				},
				'100000000000' => {
					'one' => '0 ਖਰਬ',
					'other' => '0 ਖਰਬ',
				},
				'1000000000000' => {
					'one' => '00 ਖਰਬ',
					'other' => '00 ਖਰਬ',
				},
				'10000000000000' => {
					'one' => '0 ਨੀਲ',
					'other' => '0 ਨੀਲ',
				},
				'100000000000000' => {
					'one' => '00 ਨੀਲ',
					'other' => '00 ਨੀਲ',
				},
				'standard' => {
					'default' => '#,##,##0.###',
				},
			},
			'long' => {
				'1000' => {
					'one' => '0 ਹਜ਼ਾਰ',
					'other' => '0 ਹਜ਼ਾਰ',
				},
				'10000' => {
					'one' => '00 ਹਜ਼ਾਰ',
					'other' => '00 ਹਜ਼ਾਰ',
				},
				'100000' => {
					'one' => '0 ਲੱਖ',
					'other' => '0 ਲੱਖ',
				},
				'1000000' => {
					'one' => '00 ਲੱਖ',
					'other' => '00 ਲੱਖ',
				},
				'10000000' => {
					'one' => '0 ਕਰੋੜ',
					'other' => '0 ਕਰੋੜ',
				},
				'100000000' => {
					'one' => '00 ਕਰੋੜ',
					'other' => '00 ਕਰੋੜ',
				},
				'1000000000' => {
					'one' => '0 ਅਰਬ',
					'other' => '0 ਅਰਬ',
				},
				'10000000000' => {
					'one' => '00 ਅਰਬ',
					'other' => '00 ਅਰਬ',
				},
				'100000000000' => {
					'one' => '0 ਖਰਬ',
					'other' => '0 ਖਰਬ',
				},
				'1000000000000' => {
					'one' => '00 ਖਰਬ',
					'other' => '00 ਖਰਬ',
				},
				'10000000000000' => {
					'one' => '0 ਨੀਲ',
					'other' => '0 ਨੀਲ',
				},
				'100000000000000' => {
					'one' => '00 ਨੀਲ',
					'other' => '00 ਨੀਲ',
				},
			},
			'short' => {
				'1000' => {
					'one' => '0 ਹਜ਼ਾਰ',
					'other' => '0 ਹਜ਼ਾਰ',
				},
				'10000' => {
					'one' => '00 ਹਜ਼ਾਰ',
					'other' => '00 ਹਜ਼ਾਰ',
				},
				'100000' => {
					'one' => '0 ਲੱਖ',
					'other' => '0 ਲੱਖ',
				},
				'1000000' => {
					'one' => '00 ਲੱਖ',
					'other' => '00 ਲੱਖ',
				},
				'10000000' => {
					'one' => '0 ਕਰੋੜ',
					'other' => '0 ਕਰੋੜ',
				},
				'100000000' => {
					'one' => '00 ਕਰੋੜ',
					'other' => '00 ਕਰੋੜ',
				},
				'1000000000' => {
					'one' => '0 ਅਰਬ',
					'other' => '0 ਅਰਬ',
				},
				'10000000000' => {
					'one' => '00 ਅਰਬ',
					'other' => '00 ਅਰਬ',
				},
				'100000000000' => {
					'one' => '0 ਖਰਬ',
					'other' => '0 ਖਰਬ',
				},
				'1000000000000' => {
					'one' => '00 ਖਰਬ',
					'other' => '00 ਖਰਬ',
				},
				'10000000000000' => {
					'one' => '0 ਨੀਲ',
					'other' => '0 ਨੀਲ',
				},
				'100000000000000' => {
					'one' => '00 ਨੀਲ',
					'other' => '00 ਨੀਲ',
				},
			},
		},
		percentFormat => {
			'default' => {
				'standard' => {
					'default' => '#,##,##0%',
				},
			},
		},
		scientificFormat => {
			'default' => {
				'standard' => {
					'default' => '[#E0]',
				},
			},
		},
} },
);

has 'number_currency_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'arab' => {
			'pattern' => {
				'default' => {
					'standard' => {
						'positive' => '¤#,##,##0.00',
					},
				},
			},
		},
		'arabext' => {
			'pattern' => {
				'default' => {
					'standard' => {
						'positive' => '¤ #,##,##0.00',
					},
				},
			},
		},
		'latn' => {
			'pattern' => {
				'default' => {
					'accounting' => {
						'positive' => '¤ #,##0.00',
					},
					'standard' => {
						'positive' => '¤#,##,##0.00',
					},
				},
			},
		},
} },
);

has 'currencies' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'AED' => {
			display_name => {
				'currency' => q(ਸੰਯੁਕਤ ਅਰਬ ਅਮੀਰਾਤ ਦਿਰਹਾਮ),
			},
		},
		'AFN' => {
			display_name => {
				'currency' => q(ਅਫ਼ਗਾਨ ਅਫ਼ਗਾਨੀ),
			},
		},
		'ALL' => {
			display_name => {
				'currency' => q(ਅਲਬਾਨੀਆਈ ਲੇਕ),
			},
		},
		'AMD' => {
			display_name => {
				'currency' => q(ਅਰਮੀਨੀਆਈ ਦਰਾਮ),
			},
		},
		'ANG' => {
			display_name => {
				'currency' => q(ਨੀਦਰਲੈਂਡਸ ਐਂਟੀਲੀਅਨ ਗਿਲਡਰ),
			},
		},
		'AOA' => {
			display_name => {
				'currency' => q(ਅੰਗੋਲਾ ਕਵਾਂਜਾ),
			},
		},
		'ARA' => {
			display_name => {
				'currency' => q(ਅਰਜਨਟੀਨੀ ਅਸਟਰਾਲ),
			},
		},
		'ARL' => {
			display_name => {
				'currency' => q(ਅਰਜਨਟੀਨੀ ਪੇਸੋ ਲੇ \(1970–1983\)),
			},
		},
		'ARM' => {
			display_name => {
				'currency' => q(ਅਰਜਨਟੀਨੀ ਪੇਸੋ \(1881–1970\)),
			},
		},
		'ARP' => {
			display_name => {
				'currency' => q(ਅਰਜਨਟੀਨੀ ਪੇਸੋ \(1983–1985\)),
			},
		},
		'ARS' => {
			display_name => {
				'currency' => q(ਅਰਜਨਟੀਨੀ ਪੇਸੋ),
			},
		},
		'AUD' => {
			display_name => {
				'currency' => q(ਆਸਟ੍ਰੇਲੀਆਈ ਡਾਲਰ),
			},
		},
		'AWG' => {
			display_name => {
				'currency' => q(ਅਰੂਬਨ ਫਲੋਰਿਨ),
			},
		},
		'AZN' => {
			display_name => {
				'currency' => q(ਅਜ਼ਰਬਾਈਜਾਨ ਮਾਨਤ),
			},
		},
		'BAM' => {
			display_name => {
				'currency' => q(ਬੋਸਨੀਆ-ਹਰਜ਼ੇਗੋਵੀਨਾ ਬਦਲਣਯੋਗ ਮਾਰਕ),
			},
		},
		'BBD' => {
			display_name => {
				'currency' => q(ਬਾਰਬਾਡੀਅਨ ਡਾਲਰ),
			},
		},
		'BDT' => {
			display_name => {
				'currency' => q(ਬੰਗਲਾਦੇਸ਼ੀ ਟਕਾ),
			},
		},
		'BGN' => {
			display_name => {
				'currency' => q(ਬੁਲਗਾਰੀਆਈ ਲੇਵ),
			},
		},
		'BHD' => {
			display_name => {
				'currency' => q(ਬਹਿਰੀਨੀ ਦਿਨਾਰ),
			},
		},
		'BIF' => {
			display_name => {
				'currency' => q(ਬੁਰੁੰਡੀਆਈ ਫ੍ਰੈਂਕ),
			},
		},
		'BMD' => {
			display_name => {
				'currency' => q(ਬਰਮੂਡਾ ਡਾਲਰ),
			},
		},
		'BND' => {
			display_name => {
				'currency' => q(ਬਰੂਨੇਈ ਡਾਲਰ),
			},
		},
		'BOB' => {
			display_name => {
				'currency' => q(ਬੋਲੀਵੀਅਨ ਬੋਲੀਵੀਅਨੋ),
			},
		},
		'BOL' => {
			display_name => {
				'currency' => q(ਬੋਲੀਵੀਆਈ ਬੋਲੀਵੀਅਨੋ \(1863–1963\)),
			},
		},
		'BOP' => {
			display_name => {
				'currency' => q(ਬੋਲੀਵੀਆਈ ਪੇਸੋ),
			},
		},
		'BOV' => {
			display_name => {
				'currency' => q(ਬੋਲੀਵੀਆਈ ਮਵਡੋਲ),
			},
		},
		'BRB' => {
			display_name => {
				'currency' => q(ਬ੍ਰਾਜ਼ੀਲੀਆਈ ਨਿਊ ਕਰੁਜ਼ਿਰੋਸ \(1967–1986\)),
			},
		},
		'BRC' => {
			display_name => {
				'currency' => q(ਬ੍ਰਾਜ਼ੀਲੀਆਈ ਕਰੁਜ਼ਾਡੂ \(1986–1989\)),
			},
		},
		'BRE' => {
			display_name => {
				'currency' => q(ਬ੍ਰਾਜ਼ੀਲੀਆਈ ਕਰੁਜ਼ਿਰੋਸ \(1990–1993\)),
			},
		},
		'BRL' => {
			display_name => {
				'currency' => q(ਬ੍ਰਾਜ਼ੀਲੀਆਈ ਰੀਅਲ),
			},
		},
		'BRN' => {
			display_name => {
				'currency' => q(ਬ੍ਰਾਜ਼ੀਲੀਆਈ ਨਿਊ ਕਰੁਜ਼ਾਡੂ \(1989–1990\)),
			},
		},
		'BRR' => {
			display_name => {
				'currency' => q(ਬ੍ਰਾਜ਼ੀਲੀਆਈ ਕਰੁਜ਼ਿਰੋਸ \(1993–1994\)),
			},
		},
		'BRZ' => {
			display_name => {
				'currency' => q(ਬ੍ਰਾਜ਼ੀਲੀਆਈ ਕਰੁਜ਼ਿਰੋਸ \(1942–1967\)),
			},
		},
		'BSD' => {
			display_name => {
				'currency' => q(ਬਾਹਾਮੀਅਨ ਡਾਲਰ),
			},
		},
		'BTN' => {
			display_name => {
				'currency' => q(ਭੂਟਾਨੀ ਐਂਗਲਟ੍ਰਮ),
			},
		},
		'BWP' => {
			display_name => {
				'currency' => q(ਬੋਟਸਵਾਨਾ ਪੁਲਾ),
			},
		},
		'BYN' => {
			symbol => 'р.',
			display_name => {
				'currency' => q(ਬੇਲਾਰੂਸੀ ਰੂਬਲ),
			},
		},
		'BYR' => {
			display_name => {
				'currency' => q(ਬੇਲਾਰੂਸੀ ਰੂਬਲ \(2000–2016\)),
			},
		},
		'BZD' => {
			display_name => {
				'currency' => q(ਬੇਲੀਜ਼ ਡਾਲਰ),
			},
		},
		'CAD' => {
			display_name => {
				'currency' => q(ਕੇਨੇਡਿਆਈ ਡਾਲਰ),
			},
		},
		'CDF' => {
			display_name => {
				'currency' => q(ਕਾਂਗੋਲੀਜ਼ ਫ੍ਰੈਂਕ),
			},
		},
		'CHF' => {
			display_name => {
				'currency' => q(ਸਵਿਸ ਫ੍ਰੈਂਕ),
			},
		},
		'CLP' => {
			display_name => {
				'currency' => q(ਚਿਲੀ ਪੇਸੋ),
			},
		},
		'CNH' => {
			display_name => {
				'currency' => q(ਚੀਨੀ ਯੁਆਨ \(ਔਫ਼ਸ਼ੋਰ\)),
			},
		},
		'CNY' => {
			display_name => {
				'currency' => q(ਚੀਨੀ ਯੁਆਨ),
			},
		},
		'COP' => {
			display_name => {
				'currency' => q(ਕੋਲੰਬਿਆਈ ਪੇਸੋ),
			},
		},
		'CRC' => {
			display_name => {
				'currency' => q(ਕੋਸਟਾ ਰੀਕਨ ਕੋਲਨ),
			},
		},
		'CUC' => {
			display_name => {
				'currency' => q(ਕਿਊਬਨ ਬਦਲਣਯੋਗ ਪੇਸੋ),
			},
		},
		'CUP' => {
			display_name => {
				'currency' => q(ਕਿਊਬਨ ਪੇਸੋ),
			},
		},
		'CVE' => {
			display_name => {
				'currency' => q(ਕੇਪ ਵਰਡੀਅਨ ਸਕੂਡੋ),
			},
		},
		'CZK' => {
			display_name => {
				'currency' => q(ਚੈਕ ਗਣਰਾਜ ਕੋਰੁਨਾ),
			},
		},
		'DEM' => {
			display_name => {
				'currency' => q(ਜਰਮਨ ਮਾਰਕ),
			},
		},
		'DJF' => {
			display_name => {
				'currency' => q(ਜ਼ੀਬੂਤੀਅਨ ਫ੍ਰੈਂਕ),
			},
		},
		'DKK' => {
			display_name => {
				'currency' => q(ਡੈਨਿਸ਼ ਕਰੌਨ),
			},
		},
		'DOP' => {
			display_name => {
				'currency' => q(ਡੌਮਿਨਿਕਨ ਪੇਸੋ),
			},
		},
		'DZD' => {
			display_name => {
				'currency' => q(ਅਲਜੀਰਿਆਈ ਦਿਨਾਰ),
			},
		},
		'EGP' => {
			display_name => {
				'currency' => q(ਮਿਸਰੀ ਪੌਂਡ),
			},
		},
		'ERN' => {
			display_name => {
				'currency' => q(ਇਰੀਟ੍ਰਿਆਈ ਨਾਫ਼ਾ),
			},
		},
		'ETB' => {
			display_name => {
				'currency' => q(ਇਥੋਪੀਆਈ ਬਿਰ),
			},
		},
		'EUR' => {
			display_name => {
				'currency' => q(ਯੂਰੋ),
			},
		},
		'FJD' => {
			display_name => {
				'currency' => q(ਫ਼ਿਜ਼ੀ ਡਾਲਰ),
			},
		},
		'FKP' => {
			display_name => {
				'currency' => q(ਫ਼ਾਕਲੈਂਡ ਆਈਲੈਂਡਸ ਪੌਂਡ),
			},
		},
		'GBP' => {
			display_name => {
				'currency' => q(ਬ੍ਰਿਟਿਸ਼ ਪੌਂਡ),
			},
		},
		'GEL' => {
			display_name => {
				'currency' => q(ਜਾਰਜੀਆਈ ਲਾਰੀ),
			},
		},
		'GHS' => {
			display_name => {
				'currency' => q(ਘਾਨਾਈ ਸੇਡੀ),
			},
		},
		'GIP' => {
			display_name => {
				'currency' => q(ਜਿਬਰਾਲਟਰ ਪੌਂਡ),
			},
		},
		'GMD' => {
			display_name => {
				'currency' => q(ਗੈਂਬੀਆਈ ਦਲਾਸੀ),
			},
		},
		'GNF' => {
			display_name => {
				'currency' => q(ਗਿਨੀ ਫ੍ਰੈਂਕ),
			},
		},
		'GTQ' => {
			display_name => {
				'currency' => q(ਗੁਆਟੇਮਾਲਾ ਕੁਏਟਜ਼ਲ),
			},
		},
		'GYD' => {
			display_name => {
				'currency' => q(ਗੁਆਨਾਆਈ ਡਾਲਰ),
			},
		},
		'HKD' => {
			display_name => {
				'currency' => q(ਹਾਂਗ ਕਾਂਗ ਡਾਲਰ),
			},
		},
		'HNL' => {
			display_name => {
				'currency' => q(ਹਾਨਡੂਰਨ ਲੇਮਪਿਰਾ),
			},
		},
		'HRK' => {
			display_name => {
				'currency' => q(ਕਰੋਏਸ਼ੀਆਈ ਕੁਨਾ),
			},
		},
		'HTG' => {
			display_name => {
				'currency' => q(ਹੈਤੀ ਗੌਰਡੇ),
			},
		},
		'HUF' => {
			display_name => {
				'currency' => q(ਹੰਗਰੀ ਫੋਰਿੰਟ),
			},
		},
		'IDR' => {
			display_name => {
				'currency' => q(ਇੰਡੋਨੇਸ਼ੀਆਈ ਰੁਪਿਆਹ),
			},
		},
		'IEP' => {
			display_name => {
				'currency' => q(ਆਇਰਿਸ਼ ਪੌਂਡ),
			},
		},
		'ILP' => {
			display_name => {
				'currency' => q(ਇਜ਼ਰਾਈਲੀ ਪੌਂਡ),
			},
		},
		'ILS' => {
			display_name => {
				'currency' => q(ਇਜ਼ਰਾਈਲੀ ਨਵੀਂ ਸ਼ੇਕੇਲ),
			},
		},
		'INR' => {
			display_name => {
				'currency' => q(ਭਾਰਤੀ ਰੁਪਇਆ),
				'one' => q(ਭਾਰਤੀ ਰੁਪਇਆ),
				'other' => q(ਭਾਰਤੀ ਰੁਪਏ),
			},
		},
		'IQD' => {
			display_name => {
				'currency' => q(ਇਰਾਕੀ ਦਿਨਾਰ),
			},
		},
		'IRR' => {
			display_name => {
				'currency' => q(ਈਰਾਨੀ ਰਿਆਲ),
			},
		},
		'ISK' => {
			display_name => {
				'currency' => q(ਆਈਸਲੈਂਡੀ ਕਰੋਨਾ),
			},
		},
		'JMD' => {
			display_name => {
				'currency' => q(ਜਮਾਇਕਨ ਡਾਲਰ),
			},
		},
		'JOD' => {
			display_name => {
				'currency' => q(ਜਾਰਡਨ ਦਿਨਾਰ),
			},
		},
		'JPY' => {
			display_name => {
				'currency' => q(ਜਪਾਨੀ ਯੇਨ),
			},
		},
		'KES' => {
			display_name => {
				'currency' => q(ਕੀਨੀਆਈ ਸ਼ਿਲਿੰਗ),
			},
		},
		'KGS' => {
			display_name => {
				'currency' => q(ਕਿਰਗਿਸਤਾਨੀ ਸੋਮ),
			},
		},
		'KHR' => {
			display_name => {
				'currency' => q(ਕੰਬੋਡੀਆਈ ਰੀਅਲ),
			},
		},
		'KMF' => {
			display_name => {
				'currency' => q(ਕੋਮੋਰੀਅਨ ਫ੍ਰੈਂਕ),
			},
		},
		'KPW' => {
			display_name => {
				'currency' => q(ਉੱਤਰੀ ਕੋਰੀਆਈ ਵੋਨ),
			},
		},
		'KRW' => {
			display_name => {
				'currency' => q(ਦੱਖਣੀ ਕੋਰੀਆਈ ਵੋਨ),
			},
		},
		'KWD' => {
			display_name => {
				'currency' => q(ਕੁਵੈਤੀ ਦਿਨਾਰ),
			},
		},
		'KYD' => {
			display_name => {
				'currency' => q(ਕੇਮੈਨ ਆਈਲੈਂਡਸ ਡਾਲਰ),
			},
		},
		'KZT' => {
			display_name => {
				'currency' => q(ਕਜ਼ਾਖਸਤਾਨੀ ਤੇਂਗੇ),
			},
		},
		'LAK' => {
			display_name => {
				'currency' => q(ਲਾਓਟਿਆਈ ਕਿਪ),
			},
		},
		'LBP' => {
			display_name => {
				'currency' => q(ਲੈਬਨਾਨੀ ਪੌਂਡ),
			},
		},
		'LKR' => {
			display_name => {
				'currency' => q(ਸ੍ਰੀਲੰਕਾਈ ਰੁਪਇਆ),
				'one' => q(ਸ੍ਰੀਲੰਕਾਈ ਰੁਪਇਆ),
				'other' => q(ਸ੍ਰੀਲੰਕਾਈ ਰੁਪਏ),
			},
		},
		'LRD' => {
			display_name => {
				'currency' => q(ਲਾਈਬੀਰੀਆਈ ਡਾਲਰ),
			},
		},
		'LSL' => {
			display_name => {
				'currency' => q(ਲੇਸੋਥੋ ਲੋਟੀ),
			},
		},
		'LTL' => {
			display_name => {
				'currency' => q(ਲਿਥੁਆਨੀਆਈ ਲਿਤਾਸ),
			},
		},
		'LVL' => {
			display_name => {
				'currency' => q(ਲਾਟਵਿਆਈ ਲਾਟਸ),
			},
		},
		'LYD' => {
			display_name => {
				'currency' => q(ਲੀਬੀਆਈ ਦਿਨਾਰ),
			},
		},
		'MAD' => {
			display_name => {
				'currency' => q(ਮੋਰੱਕਨ ਦਿਰਹਾਮ),
			},
		},
		'MDL' => {
			display_name => {
				'currency' => q(ਮੋਲਡੋਵਨ ਲੇਉ),
			},
		},
		'MGA' => {
			display_name => {
				'currency' => q(ਮਾਲਾਗਾਸੀ ਅਰਾਇਰੀ),
			},
		},
		'MKD' => {
			display_name => {
				'currency' => q(ਮੈਕਡੋਨੀਆਈ ਡੇਨਾਰ),
			},
		},
		'MMK' => {
			display_name => {
				'currency' => q(ਮਿਆਂਮਾਰ ਕਿਆਤ),
			},
		},
		'MNT' => {
			display_name => {
				'currency' => q(ਮੰਗੋਲੀਆਈ ਤੁਗਰਿਕ),
			},
		},
		'MOP' => {
			display_name => {
				'currency' => q(ਮੇਕਾਨੀ ਪਟਾਕਾ),
			},
		},
		'MRO' => {
			display_name => {
				'currency' => q(ਮੋਰਿਟਾਨੀਆਈ ਊਗੀਆ \(1973–2017\)),
			},
		},
		'MRU' => {
			display_name => {
				'currency' => q(ਮੋਰਿਟਾਨੀਆਈ ਊਗੀਆ),
			},
		},
		'MUR' => {
			display_name => {
				'currency' => q(ਮੌਰਿਸ਼ੀਆਈ ਰੁਪਇਆ),
				'one' => q(ਮੌਰਿਸ਼ੀਆਈ ਰੁਪਇਆ),
				'other' => q(ਮੌਰਿਸ਼ੀਆਈ ਰੁਪਏ),
			},
		},
		'MVR' => {
			display_name => {
				'currency' => q(ਮਾਲਦੀਵੀ ਰੁਫੀਆ),
			},
		},
		'MWK' => {
			display_name => {
				'currency' => q(ਮਾਲਾਵੀਆਈ ਕਵਾਚਾ),
			},
		},
		'MXN' => {
			display_name => {
				'currency' => q(ਮੈਕਸੀਕਨ ਪੇਸੋ),
			},
		},
		'MYR' => {
			display_name => {
				'currency' => q(ਮਲੇਸ਼ੀਆਈ ਰਿੰਗਿਟ),
			},
		},
		'MZN' => {
			display_name => {
				'currency' => q(ਮੋਜ਼ਾਮਬੀਕਨ ਮੈਟੀਕਲ),
			},
		},
		'NAD' => {
			display_name => {
				'currency' => q(ਨਾਮੀਬੀਆਈ ਡਾਲਰ),
			},
		},
		'NGN' => {
			display_name => {
				'currency' => q(ਨਾਇਜੀਰੀਆਈ ਨਾਇਰਾ),
			},
		},
		'NIO' => {
			display_name => {
				'currency' => q(ਨਿਕਾਰਾਗੁਆਈ ਕੋਰਡੋਬਾ),
			},
		},
		'NOK' => {
			display_name => {
				'currency' => q(ਨਾਰਵੇਜੀਆਈ ਕਰੌਨ),
			},
		},
		'NPR' => {
			display_name => {
				'currency' => q(ਨੇਪਾਲੀ ਰੁਪਇਆ),
				'one' => q(ਨੇਪਾਲੀ ਰੁਪਇਆ),
				'other' => q(ਨੇਪਾਲੀ ਰੁਪਏ),
			},
		},
		'NZD' => {
			display_name => {
				'currency' => q(ਨਿਊਜ਼ੀਲੈਂਡ ਡਾਲਰ),
			},
		},
		'OMR' => {
			display_name => {
				'currency' => q(ਓਮਾਨੀ ਰਿਆਲ),
			},
		},
		'PAB' => {
			display_name => {
				'currency' => q(ਪਨਾਮੇਨੀਅਨ ਬਾਲਬੋਆ),
			},
		},
		'PEN' => {
			display_name => {
				'currency' => q(ਪੇਰੂਵੀਅਨ ਸੋਲ),
			},
		},
		'PGK' => {
			display_name => {
				'currency' => q(ਪਾਪੂਆ ਨਿਊ ਗਿਨੀਆਈ ਕੀਨਾ),
			},
		},
		'PHP' => {
			symbol => 'PHP',
			display_name => {
				'currency' => q(ਫਿਲਿਪੀਨੀ ਪੇਸੋ),
			},
		},
		'PKR' => {
			display_name => {
				'currency' => q(ਪਾਕਿਸਤਾਨੀ ਰੁਪਇਆ),
				'one' => q(ਪਾਕਿਸਤਾਨੀ ਰੁਪਇਆ),
				'other' => q(ਪਾਕਿਸਤਾਨੀ ਰੁਪਏ),
			},
		},
		'PLN' => {
			display_name => {
				'currency' => q(ਪੋਲੈਂਡੀ ਜ਼ਲੌਟੀ),
			},
		},
		'PYG' => {
			display_name => {
				'currency' => q(ਪੈਰਾਗੁਵਾਇਨ ਗੁਆਰਾਨੀ),
			},
		},
		'QAR' => {
			display_name => {
				'currency' => q(ਕਤਰੀ ਰਿਆਲ),
			},
		},
		'RON' => {
			display_name => {
				'currency' => q(ਰੋਮਾਨੀਆਈ ਲੇਉ),
			},
		},
		'RSD' => {
			display_name => {
				'currency' => q(ਸਰਬੀਆਈ ਦਿਨਾਰ),
			},
		},
		'RUB' => {
			display_name => {
				'currency' => q(ਰੂਸੀ ਰੂਬਲ),
			},
		},
		'RWF' => {
			display_name => {
				'currency' => q(ਰਵਾਂਡਨ ਫ੍ਰੈਂਕ),
			},
		},
		'SAR' => {
			display_name => {
				'currency' => q(ਸਾਊਦੀ ਰਿਆਲ),
			},
		},
		'SBD' => {
			display_name => {
				'currency' => q(ਸੋਲੋਮਨ ਆਈਲੈਂਡਸ ਡਾਲਰ),
			},
		},
		'SCR' => {
			display_name => {
				'currency' => q(ਸੇਸ਼ਲਸ ਰੁਪਇਆ),
				'one' => q(ਸੇਸ਼ਲਸ ਰੁਪਇਆ),
				'other' => q(ਸੇਸ਼ਲਸ ਰੁਪਏ),
			},
		},
		'SDG' => {
			display_name => {
				'currency' => q(ਸੂਡਾਨੀ ਪੌਂਡ),
			},
		},
		'SEK' => {
			display_name => {
				'currency' => q(ਸਵੀਡਿਸ਼ ਕਰੋਨਾ),
			},
		},
		'SGD' => {
			display_name => {
				'currency' => q(ਸਿੰਗਾਪੁਰ ਡਾਲਰ),
			},
		},
		'SHP' => {
			display_name => {
				'currency' => q(ਸੇਂਟ ਹੇਲੇਨਾ ਪੌਂਡ),
			},
		},
		'SLE' => {
			display_name => {
				'currency' => q(ਸਿਏਰਾ ਲਿਓਨੀਅਨ ਲਿਓਨ),
			},
		},
		'SLL' => {
			display_name => {
				'currency' => q(ਸਿਏਰਾ ਲਿਓਨੀਅਨ ਲਿਓਨ \(1964—2022\)),
			},
		},
		'SOS' => {
			display_name => {
				'currency' => q(ਸੋਮਾਲੀ ਸ਼ਿਲਿੰਗ),
			},
		},
		'SRD' => {
			display_name => {
				'currency' => q(ਸੂਰੀਨਾਮੀ ਡਾਲਰ),
			},
		},
		'SSP' => {
			display_name => {
				'currency' => q(ਦੱਖਣੀ ਸੂਡਾਨੀ ਪੌਂਡ),
			},
		},
		'STD' => {
			display_name => {
				'currency' => q(ਸਾਉ ਟੋਮੀ ਐਂਡ ਪ੍ਰਿੰਸਪੀ ਡੋਬਰਾ \(1977–2017\)),
			},
		},
		'STN' => {
			display_name => {
				'currency' => q(ਸਾਉ ਟੋਮੀ ਐਂਡ ਪ੍ਰਿੰਸਪੀ ਡੋਬਰਾ),
			},
		},
		'SUR' => {
			display_name => {
				'currency' => q(ਸੋਵੀਅਤ ਰੂਬਲ),
			},
		},
		'SYP' => {
			display_name => {
				'currency' => q(ਸੀਰੀਆਈ ਪੌਂਡ),
			},
		},
		'SZL' => {
			display_name => {
				'currency' => q(ਸਵਾਜ਼ੀ ਲਾਇਲੈਂਗਨੀ),
			},
		},
		'THB' => {
			symbol => '฿',
			display_name => {
				'currency' => q(ਥਾਈ ਬਾਹਤ),
			},
		},
		'TJS' => {
			display_name => {
				'currency' => q(ਤਾਜਿਕਿਸਤਾਨੀ ਸੋਮੋਨੀ),
			},
		},
		'TMT' => {
			display_name => {
				'currency' => q(ਤੁਰਕਮੇਨਿਸਤਾਨੀ ਮਾਨਤ),
			},
		},
		'TND' => {
			display_name => {
				'currency' => q(ਟਿਉਨੀਸ਼ੀਆਈ ਦਿਨਾਰ),
			},
		},
		'TOP' => {
			display_name => {
				'currency' => q(ਟੌਂਗਨ ਪੈਂਗਾ),
			},
		},
		'TRY' => {
			display_name => {
				'currency' => q(ਤੁਰਕੀ ਲੀਰਾ),
			},
		},
		'TTD' => {
			display_name => {
				'currency' => q(ਟ੍ਰਿਨੀਡਾਡ ਅਤੇ ਟੋਬਾਗੋ ਡਾਲਰ),
			},
		},
		'TWD' => {
			symbol => 'NT$',
			display_name => {
				'currency' => q(ਨਵਾਂ ਤਾਇਵਾਨ ਡਾਲਰ),
			},
		},
		'TZS' => {
			display_name => {
				'currency' => q(ਤਨਜ਼ਾਨੀਆਈ ਸ਼ਿਲਿੰਗ),
			},
		},
		'UAH' => {
			display_name => {
				'currency' => q(ਯੂਕਰੇਨੀਆਈ ਰਿਵਨਿਆ),
			},
		},
		'UGX' => {
			display_name => {
				'currency' => q(ਯੂਗਾਂਡੀਆਈ ਸ਼ਿਲਿੰਗ),
			},
		},
		'USD' => {
			display_name => {
				'currency' => q(ਯੂ.ਐਸ. ਡਾਲਰ),
			},
		},
		'UYP' => {
			display_name => {
				'currency' => q(ਉਰੂਗੁਵਾਇਨ ਪੇਸੋ \(1975–1993\)),
			},
		},
		'UYU' => {
			display_name => {
				'currency' => q(ਉਰੂਗੁਵਾਇਨ ਪੇਸੋ),
			},
		},
		'UZS' => {
			display_name => {
				'currency' => q(ਉਜ਼ਬੇਕਿਸਤਾਨ ਸੋਮ),
			},
		},
		'VEB' => {
			display_name => {
				'currency' => q(ਵੇਨੇਜ਼ੂਏਲਨ ਬੋਲੀਵਰ \(1871–2008\)),
			},
		},
		'VEF' => {
			display_name => {
				'currency' => q(ਵੇਨੇਜ਼ੂਏਲਨ ਬੋਲੀਵਰ \(2008–2018\)),
			},
		},
		'VES' => {
			display_name => {
				'currency' => q(ਵੇਨੇਜ਼ੂਏਲਨ ਬੋਲੀਵਰ),
			},
		},
		'VND' => {
			display_name => {
				'currency' => q(ਵੀਅਤਨਾਮੀ ਡੋਂਗ),
			},
		},
		'VNN' => {
			display_name => {
				'currency' => q(ਵੀਅਤਨਾਮੀ ਡੋਂਗ \(1978–1985\)),
			},
		},
		'VUV' => {
			display_name => {
				'currency' => q(ਵਾਨੂਆਟੂ ਵਾਟੂ),
			},
		},
		'WST' => {
			display_name => {
				'currency' => q(ਸਾਮੋਆਈ ਤਾਲਾ),
			},
		},
		'XAF' => {
			display_name => {
				'currency' => q(ਕੇਂਦਰੀ ਅਫ਼ਰੀਕੀ [CFA] ਫ੍ਰੈਂਕ),
			},
		},
		'XAG' => {
			display_name => {
				'currency' => q(ਚਾਂਦੀ),
				'one' => q(ਚਾਂਦੀ ਦਾ ਟਰੌਏ ਔਂਸ),
				'other' => q(ਚਾਂਦੀ ਦਾ ਟਰੌਏ ਔਂਸ),
			},
		},
		'XAU' => {
			display_name => {
				'currency' => q(ਸੋਨਾ),
				'one' => q(ਸੋਨੇ ਦਾ ਟਰੌਏ ਔਂਸ),
				'other' => q(ਸੋਨੇ ਦਾ ਟਰੌਏ ਔਂਸ),
			},
		},
		'XBB' => {
			display_name => {
				'currency' => q(ਯੂਰਪੀ ਵਿੱਤੀ ਇਕਾਈ),
			},
		},
		'XCD' => {
			display_name => {
				'currency' => q(ਪੂਰਬੀ ਕੈਰੇਬੀਅਨ ਡਾਲਰ),
			},
		},
		'XEU' => {
			display_name => {
				'currency' => q(ਯੂਰਪੀ ਮੁਦਰਾ ਇਕਾਈ),
				'one' => q(ਯੂਰਪੀਅਨ ਮੁਦਰਾ ਇਕਾਈ),
				'other' => q(ਯੂਰਪੀ ਮੁਦਰਾ ਇਕਾਈ),
			},
		},
		'XOF' => {
			display_name => {
				'currency' => q(ਪੱਛਮੀ ਅਫ਼ਰੀਕੀ \(CFA\) ਫ੍ਰੈਂਕ),
			},
		},
		'XPF' => {
			display_name => {
				'currency' => q(ਫ੍ਰੈਂਕ \(CFP\)),
			},
		},
		'XXX' => {
			symbol => 'XXX',
			display_name => {
				'currency' => q(ਅਗਿਆਤ ਮੁਦਰਾ),
				'one' => q(\(ਮੁਦਰਾ ਦੀ ਅਗਿਆਤ ਇਕਾਈ\)),
				'other' => q(\(ਅਗਿਆਤ ਮੁਦਰਾ\)),
			},
		},
		'YER' => {
			display_name => {
				'currency' => q(ਯਮਨੀ ਰਿਆਲ),
			},
		},
		'ZAR' => {
			display_name => {
				'currency' => q(ਦੱਖਣੀ ਅਫਰੀਕੀ ਰੈਂਡ),
			},
		},
		'ZMW' => {
			display_name => {
				'currency' => q(ਜ਼ਾਮਬੀਆਈ ਕਵਾਚਾ),
			},
		},
	} },
);


has 'calendar_months' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'coptic' => {
				'format' => {
					wide => {
						nonleap => [
							'ਟੋਉਟ',
							'ਬਾਬਾ',
							'ਹੇਟਰ',
							'ਕੀਅਕ',
							'ਤੋਬਾ',
							'ਅਮਸ਼ੀਰ',
							'ਬ੍ਰਾਮਹਟ',
							'ਬਾਰਾਮੂਡਾ',
							'ਬਾਸ਼ਨਸ',
							'ਪਾਓਨਾ',
							'ਅਪੈਪ',
							'ਮੈਸਰਾ',
							'ਨੇਜ਼ੀ'
						],
						leap => [
							
						],
					},
				},
			},
			'ethiopic' => {
				'format' => {
					wide => {
						nonleap => [
							'ਮੇਸਕੇਰੇਮ',
							'ਟੇਕੇਮਟ',
							'ਹੈਡਰ',
							'ਤਾਹਸਸ',
							'ਟਰ',
							'ਯਕੇਟਿਤ',
							'ਮੇਗਾਬਿਟ',
							'ਮਿਆਜਿਆ',
							'ਜੇਨਬੋਟ',
							'ਸੀਨ',
							'ਹਮਲੇ',
							'ਨੇਹਾਸੇ',
							'ਪਾਗੂਮੇਨ'
						],
						leap => [
							
						],
					},
				},
			},
			'gregorian' => {
				'format' => {
					abbreviated => {
						nonleap => [
							'ਜਨ',
							'ਫ਼ਰ',
							'ਮਾਰਚ',
							'ਅਪ੍ਰੈ',
							'ਮਈ',
							'ਜੂਨ',
							'ਜੁਲਾ',
							'ਅਗ',
							'ਸਤੰ',
							'ਅਕਤੂ',
							'ਨਵੰ',
							'ਦਸੰ'
						],
						leap => [
							
						],
					},
					wide => {
						nonleap => [
							'ਜਨਵਰੀ',
							'ਫ਼ਰਵਰੀ',
							'ਮਾਰਚ',
							'ਅਪ੍ਰੈਲ',
							'ਮਈ',
							'ਜੂਨ',
							'ਜੁਲਾਈ',
							'ਅਗਸਤ',
							'ਸਤੰਬਰ',
							'ਅਕਤੂਬਰ',
							'ਨਵੰਬਰ',
							'ਦਸੰਬਰ'
						],
						leap => [
							
						],
					},
				},
				'stand-alone' => {
					narrow => {
						nonleap => [
							'ਜ',
							'ਫ਼',
							'ਮਾ',
							'ਅ',
							'ਮ',
							'ਜੂ',
							'ਜੁ',
							'ਅ',
							'ਸ',
							'ਅ',
							'ਨ',
							'ਦ'
						],
						leap => [
							
						],
					},
				},
			},
			'hebrew' => {
				'format' => {
					wide => {
						nonleap => [
							'ਤਿਸ਼ਰੀ',
							'ਹੇਸ਼ਵਨ',
							'ਕਿਸਲੇਵ',
							'ਟੇਵਟ',
							'ਸ਼ੇਵਟ',
							'ਅਦਰ I',
							'ਅਦਰ',
							'ਨਿਸਾਨ',
							'ਅਇਯਰ',
							'ਸਿਵਾਨ',
							'ਤਾਮੁਜ਼',
							'ਅਵ',
							'ਏਲੁਲ'
						],
						leap => [
							undef(),
							undef(),
							undef(),
							undef(),
							undef(),
							undef(),
							
						],
					},
				},
			},
			'indian' => {
				'format' => {
					wide => {
						nonleap => [
							'ਚੇਤ',
							'ਵੈਸਾਖ',
							'ਜੇਠ',
							'ਹਾੜ',
							'ਸਾਉਣ',
							'ਭਾਦੋਂ',
							'ਅੱਸੂ',
							'ਕੱਤਕ',
							'ਮੱਘਰ',
							'ਪੋਹ',
							'ਮਾਘ',
							'ਫੱਗਣ'
						],
						leap => [
							
						],
					},
				},
				'stand-alone' => {
					narrow => {
						nonleap => [
							'੧',
							'੨',
							'੩',
							'੪',
							'੫',
							'੬',
							'੭',
							'੮',
							'੯',
							'੧੦',
							'੧੧',
							'੧੨'
						],
						leap => [
							
						],
					},
				},
			},
			'islamic' => {
				'format' => {
					abbreviated => {
						nonleap => [
							'ਮੁਹੱ.',
							'ਸਫ.',
							'ਰਬ. I',
							'ਰਬ. II',
							'ਜੁਮ. I',
							'ਜੁਮ. II',
							'ਰਾਜ.',
							'ਸ਼ਾ.',
							'ਰਾਮ.',
							'ਸ਼ਅ.',
							'ਦੂ-ਅਲ-ਕੀ.',
							'ਦੂ-ਅਲ-ਹਿ.'
						],
						leap => [
							
						],
					},
					wide => {
						nonleap => [
							'ਮੁਹੱਰਮ',
							'ਸਫਰ',
							'ਰਬੀ ʻ I',
							'ਰਬੀ ʻ II',
							'ਜੁਮਾਦਾ I',
							'ਜੁਮਾਦਾ II',
							'ਰਜਬ',
							'ਸ਼ਬਾਨ',
							'ਰਮਜ਼ਾਨ',
							'ਸ਼ਵਾਲ',
							'ਦੂ-ਅਲ-ਕੀਦਾਹ',
							'ਦੂ-ਅਲ-ਹਿਜ੍ਹਾ'
						],
						leap => [
							
						],
					},
				},
				'stand-alone' => {
					wide => {
						nonleap => [
							'ਮੁਹੱਰਮ',
							'ਸਫਰ',
							'ਰਬੀʻ I',
							'ਰਬੀʻ II',
							'ਜੁਮਾਦਾ I',
							'ਜੁਮਾਦਾ II',
							'ਰਜਬ',
							'ਸ਼ਬਾਨ',
							'ਰਮਜ਼ਾਨ',
							'ਸ਼ਵਾਲ',
							'ਦੂ-ਅਲ-ਕੀਦਾਹ',
							'ਦੂ-ਅਲ-ਹਿਜ੍ਹਾ'
						],
						leap => [
							
						],
					},
				},
			},
			'persian' => {
				'format' => {
					wide => {
						nonleap => [
							'ਫਾਰਵਰਡੀਨ',
							'ਔਰਡਾਈਬਹੈਸ਼ਟ',
							'ਖੋਡਰਡ',
							'ਟਿਰ',
							'ਮੋਰਡਾਦ',
							'ਸ਼ਰਾਇਵਰ',
							'ਮੇਹਰ',
							'ਅਬਾਨ',
							'ਅਜ਼ਾਰ',
							'ਡੇਅ',
							'ਬਾਹਮਨ',
							'ਐਸਫੰਡ'
						],
						leap => [
							
						],
					},
				},
			},
	} },
);

has 'calendar_days' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					abbreviated => {
						mon => 'ਸੋਮ',
						tue => 'ਮੰਗਲ',
						wed => 'ਬੁੱਧ',
						thu => 'ਵੀਰ',
						fri => 'ਸ਼ੁੱਕਰ',
						sat => 'ਸ਼ਨਿੱਚਰ',
						sun => 'ਐਤ'
					},
					short => {
						mon => 'ਸੋਮ',
						tue => 'ਮੰਗ',
						wed => 'ਬੁੱਧ',
						thu => 'ਵੀਰ',
						fri => 'ਸ਼ੁੱਕ',
						sat => 'ਸ਼ਨਿੱ',
						sun => 'ਐਤ'
					},
					wide => {
						mon => 'ਸੋਮਵਾਰ',
						tue => 'ਮੰਗਲਵਾਰ',
						wed => 'ਬੁੱਧਵਾਰ',
						thu => 'ਵੀਰਵਾਰ',
						fri => 'ਸ਼ੁੱਕਰਵਾਰ',
						sat => 'ਸ਼ਨਿੱਚਰਵਾਰ',
						sun => 'ਐਤਵਾਰ'
					},
				},
				'stand-alone' => {
					narrow => {
						mon => 'ਸੋ',
						tue => 'ਮੰ',
						wed => 'ਬੁੱ',
						thu => 'ਵੀ',
						fri => 'ਸ਼ੁੱ',
						sat => 'ਸ਼',
						sun => 'ਐ'
					},
				},
			},
	} },
);

has 'calendar_quarters' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					abbreviated => {0 => 'ਤਿਮਾਹੀ1',
						1 => 'ਤਿਮਾਹੀ2',
						2 => 'ਤਿਮਾਹੀ3',
						3 => 'ਤਿਮਾਹੀ4'
					},
					wide => {0 => 'ਪਹਿਲੀ ਤਿਮਾਹੀ',
						1 => 'ਦੂਜੀ ਤਿਮਾਹੀ',
						2 => 'ਤੀਜੀ ਤਿਮਾਹੀ',
						3 => 'ਚੌਥੀ ਤਿਮਾਹੀ'
					},
				},
			},
	} },
);

has 'day_period_data' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub { sub {
		# Time in hhmm format
		my ($self, $type, $time, $day_period_type) = @_;
		$day_period_type //= 'default';
		SWITCH:
		for ($type) {
			if ($_ eq 'buddhist') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				last SWITCH;
				}
			if ($_ eq 'coptic') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				last SWITCH;
				}
			if ($_ eq 'ethiopic') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				last SWITCH;
				}
			if ($_ eq 'generic') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				last SWITCH;
				}
			if ($_ eq 'gregorian') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				last SWITCH;
				}
			if ($_ eq 'hebrew') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				last SWITCH;
				}
			if ($_ eq 'indian') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				last SWITCH;
				}
			if ($_ eq 'islamic') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				last SWITCH;
				}
			if ($_ eq 'persian') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				last SWITCH;
				}
			if ($_ eq 'roc') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1600;
					return 'evening1' if $time >= 1600
						&& $time < 2100;
					return 'morning1' if $time >= 400
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 400;
				}
				last SWITCH;
				}
		}
	} },
);

around day_period_data => sub {
    my ($orig, $self) = @_;
    return $self->$orig;
};

has 'day_periods' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'gregorian' => {
			'format' => {
				'abbreviated' => {
					'afternoon1' => q{ਦੁਪਹਿਰੇ},
					'am' => q{ਪੂ.ਦੁ.},
					'evening1' => q{ਸ਼ਾਮੀਂ},
					'midnight' => q{ਅੱਧੀ ਰਾਤ},
					'morning1' => q{ਸਵੇਰੇ},
					'night1' => q{ਰਾਤੀਂ},
					'pm' => q{ਬਾ.ਦੁ.},
				},
				'narrow' => {
					'am' => q{ਸ.},
					'pm' => q{ਸ਼.},
				},
			},
			'stand-alone' => {
				'wide' => {
					'afternoon1' => q{ਦੁਪਹਿਰੇ},
					'evening1' => q{ਸ਼ਾਮ},
					'morning1' => q{ਸਵੇਰੇ},
					'night1' => q{ਰਾਤ},
				},
			},
		},
	} },
);

has 'eras' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'buddhist' => {
			abbreviated => {
				'0' => 'ਈਸਵੀ ਪੂਰਵ'
			},
			narrow => {
				'0' => 'ਈ. ਪੂ.'
			},
		},
		'coptic' => {
			abbreviated => {
				'0' => 'ਕਾਲ0',
				'1' => 'ਕਾਲ1'
			},
		},
		'ethiopic' => {
			abbreviated => {
				'0' => 'ਕਾਲ0',
				'1' => 'ਕਾਲ1'
			},
		},
		'generic' => {
		},
		'gregorian' => {
			abbreviated => {
				'0' => 'ਈ. ਪੂ.',
				'1' => 'ਸੰਨ'
			},
			narrow => {
				'0' => 'ਈ.ਪੂ.'
			},
			wide => {
				'0' => 'ਈਸਵੀ ਪੂਰਵ',
				'1' => 'ਈਸਵੀ ਸੰਨ'
			},
		},
		'hebrew' => {
		},
		'indian' => {
			abbreviated => {
				'0' => 'ਸਾਕਾ'
			},
		},
		'islamic' => {
		},
		'persian' => {
		},
		'roc' => {
			abbreviated => {
				'0' => 'ਆਰ.ਓ.ਸੀ ਤੋਂ ਪਹਿਲਾਂ',
				'1' => 'ਮਿੰਗ'
			},
			wide => {
				'0' => 'ਚੀਨ ਦੇ ਗਣਰਾਜ ਤੋਂ ਪਹਿਲਾਂ'
			},
		},
	} },
);

has 'date_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'buddhist' => {
		},
		'coptic' => {
		},
		'ethiopic' => {
		},
		'generic' => {
			'full' => q{EEEE, dd MMMM y G},
			'long' => q{d MMMM y G},
			'medium' => q{d MMM y G},
			'short' => q{dd/MM/y GGGGG},
		},
		'gregorian' => {
			'full' => q{EEEE, d MMMM y},
			'long' => q{d MMMM y},
			'medium' => q{d MMM y},
			'short' => q{d/M/yy},
		},
		'hebrew' => {
		},
		'indian' => {
		},
		'islamic' => {
		},
		'persian' => {
		},
		'roc' => {
		},
	} },
);

has 'time_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'buddhist' => {
		},
		'coptic' => {
		},
		'ethiopic' => {
		},
		'generic' => {
		},
		'gregorian' => {
			'full' => q{h:mm:ss a zzzz},
			'long' => q{h:mm:ss a z},
			'medium' => q{h:mm:ss a},
			'short' => q{h:mm a},
		},
		'hebrew' => {
		},
		'indian' => {
		},
		'islamic' => {
		},
		'persian' => {
		},
		'roc' => {
		},
	} },
);

has 'datetime_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'buddhist' => {
			'full' => q{{1}, {0}},
			'long' => q{{1}, {0}},
			'medium' => q{{1}, {0}},
			'short' => q{{1}, {0}},
		},
		'coptic' => {
		},
		'ethiopic' => {
		},
		'generic' => {
			'full' => q{{1} {0}},
			'long' => q{{1} {0}},
			'medium' => q{{1}, {0}},
			'short' => q{{1}, {0}},
		},
		'gregorian' => {
			'full' => q{{1} {0}},
			'long' => q{{1} {0}},
			'medium' => q{{1}, {0}},
			'short' => q{{1}, {0}},
		},
		'hebrew' => {
		},
		'indian' => {
		},
		'islamic' => {
		},
		'persian' => {
		},
		'roc' => {
		},
	} },
);

has 'datetime_formats_available_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			Ed => q{E, d},
			GyMMM => q{MMM y G},
			GyMMMEd => q{E, d MMM y G},
			GyMMMd => q{d MMM,y G},
			GyMd => q{d/M/GGGGG y},
			MEd => q{E, d/M},
			MMMEd => q{E, d MMM},
			MMMMd => q{d MMMM},
			MMMd => q{d MMM},
			Md => q{d/M},
			y => q{y G},
			yMMM => q{MMM y G},
			yQQQ => q{QQQ y G},
			yyyy => q{y G},
			yyyyM => q{M/y GGGGG},
			yyyyMEd => q{E, d/M/y GGGGG},
			yyyyMMM => q{MMM y G},
			yyyyMMMEd => q{E, d MMM y G},
			yyyyMMMM => q{MMMM y G},
			yyyyMMMd => q{d MMM y G},
			yyyyMd => q{d/M/y GGGGG},
			yyyyQQQ => q{QQQ y G},
			yyyyQQQQ => q{QQQQ y G},
		},
		'gregorian' => {
			GyMMM => q{MMM, G y},
			GyMMMEd => q{E d MMM, G y},
			GyMMMd => q{d MMM, G y},
			GyMd => q{d/M/GGGGG y},
			MEd => q{E, dd-MM.},
			MMMEd => q{E, d MMM},
			MMMMW => q{MMMM ਦਾ W ਹਫ਼ਤਾ},
			MMMd => q{d MMM},
			Md => q{d/M},
			mmss => q{mm:ss},
			yM => q{M/y},
			yMEd => q{E, d/M/y},
			yMMM => q{MMM y},
			yMMMEd => q{E, d MMM y},
			yMMMM => q{MMMM y},
			yMMMd => q{d MMM y},
			yMd => q{d/M/y},
			yQQQ => q{QQQ y},
			yQQQQ => q{QQQQ y},
			yw => q{Y ਦਾ w ਹਫ਼ਤਾ},
		},
		'islamic' => {
			GyMMMd => q{d MMM, y G},
		},
	} },
);

has 'datetime_formats_append_item' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
	} },
);

has 'datetime_formats_interval' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			MEd => {
				M => q{E, d/M – E, d/M},
				d => q{E, d/M – E, d/M},
			},
			MMM => {
				M => q{MMM – MMM},
			},
			MMMEd => {
				M => q{E, d MMM – E, d MMM},
				d => q{E, d MMM – E, d MMM},
			},
			MMMd => {
				M => q{d MMM – d MMM},
				d => q{d – d MMM},
			},
			Md => {
				M => q{d/M – d/M},
				d => q{d/M – d/M},
			},
			d => {
				d => q{d – d},
			},
			fallback => '{0} – {1}',
			y => {
				y => q{y – y G},
			},
			yM => {
				M => q{M/y – M/y GGGGG},
				y => q{M/y – M/y GGGGG},
			},
			yMEd => {
				M => q{E, d/M/y – E, d/M/y GGGGG},
				d => q{E, d/M/y – E, d/M/y GGGGG},
				y => q{E, d/M/y – E, d/M/y GGGGG},
			},
			yMMM => {
				M => q{MMM – MMM y G},
				y => q{MMM y – MMM y G},
			},
			yMMMEd => {
				M => q{E, d MMM – E, d MMM y G},
				d => q{E, d MMM – E, d MMM y G},
				y => q{E, d MMM y – E, d MMM y G},
			},
			yMMMM => {
				M => q{MMMM – MMMM y G},
				y => q{MMMM y – MMMM y G},
			},
			yMMMd => {
				M => q{d MMM – d MMM y G},
				d => q{d – d, MMM y G},
				y => q{d, MMM y – d, MMM y G},
			},
			yMd => {
				M => q{d/M/y – d/M/y GGGGG},
				d => q{d/M/y – d/M/y GGGGG},
				y => q{d/M/y – d/M/y GGGGG},
			},
		},
		'gregorian' => {
			M => {
				M => q{M–M},
			},
			MEd => {
				M => q{E, d/M – E, d/M},
				d => q{E, d/M – E, d/M},
			},
			MMM => {
				M => q{MMM–MMM},
			},
			MMMEd => {
				M => q{E, d MMM – E, d MMM},
				d => q{E, d MMM – E, d MMM},
			},
			MMMd => {
				M => q{d MMM – d MMM},
				d => q{d–d MMM},
			},
			Md => {
				M => q{d/M – d/M},
				d => q{d/M – d/M},
			},
			fallback => '{0} – {1}',
			yM => {
				M => q{M/y – M/y},
				y => q{M/y – M/y},
			},
			yMEd => {
				M => q{E, d/M/y – E, d/M/y},
				d => q{E, d/M/y – E, d/M/y},
				y => q{E, d/M/y – E, d/M/y},
			},
			yMMM => {
				M => q{MMM–MMM y},
				y => q{MMM y – MMM y},
			},
			yMMMEd => {
				M => q{E, d MMM – E, d MMM y},
				d => q{E, d MMM – E, d MMM y},
				y => q{E, d MMM y – E, d MMM y},
			},
			yMMMM => {
				M => q{MMMM–MMMM y},
				y => q{MMMM y – MMMM y},
			},
			yMMMd => {
				M => q{d MMM – d MMM y},
				d => q{d–d MMM y},
				y => q{d MMM y – d MMM y},
			},
			yMd => {
				M => q{d/M/y – d/M/y},
				d => q{d/M/y – d/M/y},
				y => q{d/M/y – d/M/y},
			},
		},
	} },
);

has 'time_zone_names' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default	=> sub { {
		regionFormat => q({0} ਵੇਲਾ),
		regionFormat => q({0} ਪ੍ਰਕਾਸ਼ ਵੇਲਾ),
		regionFormat => q({0} ਮਿਆਰੀ ਵੇਲਾ),
		'Afghanistan' => {
			long => {
				'standard' => q#ਅਫ਼ਗਾਨਿਸਤਾਨ ਵੇਲਾ#,
			},
		},
		'Africa/Abidjan' => {
			exemplarCity => q#ਅਬੀਦਜਾਨ#,
		},
		'Africa/Accra' => {
			exemplarCity => q#ਅੱਕਰਾ#,
		},
		'Africa/Addis_Ababa' => {
			exemplarCity => q#ਐਡਿਸ ਅਬਾਬਾ#,
		},
		'Africa/Algiers' => {
			exemplarCity => q#ਅਲਜੀਅਰਸ#,
		},
		'Africa/Asmera' => {
			exemplarCity => q#ਅਸਮਾਰਾ#,
		},
		'Africa/Bamako' => {
			exemplarCity => q#ਬਮੇਕੋ#,
		},
		'Africa/Bangui' => {
			exemplarCity => q#ਬਾਂਗੁਈ#,
		},
		'Africa/Banjul' => {
			exemplarCity => q#ਬਾਂਜੁਲ#,
		},
		'Africa/Bissau' => {
			exemplarCity => q#ਬਿਸਾਉ#,
		},
		'Africa/Blantyre' => {
			exemplarCity => q#ਬਲੰਟਾਇਰ#,
		},
		'Africa/Brazzaville' => {
			exemplarCity => q#ਬ੍ਰਾਜ਼ਾਵਿਲੇ#,
		},
		'Africa/Bujumbura' => {
			exemplarCity => q#ਬੁਜੁੰਬੁਰਾ#,
		},
		'Africa/Cairo' => {
			exemplarCity => q#ਕੈਰੋ#,
		},
		'Africa/Casablanca' => {
			exemplarCity => q#ਕਾਸਾਬਲਾਂਕਾ#,
		},
		'Africa/Ceuta' => {
			exemplarCity => q#ਸੀਊਟਾ#,
		},
		'Africa/Conakry' => {
			exemplarCity => q#ਕੋਨੇਕਰੀ#,
		},
		'Africa/Dakar' => {
			exemplarCity => q#ਡਕਾਰ#,
		},
		'Africa/Dar_es_Salaam' => {
			exemplarCity => q#ਦਾਰ ਏਸ ਸਲਾਮ#,
		},
		'Africa/Djibouti' => {
			exemplarCity => q#ਜਿਬੂਤੀ#,
		},
		'Africa/Douala' => {
			exemplarCity => q#ਡੌਆਲਾ#,
		},
		'Africa/El_Aaiun' => {
			exemplarCity => q#ਅਲ ਅਯੂਨ#,
		},
		'Africa/Freetown' => {
			exemplarCity => q#ਫਰੀਟਾਉਨ#,
		},
		'Africa/Gaborone' => {
			exemplarCity => q#ਗਾਬੋਰੋਨ#,
		},
		'Africa/Harare' => {
			exemplarCity => q#ਹਰਾਰੇ#,
		},
		'Africa/Johannesburg' => {
			exemplarCity => q#ਜੋਹਨਸਬਰਗ#,
		},
		'Africa/Juba' => {
			exemplarCity => q#ਜੂਬਾ#,
		},
		'Africa/Kampala' => {
			exemplarCity => q#ਕੰਪਾਲਾ#,
		},
		'Africa/Khartoum' => {
			exemplarCity => q#ਖਾਰਟੌਮ#,
		},
		'Africa/Kigali' => {
			exemplarCity => q#ਕਿਗਾਲੀ#,
		},
		'Africa/Kinshasa' => {
			exemplarCity => q#ਕਿੰਸ਼ਾਸਾ#,
		},
		'Africa/Lagos' => {
			exemplarCity => q#ਲਾਗੋਸ#,
		},
		'Africa/Libreville' => {
			exemplarCity => q#ਲਿਬਰਵਿਲੇ#,
		},
		'Africa/Lome' => {
			exemplarCity => q#ਲੋਮ#,
		},
		'Africa/Luanda' => {
			exemplarCity => q#ਲੁਆਂਡਾ#,
		},
		'Africa/Lubumbashi' => {
			exemplarCity => q#ਲੁਬੁਮਬਾਸ਼ੀ#,
		},
		'Africa/Lusaka' => {
			exemplarCity => q#ਲੁਸਾਕਾ#,
		},
		'Africa/Malabo' => {
			exemplarCity => q#ਮਾਲਾਬੋ#,
		},
		'Africa/Maputo' => {
			exemplarCity => q#ਮਾਪੁਟੋ#,
		},
		'Africa/Maseru' => {
			exemplarCity => q#ਮਸੇਰੂ#,
		},
		'Africa/Mbabane' => {
			exemplarCity => q#ਏਮਬਾਬਾਨੇ#,
		},
		'Africa/Mogadishu' => {
			exemplarCity => q#ਮੋਗਾਦਿਸ਼ੂ#,
		},
		'Africa/Monrovia' => {
			exemplarCity => q#ਮੋਨਰੋਵੀਆ#,
		},
		'Africa/Nairobi' => {
			exemplarCity => q#ਨੈਰੋਬੀ#,
		},
		'Africa/Ndjamena' => {
			exemplarCity => q#ਐਂਜਾਮੇਨਾ#,
		},
		'Africa/Niamey' => {
			exemplarCity => q#ਨਿਆਮੇ#,
		},
		'Africa/Nouakchott' => {
			exemplarCity => q#ਨੌਆਕਸ਼ਾਟ#,
		},
		'Africa/Ouagadougou' => {
			exemplarCity => q#ਉਆਗਾਡੂਗੂ#,
		},
		'Africa/Porto-Novo' => {
			exemplarCity => q#ਪੋਰਟੋ-ਨੋਵੋ#,
		},
		'Africa/Sao_Tome' => {
			exemplarCity => q#ਸਾਓ ਟੋਮ#,
		},
		'Africa/Tripoli' => {
			exemplarCity => q#ਤ੍ਰਿਪੋਲੀ#,
		},
		'Africa/Tunis' => {
			exemplarCity => q#ਟੁਨਿਸ#,
		},
		'Africa/Windhoek' => {
			exemplarCity => q#ਵਿੰਡਹੋਇਕ#,
		},
		'Africa_Central' => {
			long => {
				'standard' => q#ਕੇਂਦਰੀ ਅਫਰੀਕਾ ਵੇਲਾ#,
			},
		},
		'Africa_Eastern' => {
			long => {
				'standard' => q#ਪੂਰਬੀ ਅਫਰੀਕਾ ਵੇਲਾ#,
			},
		},
		'Africa_Southern' => {
			long => {
				'standard' => q#ਦੱਖਣੀ ਅਫ਼ਰੀਕਾ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Africa_Western' => {
			long => {
				'daylight' => q#ਪੱਛਮੀ ਅਫਰੀਕਾ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਪੱਛਮੀ ਅਫਰੀਕਾ ਵੇਲਾ#,
				'standard' => q#ਪੱਛਮੀ ਅਫਰੀਕਾ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Alaska' => {
			long => {
				'daylight' => q#ਅਲਾਸਕਾ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਅਲਾਸਕਾ ਵੇਲਾ#,
				'standard' => q#ਅਲਾਸਕਾ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Almaty' => {
			long => {
				'daylight' => q#ਅਲਮਾਟੀ ਗਰਮੀ-ਰੁੱਤ ਸਮਾਂ#,
				'generic' => q#ਅਲਮਾਟੀ ਸਮਾਂ#,
				'standard' => q#ਅਲਮਾਟੀ ਮਿਆਰੀ ਸਮਾਂ#,
			},
		},
		'Amazon' => {
			long => {
				'daylight' => q#ਅਮੇਜ਼ਨ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਅਮੇਜ਼ਨ ਵੇਲਾ#,
				'standard' => q#ਅਮੇਜ਼ਨ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'America/Adak' => {
			exemplarCity => q#ਏਡਕ#,
		},
		'America/Anchorage' => {
			exemplarCity => q#ਐਂਕਰੇਜ#,
		},
		'America/Anguilla' => {
			exemplarCity => q#ਅੰਗੁਇਲਾ#,
		},
		'America/Antigua' => {
			exemplarCity => q#ਐਂਟੀਗੁਆ#,
		},
		'America/Araguaina' => {
			exemplarCity => q#ਆਰਗੁਆਇਨਾ#,
		},
		'America/Argentina/La_Rioja' => {
			exemplarCity => q#ਲਾ ਰਿਉਜਾ#,
		},
		'America/Argentina/Rio_Gallegos' => {
			exemplarCity => q#ਰਿਓ ਗੈਲੇਗੋਸ#,
		},
		'America/Argentina/Salta' => {
			exemplarCity => q#ਸਾਲਟਾ#,
		},
		'America/Argentina/San_Juan' => {
			exemplarCity => q#ਸੇਨ ਜੁਆਨ#,
		},
		'America/Argentina/San_Luis' => {
			exemplarCity => q#ਸੇਨ ਲੂਈਸ#,
		},
		'America/Argentina/Tucuman' => {
			exemplarCity => q#ਟੁਕੁਮਨ#,
		},
		'America/Argentina/Ushuaia' => {
			exemplarCity => q#ਉਸ਼ਵਾਇਆ#,
		},
		'America/Aruba' => {
			exemplarCity => q#ਅਰੂਬਾ#,
		},
		'America/Asuncion' => {
			exemplarCity => q#ਐਸੁੰਕੀਅਨ#,
		},
		'America/Bahia' => {
			exemplarCity => q#ਬਾਹੀਆ#,
		},
		'America/Bahia_Banderas' => {
			exemplarCity => q#ਬਾਹੀਆ ਬਾਂਦੇਰਸ#,
		},
		'America/Barbados' => {
			exemplarCity => q#ਬਾਰਬਾਡੋਸ#,
		},
		'America/Belem' => {
			exemplarCity => q#ਬੇਲੇਮ#,
		},
		'America/Belize' => {
			exemplarCity => q#ਬੇਲੀਜ਼#,
		},
		'America/Blanc-Sablon' => {
			exemplarCity => q#ਬਲੈਂਕ-ਸੈਬਲਾਨ#,
		},
		'America/Boa_Vista' => {
			exemplarCity => q#ਬੋਆ ਵਿਸਟਾ#,
		},
		'America/Bogota' => {
			exemplarCity => q#ਬੋਗੋਟਾ#,
		},
		'America/Boise' => {
			exemplarCity => q#ਬੋਇਸ#,
		},
		'America/Buenos_Aires' => {
			exemplarCity => q#ਬੂਈਨਸ ਆਇਰਸ#,
		},
		'America/Cambridge_Bay' => {
			exemplarCity => q#ਕੈਮਬ੍ਰਿਜ ਬੇ#,
		},
		'America/Campo_Grande' => {
			exemplarCity => q#ਕੈਂਪੋ ਗ੍ਰਾਂਡੇ#,
		},
		'America/Cancun' => {
			exemplarCity => q#ਕੈਨਕੁਨ#,
		},
		'America/Caracas' => {
			exemplarCity => q#ਕੈਰਾਕਾਸ#,
		},
		'America/Catamarca' => {
			exemplarCity => q#ਕੈਟਾਮਾਰਕਾ#,
		},
		'America/Cayenne' => {
			exemplarCity => q#ਕੇਯੇਨੇ#,
		},
		'America/Cayman' => {
			exemplarCity => q#ਕੇਮੈਨ#,
		},
		'America/Chicago' => {
			exemplarCity => q#ਸ਼ਿਕਾਗੋ#,
		},
		'America/Chihuahua' => {
			exemplarCity => q#ਚਿਹੁਆਹੁਆ#,
		},
		'America/Ciudad_Juarez' => {
			exemplarCity => q#ਸਿਉਡਾਡ ਹੁਆਰੇਜ਼#,
		},
		'America/Coral_Harbour' => {
			exemplarCity => q#ਐਟੀਕੋਕਨ#,
		},
		'America/Cordoba' => {
			exemplarCity => q#ਕੋਰਡੋਬਾ#,
		},
		'America/Costa_Rica' => {
			exemplarCity => q#ਕੋਸਟਾ ਰੀਕਾ#,
		},
		'America/Creston' => {
			exemplarCity => q#ਕ੍ਰੈਸਟਨ#,
		},
		'America/Cuiaba' => {
			exemplarCity => q#ਕਯੁਏਬਾ#,
		},
		'America/Curacao' => {
			exemplarCity => q#ਕੁਰਾਕਾਓ#,
		},
		'America/Danmarkshavn' => {
			exemplarCity => q#ਡੈਨਮਾਰਕਸ਼ੌਨ#,
		},
		'America/Dawson' => {
			exemplarCity => q#ਡੌਅਸਨ#,
		},
		'America/Dawson_Creek' => {
			exemplarCity => q#ਡੌਅਸਨ ਕ੍ਰੀਕ#,
		},
		'America/Denver' => {
			exemplarCity => q#ਡੇਨਵਰ#,
		},
		'America/Detroit' => {
			exemplarCity => q#ਡਿਟਰੋਇਟ#,
		},
		'America/Dominica' => {
			exemplarCity => q#ਡੋਮੀਨਿਕਾ#,
		},
		'America/Edmonton' => {
			exemplarCity => q#ਐਡਮੋਂਟਨ#,
		},
		'America/Eirunepe' => {
			exemplarCity => q#ਯੁਰੂਨੀਪੇ#,
		},
		'America/El_Salvador' => {
			exemplarCity => q#ਅਲ ਸਲਵਾਡੋਰ#,
		},
		'America/Fort_Nelson' => {
			exemplarCity => q#ਫੋਰਟ ਨੈਲਸਨ#,
		},
		'America/Fortaleza' => {
			exemplarCity => q#ਫੋਰਟਾਲੇਜ਼ਾ#,
		},
		'America/Glace_Bay' => {
			exemplarCity => q#ਗਲੇਸ ਬੇ#,
		},
		'America/Godthab' => {
			exemplarCity => q#ਨੂਕ#,
		},
		'America/Goose_Bay' => {
			exemplarCity => q#ਗੂਜ਼ ਬੇ#,
		},
		'America/Grand_Turk' => {
			exemplarCity => q#ਗਰਾਂਡ ਤੁਰਕ#,
		},
		'America/Grenada' => {
			exemplarCity => q#ਗ੍ਰੇਨਾਡਾ#,
		},
		'America/Guadeloupe' => {
			exemplarCity => q#ਗੁਆਡੇਲੋਪ#,
		},
		'America/Guatemala' => {
			exemplarCity => q#ਗੁਆਟੇਮਾਲਾ#,
		},
		'America/Guayaquil' => {
			exemplarCity => q#ਗੁਆਇਕਵਿਲ#,
		},
		'America/Guyana' => {
			exemplarCity => q#ਗੁਆਨਾ#,
		},
		'America/Halifax' => {
			exemplarCity => q#ਹੈਲੀਫੈਕਸ#,
		},
		'America/Havana' => {
			exemplarCity => q#ਹਵਾਨਾ#,
		},
		'America/Hermosillo' => {
			exemplarCity => q#ਹਰਮੋਸਿੱਲੋ#,
		},
		'America/Indiana/Knox' => {
			exemplarCity => q#ਨੋਕਸ, ਇੰਡੀਆਨਾ#,
		},
		'America/Indiana/Marengo' => {
			exemplarCity => q#ਮਾਰੇਂਗੋ, ਇੰਡੀਆਨਾ#,
		},
		'America/Indiana/Petersburg' => {
			exemplarCity => q#ਪੀਟਰਸਬਰਗ, ਇੰਡੀਆਨਾ#,
		},
		'America/Indiana/Tell_City' => {
			exemplarCity => q#ਟੈਲ ਸਿਟੀ, ਇੰਡੀਆਨਾ#,
		},
		'America/Indiana/Vevay' => {
			exemplarCity => q#ਵੇਵੇ, ਇੰਡੀਆਨਾ#,
		},
		'America/Indiana/Vincennes' => {
			exemplarCity => q#ਵਿੰਸੇਨੇਸ, ਇੰਡੀਆਨਾ#,
		},
		'America/Indiana/Winamac' => {
			exemplarCity => q#ਵਿਨਮੈਕ, ਇੰਡੀਆਨਾ#,
		},
		'America/Indianapolis' => {
			exemplarCity => q#ਇੰਡੀਆਨਾਪੋਲਿਸ#,
		},
		'America/Inuvik' => {
			exemplarCity => q#ਇਨੁਵਿਕ#,
		},
		'America/Iqaluit' => {
			exemplarCity => q#ਇਕਾਲੁਈਟ#,
		},
		'America/Jamaica' => {
			exemplarCity => q#ਜਮਾਇਕਾ#,
		},
		'America/Jujuy' => {
			exemplarCity => q#ਜੂਜੁਏ#,
		},
		'America/Juneau' => {
			exemplarCity => q#ਜਯੂਨੋ#,
		},
		'America/Kentucky/Monticello' => {
			exemplarCity => q#ਮੋਂਟੀਸੈਲੋ, ਕੈਂਟਕੀ#,
		},
		'America/Kralendijk' => {
			exemplarCity => q#ਕ੍ਰਾਲੇਂਦਿਜਕ#,
		},
		'America/La_Paz' => {
			exemplarCity => q#ਲਾ ਪਾਜ਼#,
		},
		'America/Lima' => {
			exemplarCity => q#ਲੀਮਾ#,
		},
		'America/Los_Angeles' => {
			exemplarCity => q#ਲਾਸ ਐਂਜਲਸ#,
		},
		'America/Louisville' => {
			exemplarCity => q#ਲੁਈਸਵਿਲੇ#,
		},
		'America/Lower_Princes' => {
			exemplarCity => q#ਲੋਅਰ ਪ੍ਰਿੰਸ’ਸ ਕਵਾਰਟਰ#,
		},
		'America/Maceio' => {
			exemplarCity => q#ਮੈਸੀਓ#,
		},
		'America/Managua' => {
			exemplarCity => q#ਮਨਾਗੁਆ#,
		},
		'America/Manaus' => {
			exemplarCity => q#ਮਨੌਸ#,
		},
		'America/Marigot' => {
			exemplarCity => q#ਮੈਰੀਗੋਟ#,
		},
		'America/Martinique' => {
			exemplarCity => q#ਮਾਰਟੀਨਿਕ#,
		},
		'America/Matamoros' => {
			exemplarCity => q#ਮਾਟਾਮੋਰਸ#,
		},
		'America/Mazatlan' => {
			exemplarCity => q#ਮਜ਼ੇਤਲਾਨ#,
		},
		'America/Mendoza' => {
			exemplarCity => q#ਮੈਂਡੋਜ਼ਾ#,
		},
		'America/Menominee' => {
			exemplarCity => q#ਮੈਨੋਮਿਨੀ#,
		},
		'America/Merida' => {
			exemplarCity => q#ਮੇਰਿਡਾ#,
		},
		'America/Metlakatla' => {
			exemplarCity => q#ਮੇਟਲਾਕਾਟਲਾ#,
		},
		'America/Mexico_City' => {
			exemplarCity => q#ਮੈਕਸੀਕੋ ਸਿਟੀ#,
		},
		'America/Miquelon' => {
			exemplarCity => q#ਮਿਕੇਲਨ#,
		},
		'America/Moncton' => {
			exemplarCity => q#ਮੋਂਕਟਨ#,
		},
		'America/Monterrey' => {
			exemplarCity => q#ਮੋਨਟੇਰੀ#,
		},
		'America/Montevideo' => {
			exemplarCity => q#ਮੋਂਟੇਵੀਡੀਓ#,
		},
		'America/Montserrat' => {
			exemplarCity => q#ਮੋਂਟਸੇਰਾਤ#,
		},
		'America/Nassau' => {
			exemplarCity => q#ਨਾਸਾਓ#,
		},
		'America/New_York' => {
			exemplarCity => q#ਨਿਊ ਯਾਰਕ#,
		},
		'America/Nome' => {
			exemplarCity => q#ਨੋਮ#,
		},
		'America/Noronha' => {
			exemplarCity => q#ਨੌਰੋਨਹਾ#,
		},
		'America/North_Dakota/Beulah' => {
			exemplarCity => q#ਬਿਉਲਾ, ਉੱਤਰੀ ਡਕੋਟਾ#,
		},
		'America/North_Dakota/Center' => {
			exemplarCity => q#ਸੇਂਟਰ, ਉੱਤਰੀ ਡਕੋਟਾ#,
		},
		'America/North_Dakota/New_Salem' => {
			exemplarCity => q#ਨਿਊ ਸਲੇਮ, ਉੱਤਰੀ ਡਕੋਟਾ#,
		},
		'America/Ojinaga' => {
			exemplarCity => q#ਓਜੀਨਾਗਾ#,
		},
		'America/Panama' => {
			exemplarCity => q#ਪਨਾਮਾ#,
		},
		'America/Paramaribo' => {
			exemplarCity => q#ਪੈਰਾਮਰੀਬੋ#,
		},
		'America/Phoenix' => {
			exemplarCity => q#ਫਿਨਿਕਸ#,
		},
		'America/Port-au-Prince' => {
			exemplarCity => q#ਪੋਰਟ-ਔ-ਪ੍ਰਿੰਸ#,
		},
		'America/Port_of_Spain' => {
			exemplarCity => q#ਪੋਰਟ ਔਫ ਸਪੇਨ#,
		},
		'America/Porto_Velho' => {
			exemplarCity => q#ਪੋਰਟੋ ਵੇਲ੍ਹੋ#,
		},
		'America/Puerto_Rico' => {
			exemplarCity => q#ਪਿਊਰਟੋ ਰੀਕੋ#,
		},
		'America/Punta_Arenas' => {
			exemplarCity => q#ਪੰਟਾ ਅਰੇਨਸ#,
		},
		'America/Rankin_Inlet' => {
			exemplarCity => q#ਰੈਂਕਿਨ ਇਨਲੈਟ#,
		},
		'America/Recife' => {
			exemplarCity => q#ਰੇਸੀਫੇ#,
		},
		'America/Regina' => {
			exemplarCity => q#ਰੈਜੀਨਾ#,
		},
		'America/Resolute' => {
			exemplarCity => q#ਰੈਜ਼ੋਲਿਊਟ#,
		},
		'America/Rio_Branco' => {
			exemplarCity => q#ਰੀਓ ਬ੍ਰਾਂਕੋ#,
		},
		'America/Santarem' => {
			exemplarCity => q#ਸੇਂਟਾਰਮ#,
		},
		'America/Santiago' => {
			exemplarCity => q#ਸੇਂਟੀਆਗੋ#,
		},
		'America/Santo_Domingo' => {
			exemplarCity => q#ਸੇਂਟੋ ਡੋਮਿੰਗੋ#,
		},
		'America/Sao_Paulo' => {
			exemplarCity => q#ਸਾਓ ਪੌਲੋ#,
		},
		'America/Scoresbysund' => {
			exemplarCity => q#ਇੱਟੋਕੋਰਟੂਰਮੀਟ#,
		},
		'America/Sitka' => {
			exemplarCity => q#ਸਿਟਕਾ#,
		},
		'America/St_Barthelemy' => {
			exemplarCity => q#ਸੇਂਟ ਬਾਰਥੇਲੇਮੀ#,
		},
		'America/St_Johns' => {
			exemplarCity => q#ਸੇਂਟ ਜੌਹਨਸ#,
		},
		'America/St_Kitts' => {
			exemplarCity => q#ਸੇਂਟ ਕਿਟਸ#,
		},
		'America/St_Lucia' => {
			exemplarCity => q#ਸੇਂਟ ਲੁਸੀਆ#,
		},
		'America/St_Thomas' => {
			exemplarCity => q#ਸੇਂਟ ਥੋਮਸ#,
		},
		'America/St_Vincent' => {
			exemplarCity => q#ਸੇਂਟ ਵਿਨਸੇਂਟ#,
		},
		'America/Swift_Current' => {
			exemplarCity => q#ਸਵਿਫਟ ਕਰੰਟ#,
		},
		'America/Tegucigalpa' => {
			exemplarCity => q#ਟੇਗੁਸੀਗਲਪਾ#,
		},
		'America/Thule' => {
			exemplarCity => q#ਥੁਲੇ#,
		},
		'America/Tijuana' => {
			exemplarCity => q#ਟਿਜੂਆਨਾ#,
		},
		'America/Toronto' => {
			exemplarCity => q#ਟੋਰਾਂਟੋ#,
		},
		'America/Tortola' => {
			exemplarCity => q#ਟੋਰਟੋਲਾ#,
		},
		'America/Vancouver' => {
			exemplarCity => q#ਵੈਨਕੂਵਰ#,
		},
		'America/Whitehorse' => {
			exemplarCity => q#ਵਾਈਟਹੌਰਸ#,
		},
		'America/Winnipeg' => {
			exemplarCity => q#ਵਿਨੀਪੈਗ#,
		},
		'America/Yakutat' => {
			exemplarCity => q#ਯਕੁਤਤ#,
		},
		'America_Central' => {
			long => {
				'daylight' => q#ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਵੇਲਾ#,
				'standard' => q#ਉੱਤਰੀ ਅਮਰੀਕੀ ਕੇਂਦਰੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'America_Eastern' => {
			long => {
				'daylight' => q#ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਵੇਲਾ#,
				'standard' => q#ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੂਰਬੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'America_Mountain' => {
			long => {
				'daylight' => q#ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਵੇਲਾ#,
				'standard' => q#ਉੱਤਰੀ ਅਮਰੀਕੀ ਮਾਉਂਟੇਨ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'America_Pacific' => {
			long => {
				'daylight' => q#ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੈਸਿਫਿਕ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੈਸਿਫਿਕ ਵੇਲਾ#,
				'standard' => q#ਉੱਤਰੀ ਅਮਰੀਕੀ ਪੈਸਿਫਿਕ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Antarctica/Casey' => {
			exemplarCity => q#ਕਾਸੇ#,
		},
		'Antarctica/Davis' => {
			exemplarCity => q#ਡੇਵਿਸ#,
		},
		'Antarctica/DumontDUrville' => {
			exemplarCity => q#ਡਿਉਮੋਂਟ ਡਿਉਰਵਿਲੇ#,
		},
		'Antarctica/Macquarie' => {
			exemplarCity => q#ਮੈਕਕਵੈਰੀ#,
		},
		'Antarctica/Mawson' => {
			exemplarCity => q#ਮੌਸਨ#,
		},
		'Antarctica/McMurdo' => {
			exemplarCity => q#ਮੈਕਮੁਰਡੋ#,
		},
		'Antarctica/Palmer' => {
			exemplarCity => q#ਪਾਮਰ#,
		},
		'Antarctica/Rothera' => {
			exemplarCity => q#ਰੋਥੇਰਾ#,
		},
		'Antarctica/Syowa' => {
			exemplarCity => q#ਸਵੋਯਾ#,
		},
		'Antarctica/Troll' => {
			exemplarCity => q#ਟਰੋਲ#,
		},
		'Antarctica/Vostok' => {
			exemplarCity => q#ਵੋਸਟੋਕ#,
		},
		'Apia' => {
			long => {
				'daylight' => q#ਐਪੀਆ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਐਪੀਆ ਵੇਲਾ#,
				'standard' => q#ਐਪੀਆ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Aqtau' => {
			long => {
				'daylight' => q#ਅਕਤਾਉ ਗਰਮੀ-ਰੁੱਤ ਸਮਾਂ#,
				'generic' => q#ਅਕਤਾਉ ਸਮਾਂ#,
				'standard' => q#ਅਕਤਾਉ ਮਿਆਰੀ ਸਮਾਂ#,
			},
		},
		'Aqtobe' => {
			long => {
				'daylight' => q#ਅਕਤੋਬ ਗਰਮੀ-ਰੁੱਤ ਸਮਾਂ#,
				'generic' => q#ਅਕਤੋਬ ਸਮਾਂ#,
				'standard' => q#ਅਕਤੋਬ ਮਿਆਰੀ ਸਮਾਂ#,
			},
		},
		'Arabian' => {
			long => {
				'daylight' => q#ਅਰਬੀ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਅਰਬੀ ਵੇਲਾ#,
				'standard' => q#ਅਰਬੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Arctic/Longyearbyen' => {
			exemplarCity => q#ਲੋਂਗਈਅਰਬਾਇਨ#,
		},
		'Argentina' => {
			long => {
				'daylight' => q#ਅਰਜਨਟੀਨਾ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਅਰਜਨਟੀਨਾ ਵੇਲਾ#,
				'standard' => q#ਅਰਜਨਟੀਨਾ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Argentina_Western' => {
			long => {
				'daylight' => q#ਪੱਛਮੀ ਅਰਜਨਟੀਨਾ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਪੱਛਮੀ ਅਰਜਨਟੀਨਾ ਵੇਲਾ#,
				'standard' => q#ਪੱਛਮੀ ਅਰਜਨਟੀਨਾ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Armenia' => {
			long => {
				'daylight' => q#ਅਰਮੀਨੀਆ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਅਰਮੀਨੀਆ ਵੇਲਾ#,
				'standard' => q#ਅਰਮੀਨੀਆ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Asia/Aden' => {
			exemplarCity => q#ਅਡੇਨ#,
		},
		'Asia/Almaty' => {
			exemplarCity => q#ਅਲਮੇਟੀ#,
		},
		'Asia/Amman' => {
			exemplarCity => q#ਅਮਾਨ#,
		},
		'Asia/Anadyr' => {
			exemplarCity => q#ਐਨਾਡਾਇਰ#,
		},
		'Asia/Aqtau' => {
			exemplarCity => q#ਅਕਤੌ#,
		},
		'Asia/Aqtobe' => {
			exemplarCity => q#ਅਕਤੋਬੇ#,
		},
		'Asia/Ashgabat' => {
			exemplarCity => q#ਅਸ਼ਗਾਬਾਟ#,
		},
		'Asia/Atyrau' => {
			exemplarCity => q#ਏਤੇਰਾਓ#,
		},
		'Asia/Baghdad' => {
			exemplarCity => q#ਬਗਦਾਦ#,
		},
		'Asia/Bahrain' => {
			exemplarCity => q#ਬਹਿਰੀਨ#,
		},
		'Asia/Baku' => {
			exemplarCity => q#ਬਾਕੂ#,
		},
		'Asia/Bangkok' => {
			exemplarCity => q#ਬੈਂਕਾਕ#,
		},
		'Asia/Barnaul' => {
			exemplarCity => q#ਬਰਨੌਲ#,
		},
		'Asia/Beirut' => {
			exemplarCity => q#ਬੈਰੂਤ#,
		},
		'Asia/Bishkek' => {
			exemplarCity => q#ਬਿਸ਼ਕੇਕ#,
		},
		'Asia/Brunei' => {
			exemplarCity => q#ਬਰੂਨੇਈ#,
		},
		'Asia/Calcutta' => {
			exemplarCity => q#ਕੋਲਕਾਤਾ#,
		},
		'Asia/Chita' => {
			exemplarCity => q#ਚਿਤਾ#,
		},
		'Asia/Colombo' => {
			exemplarCity => q#ਕੋਲੰਬੋ#,
		},
		'Asia/Damascus' => {
			exemplarCity => q#ਡੈਮਸਕਸ#,
		},
		'Asia/Dhaka' => {
			exemplarCity => q#ਢਾਕਾ#,
		},
		'Asia/Dili' => {
			exemplarCity => q#ਡਿਲੀ#,
		},
		'Asia/Dubai' => {
			exemplarCity => q#ਦੁਬਈ#,
		},
		'Asia/Dushanbe' => {
			exemplarCity => q#ਦੁਸ਼ਾਂਬੇ#,
		},
		'Asia/Famagusta' => {
			exemplarCity => q#ਫਾਮਾਗੁਸਟਾ#,
		},
		'Asia/Gaza' => {
			exemplarCity => q#ਗਾਜ਼ਾ#,
		},
		'Asia/Hebron' => {
			exemplarCity => q#ਹੇਬਰਾਨ#,
		},
		'Asia/Hong_Kong' => {
			exemplarCity => q#ਹਾਂਗ ਕਾਂਗ#,
		},
		'Asia/Hovd' => {
			exemplarCity => q#ਹੋਵਡ#,
		},
		'Asia/Irkutsk' => {
			exemplarCity => q#ਇਰਕੁਤਸਕ#,
		},
		'Asia/Jakarta' => {
			exemplarCity => q#ਜਕਾਰਤਾ#,
		},
		'Asia/Jayapura' => {
			exemplarCity => q#ਜਯਾਪੁਰਾ#,
		},
		'Asia/Jerusalem' => {
			exemplarCity => q#ਜੇਰੂਸਲਮ#,
		},
		'Asia/Kabul' => {
			exemplarCity => q#ਕਾਬੁਲ#,
		},
		'Asia/Kamchatka' => {
			exemplarCity => q#ਕਮਚਟਕਾ#,
		},
		'Asia/Karachi' => {
			exemplarCity => q#ਕਰਾਚੀ#,
		},
		'Asia/Katmandu' => {
			exemplarCity => q#ਕਾਠਮਾਂਡੂ#,
		},
		'Asia/Khandyga' => {
			exemplarCity => q#ਖਾਨਡਿਗਾ#,
		},
		'Asia/Krasnoyarsk' => {
			exemplarCity => q#ਕਰੈਸਨੇਜਰਸ#,
		},
		'Asia/Kuala_Lumpur' => {
			exemplarCity => q#ਕੁਆਲਾਲੰਪੁਰ#,
		},
		'Asia/Kuching' => {
			exemplarCity => q#ਕੁਚਿੰਗ#,
		},
		'Asia/Kuwait' => {
			exemplarCity => q#ਕੁਵੈਤ#,
		},
		'Asia/Macau' => {
			exemplarCity => q#ਮਕਾਉ#,
		},
		'Asia/Magadan' => {
			exemplarCity => q#ਮੈਗੇਡਨ#,
		},
		'Asia/Makassar' => {
			exemplarCity => q#ਮਕਸਾਰ#,
		},
		'Asia/Manila' => {
			exemplarCity => q#ਮਨੀਲਾ#,
		},
		'Asia/Muscat' => {
			exemplarCity => q#ਮਸਕਟ#,
		},
		'Asia/Nicosia' => {
			exemplarCity => q#ਨਿਕੋਸੀਆ#,
		},
		'Asia/Novokuznetsk' => {
			exemplarCity => q#ਨੋਵੋਕੁਜ਼ਨੇਟਸਕ#,
		},
		'Asia/Novosibirsk' => {
			exemplarCity => q#ਨੋਵੋਸਿਬੀਰਸਕ#,
		},
		'Asia/Omsk' => {
			exemplarCity => q#ਓਮਸਕ#,
		},
		'Asia/Oral' => {
			exemplarCity => q#ਓਰਲ#,
		},
		'Asia/Phnom_Penh' => {
			exemplarCity => q#ਫਨੋਮ ਪੇਨਹ#,
		},
		'Asia/Pontianak' => {
			exemplarCity => q#ਪੌਂਟੀਆਨਾਕ#,
		},
		'Asia/Pyongyang' => {
			exemplarCity => q#ਪਯੋਂਗਯਾਂਗ#,
		},
		'Asia/Qatar' => {
			exemplarCity => q#ਕਤਰ#,
		},
		'Asia/Qostanay' => {
			exemplarCity => q#ਕੋਸਤਾਨਾਏ#,
		},
		'Asia/Qyzylorda' => {
			exemplarCity => q#ਕਿਜ਼ੀਲੋਰਡਾ#,
		},
		'Asia/Rangoon' => {
			exemplarCity => q#ਰੰਗੂਨ#,
		},
		'Asia/Riyadh' => {
			exemplarCity => q#ਰਿਆਧ#,
		},
		'Asia/Saigon' => {
			exemplarCity => q#ਹੋ ਚੀ ਮਿਨ੍ਹ ਸਿਟੀ#,
		},
		'Asia/Sakhalin' => {
			exemplarCity => q#ਸਖਲੀਨ#,
		},
		'Asia/Samarkand' => {
			exemplarCity => q#ਸਮਰਕੰਦ#,
		},
		'Asia/Seoul' => {
			exemplarCity => q#ਸਿਉਲ#,
		},
		'Asia/Shanghai' => {
			exemplarCity => q#ਸ਼ੰਘਾਈ#,
		},
		'Asia/Singapore' => {
			exemplarCity => q#ਸਿੰਗਾਪੁਰ#,
		},
		'Asia/Srednekolymsk' => {
			exemplarCity => q#ਸਰਿਡਨੀਕੋਲਿਸਕ#,
		},
		'Asia/Taipei' => {
			exemplarCity => q#ਤੈਪਈ#,
		},
		'Asia/Tashkent' => {
			exemplarCity => q#ਤਾਸ਼ਕੰਦ#,
		},
		'Asia/Tbilisi' => {
			exemplarCity => q#ਟਬਿਲਿਸੀ#,
		},
		'Asia/Tehran' => {
			exemplarCity => q#ਤੇਹਰਾਨ#,
		},
		'Asia/Thimphu' => {
			exemplarCity => q#ਥਿੰਫੂ#,
		},
		'Asia/Tokyo' => {
			exemplarCity => q#ਟੋਕੀਓ#,
		},
		'Asia/Tomsk' => {
			exemplarCity => q#ਟੋਮਸਕ#,
		},
		'Asia/Ulaanbaatar' => {
			exemplarCity => q#ਉਲਾਨਬਾਤਰ#,
		},
		'Asia/Urumqi' => {
			exemplarCity => q#ਊਰੂਮਕੀ#,
		},
		'Asia/Ust-Nera' => {
			exemplarCity => q#ਉਸਤ-ਨੇਰਾ#,
		},
		'Asia/Vientiane' => {
			exemplarCity => q#ਵਾਏਨਟਿਆਨੇ#,
		},
		'Asia/Vladivostok' => {
			exemplarCity => q#ਵਲਾਦੀਵੋਸਤਕ#,
		},
		'Asia/Yakutsk' => {
			exemplarCity => q#ਯਕੁਤਸਕ#,
		},
		'Asia/Yekaterinburg' => {
			exemplarCity => q#ਯਕੇਤਰਿਨਬਰਗ#,
		},
		'Asia/Yerevan' => {
			exemplarCity => q#ਯੇਰੇਵਨ#,
		},
		'Atlantic' => {
			long => {
				'daylight' => q#ਅਟਲਾਂਟਿਕ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਅਟਲਾਂਟਿਕ ਵੇਲਾ#,
				'standard' => q#ਅਟਲਾਂਟਿਕ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Atlantic/Azores' => {
			exemplarCity => q#ਅਜੋਰੇਸ#,
		},
		'Atlantic/Bermuda' => {
			exemplarCity => q#ਬਰਮੂਡਾ#,
		},
		'Atlantic/Canary' => {
			exemplarCity => q#ਕੇਨੇਰੀ#,
		},
		'Atlantic/Cape_Verde' => {
			exemplarCity => q#ਕੇਪ ਵਰਡ#,
		},
		'Atlantic/Faeroe' => {
			exemplarCity => q#ਫੈਰੋ#,
		},
		'Atlantic/Madeira' => {
			exemplarCity => q#ਮਡੀਅਰਾ#,
		},
		'Atlantic/Reykjavik' => {
			exemplarCity => q#ਰੇਕਜਾਵਿਕ#,
		},
		'Atlantic/South_Georgia' => {
			exemplarCity => q#ਦੱਖਣੀ ਜਾਰਜੀਆ#,
		},
		'Atlantic/St_Helena' => {
			exemplarCity => q#ਸੇਂਟ ਹੇਲੇਨਾ#,
		},
		'Atlantic/Stanley' => {
			exemplarCity => q#ਸਟੇਨਲੀ#,
		},
		'Australia/Adelaide' => {
			exemplarCity => q#ਐਡੀਲੇਡ#,
		},
		'Australia/Brisbane' => {
			exemplarCity => q#ਬ੍ਰਿਸਬੇਨ#,
		},
		'Australia/Broken_Hill' => {
			exemplarCity => q#ਬ੍ਰੋਕਨ ਹਿਲ#,
		},
		'Australia/Darwin' => {
			exemplarCity => q#ਡਾਰਵਿਨ#,
		},
		'Australia/Eucla' => {
			exemplarCity => q#ਯੂਕਲਾ#,
		},
		'Australia/Hobart' => {
			exemplarCity => q#ਹੋਬਾਰਟ#,
		},
		'Australia/Lindeman' => {
			exemplarCity => q#ਲਿੰਡੇਮਨ#,
		},
		'Australia/Lord_Howe' => {
			exemplarCity => q#ਲੌਰਡ ਹੋਵੇ#,
		},
		'Australia/Melbourne' => {
			exemplarCity => q#ਮੈਲਬੋਰਨ#,
		},
		'Australia/Perth' => {
			exemplarCity => q#ਪਰਥ#,
		},
		'Australia/Sydney' => {
			exemplarCity => q#ਸਿਡਨੀ#,
		},
		'Australia_Central' => {
			long => {
				'daylight' => q#ਆਸਟ੍ਰੇਲੀਆਈ ਕੇਂਦਰੀ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਕੇਂਦਰੀ ਆਸਟ੍ਰੇਲੀਆਈ ਵੇਲਾ#,
				'standard' => q#ਆਸਟ੍ਰੇਲੀਆਈ ਕੇਂਦਰੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Australia_CentralWestern' => {
			long => {
				'daylight' => q#ਆਸਟ੍ਰੇਲੀਆਈ ਕੇਂਦਰੀ ਪੱਛਮੀ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਆਸਟ੍ਰੇਲੀਆਈ ਕੇਂਦਰੀ ਪੱਛਮੀ ਵੇਲਾ#,
				'standard' => q#ਆਸਟ੍ਰੇਲੀਆਈ ਕੇਂਦਰੀ ਪੱਛਮੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Australia_Eastern' => {
			long => {
				'daylight' => q#ਆਸਟ੍ਰੇਲੀਆਈ ਪੂਰਬੀ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਪੂਰਬੀ ਆਸਟ੍ਰੇਲੀਆਈ ਵੇਲਾ#,
				'standard' => q#ਆਸਟ੍ਰੇਲੀਆਈ ਪੂਰਬੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Australia_Western' => {
			long => {
				'daylight' => q#ਆਸਟ੍ਰੇਲੀਆਈ ਪੱਛਮੀ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਪੱਛਮੀ ਆਸਟ੍ਰੇਲੀਆਈ ਵੇਲਾ#,
				'standard' => q#ਆਸਟ੍ਰੇਲੀਆਈ ਪੱਛਮੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Azerbaijan' => {
			long => {
				'daylight' => q#ਅਜ਼ਰਬਾਈਜਾਨ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਅਜ਼ਰਬਾਈਜਾਨ ਵੇਲਾ#,
				'standard' => q#ਅਜ਼ਰਬਾਈਜਾਨ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Azores' => {
			long => {
				'daylight' => q#ਅਜੋਰੇਸ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਅਜੋਰੇਸ ਵੇਲਾ#,
				'standard' => q#ਅਜੋਰੇਸ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Bangladesh' => {
			long => {
				'daylight' => q#ਬੰਗਲਾਦੇਸ਼ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਬੰਗਲਾਦੇਸ਼ ਵੇਲਾ#,
				'standard' => q#ਬੰਗਲਾਦੇਸ਼ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Bhutan' => {
			long => {
				'standard' => q#ਭੂਟਾਨ ਵੇਲਾ#,
			},
		},
		'Bolivia' => {
			long => {
				'standard' => q#ਬੋਲੀਵੀਆ ਵੇਲਾ#,
			},
		},
		'Brasilia' => {
			long => {
				'daylight' => q#ਬ੍ਰਾਜ਼ੀਲੀਆ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਬ੍ਰਾਜ਼ੀਲੀਆ ਵੇਲਾ#,
				'standard' => q#ਬ੍ਰਾਜ਼ੀਲੀਆ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Brunei' => {
			long => {
				'standard' => q#ਬਰੂਨੇਈ ਦਾਰੂਸਲਾਮ ਵੇਲਾ#,
			},
		},
		'Cape_Verde' => {
			long => {
				'daylight' => q#ਕੇਪ ਵਰਡ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਕੇਪ ਵਰਡ ਵੇਲਾ#,
				'standard' => q#ਕੇਪ ਵਰਡ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Casey' => {
			long => {
				'standard' => q#ਕੇਸੀ ਸਮਾਂ#,
			},
		},
		'Chamorro' => {
			long => {
				'standard' => q#ਚਾਮੋਰੋ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Chatham' => {
			long => {
				'daylight' => q#ਚੈਥਮ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਚੈਥਮ ਵੇਲਾ#,
				'standard' => q#ਚੈਥਮ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Chile' => {
			long => {
				'daylight' => q#ਚਿਲੀ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਚਿਲੀ ਵੇਲਾ#,
				'standard' => q#ਚਿਲੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'China' => {
			long => {
				'daylight' => q#ਚੀਨ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਚੀਨ ਵੇਲਾ#,
				'standard' => q#ਚੀਨ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Christmas' => {
			long => {
				'standard' => q#ਕ੍ਰਿਸਮਸ ਆਈਲੈਂਡ ਵੇਲਾ#,
			},
		},
		'Cocos' => {
			long => {
				'standard' => q#ਕੋਕਸ ਆਈਲੈਂਡ ਵੇਲਾ#,
			},
		},
		'Colombia' => {
			long => {
				'daylight' => q#ਕੋਲੰਬੀਆ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਕੋਲੰਬੀਆ ਵੇਲਾ#,
				'standard' => q#ਕੋਲੰਬੀਆ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Cook' => {
			long => {
				'daylight' => q#ਕੁੱਕ ਆਈਲੈਂਡ ਅੱਧ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਕੁੱਕ ਆਈਲੈਂਡ ਵੇਲਾ#,
				'standard' => q#ਕੁੱਕ ਆਈਲੈਂਡ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Cuba' => {
			long => {
				'daylight' => q#ਕਿਊਬਾ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਕਿਊਬਾ ਵੇਲਾ#,
				'standard' => q#ਕਿਊਬਾ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Davis' => {
			long => {
				'standard' => q#ਡੇਵਿਸ ਵੇਲਾ#,
			},
		},
		'DumontDUrville' => {
			long => {
				'standard' => q#ਡਿਉਮੋਂਟ ਡਿਉਰਵਿਲੇ ਵੇਲਾ#,
			},
		},
		'East_Timor' => {
			long => {
				'standard' => q#ਪੂਰਬੀ ਤਿਮੂਰ ਵੇਲਾ#,
			},
		},
		'Easter' => {
			long => {
				'daylight' => q#ਈਸਟਰ ਆਈਲੈਂਡ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਈਸਟਰ ਆਈਲੈਂਡ ਵੇਲਾ#,
				'standard' => q#ਈਸਟਰ ਆਈਲੈਂਡ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Ecuador' => {
			long => {
				'standard' => q#ਇਕਵੇਡੋਰ ਵੇਲਾ#,
			},
		},
		'Etc/UTC' => {
			long => {
				'standard' => q#ਕੋਔਰਡੀਨੇਟੇਡ ਵਿਆਪਕ ਵੇਲਾ#,
			},
		},
		'Etc/Unknown' => {
			exemplarCity => q#ਅਣਪਛਾਤਾ ਸ਼ਹਿਰ#,
		},
		'Europe/Amsterdam' => {
			exemplarCity => q#ਐਮਸਟਰਡਮ#,
		},
		'Europe/Andorra' => {
			exemplarCity => q#ਅੰਡੋਰਾ#,
		},
		'Europe/Astrakhan' => {
			exemplarCity => q#ਆਸਟ੍ਰਾਖਾਨ#,
		},
		'Europe/Athens' => {
			exemplarCity => q#ਏਥਨਸ#,
		},
		'Europe/Belgrade' => {
			exemplarCity => q#ਬੈਲਗ੍ਰੇਡ#,
		},
		'Europe/Berlin' => {
			exemplarCity => q#ਬਰਲਿਨ#,
		},
		'Europe/Bratislava' => {
			exemplarCity => q#ਬ੍ਰਾਟਿਸਲਾਵਾ#,
		},
		'Europe/Brussels' => {
			exemplarCity => q#ਬਰੱਸਲਜ#,
		},
		'Europe/Bucharest' => {
			exemplarCity => q#ਬੂਕਾਰੈਸਟ#,
		},
		'Europe/Budapest' => {
			exemplarCity => q#ਬੁਡਾਪੈਸਟ#,
		},
		'Europe/Busingen' => {
			exemplarCity => q#ਬੁਸਿੰਜੇਨ#,
		},
		'Europe/Chisinau' => {
			exemplarCity => q#ਚਿਸਿਨੌ#,
		},
		'Europe/Copenhagen' => {
			exemplarCity => q#ਕੋਪਨਹੇਗਨ#,
		},
		'Europe/Dublin' => {
			exemplarCity => q#ਡਬਲਿਨ#,
			long => {
				'daylight' => q#ਆਇਰਿਸ਼ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Europe/Gibraltar' => {
			exemplarCity => q#ਜਿਬਰਾਲਟਰ#,
		},
		'Europe/Guernsey' => {
			exemplarCity => q#ਗਰਨਜੀ#,
		},
		'Europe/Helsinki' => {
			exemplarCity => q#ਹੇਲਸਿੰਕੀ#,
		},
		'Europe/Isle_of_Man' => {
			exemplarCity => q#ਆਇਲ ਆਫ ਮੈਨ#,
		},
		'Europe/Istanbul' => {
			exemplarCity => q#ਇਸਤਾਂਬੁਲ#,
		},
		'Europe/Jersey' => {
			exemplarCity => q#ਜਰਸੀ#,
		},
		'Europe/Kaliningrad' => {
			exemplarCity => q#ਕਲੀਨਿੰਗ੍ਰੇਡ#,
		},
		'Europe/Kiev' => {
			exemplarCity => q#ਕੀਵ#,
		},
		'Europe/Kirov' => {
			exemplarCity => q#ਕੀਰੋਵ#,
		},
		'Europe/Lisbon' => {
			exemplarCity => q#ਲਿਸਬਨ#,
		},
		'Europe/Ljubljana' => {
			exemplarCity => q#ਲਜੁਬਲਜਾਨਾ#,
		},
		'Europe/London' => {
			exemplarCity => q#ਲੰਡਨ#,
			long => {
				'daylight' => q#ਬ੍ਰਿਟਿਸ਼ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
			},
		},
		'Europe/Luxembourg' => {
			exemplarCity => q#ਲਕਜ਼ਮਬਰਗ#,
		},
		'Europe/Madrid' => {
			exemplarCity => q#ਮੈਡ੍ਰਿਡ#,
		},
		'Europe/Malta' => {
			exemplarCity => q#ਮਾਲਟਾ#,
		},
		'Europe/Mariehamn' => {
			exemplarCity => q#ਮਾਰੀਏਹਾਮੇਨ#,
		},
		'Europe/Minsk' => {
			exemplarCity => q#ਮਿੰਸਕ#,
		},
		'Europe/Monaco' => {
			exemplarCity => q#ਮੋਨਾਕੋ#,
		},
		'Europe/Moscow' => {
			exemplarCity => q#ਮਾਸਕੋ#,
		},
		'Europe/Oslo' => {
			exemplarCity => q#ਓਸਲੋ#,
		},
		'Europe/Paris' => {
			exemplarCity => q#ਪੈਰਿਸ#,
		},
		'Europe/Podgorica' => {
			exemplarCity => q#ਪੋਡਗੋਰੀਕਾ#,
		},
		'Europe/Prague' => {
			exemplarCity => q#ਪ੍ਰਾਗ#,
		},
		'Europe/Riga' => {
			exemplarCity => q#ਰਿਗਾ#,
		},
		'Europe/Rome' => {
			exemplarCity => q#ਰੋਮ#,
		},
		'Europe/Samara' => {
			exemplarCity => q#ਸਮਾਰਾ#,
		},
		'Europe/San_Marino' => {
			exemplarCity => q#ਸੈਨ ਮਰੀਨੋ#,
		},
		'Europe/Sarajevo' => {
			exemplarCity => q#ਸਾਰਾਜੇਵੋ#,
		},
		'Europe/Saratov' => {
			exemplarCity => q#ਸੈਰਾਟੋਵ#,
		},
		'Europe/Simferopol' => {
			exemplarCity => q#ਸਿਮਫਰੋਪੋਲ#,
		},
		'Europe/Skopje' => {
			exemplarCity => q#ਸਕੋਪਜੇ#,
		},
		'Europe/Sofia' => {
			exemplarCity => q#ਸੋਫੀਆ#,
		},
		'Europe/Stockholm' => {
			exemplarCity => q#ਸਟਾਕਹੋਮ#,
		},
		'Europe/Tallinn' => {
			exemplarCity => q#ਟੱਲਿਨ#,
		},
		'Europe/Tirane' => {
			exemplarCity => q#ਤਿਰਾਨੇ#,
		},
		'Europe/Ulyanovsk' => {
			exemplarCity => q#ਯੁਲਿਆਨੋਸਕ#,
		},
		'Europe/Vaduz' => {
			exemplarCity => q#ਵਾਡੁਜ਼#,
		},
		'Europe/Vatican' => {
			exemplarCity => q#ਵੈਟਿਕਨ#,
		},
		'Europe/Vienna' => {
			exemplarCity => q#ਵਿਆਨਾ#,
		},
		'Europe/Vilnius' => {
			exemplarCity => q#ਵਿਲਨਿਅਸ#,
		},
		'Europe/Volgograd' => {
			exemplarCity => q#ਵੋਲਗੋਗ੍ਰੇਡ#,
		},
		'Europe/Warsaw' => {
			exemplarCity => q#ਵਾਰਸਾਅ#,
		},
		'Europe/Zagreb' => {
			exemplarCity => q#ਜ਼ਗਰੇਬ#,
		},
		'Europe/Zurich' => {
			exemplarCity => q#ਜਿਊਰਿਖ#,
		},
		'Europe_Central' => {
			long => {
				'daylight' => q#ਮੱਧ ਯੂਰਪੀ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਮੱਧ ਯੂਰਪੀ ਵੇਲਾ#,
				'standard' => q#ਮੱਧ ਯੂਰਪੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Europe_Eastern' => {
			long => {
				'daylight' => q#ਪੂਰਬੀ ਯੂਰਪੀ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ#,
				'standard' => q#ਪੂਰਬੀ ਯੂਰਪੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Europe_Further_Eastern' => {
			long => {
				'standard' => q#ਹੋਰ-ਪੂਰਬੀ ਯੂਰਪੀ ਵੇਲਾ#,
			},
		},
		'Europe_Western' => {
			long => {
				'daylight' => q#ਪੱਛਮੀ ਯੂਰਪੀ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਪੱਛਮੀ ਯੂਰਪੀ ਵੇਲਾ#,
				'standard' => q#ਪੱਛਮੀ ਯੂਰਪੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Falkland' => {
			long => {
				'daylight' => q#ਫ਼ਾਕਲੈਂਡ ਆਈਲੈਂਡਸ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਫ਼ਾਕਲੈਂਡ ਆਈਲੈਂਡਸ ਵੇਲਾ#,
				'standard' => q#ਫ਼ਾਕਲੈਂਡ ਆਈਲੈਂਡਸ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Fiji' => {
			long => {
				'daylight' => q#ਫ਼ਿਜ਼ੀ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਫ਼ਿਜ਼ੀ ਵੇਲਾ#,
				'standard' => q#ਫ਼ਿਜ਼ੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'French_Guiana' => {
			long => {
				'standard' => q#ਫ੍ਰੈਂਚ ਗੁਏਨਾ ਵੇਲਾ#,
			},
		},
		'French_Southern' => {
			long => {
				'standard' => q#ਫ੍ਰੈਂਚ ਦੱਖਣੀ ਅਤੇ ਐਂਟਾਰਟਿਕ ਵੇਲਾ#,
			},
		},
		'GMT' => {
			long => {
				'standard' => q#ਗ੍ਰੀਨਵਿਚ ਮੀਨ ਵੇਲਾ#,
			},
		},
		'Galapagos' => {
			long => {
				'standard' => q#ਗਲਾਪਾਗੋਸ ਵੇਲਾ#,
			},
		},
		'Gambier' => {
			long => {
				'standard' => q#ਗੈਂਬੀਅਰ ਵੇਲਾ#,
			},
		},
		'Georgia' => {
			long => {
				'daylight' => q#ਜਾਰਜੀਆ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਜਾਰਜੀਆ ਵੇਲਾ#,
				'standard' => q#ਜਾਰਜੀਆ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Gilbert_Islands' => {
			long => {
				'standard' => q#ਗਿਲਬਰਟ ਆਈਲੈਂਡ ਵੇਲਾ#,
			},
		},
		'Greenland_Eastern' => {
			long => {
				'daylight' => q#ਪੂਰਬੀ ਗ੍ਰੀਨਲੈਂਡ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਪੂਰਬੀ ਗ੍ਰੀਨਲੈਂਡ ਵੇਲਾ#,
				'standard' => q#ਪੂਰਬੀ ਗ੍ਰੀਨਲੈਂਡ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Greenland_Western' => {
			long => {
				'daylight' => q#ਪੱਛਮੀ ਗ੍ਰੀਨਲੈਂਡ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਪੱਛਮੀ ਗ੍ਰੀਨਲੈਂਡ ਵੇਲਾ#,
				'standard' => q#ਪੱਛਮੀ ਗ੍ਰੀਨਲੈਂਡ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Guam' => {
			long => {
				'standard' => q#ਗੁਆਮ ਸਮਾਂ#,
			},
		},
		'Gulf' => {
			long => {
				'standard' => q#ਖਾੜੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Guyana' => {
			long => {
				'standard' => q#ਗੁਯਾਨਾ ਵੇਲਾ#,
			},
		},
		'Hawaii_Aleutian' => {
			long => {
				'daylight' => q#ਹਵਾਈ-ਅਲੇਯੂਸ਼ਿਅਨ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਹਵਾਈ-ਅਲੇਯੂਸ਼ਿਅਨ ਵੇਲਾ#,
				'standard' => q#ਹਵਾਈ-ਅਲੇਯੂਸ਼ਿਅਨ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Hong_Kong' => {
			long => {
				'daylight' => q#ਹਾਂਗ ਕਾਂਗ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਹਾਂਗ ਕਾਂਗ ਵੇਲਾ#,
				'standard' => q#ਹਾਂਗ ਕਾਂਗ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Hovd' => {
			long => {
				'daylight' => q#ਹੋਵਡ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਹੋਵਡ ਵੇਲਾ#,
				'standard' => q#ਹੋਵਡ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'India' => {
			long => {
				'standard' => q#ਭਾਰਤੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
			short => {
				'standard' => q#IST#,
			},
		},
		'Indian/Antananarivo' => {
			exemplarCity => q#ਅੰਟਾਨਨੇਰਿਵੋ#,
		},
		'Indian/Chagos' => {
			exemplarCity => q#ਚਾਗੋਸ#,
		},
		'Indian/Christmas' => {
			exemplarCity => q#ਕ੍ਰਿਸਮਸ#,
		},
		'Indian/Cocos' => {
			exemplarCity => q#ਕੋਕੋਜ਼#,
		},
		'Indian/Comoro' => {
			exemplarCity => q#ਕੋਮੋਰੋ#,
		},
		'Indian/Kerguelen' => {
			exemplarCity => q#ਕਰਗਯੂਲੇਨ#,
		},
		'Indian/Mahe' => {
			exemplarCity => q#ਮਾਹੇ#,
		},
		'Indian/Maldives' => {
			exemplarCity => q#ਮਾਲਦੀਵ#,
		},
		'Indian/Mauritius' => {
			exemplarCity => q#ਮੌਰਿਸ਼ਸ#,
		},
		'Indian/Mayotte' => {
			exemplarCity => q#ਮਾਯੋਟੀ#,
		},
		'Indian/Reunion' => {
			exemplarCity => q#ਰਿਯੂਨੀਅਨ#,
		},
		'Indian_Ocean' => {
			long => {
				'standard' => q#ਹਿੰਦ ਮਹਾਂਸਾਗਰ ਵੇਲਾ#,
			},
		},
		'Indochina' => {
			long => {
				'standard' => q#ਇੰਡੋਚਾਈਨਾ ਵੇਲਾ#,
			},
		},
		'Indonesia_Central' => {
			long => {
				'standard' => q#ਮੱਧ ਇੰਡੋਨੇਸ਼ੀਆਈ ਵੇਲਾ#,
			},
		},
		'Indonesia_Eastern' => {
			long => {
				'standard' => q#ਪੂਰਬੀ ਇੰਡੋਨੇਸ਼ੀਆ ਵੇਲਾ#,
			},
		},
		'Indonesia_Western' => {
			long => {
				'standard' => q#ਪੱਛਮੀ ਇੰਡੋਨੇਸ਼ੀਆ ਵੇਲਾ#,
			},
		},
		'Iran' => {
			long => {
				'daylight' => q#ਈਰਾਨ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਈਰਾਨ ਵੇਲਾ#,
				'standard' => q#ਈਰਾਨ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Irkutsk' => {
			long => {
				'daylight' => q#ਇਰਕੁਤਸਕ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਇਰਕੁਤਸਕ ਵੇਲਾ#,
				'standard' => q#ਇਰਕੁਤਸਕ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Israel' => {
			long => {
				'daylight' => q#ਇਜ਼ਰਾਈਲ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਇਜ਼ਰਾਈਲ ਵੇਲਾ#,
				'standard' => q#ਇਜ਼ਰਾਈਲ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Japan' => {
			long => {
				'daylight' => q#ਜਪਾਨ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਜਪਾਨ ਵੇਲਾ#,
				'standard' => q#ਜਪਾਨ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Kazakhstan' => {
			long => {
				'standard' => q#ਕਜ਼ਾਖ਼ਸਤਾਨ ਵੇਲਾ#,
			},
		},
		'Kazakhstan_Eastern' => {
			long => {
				'standard' => q#ਪੂਰਬੀ ਕਜ਼ਾਖ਼ਸਤਾਨ ਵੇਲਾ#,
			},
		},
		'Kazakhstan_Western' => {
			long => {
				'standard' => q#ਪੱਛਮੀ ਕਜ਼ਾਖ਼ਸਤਾਨ ਵੇਲਾ#,
			},
		},
		'Korea' => {
			long => {
				'daylight' => q#ਕੋਰੀਆਈ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਕੋਰੀਆਈ ਵੇਲਾ#,
				'standard' => q#ਕੋਰੀਆਈ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Kosrae' => {
			long => {
				'standard' => q#ਕੋਸਰੇ ਵੇਲਾ#,
			},
		},
		'Krasnoyarsk' => {
			long => {
				'daylight' => q#ਕ੍ਰਾਸਨੋਯਾਰਸਕ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਕ੍ਰਾਸਨੋਯਾਰਸਕ ਵੇਲਾ#,
				'standard' => q#ਕ੍ਰਾਸਨੋਯਾਰਸਕ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Kyrgystan' => {
			long => {
				'standard' => q#ਕਿਰਗਿਸਤਾਨ ਵੇਲਾ#,
			},
		},
		'Lanka' => {
			long => {
				'standard' => q#ਲੰਕਾ ਸਮਾਂ#,
			},
		},
		'Line_Islands' => {
			long => {
				'standard' => q#ਲਾਈਨ ਆਈਲੈਂਡ ਵੇਲਾ#,
			},
		},
		'Lord_Howe' => {
			long => {
				'daylight' => q#ਲੌਰਡ ਹੋਵੇ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਲੌਰਡ ਹੋਵੇ ਵੇਲਾ#,
				'standard' => q#ਲੌਰਡ ਹੋਵੇ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Macau' => {
			long => {
				'daylight' => q#ਮਕਾਉ ਗਰਮੀ-ਰੁੱਤ ਸਮਾਂ#,
				'generic' => q#ਮਕਾਉ ਸਮਾਂ#,
				'standard' => q#ਮਕਾਉ ਮਿਆਰੀ ਸਮਾਂ#,
			},
		},
		'Magadan' => {
			long => {
				'daylight' => q#ਮੈਗੇਡਨ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਮੈਗੇਡਨ ਵੇਲਾ#,
				'standard' => q#ਮੈਗੇਡਨ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Malaysia' => {
			long => {
				'standard' => q#ਮਲੇਸ਼ੀਆ ਵੇਲਾ#,
			},
		},
		'Maldives' => {
			long => {
				'standard' => q#ਮਾਲਦੀਵ ਵੇਲਾ#,
			},
		},
		'Marquesas' => {
			long => {
				'standard' => q#ਮਾਰਕਿਸਾਸ ਵੇਲਾ#,
			},
		},
		'Marshall_Islands' => {
			long => {
				'standard' => q#ਮਾਰਸ਼ਲ ਆਈਲੈਂਡ ਵੇਲਾ#,
			},
		},
		'Mauritius' => {
			long => {
				'daylight' => q#ਮੌਰਿਸ਼ਸ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਮੌਰਿਸ਼ਸ ਵੇਲਾ#,
				'standard' => q#ਮੌਰਿਸ਼ਸ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Mawson' => {
			long => {
				'standard' => q#ਮੌਸਨ ਵੇਲਾ#,
			},
		},
		'Mexico_Pacific' => {
			long => {
				'daylight' => q#ਮੈਕਸੀਕਨ ਪੈਸਿਫਿਕ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਮੈਕਸੀਕਨ ਪੈਸਿਫਿਕ ਵੇਲਾ#,
				'standard' => q#ਮੈਕਸੀਕਨ ਪੈਸਿਫਿਕ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Mongolia' => {
			long => {
				'daylight' => q#ਉਲਨ ਬਟੋਰ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਉਲਨ ਬਟੋਰ ਵੇਲਾ#,
				'standard' => q#ਉਲਨ ਬਟੋਰ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Moscow' => {
			long => {
				'daylight' => q#ਮਾਸਕੋ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਮਾਸਕੋ ਵੇਲਾ#,
				'standard' => q#ਮਾਸਕੋ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Myanmar' => {
			long => {
				'standard' => q#ਮਿਆਂਮਾਰ ਵੇਲਾ#,
			},
		},
		'Nauru' => {
			long => {
				'standard' => q#ਨਾਉਰੂ ਵੇਲਾ#,
			},
		},
		'Nepal' => {
			long => {
				'standard' => q#ਨੇਪਾਲ ਵੇਲਾ#,
			},
		},
		'New_Caledonia' => {
			long => {
				'daylight' => q#ਨਿਊ ਕੈਲੇਡੋਨੀਆ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਨਿਊ ਕੈਲੇਡੋਨੀਆ ਵੇਲਾ#,
				'standard' => q#ਨਿਊ ਕੈਲੇਡੋਨੀਆ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'New_Zealand' => {
			long => {
				'daylight' => q#ਨਿਊਜ਼ੀਲੈਂਡ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਨਿਊਜ਼ੀਲੈਂਡ ਵੇਲਾ#,
				'standard' => q#ਨਿਊਜ਼ੀਲੈਂਡ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Newfoundland' => {
			long => {
				'daylight' => q#ਨਿਊਫਾਉਂਡਲੈਂਡ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਨਿਊਫਾਉਂਡਲੈਂਡ ਵੇਲਾ#,
				'standard' => q#ਨਿਊਫਾਉਂਡਲੈਂਡ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Niue' => {
			long => {
				'standard' => q#ਨੀਊ ਵੇਲਾ#,
			},
		},
		'Norfolk' => {
			long => {
				'daylight' => q#ਨੋਰਫੌਕ ਆਈਲੈਂਡ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਨੋਰਫੌਕ ਆਈਲੈਂਡ ਵੇਲਾ#,
				'standard' => q#ਨੋਰਫੌਕ ਆਈਲੈਂਡ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Noronha' => {
			long => {
				'daylight' => q#ਫਰਨਾਂਡੋ ਡੇ ਨੋਰੋਨਹਾ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਫਰਨਾਂਡੋ ਡੇ ਨੋਰੋਨਹਾ ਵੇਲਾ#,
				'standard' => q#ਫਰਨਾਂਡੋ ਡੇ ਨੋਰੋਨਹਾ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'North_Mariana' => {
			long => {
				'standard' => q#ਉੱਤਰੀ ਮਰਿਆਨਾ ਆਈਲੈਂਡ ਸਮਾਂ#,
			},
		},
		'Novosibirsk' => {
			long => {
				'daylight' => q#ਨੌਵੋਸਿਬੀਰਸਕ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਨੌਵੋਸਿਬੀਰਸਕ ਵੇਲਾ#,
				'standard' => q#ਨੌਵੋਸਿਬੀਰਸਕ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Omsk' => {
			long => {
				'daylight' => q#ਓਮਸਕ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਓਮਸਕ ਵੇਲਾ#,
				'standard' => q#ਓਮਸਕ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Pacific/Apia' => {
			exemplarCity => q#ਐਪੀਆ#,
		},
		'Pacific/Auckland' => {
			exemplarCity => q#ਆਕਲੈਂਡ#,
		},
		'Pacific/Bougainville' => {
			exemplarCity => q#ਬੋਗਨਵਿਲੇ#,
		},
		'Pacific/Chatham' => {
			exemplarCity => q#ਚੈਥਮ#,
		},
		'Pacific/Easter' => {
			exemplarCity => q#ਈਸਟਰ#,
		},
		'Pacific/Efate' => {
			exemplarCity => q#ਇਫੇਟ#,
		},
		'Pacific/Enderbury' => {
			exemplarCity => q#ਏਂਡਰਬਰੀ#,
		},
		'Pacific/Fakaofo' => {
			exemplarCity => q#ਫਕਾਉਫੋ#,
		},
		'Pacific/Fiji' => {
			exemplarCity => q#ਫ਼ਿਜੀ#,
		},
		'Pacific/Funafuti' => {
			exemplarCity => q#ਫੁਨਾਫੁਟੀ#,
		},
		'Pacific/Galapagos' => {
			exemplarCity => q#ਗਲਪੇਗੋਸ#,
		},
		'Pacific/Gambier' => {
			exemplarCity => q#ਗੈਂਬੀਅਰ#,
		},
		'Pacific/Guadalcanal' => {
			exemplarCity => q#ਗੁਆਡਾਕੇਨਲ#,
		},
		'Pacific/Guam' => {
			exemplarCity => q#ਗੁਆਮ#,
		},
		'Pacific/Honolulu' => {
			exemplarCity => q#ਹੋਨੋਲੁਲੂ#,
		},
		'Pacific/Kanton' => {
			exemplarCity => q#ਕੈਂਟੋਨ#,
		},
		'Pacific/Kiritimati' => {
			exemplarCity => q#ਕਿਰਿਤਿਮਤੀ#,
		},
		'Pacific/Kosrae' => {
			exemplarCity => q#ਕੋਸ੍ਰਾਏ#,
		},
		'Pacific/Kwajalein' => {
			exemplarCity => q#ਕਵਾਜਾਲੀਨ#,
		},
		'Pacific/Majuro' => {
			exemplarCity => q#ਮੇਜੁਰੋ#,
		},
		'Pacific/Marquesas' => {
			exemplarCity => q#ਮਾਰਕਿਸਾਸ#,
		},
		'Pacific/Midway' => {
			exemplarCity => q#ਮਿਡਵੇ#,
		},
		'Pacific/Nauru' => {
			exemplarCity => q#ਨਾਉਰੂ#,
		},
		'Pacific/Niue' => {
			exemplarCity => q#ਨਿਯੂ#,
		},
		'Pacific/Norfolk' => {
			exemplarCity => q#ਨੋਰਫੌਕ#,
		},
		'Pacific/Noumea' => {
			exemplarCity => q#ਨੌਮਿਆ#,
		},
		'Pacific/Pago_Pago' => {
			exemplarCity => q#ਪਾਗੋ ਪਾਗੋ#,
		},
		'Pacific/Palau' => {
			exemplarCity => q#ਪਲਾਉ#,
		},
		'Pacific/Pitcairn' => {
			exemplarCity => q#ਪਿਟਕੈਰਨ#,
		},
		'Pacific/Ponape' => {
			exemplarCity => q#ਪੋਹਨਪੇਈ#,
		},
		'Pacific/Port_Moresby' => {
			exemplarCity => q#ਪੋਰਟ ਮੋਰੇਸਬੀ#,
		},
		'Pacific/Rarotonga' => {
			exemplarCity => q#ਰਾਰੋਟੋਂਗਾ#,
		},
		'Pacific/Saipan' => {
			exemplarCity => q#ਸੈਪਾਨ#,
		},
		'Pacific/Tahiti' => {
			exemplarCity => q#ਤਹਿਤੀ#,
		},
		'Pacific/Tarawa' => {
			exemplarCity => q#ਟਾਰਾਵਾ#,
		},
		'Pacific/Tongatapu' => {
			exemplarCity => q#ਟੋਂਗਾਟਾਪੂ#,
		},
		'Pacific/Truk' => {
			exemplarCity => q#ਚੂਕ#,
		},
		'Pacific/Wake' => {
			exemplarCity => q#ਵੇਕ#,
		},
		'Pacific/Wallis' => {
			exemplarCity => q#ਵਾਲਿਸ#,
		},
		'Pakistan' => {
			long => {
				'daylight' => q#ਪਾਕਿਸਤਾਨ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਪਾਕਿਸਤਾਨ ਵੇਲਾ#,
				'standard' => q#ਪਾਕਿਸਤਾਨ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Palau' => {
			long => {
				'standard' => q#ਪਲਾਉ ਵੇਲਾ#,
			},
		},
		'Papua_New_Guinea' => {
			long => {
				'standard' => q#ਪਾਪੂਆ ਨਿਊ ਗਿਨੀ ਵੇਲਾ#,
			},
		},
		'Paraguay' => {
			long => {
				'daylight' => q#ਪੈਰਾਗਵੇ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਪੈਰਾਗਵੇ ਵੇਲਾ#,
				'standard' => q#ਪੈਰਾਗਵੇ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Peru' => {
			long => {
				'daylight' => q#ਪੇਰੂ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਪੇਰੂ ਵੇਲਾ#,
				'standard' => q#ਪੇਰੂ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Philippines' => {
			long => {
				'daylight' => q#ਫਿਲਿਪੀਨੀ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਫਿਲਿਪੀਨੀ ਵੇਲਾ#,
				'standard' => q#ਫਿਲਿਪੀਨੀ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Phoenix_Islands' => {
			long => {
				'standard' => q#ਫਿਨਿਕਸ ਆਈਲੈਂਡ ਵੇਲਾ#,
			},
		},
		'Pierre_Miquelon' => {
			long => {
				'daylight' => q#ਸੈਂਟ ਪੀਅਰੇ ਅਤੇ ਮਿਕੇਲਨ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਸੈਂਟ ਪੀਅਰੇ ਅਤੇ ਮਿਕੇਲਨ ਵੇਲਾ#,
				'standard' => q#ਸੈਂਟ ਪੀਅਰੇ ਅਤੇ ਮਿਕੇਲਨ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Pitcairn' => {
			long => {
				'standard' => q#ਪਿਟਕੈਰਨ ਵੇਲਾ#,
			},
		},
		'Ponape' => {
			long => {
				'standard' => q#ਪੋਨਾਪੇ ਵੇਲਾ#,
			},
		},
		'Pyongyang' => {
			long => {
				'standard' => q#ਪਯੋਂਗਯਾਂਗ ਵੇਲਾ#,
			},
		},
		'Qyzylorda' => {
			long => {
				'daylight' => q#ਕਿਜ਼ਲੋਰਡਾ ਗਰਮੀ-ਰੁੱਤ ਸਮਾਂ#,
				'generic' => q#ਕਿਜ਼ਲੋਰਡਾ ਸਮਾਂ#,
				'standard' => q#ਕਿਜ਼ਲੋਰਡਾ ਮਿਆਰੀ ਸਮਾਂ#,
			},
		},
		'Reunion' => {
			long => {
				'standard' => q#ਰਿਯੂਨੀਅਨ ਵੇਲਾ#,
			},
		},
		'Rothera' => {
			long => {
				'standard' => q#ਰੋਥੇਰਾ ਵੇਲਾ#,
			},
		},
		'Sakhalin' => {
			long => {
				'daylight' => q#ਸਖਲੀਨ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਸਖਲੀਨ ਵੇਲਾ#,
				'standard' => q#ਸਖਲੀਨ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Samoa' => {
			long => {
				'daylight' => q#ਸਾਮੋਆ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਸਾਮੋਆ ਵੇਲਾ#,
				'standard' => q#ਸਾਮੋਆ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Seychelles' => {
			long => {
				'standard' => q#ਸੇਸ਼ਲਸ ਵੇਲਾ#,
			},
		},
		'Singapore' => {
			long => {
				'standard' => q#ਸਿੰਗਾਪੁਰ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Solomon' => {
			long => {
				'standard' => q#ਸੋਲੋਮਨ ਆਈਲੈਂਡਸ ਵੇਲਾ#,
			},
		},
		'South_Georgia' => {
			long => {
				'standard' => q#ਦੱਖਣੀ ਜਾਰਜੀਆ ਵੇਲਾ#,
			},
		},
		'Suriname' => {
			long => {
				'standard' => q#ਸੂਰੀਨਾਮ ਵੇਲਾ#,
			},
		},
		'Syowa' => {
			long => {
				'standard' => q#ਸਿਓਵਾ ਵੇਲਾ#,
			},
		},
		'Tahiti' => {
			long => {
				'standard' => q#ਤਾਹੀਤੀ ਵੇਲਾ#,
			},
		},
		'Taipei' => {
			long => {
				'daylight' => q#ਤੈਪਈ ਪ੍ਰਕਾਸ਼ ਵੇਲਾ#,
				'generic' => q#ਤੈਪਈ ਵੇਲਾ#,
				'standard' => q#ਤੈਪਈ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Tajikistan' => {
			long => {
				'standard' => q#ਤਾਜਿਕਿਸਤਾਨ ਵੇਲਾ#,
			},
		},
		'Tokelau' => {
			long => {
				'standard' => q#ਟੋਕੇਲਾਉ ਵੇਲਾ#,
			},
		},
		'Tonga' => {
			long => {
				'daylight' => q#ਟੋਂਗਾ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਟੋਂਗਾ ਵੇਲਾ#,
				'standard' => q#ਟੋਂਗਾ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Truk' => {
			long => {
				'standard' => q#ਚੂਕ ਵੇਲਾ#,
			},
		},
		'Turkmenistan' => {
			long => {
				'daylight' => q#ਤੁਰਕਮੇਨਿਸਤਾਨ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਤੁਰਕਮੇਨਿਸਤਾਨ ਵੇਲਾ#,
				'standard' => q#ਤੁਰਕਮੇਨਿਸਤਾਨ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Tuvalu' => {
			long => {
				'standard' => q#ਟੁਵਾਲੂ ਵੇਲਾ#,
			},
		},
		'Uruguay' => {
			long => {
				'daylight' => q#ਉਰੂਗਵੇ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਉਰੂਗਵੇ ਵੇਲਾ#,
				'standard' => q#ਉਰੂਗਵੇ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Uzbekistan' => {
			long => {
				'daylight' => q#ਉਜ਼ਬੇਕਿਸਤਾਨ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਉਜ਼ਬੇਕਿਸਤਾਨ ਵੇਲਾ#,
				'standard' => q#ਉਜ਼ਬੇਕਿਸਤਾਨ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Vanuatu' => {
			long => {
				'daylight' => q#ਵਾਨੂਆਟੂ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਵਾਨੂਆਟੂ ਵੇਲਾ#,
				'standard' => q#ਵਾਨੂਆਟੂ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Venezuela' => {
			long => {
				'standard' => q#ਵੈਨੇਜ਼ੂਏਲਾ ਵੇਲਾ#,
			},
		},
		'Vladivostok' => {
			long => {
				'daylight' => q#ਵਲਾਦੀਵੋਸਤਕ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਵਲਾਦੀਵੋਸਤਕ ਵੇਲਾ#,
				'standard' => q#ਵਲਾਦੀਵੋਸਤਕ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Volgograd' => {
			long => {
				'daylight' => q#ਵੋਲਗੋਗ੍ਰੇਡ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਵੋਲਗੋਗ੍ਰੇਡ ਵੇਲਾ#,
				'standard' => q#ਵੋਲਗੋਗ੍ਰੇਡ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Vostok' => {
			long => {
				'standard' => q#ਵੋਸਟੋਕ ਵੇਲਾ#,
			},
		},
		'Wake' => {
			long => {
				'standard' => q#ਵੇਕ ਆਈਲੈਂਡ ਵੇਲਾ#,
			},
		},
		'Wallis' => {
			long => {
				'standard' => q#ਵਾਲਿਸ ਅਤੇ ਫੁਟੂਨਾ ਵੇਲਾ#,
			},
		},
		'Yakutsk' => {
			long => {
				'daylight' => q#ਯਕੁਤਸਕ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਯਕੁਤਸਕ ਵੇਲਾ#,
				'standard' => q#ਯਕੁਤਸਕ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Yekaterinburg' => {
			long => {
				'daylight' => q#ਯਕੇਤਰਿਨਬਰਗ ਗਰਮੀਆਂ ਦਾ ਵੇਲਾ#,
				'generic' => q#ਯਕੇਤਰਿਨਬਰਗ ਵੇਲਾ#,
				'standard' => q#ਯਕੇਤਰਿਨਬਰਗ ਮਿਆਰੀ ਵੇਲਾ#,
			},
		},
		'Yukon' => {
			long => {
				'standard' => q#ਯੂਕੋਨ ਸਮਾਂ#,
			},
		},
	 } }
);
no Moo;

1;

# vim: tabstop=4
